@@ -7,8 +7,8 @@
 #include <pcl/apps/cloud_composer/impl/transform_clouds.hpp>
 
 pcl::cloud_composer::TransformClouds::TransformClouds (QMap <QString, vtkSmartPointer<vtkMatrix4x4> > transform_map, QObject* parent)
-  : ModifyItemTool (0, parent)
-  , transform_map_ (transform_map)
+  : ModifyItemTool (nullptr, parent)
+  , transform_map_ (std::move(transform_map))
 {
   
 }
@@ -23,7 +23,7 @@ pcl::cloud_composer::TransformClouds::performAction (ConstItemList input_data, P
 {
   if (type != PointTypeFlags::NONE)
   {
-    switch ((uint8_t) type)
+    switch ((std::uint8_t) type)
     {
       case (PointTypeFlags::XYZ):
         return this->performTemplatedAction<pcl::PointXYZ> (input_data);
@@ -39,4 +39,4 @@ pcl::cloud_composer::TransformClouds::performAction (ConstItemList input_data, P
   qCritical () << "Transform requires templated types!";
   
   return output;
-}
\ No newline at end of file
+}
