@@ -50,7 +50,6 @@
 #include <pcl/segmentation/sac_segmentation.h>
 #include <pcl/segmentation/extract_polygonal_prism_data.h>
 #include <pcl/sample_consensus/sac_model_plane.h>
-//#include <pcl/io/tar_io.h>
 #include <pcl/surface/convex_hull.h>
 #include <pcl/visualization/point_cloud_handlers.h>
 #include <pcl/visualization/pcl_visualizer.h>
@@ -62,10 +61,14 @@
 #include <pcl/segmentation/edge_aware_plane_comparator.h>
 #include <pcl/geometry/polygon_operations.h>
 
+#include <mutex>
+#include <thread>
+
 using namespace pcl;
 using namespace std;
+using namespace std::chrono_literals;
 
-typedef PointXYZRGBA PointT;
+using PointT = PointXYZRGBA;
 
 #define SHOW_FPS 1
 
@@ -73,9 +76,9 @@ typedef PointXYZRGBA PointT;
 class NILinemod
 {
   public:
-    typedef PointCloud<PointT> Cloud;
-    typedef Cloud::Ptr CloudPtr;
-    typedef Cloud::ConstPtr CloudConstPtr;
+    using Cloud = PointCloud<PointT>;
+    using CloudPtr = Cloud::Ptr;
+    using CloudConstPtr = Cloud::ConstPtr;
     bool added;
 
     NILinemod (Grabber& grabber)
@@ -107,7 +110,7 @@ class NILinemod
     cloud_callback (const CloudConstPtr& cloud)
     {
       FPS_CALC ("cloud callback");
-      boost::mutex::scoped_lock lock (cloud_mutex_);
+      std::lock_guard<std::mutex> lock (cloud_mutex_);
       cloud_ = cloud;
       search_.setInputCloud (cloud);
 
@@ -151,16 +154,13 @@ class NILinemod
           first_frame_ = true;
           return;
         }
-        else
-        {
-          plane_.reset (new Cloud);
+        plane_.reset (new Cloud);
 
-          // Compute the convex hull of the plane
-          ConvexHull<PointT> chull;
-          chull.setDimension (2);
-          chull.setInputCloud (plane_inliers);
-          chull.reconstruct (*plane_);
-        }
+        // Compute the convex hull of the plane
+        ConvexHull<PointT> chull;
+        chull.setDimension (2);
+        chull.setInputCloud (plane_inliers);
+        chull.reconstruct (*plane_);
       }
     }
 
@@ -169,7 +169,7 @@ class NILinemod
     getLatestCloud ()
     {
       // Lock while we swap our cloud and reset it.
-      boost::mutex::scoped_lock lock (cloud_mutex_);
+      std::lock_guard<std::mutex> lock (cloud_mutex_);
       CloudConstPtr temp_cloud;
       temp_cloud.swap (cloud_);
       return (temp_cloud);
@@ -180,13 +180,13 @@ class NILinemod
     keyboard_callback (const visualization::KeyboardEvent&, void*)
     {
       //if (event.getKeyCode())
-      //  cout << "the key \'" << event.getKeyCode() << "\' (" << event.getKeyCode() << ") was";
+      //  std::cout << "the key \'" << event.getKeyCode() << "\' (" << event.getKeyCode() << ") was";
       //else
-      //  cout << "the special key \'" << event.getKeySym() << "\' was";
+      //  std::cout << "the special key \'" << event.getKeySym() << "\' was";
       //if (event.keyDown())
-      //  cout << " pressed" << endl;
+      //  std::cout << " pressed" << std::endl;
       //else
-      //  cout << " released" << endl;
+      //  std::cout << " released" << std::endl;
     }
     
     /////////////////////////////////////////////////////////////////////////
@@ -195,7 +195,7 @@ class NILinemod
     {
       //if (mouse_event.getType() == visualization::MouseEvent::MouseButtonPress && mouse_event.getButton() == visualization::MouseEvent::LeftButton)
       //{
-      //  cout << "left button pressed @ " << mouse_event.getX () << " , " << mouse_event.getY () << endl;
+      //  std::cout << "left button pressed @ " << mouse_event.getX () << " , " << mouse_event.getY () << std::endl;
       //}
     }
 
@@ -256,33 +256,30 @@ class NILinemod
       Label l; l.label = 0;
       PointCloud<Label>::Ptr scene (new PointCloud<Label> (cloud->width, cloud->height, l));
       // Mask the objects that we want to split into clusters
-      for (int i = 0; i < static_cast<int> (points_above_plane->indices.size ()); ++i)
-        scene->points[points_above_plane->indices[i]].label = 1;
+      for (const int &index : points_above_plane->indices)
+        scene->points[index].label = 1;
       euclidean_cluster_comparator->setLabels (scene);
 
-      boost::shared_ptr<std::set<uint32_t> > exclude_labels = boost::make_shared<std::set<uint32_t> > ();
-      exclude_labels->insert (0);
-
       OrganizedConnectedComponentSegmentation<PointT, Label> euclidean_segmentation (euclidean_cluster_comparator);
       euclidean_segmentation.setInputCloud (cloud);
 
       PointCloud<Label> euclidean_labels;
-      vector<PointIndices> euclidean_label_indices;
+      std::vector<PointIndices> euclidean_label_indices;
       euclidean_segmentation.segment (euclidean_labels, euclidean_label_indices);
 
       // For each cluster found
       bool cluster_found = false;
-      for (size_t i = 0; i < euclidean_label_indices.size (); i++)
+      for (const auto &euclidean_label_index : euclidean_label_indices)
       {
         if (cluster_found)
           break;
         // Check if the point that we picked belongs to it
-        for (size_t j = 0; j < euclidean_label_indices[i].indices.size (); ++j)
+        for (std::size_t j = 0; j < euclidean_label_index.indices.size (); ++j)
         {
-          if (picked_idx != euclidean_label_indices[i].indices[j])
+          if (picked_idx != euclidean_label_index.indices[j])
             continue;
           //pcl::PointCloud<PointT> cluster;
-          pcl::copyPointCloud (*cloud, euclidean_label_indices[i].indices, object);
+          pcl::copyPointCloud (*cloud, euclidean_label_index.indices, object);
           cluster_found = true;
           break;
           //object_indices = euclidean_label_indices[i].indices;
@@ -316,19 +313,19 @@ class NILinemod
       mps_.setInputCloud (search_.getInputCloud ());
 
       // Use one of the overloaded segmentAndRefine calls to get all the information that we want out
-      vector<PlanarRegion<PointT>, Eigen::aligned_allocator<PlanarRegion<PointT> > > regions;
-      vector<ModelCoefficients> model_coefficients;
-      vector<PointIndices> inlier_indices;  
+      std::vector<PlanarRegion<PointT>, Eigen::aligned_allocator<PlanarRegion<PointT> > > regions;
+      std::vector<ModelCoefficients> model_coefficients;
+      std::vector<PointIndices> inlier_indices;  
       PointCloud<Label>::Ptr labels (new PointCloud<Label>);
-      vector<PointIndices> label_indices;
-      vector<PointIndices> boundary_indices;
+      std::vector<PointIndices> label_indices;
+      std::vector<PointIndices> boundary_indices;
       mps_.segmentAndRefine (regions, model_coefficients, inlier_indices, labels, label_indices, boundary_indices);
       PCL_DEBUG ("Number of planar regions detected: %lu for a cloud of %lu points and %lu normals.\n", regions.size (), search_.getInputCloud ()->points.size (), normal_cloud->points.size ());
 
-      double max_dist = numeric_limits<double>::max ();
+      double max_dist = std::numeric_limits<double>::max ();
       // Compute the distances from all the planar regions to the picked point, and select the closest region
       int idx = -1;
-      for (size_t i = 0; i < regions.size (); ++i)
+      for (std::size_t i = 0; i < regions.size (); ++i)
       {
         double dist = pointToPlaneDistance (picked_point, regions[i].getCoefficients ()); 
         if (dist < max_dist)
@@ -373,11 +370,11 @@ class NILinemod
       if (idx == -1)
         return;
 
-      vector<int> indices (1);
-      vector<float> distances (1);
+      std::vector<int> indices (1);
+      std::vector<float> distances (1);
 
       // Use mutices to make sure we get the right cloud
-      boost::mutex::scoped_lock lock1 (cloud_mutex_);
+      std::lock_guard<std::mutex> lock1 (cloud_mutex_);
 
       // Get the point that was picked
       PointT picked_pt;
@@ -396,7 +393,7 @@ class NILinemod
       search_.nearestKSearch (picked_pt, 1, indices, distances);
 
       // Get the [u, v] in pixel coordinates for the ImageViewer. Remember that 0,0 is bottom left.
-      uint32_t width  = search_.getInputCloud ()->width;
+      std::uint32_t width  = search_.getInputCloud ()->width;
 //               height = search_.getInputCloud ()->height;
       int v = indices[0] / width,
           u = indices[0] % width;
@@ -421,20 +418,17 @@ class NILinemod
         return;
       }
       // Else, draw it on screen
-      else
-      {
-        //cloud_viewer_.addPolygon (region, 1.0, 0.0, 0.0, "region");
-        //cloud_viewer_.setShapeRenderingProperties (visualization::PCL_VISUALIZER_LINE_WIDTH, 10, "region");
+      //cloud_viewer_.addPolygon (region, 1.0, 0.0, 0.0, "region");
+      //cloud_viewer_.setShapeRenderingProperties (visualization::PCL_VISUALIZER_LINE_WIDTH, 10, "region");
 
-        PlanarRegion<PointT> refined_region;
-        pcl::approximatePolygon (region, refined_region, 0.01, false, true);
-        PCL_INFO ("Planar region: %lu points initial, %lu points after refinement.\n", region.getContour ().size (), refined_region.getContour ().size ());
-        cloud_viewer_.addPolygon (refined_region, 0.0, 0.0, 1.0, "refined_region");
-        cloud_viewer_.setShapeRenderingProperties (visualization::PCL_VISUALIZER_LINE_WIDTH, 10, "refined_region");
+      PlanarRegion<PointT> refined_region;
+      pcl::approximatePolygon (region, refined_region, 0.01, false, true);
+      PCL_INFO ("Planar region: %lu points initial, %lu points after refinement.\n", region.getContour ().size (), refined_region.getContour ().size ());
+      cloud_viewer_.addPolygon (refined_region, 0.0, 0.0, 1.0, "refined_region");
+      cloud_viewer_.setShapeRenderingProperties (visualization::PCL_VISUALIZER_LINE_WIDTH, 10, "refined_region");
 
-        // Draw in image space
-        image_viewer_.addPlanarPolygon (search_.getInputCloud (), refined_region, 0.0, 0.0, 1.0, "refined_region", 1.0);
-      }
+      // Draw in image space
+      image_viewer_.addPlanarPolygon (search_.getInputCloud (), refined_region, 0.0, 0.0, 1.0, "refined_region", 1.0);
 
       // If no object could be determined, exit
       if (!object)
@@ -442,28 +436,25 @@ class NILinemod
         PCL_ERROR ("No object detected. Please select another point or relax the thresholds and continue.\n");
         return;
       }
-      else
-      {
-        // Visualize the object in 3D...
-        visualization::PointCloudColorHandlerCustom<PointT> red (object, 255, 0, 0);
-        if (!cloud_viewer_.updatePointCloud (object, red, "object"))
-          cloud_viewer_.addPointCloud (object, red, "object");
-        // ...and 2D
-        image_viewer_.removeLayer ("object");
-        image_viewer_.addMask (search_.getInputCloud (), *object, "object");
+      // Visualize the object in 3D...
+      visualization::PointCloudColorHandlerCustom<PointT> red (object, 255, 0, 0);
+      if (!cloud_viewer_.updatePointCloud (object, red, "object"))
+        cloud_viewer_.addPointCloud (object, red, "object");
+      // ...and 2D
+      image_viewer_.removeLayer ("object");
+      image_viewer_.addMask (search_.getInputCloud (), *object, "object");
 
-        // Compute the min/max of the object
-        PointT min_pt, max_pt;
-        getMinMax3D (*object, min_pt, max_pt);
-        stringstream ss;
-        ss << "cube_" << idx;
-        // Visualize the bounding box in 3D...
-        cloud_viewer_.addCube (min_pt.x, max_pt.x, min_pt.y, max_pt.y, min_pt.z, max_pt.z, 0.0, 1.0, 0.0, ss.str ());
-        cloud_viewer_.setShapeRenderingProperties (visualization::PCL_VISUALIZER_LINE_WIDTH, 10, ss.str ());
+      // Compute the min/max of the object
+      PointT min_pt, max_pt;
+      getMinMax3D (*object, min_pt, max_pt);
+      stringstream ss2;
+      ss2 << "cube_" << idx;
+      // Visualize the bounding box in 3D...
+      cloud_viewer_.addCube (min_pt.x, max_pt.x, min_pt.y, max_pt.y, min_pt.z, max_pt.z, 0.0, 1.0, 0.0, ss2.str ());
+      cloud_viewer_.setShapeRenderingProperties (visualization::PCL_VISUALIZER_LINE_WIDTH, 10, ss2.str ());
 
-        // ...and 2D
-        image_viewer_.addRectangle (search_.getInputCloud (), *object);
-      }
+      // ...and 2D
+      image_viewer_.addRectangle (search_.getInputCloud (), *object);
     }
     
     /////////////////////////////////////////////////////////////////////////
@@ -473,7 +464,7 @@ class NILinemod
       cloud_viewer_.registerMouseCallback (&NILinemod::mouse_callback, *this);
       cloud_viewer_.registerKeyboardCallback(&NILinemod::keyboard_callback, *this);
       cloud_viewer_.registerPointPickingCallback (&NILinemod::pp_callback, *this);
-      boost::function<void (const CloudConstPtr&) > cloud_cb = boost::bind (&NILinemod::cloud_callback, this, _1);
+      std::function<void (const CloudConstPtr&) > cloud_cb = [this] (const CloudConstPtr& cloud) { cloud_callback (cloud); };
       cloud_connection = grabber_.registerCallback (cloud_cb);
       
       image_viewer_.registerMouseCallback (&NILinemod::mouse_callback, *this);
@@ -497,7 +488,7 @@ class NILinemod
           {
             cloud_viewer_.setPosition (0, 0);
             cloud_viewer_.setSize (cloud->width, cloud->height);
-            cloud_init = !cloud_init;
+            cloud_init = true;
           }
 
           if (!cloud_viewer_.updatePointCloud (cloud, "OpenNICloud"))
@@ -510,7 +501,7 @@ class NILinemod
           {
             image_viewer_.setPosition (cloud->width, 0);
             image_viewer_.setSize (cloud->width, cloud->height);
-            image_init = !image_init;
+            image_init = true;
           }
 
           image_viewer_.showRGBImage<PointT> (cloud);
@@ -527,7 +518,7 @@ class NILinemod
         cloud_viewer_.spinOnce ();
 
         image_viewer_.spinOnce ();
-        boost::this_thread::sleep (boost::posix_time::microseconds (100));
+        std::this_thread::sleep_for(100us);
       }
 
       grabber_.stop ();
@@ -537,7 +528,7 @@ class NILinemod
     
     visualization::PCLVisualizer cloud_viewer_;
     Grabber& grabber_;
-    boost::mutex cloud_mutex_;
+    std::mutex cloud_mutex_;
     CloudConstPtr cloud_;
     
     visualization::ImageViewer image_viewer_;
