@@ -4,6 +4,8 @@
  *  Created on: Dec 23, 2011
  *      Author: aitor
  */
+#include <array>
+
 #include <pcl/point_types.h>
 #include <pcl/apps/render_views_tesselated_sphere.h>
 #include <vtkCellData.h>
@@ -13,12 +15,8 @@
 #include <vtkLoopSubdivisionFilter.h>
 #include <vtkTriangle.h>
 #include <vtkTransform.h>
-#if VTK_MAJOR_VERSION>=6 || (VTK_MAJOR_VERSION==5 && VTK_MINOR_VERSION>4)
 #include <vtkHardwareSelector.h>
 #include <vtkSelectionNode.h>
-#else 
-#include <vtkVisibleCellSelector.h>
-#endif
 #include <vtkSelection.h>
 #include <vtkCellArray.h>
 #include <vtkTransformFilter.h>
@@ -33,10 +31,10 @@ void
 pcl::apps::RenderViewsTesselatedSphere::generateViews() {
   //center object
   double CoM[3];
-  vtkIdType npts_com = 0, *ptIds_com = NULL;
+  vtkIdType npts_com = 0, *ptIds_com = nullptr;
   vtkSmartPointer<vtkCellArray> cells_com = polydata_->GetPolys ();
 
-  double center[3], p1_com[3], p2_com[3], p3_com[3], area_com, totalArea_com = 0;
+  double center[3], p1_com[3], p2_com[3], p3_com[3], totalArea_com = 0;
   double comx = 0, comy = 0, comz = 0;
   for (cells_com->InitTraversal (); cells_com->GetNextCell (npts_com, ptIds_com);)
   {
@@ -44,7 +42,7 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
     polydata_->GetPoint (ptIds_com[1], p2_com);
     polydata_->GetPoint (ptIds_com[2], p3_com);
     vtkTriangle::TriangleCenter (p1_com, p2_com, p3_com, center);
-    area_com = vtkTriangle::TriangleArea (p1_com, p2_com, p3_com);
+    double area_com = vtkTriangle::TriangleArea (p1_com, p2_com, p3_com);
     comx += center[0] * area_com;
     comy += center[1] * area_com;
     comz += center[2] * area_com;
@@ -61,11 +59,7 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
 
   vtkSmartPointer<vtkTransformFilter> trans_filter_center = vtkSmartPointer<vtkTransformFilter>::New ();
   trans_filter_center->SetTransform (trans_center);
-#if VTK_MAJOR_VERSION < 6
-  trans_filter_center->SetInput (polydata_);
-#else
   trans_filter_center->SetInputData (polydata_);
-#endif
   trans_filter_center->Update ();
 
   vtkSmartPointer<vtkPolyDataMapper> mapper = vtkSmartPointer<vtkPolyDataMapper>::New ();
@@ -96,16 +90,15 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
   // * Compute area of the mesh
   //////////////////////////////
   vtkSmartPointer<vtkCellArray> cells = mapper->GetInput ()->GetPolys ();
-  vtkIdType npts = 0, *ptIds = NULL;
+  vtkIdType npts = 0, *ptIds = nullptr;
 
-  double p1[3], p2[3], p3[3], area, totalArea = 0;
+  double p1[3], p2[3], p3[3], totalArea = 0;
   for (cells->InitTraversal (); cells->GetNextCell (npts, ptIds);)
   {
     polydata_->GetPoint (ptIds[0], p1);
     polydata_->GetPoint (ptIds[1], p2);
     polydata_->GetPoint (ptIds[2], p3);
-    area = vtkTriangle::TriangleArea (p1, p2, p3);
-    totalArea += area;
+    totalArea += vtkTriangle::TriangleArea (p1, p2, p3);
   }
 
   //create icosahedron
@@ -117,15 +110,10 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
   vtkSmartPointer<vtkLoopSubdivisionFilter> subdivide = vtkSmartPointer<vtkLoopSubdivisionFilter>::New ();
   subdivide->SetNumberOfSubdivisions (tesselation_level_);
   subdivide->SetInputConnection (ico->GetOutputPort ());
-#if VTK_MAJOR_VERSION>=6
   subdivide->Update();
-#endif
 
   // Get camera positions
   vtkPolyData *sphere = subdivide->GetOutput ();
-#if VTK_MAJOR_VERSION<6
-  sphere->Update ();
-#endif
 
   std::vector<Eigen::Vector3f, Eigen::aligned_allocator<Eigen::Vector3f> > cam_positions;
   if (!use_vertices_)
@@ -133,7 +121,7 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
     vtkSmartPointer<vtkCellArray> cells_sphere = sphere->GetPolys ();
     cam_positions.resize (sphere->GetNumberOfPolys ());
 
-    size_t i=0;
+    std::size_t i=0;
     for (cells_sphere->InitTraversal (); cells_sphere->GetNextCell (npts_com, ptIds_com);)
     {
       sphere->GetPoint (ptIds_com[0], p1_com);
@@ -148,7 +136,7 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
   else
   {
     cam_positions.resize (sphere->GetNumberOfPoints ());
-    for (int i = 0; i < sphere->GetNumberOfPoints (); i++)
+    for (vtkIdType i = 0; i < sphere->GetNumberOfPoints (); i++)
     {
       double cam_pos[3];
       sphere->GetPoint (i, cam_pos);
@@ -157,7 +145,7 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
   }
 
   /*int valid = 0;
-  for (size_t i = 0; i < cam_positions.size (); i++)
+  for (std::size_t i = 0; i < cam_positions.size (); i++)
   {
     if (campos_constraints_func_ (cam_positions[i]))
     {
@@ -169,8 +157,8 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
   cam_positions.resize (valid);*/
 
   double camera_radius = radius_sphere_;
-  double cam_pos[3];
-  double first_cam_pos[3];
+  std::array<double, 3> cam_pos;
+  std::array<double, 3> first_cam_pos;
 
   first_cam_pos[0] = cam_positions[0][0] * radius_sphere_;
   first_cam_pos[1] = cam_positions[0][1] * radius_sphere_;
@@ -193,16 +181,16 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
   Eigen::Vector3f perp = cam_pos_3f.cross (Eigen::Vector3f::UnitY ());
   cam->SetViewUp (perp[0], perp[1], perp[2]);
 
-  cam->SetPosition (first_cam_pos);
+  cam->SetPosition (first_cam_pos.data());
   cam->SetViewAngle (view_angle_);
   cam->Modified ();
 
   //For each camera position, traposesnsform the object and render view
-  for (size_t i = 0; i < cam_positions.size (); i++)
+  for (const auto &cam_position : cam_positions)
   {
-    cam_pos[0] = cam_positions[i][0];
-    cam_pos[1] = cam_positions[i][1];
-    cam_pos[2] = cam_positions[i][2];
+    cam_pos[0] = cam_position[0];
+    cam_pos[1] = cam_position[1];
+    cam_pos[2] = cam_position[2];
 
     //create temporal virtual camera
     vtkSmartPointer<vtkCamera> cam_tmp = vtkSmartPointer<vtkCamera>::New ();
@@ -215,7 +203,7 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
     //If the view up is parallel to ray cam_pos - focalPoint then the transformation
     //is singular and no points are rendered...
     //make sure it is perpendicular
-    if (fabs (cam_pos_3f.dot (test)) == 1)
+    if (std::abs (cam_pos_3f.dot (test)) == 1)
     {
       //parallel, create
       test = cam_pos_3f.cross (Eigen::Vector3f::UnitX ());
@@ -223,12 +211,12 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
 
     cam_tmp->SetViewUp (test[0], test[1], test[2]);
 
-    for (int k = 0; k < 3; k++)
+    for (double &cam_po : cam_pos)
     {
-      cam_pos[k] = cam_pos[k] * camera_radius;
+      cam_po *= camera_radius;
     }
 
-    cam_tmp->SetPosition (cam_pos);
+    cam_tmp->SetPosition (cam_pos.data());
     cam_tmp->SetFocalPoint (0, 0, 0);
     cam_tmp->Modified ();
 
@@ -371,7 +359,7 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
       polydata->BuildCells ();
 
       vtkSmartPointer<vtkCellArray> cells = polydata->GetPolys ();
-      vtkIdType npts = 0, *ptIds = NULL;
+      vtkIdType npts = 0, *ptIds = nullptr;
 
       double p1[3], p2[3], p3[3], area, totalArea = 0;
       for (cells->InitTraversal (); cells->GetNextCell (npts, ptIds);)
@@ -386,36 +374,6 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
       /////////////////////////////////////
       // * Select visible cells (triangles)
       /////////////////////////////////////
-#if (VTK_MAJOR_VERSION==5 && VTK_MINOR_VERSION<6)
-      vtkSmartPointer<vtkVisibleCellSelector> selector = vtkSmartPointer<vtkVisibleCellSelector>::New ();
-      vtkSmartPointer<vtkIdTypeArray> selection = vtkSmartPointer<vtkIdTypeArray>::New ();
-
-      selector->SetRenderer (renderer);
-      selector->SetArea (0, 0, resolution_ - 1, resolution_ - 1);
-      selector->Select ();
-      selector->GetSelectedIds (selection);
-
-      double visible_area = 0;
-      for (int sel_id = 3; sel_id < (selection->GetNumberOfTuples () * selection->GetNumberOfComponents ()); sel_id
-          += selection->GetNumberOfComponents ())
-      {
-        int id_mesh = int (selection->GetValue (sel_id));
-
-        if (id_mesh >= polydata->GetNumberOfCells ())
-          continue;
-
-        vtkCell * cell = polydata->GetCell (id_mesh);
-        vtkTriangle* triangle = dynamic_cast<vtkTriangle*> (cell);
-        double p0[3];
-        double p1[3];
-        double p2[3];
-        triangle->GetPoints ()->GetPoint (0, p0);
-        triangle->GetPoints ()->GetPoint (1, p1);
-        triangle->GetPoints ()->GetPoint (2, p2);
-        visible_area += vtkTriangle::TriangleArea (p0, p1, p2);
-      }
-
-#else 
       vtkSmartPointer<vtkHardwareSelector> hardware_selector = vtkSmartPointer<vtkHardwareSelector>::New ();
       hardware_selector->ClearBuffers();
       vtkSmartPointer<vtkSelection> hdw_selection = vtkSmartPointer<vtkSelection>::New ();
@@ -426,7 +384,7 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
       vtkSmartPointer<vtkIdTypeArray> ids = vtkSmartPointer<vtkIdTypeArray>::New ();
       ids = vtkIdTypeArray::SafeDownCast(hdw_selection->GetNode(0)->GetSelectionList());
       double visible_area = 0;
-      for (int sel_id = 0; sel_id < (ids->GetNumberOfTuples ()); sel_id++)
+      for (vtkIdType sel_id = 0; sel_id < (ids->GetNumberOfTuples ()); sel_id++)
       {
         int id_mesh = int (ids->GetValue (sel_id));
         if(id_mesh >= polydata->GetNumberOfPolys())
@@ -443,7 +401,6 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
         area = vtkTriangle::TriangleArea (p0, p1, p2);
         visible_area += area;
       }
-#endif
 
       entropies_.push_back (float (visible_area / totalArea));
     }
@@ -459,11 +416,11 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews() {
 
     //NOTE: vtk view coordinate system is different than the standard camera coordinates (z forward, y down, x right)
     //thus, the fliping in y and z
-    for (size_t i = 0; i < cloud->points.size (); i++)
+    for (auto &point : cloud->points)
     {
-      cloud->points[i].getVector4fMap () = trans_view * cloud->points[i].getVector4fMap ();
-      cloud->points[i].y *= -1.0f;
-      cloud->points[i].z *= -1.0f;
+      point.getVector4fMap () = trans_view * point.getVector4fMap ();
+      point.y *= -1.0f;
+      point.z *= -1.0f;
     }
 
     renderer->RemoveActor (actor_view);
