@@ -53,17 +53,16 @@
 #include <pcl/segmentation/organized_connected_component_segmentation.h>
 #include <pcl/filters/extract_indices.h>
 #include <pcl/sample_consensus/sac_model_plane.h>
-//#include <pcl/stereo/stereo_grabber.h>
 #include <pcl/stereo/stereo_matching.h>
 #include <pcl/segmentation/ground_plane_comparator.h>
 #include <pcl/segmentation/euclidean_cluster_comparator.h>
 
+#include <mutex>
 
-
-typedef pcl::PointXYZRGB PointT;
-typedef pcl::PointCloud<PointT> Cloud;
-typedef Cloud::Ptr CloudPtr;
-typedef Cloud::ConstPtr CloudConstPtr;
+using PointT = pcl::PointXYZRGB;
+using Cloud = pcl::PointCloud<PointT>;
+using CloudPtr = Cloud::Ptr;
+using CloudConstPtr = Cloud::ConstPtr;
 
   /** \brief StereoGroundSegmentation is a demonstration application for using PCL's stereo tools and segmentation tools to detect smooth surfaces suitable for driving.
     *
@@ -72,8 +71,8 @@ typedef Cloud::ConstPtr CloudConstPtr;
 class HRCSSegmentation
 {
   private:
-    boost::shared_ptr<pcl::visualization::PCLVisualizer> viewer;
-    boost::shared_ptr<pcl::visualization::ImageViewer> image_viewer;
+    pcl::visualization::PCLVisualizer::Ptr viewer;
+    pcl::visualization::ImageViewer::Ptr image_viewer;
     pcl::PointCloud<PointT>::ConstPtr prev_cloud;
     pcl::PointCloud<pcl::Normal>::ConstPtr prev_normal_cloud;
     pcl::PointCloud<pcl::PointXYZ>::ConstPtr prev_ground_cloud;
@@ -81,7 +80,7 @@ class HRCSSegmentation
     pcl::PointCloud<PointT>::ConstPtr prev_label_image;
     Eigen::Vector4f prev_ground_normal;
     Eigen::Vector4f prev_ground_centroid;
-    boost::mutex cloud_mutex;
+    std::mutex cloud_mutex;
 
     pcl::IntegralImageNormalEstimation<PointT, pcl::Normal> ne;
     pcl::GroundPlaneComparator<PointT, pcl::Normal>::Ptr road_comparator;
@@ -100,7 +99,7 @@ class HRCSSegmentation
     int smooth_strong;
 
   public:
-    HRCSSegmentation (std::vector<std::string> left_images, std::vector<std::string> right_images) :
+    HRCSSegmentation (const std::vector<std::string> &left_images, const std::vector<std::string> &right_images) :
       viewer (new pcl::visualization::PCLVisualizer ("3D Viewer")),
       image_viewer (new pcl::visualization::ImageViewer ("Image Viewer")),
       prev_cloud (new pcl::PointCloud<PointT>),
@@ -125,7 +124,7 @@ class HRCSSegmentation
       viewer->setBackgroundColor (0, 0, 0);
       viewer->addCoordinateSystem (1.0, "global");
       viewer->initCameraParameters ();
-      viewer->registerKeyboardCallback (&HRCSSegmentation::keyboardCallback, *this, 0);
+      viewer->registerKeyboardCallback (&HRCSSegmentation::keyboardCallback, *this, nullptr);
       
       // Set up the stereo matching
       stereo.setMaxDisparity(60);
@@ -266,25 +265,25 @@ class HRCSSegmentation
       std::vector<Eigen::Matrix3f, Eigen::aligned_allocator<Eigen::Matrix3f> > covariances;
       std::vector<pcl::PointIndices> inlier_indices;
 
-      for (size_t i = 0; i < region_indices.size (); i++)
+      for (const auto &region_index : region_indices)
       {
-        if (region_indices[i].indices.size () > 1000)
+        if (region_index.indices.size () > 1000)
         {
 
-          for (size_t j = 0; j < region_indices[i].indices.size (); j++)
+          for (std::size_t j = 0; j < region_index.indices.size (); j++)
           {  
-            pcl::PointXYZ ground_pt (cloud->points[region_indices[i].indices[j]].x,
-                                     cloud->points[region_indices[i].indices[j]].y,
-                                     cloud->points[region_indices[i].indices[j]].z);
+            pcl::PointXYZ ground_pt (cloud->points[region_index.indices[j]].x,
+                                     cloud->points[region_index.indices[j]].y,
+                                     cloud->points[region_index.indices[j]].z);
             ground_cloud->points.push_back (ground_pt);
-            ground_image->points[region_indices[i].indices[j]].g = static_cast<pcl::uint8_t> ((cloud->points[region_indices[i].indices[j]].g + 255) / 2);
-            label_image->points[region_indices[i].indices[j]].r = 0;
-            label_image->points[region_indices[i].indices[j]].g = 255;
-            label_image->points[region_indices[i].indices[j]].b = 0;
+            ground_image->points[region_index.indices[j]].g = static_cast<std::uint8_t> ((cloud->points[region_index.indices[j]].g + 255) / 2);
+            label_image->points[region_index.indices[j]].r = 0;
+            label_image->points[region_index.indices[j]].g = 255;
+            label_image->points[region_index.indices[j]].b = 0;
           } 
           
           // Compute plane info
-          pcl::computeMeanAndCovarianceMatrix (*cloud, region_indices[i].indices, clust_cov, clust_centroid);
+          pcl::computeMeanAndCovarianceMatrix (*cloud, region_index.indices, clust_cov, clust_centroid);
           Eigen::Vector4f plane_params;
           
           EIGEN_ALIGN16 Eigen::Vector3f::Scalar eigen_value;
@@ -310,7 +309,7 @@ class HRCSSegmentation
           model.values[2] = plane_params[2];
           model.values[3] = plane_params[3];
           model_coefficients.push_back (model);
-          inlier_indices.push_back (region_indices[i]);
+          inlier_indices.push_back (region_index);
           centroids.push_back (clust_centroid);
           covariances.push_back (clust_cov);
         }
@@ -322,14 +321,14 @@ class HRCSSegmentation
       grow_labels.resize (region_indices.size (), false);
       label_to_model.resize (region_indices.size (), 0);
       
-      for (size_t i = 0; i < model_coefficients.size (); i++)
+      for (std::size_t i = 0; i < model_coefficients.size (); i++)
       {
         int model_label = (labels)[inlier_indices[i].indices[0]].label;
         label_to_model[model_label] = static_cast<int> (i);
         grow_labels[model_label] = true;
       }
       
-      boost::shared_ptr<pcl::PointCloud<pcl::Label> > labels_ptr (new pcl::PointCloud<pcl::Label>());
+      pcl::PointCloud<pcl::Label>::Ptr labels_ptr (new pcl::PointCloud<pcl::Label>);
       *labels_ptr = labels;
       pcl::OrganizedMultiPlaneSegmentation<PointT, pcl::Normal, pcl::Label> mps;
       pcl::PlaneRefinementComparator<PointT, pcl::Normal, pcl::Label>::Ptr refinement_compare (new pcl::PlaneRefinementComparator<PointT, pcl::Normal, pcl::Label>());
@@ -347,31 +346,29 @@ class HRCSSegmentation
       mps.setInputNormals (normal_cloud);
       mps.refine (model_coefficients,
                   inlier_indices,
-                  centroids,
-                  covariances,
                   labels_ptr,
                   region_indices);
       
       //Note the regions that have been extended
       pcl::PointCloud<PointT> extended_ground_cloud;
-      for (size_t i = 0; i < region_indices.size (); i++)
+      for (const auto &region_index : region_indices)
       {
-        if (region_indices[i].indices.size () > 1000)
+        if (region_index.indices.size () > 1000)
         {
-          for (size_t j = 0; j < region_indices[i].indices.size (); j++)
+          for (std::size_t j = 0; j < region_index.indices.size (); j++)
           {
             // Check to see if it has already been labeled
-            if (ground_image->points[region_indices[i].indices[j]].g == ground_image->points[region_indices[i].indices[j]].b)
+            if (ground_image->points[region_index.indices[j]].g == ground_image->points[region_index.indices[j]].b)
             {
-              pcl::PointXYZ ground_pt (cloud->points[region_indices[i].indices[j]].x,
-                                       cloud->points[region_indices[i].indices[j]].y,
-                                       cloud->points[region_indices[i].indices[j]].z);
+              pcl::PointXYZ ground_pt (cloud->points[region_index.indices[j]].x,
+                                       cloud->points[region_index.indices[j]].y,
+                                       cloud->points[region_index.indices[j]].z);
               ground_cloud->points.push_back (ground_pt);
-              ground_image->points[region_indices[i].indices[j]].r = static_cast<pcl::uint8_t> ((cloud->points[region_indices[i].indices[j]].r + 255) / 2);
-              ground_image->points[region_indices[i].indices[j]].g = static_cast<pcl::uint8_t> ((cloud->points[region_indices[i].indices[j]].g + 255) / 2);
-              label_image->points[region_indices[i].indices[j]].r = 128;
-              label_image->points[region_indices[i].indices[j]].g = 128;
-              label_image->points[region_indices[i].indices[j]].b = 0;
+              ground_image->points[region_index.indices[j]].r = static_cast<std::uint8_t> ((cloud->points[region_index.indices[j]].r + 255) / 2);
+              ground_image->points[region_index.indices[j]].g = static_cast<std::uint8_t> ((cloud->points[region_index.indices[j]].g + 255) / 2);
+              label_image->points[region_index.indices[j]].r = 128;
+              label_image->points[region_index.indices[j]].g = 128;
+              label_image->points[region_index.indices[j]].b = 0;
             }
             
           }
@@ -382,7 +379,7 @@ class HRCSSegmentation
       Eigen::Vector4f ground_plane_params (1.0, 0.0, 0.0, 1.0);
       Eigen::Vector4f ground_centroid (0.0, 0.0, 0.0, 0.0);
       
-      if (ground_cloud->points.size () > 0)
+      if (!ground_cloud->points.empty ())
       {
         ground_centroid = centroids[0];
         ground_plane_params = Eigen::Vector4f (model_coefficients[0].values[0], model_coefficients[0].values[1], model_coefficients[0].values[2], model_coefficients[0].values[3]);
@@ -391,10 +388,10 @@ class HRCSSegmentation
       if (detect_obstacles)
       {
         pcl::PointCloud<PointT>::CloudVectorType clusters;
-        if (ground_cloud->points.size () > 0)
+        if (!ground_cloud->points.empty ())
         {
-          boost::shared_ptr<std::set<uint32_t> > plane_labels = boost::make_shared<std::set<uint32_t> > ();
-          for (size_t i = 0; i < region_indices.size (); ++i)
+          pcl::EuclideanClusterComparator<PointT, pcl::Label>::ExcludeLabelSetPtr plane_labels (new pcl::EuclideanClusterComparator<PointT, pcl::Label>::ExcludeLabelSet);
+          for (std::size_t i = 0; i < region_indices.size (); ++i)
             if ((region_indices[i].indices.size () > mps.getMinInliers ()))
               plane_labels->insert (i);
         
@@ -410,17 +407,17 @@ class HRCSSegmentation
           euclidean_segmentation.setInputCloud (cloud);
           euclidean_segmentation.segment (euclidean_labels, euclidean_label_indices);
         
-          for (size_t i = 0; i < euclidean_label_indices.size (); i++)
+          for (const auto &euclidean_label_index : euclidean_label_indices)
           {
-            if ((euclidean_label_indices[i].indices.size () > 200))
+            if ((euclidean_label_index.indices.size () > 200))
             {
               pcl::PointCloud<PointT> cluster;
-              pcl::copyPointCloud (*cloud, euclidean_label_indices[i].indices, cluster);
+              pcl::copyPointCloud (*cloud, euclidean_label_index.indices, cluster);
               clusters.push_back (cluster);
 
               Eigen::Vector4f cluster_centroid;
               Eigen::Matrix3f cluster_cov;
-              pcl::computeMeanAndCovarianceMatrix (*cloud, euclidean_label_indices[i].indices, cluster_cov, cluster_centroid);
+              pcl::computeMeanAndCovarianceMatrix (*cloud, euclidean_label_index.indices, cluster_cov, cluster_centroid);
 
               pcl::PointXYZ centroid_pt (cluster_centroid[0], cluster_centroid[1], cluster_centroid[2]);
               double ptp_dist =  pcl::pointToPlaneDistanceSigned (centroid_pt, ground_plane_params[0], ground_plane_params[1], ground_plane_params[2], ground_plane_params[3]);
@@ -428,12 +425,12 @@ class HRCSSegmentation
               if ((ptp_dist > 0.5) && (ptp_dist < 3.0))
               {
               
-                for (size_t j = 0; j < euclidean_label_indices[i].indices.size (); j++)
+                for (std::size_t j = 0; j < euclidean_label_index.indices.size (); j++)
                 {
-                  ground_image->points[euclidean_label_indices[i].indices[j]].r = 255;
-                  label_image->points[euclidean_label_indices[i].indices[j]].r = 255;
-                  label_image->points[euclidean_label_indices[i].indices[j]].g = 0;
-                  label_image->points[euclidean_label_indices[i].indices[j]].b = 0;
+                  ground_image->points[euclidean_label_index.indices[j]].r = 255;
+                  label_image->points[euclidean_label_index.indices[j]].r = 255;
+                  label_image->points[euclidean_label_index.indices[j]].g = 0;
+                  label_image->points[euclidean_label_index.indices[j]].b = 0;
                 }
 
               }
@@ -445,11 +442,11 @@ class HRCSSegmentation
       }
 
       // note the NAN points in the image as well
-      for (size_t i = 0; i < cloud->points.size (); i++)
+      for (std::size_t i = 0; i < cloud->points.size (); i++)
       {
         if (!pcl::isFinite (cloud->points[i]))
         {
-          ground_image->points[i].b = static_cast<pcl::uint8_t>((cloud->points[i].b + 255) / 2);
+          ground_image->points[i].b = static_cast<std::uint8_t>((cloud->points[i].b + 255) / 2);
           label_image->points[i].r = 0;
           label_image->points[i].g = 0;
           label_image->points[i].b = 255;
