@@ -1,5 +1,4 @@
-#ifndef PCL_SENSOR_MSGS_MESSAGE_POINTFIELD_H
-#define PCL_SENSOR_MSGS_MESSAGE_POINTFIELD_H
+#pragma once
 
 #ifdef USE_ROS
    #error USE_ROS setup requires PCL to compile against ROS message headers, which is now deprecated
@@ -8,21 +7,17 @@
 #include <string>
 #include <vector>
 #include <ostream>
-#include <boost/shared_ptr.hpp>
 #include <pcl/pcl_macros.h>
 
 namespace pcl
 {
   struct PCLPointField
   {
-    PCLPointField () : name (), offset (0), datatype (0), count (0)
-    {}
-
     std::string name;
 
-    pcl::uint32_t offset;
-    pcl::uint8_t datatype;
-    pcl::uint32_t count;
+    std::uint32_t offset = 0;
+    std::uint8_t datatype = 0;
+    std::uint32_t count = 0;
 
     enum PointFieldTypes { INT8 = 1,
                            UINT8 = 2,
@@ -34,12 +29,12 @@ namespace pcl
                            FLOAT64 = 8 };
 
   public:
-    typedef boost::shared_ptr< ::pcl::PCLPointField> Ptr;
-    typedef boost::shared_ptr< ::pcl::PCLPointField const> ConstPtr;
+    using Ptr = shared_ptr< ::pcl::PCLPointField>;
+    using ConstPtr = shared_ptr<const ::pcl::PCLPointField>;
   }; // struct PCLPointField
 
-  typedef boost::shared_ptr< ::pcl::PCLPointField> PCLPointFieldPtr;
-  typedef boost::shared_ptr< ::pcl::PCLPointField const> PCLPointFieldConstPtr;
+  using PCLPointFieldPtr = PCLPointField::Ptr;
+  using PCLPointFieldConstPtr = PCLPointField::ConstPtr;
 
   inline std::ostream& operator<<(std::ostream& s, const  ::pcl::PCLPointField & v)
   {
@@ -54,6 +49,3 @@ namespace pcl
     return (s);
   }
 } // namespace pcl
-
-#endif // PCL_SENSOR_MSGS_MESSAGE_POINTFIELD_H
-
