@@ -36,8 +36,10 @@
  * $Id$
  *
  */
-#ifndef PCL_POINT_REPRESENTATION_H_
-#define PCL_POINT_REPRESENTATION_H_
+
+#pragma once
+
+#include <algorithm>
 
 #include <pcl/point_types.h>
 #include <pcl/pcl_macros.h>
@@ -56,7 +58,7 @@ namespace pcl
   {
     protected:
       /** \brief The number of dimensions in this point's vector (i.e. the "k" in "k-D") */
-      int nr_dimensions_;
+      int nr_dimensions_ = 0;
       /** \brief A vector containing the rescale factor to apply to each dimension. */
       std::vector<float> alpha_;
       /** \brief Indicates whether this point representation is trivial. It is trivial if and only if the following
@@ -68,17 +70,15 @@ namespace pcl
        *  the point was reinterpret_casted to a float array of length nr_dimensions_ . This value says that this
        *  representation can be trivial; it is only trivial if setRescaleValues() has not been set.
        */
-      bool trivial_;
+      bool trivial_ = false;
 
     public:
-      typedef boost::shared_ptr<PointRepresentation<PointT> > Ptr;
-      typedef boost::shared_ptr<const PointRepresentation<PointT> > ConstPtr;
-
-      /** \brief Empty constructor */
-      PointRepresentation () : nr_dimensions_ (0), alpha_ (0), trivial_ (false) {}
+      using Ptr = shared_ptr<PointRepresentation<PointT> >;
+      using ConstPtr = shared_ptr<const PointRepresentation<PointT> >;
 
       /** \brief Empty destructor */
-      virtual ~PointRepresentation () {}
+      virtual ~PointRepresentation () = default;
+      //TODO: check if copy and move constructors / assignment operators are needed
 
       /** \brief Copy point data from input point to a float array. This method must be overridden in all subclasses.
        *  \param[in] p The input point
@@ -109,7 +109,7 @@ namespace pcl
 
           for (int i = 0; i < nr_dimensions_; ++i)
           {
-            if (!pcl_isfinite (temp[i]))
+            if (!std::isfinite (temp[i]))
             {
               is_valid = false;
               break;
@@ -123,7 +123,7 @@ namespace pcl
 
           for (int i = 0; i < nr_dimensions_; ++i)
           {
-            if (!pcl_isfinite (temp[i]))
+            if (!std::isfinite (temp[i]))
             {
               is_valid = false;
               break;
@@ -163,8 +163,7 @@ namespace pcl
       setRescaleValues (const float *rescale_array)
       {
         alpha_.resize (nr_dimensions_);
-        for (int i = 0; i < nr_dimensions_; ++i)
-          alpha_[i] = rescale_array[i];
+        std::copy_n(rescale_array, nr_dimensions_, alpha_.begin());
       }
 
       /** \brief Return the number of dimensions in the point's vector representation. */
@@ -182,8 +181,8 @@ namespace pcl
 
     public:
       // Boost shared pointers
-      typedef boost::shared_ptr<DefaultPointRepresentation<PointDefault> > Ptr;
-      typedef boost::shared_ptr<const DefaultPointRepresentation<PointDefault> > ConstPtr;
+      using Ptr = shared_ptr<DefaultPointRepresentation<PointDefault> >;
+      using ConstPtr = shared_ptr<const DefaultPointRepresentation<PointDefault> >;
 
       DefaultPointRepresentation ()
       {
@@ -195,7 +194,7 @@ namespace pcl
         trivial_ = true;
       }
 
-      virtual ~DefaultPointRepresentation () {}
+      ~DefaultPointRepresentation () {}
 
       inline Ptr
       makeShared () const
@@ -203,13 +202,12 @@ namespace pcl
         return (Ptr (new DefaultPointRepresentation<PointDefault> (*this)));
       }
 
-      virtual void
-      copyToFloatArray (const PointDefault &p, float * out) const
+      void
+      copyToFloatArray (const PointDefault &p, float * out) const override
       {
         // If point type is unknown, treat it as a struct/array of floats
         const float* ptr = reinterpret_cast<const float*> (&p);
-        for (int i = 0; i < nr_dimensions_; ++i)
-          out[i] = ptr[i];
+        std::copy_n(ptr, nr_dimensions_, out);
       }
   };
 
@@ -242,14 +240,14 @@ namespace pcl
 
     struct NdCopyPointFunctor
     {
-      typedef typename traits::POD<PointDefault>::type Pod;
+      using Pod = typename traits::POD<PointDefault>::type;
 
       NdCopyPointFunctor (const PointDefault &p1, float * p2)
         : p1_ (reinterpret_cast<const Pod&>(p1)), p2_ (p2), f_idx_ (0) { }
 
       template<typename Key> inline void operator() ()
       {
-        typedef typename pcl::traits::datatype<PointDefault, Key>::type FieldT;
+        using FieldT = typename pcl::traits::datatype<PointDefault, Key>::type;
         const int NrDims = pcl::traits::datatype<PointDefault, Key>::size;
         Helper<Key, FieldT, NrDims>::copyPoint (p1_, p2_, f_idx_);
       }
@@ -260,7 +258,7 @@ namespace pcl
       {
         static void copyPoint (const Pod &p1, float * p2, int &f_idx)
         {
-          const uint8_t * data_ptr = reinterpret_cast<const uint8_t *> (&p1) +
+          const std::uint8_t * data_ptr = reinterpret_cast<const std::uint8_t *> (&p1) +
             pcl::traits::offset<PointDefault, Key>::value;
           p2[f_idx++] = *reinterpret_cast<const FieldT*> (data_ptr);
         }
@@ -271,7 +269,7 @@ namespace pcl
       {
         static void copyPoint (const Pod &p1, float * p2, int &f_idx)
         {
-          const uint8_t * data_ptr = reinterpret_cast<const uint8_t *> (&p1) +
+          const std::uint8_t * data_ptr = reinterpret_cast<const std::uint8_t *> (&p1) +
             pcl::traits::offset<PointDefault, Key>::value;
           int nr_dims = NrDims;
           const FieldT * array = reinterpret_cast<const FieldT *> (data_ptr);
@@ -290,9 +288,9 @@ namespace pcl
 
     public:
       // Boost shared pointers
-      typedef typename boost::shared_ptr<DefaultFeatureRepresentation<PointDefault> > Ptr;
-      typedef typename boost::shared_ptr<const DefaultFeatureRepresentation<PointDefault> > ConstPtr;
-      typedef typename pcl::traits::fieldList<PointDefault>::type FieldList;
+      using Ptr = shared_ptr<DefaultFeatureRepresentation<PointDefault>>;
+      using ConstPtr = shared_ptr<const DefaultFeatureRepresentation<PointDefault>>;
+      using FieldList = typename pcl::traits::fieldList<PointDefault>::type;
 
       DefaultFeatureRepresentation ()
       {
@@ -306,8 +304,8 @@ namespace pcl
         return (Ptr (new DefaultFeatureRepresentation<PointDefault> (*this)));
       }
 
-      virtual void
-      copyToFloatArray (const PointDefault &p, float * out) const
+      void
+      copyToFloatArray (const PointDefault &p, float * out) const override
       {
         pcl::for_each_type <FieldList> (NdCopyPointFunctor (p, out));
       }
@@ -324,8 +322,8 @@ namespace pcl
         trivial_ = true;
       }
 
-      virtual void
-      copyToFloatArray (const PointXYZ &p, float * out) const
+      void
+      copyToFloatArray (const PointXYZ &p, float * out) const override
       {
         out[0] = p.x;
         out[1] = p.y;
@@ -344,8 +342,8 @@ namespace pcl
         trivial_ = true;
       }
 
-      virtual void
-      copyToFloatArray (const PointXYZI &p, float * out) const
+      void
+      copyToFloatArray (const PointXYZI &p, float * out) const override
       {
         out[0] = p.x;
         out[1] = p.y;
@@ -365,8 +363,8 @@ namespace pcl
         trivial_ = true;
       }
 
-      virtual void
-      copyToFloatArray (const PointNormal &p, float * out) const
+      void
+      copyToFloatArray (const PointNormal &p, float * out) const override
       {
         out[0] = p.x;
         out[1] = p.y;
@@ -395,8 +393,8 @@ namespace pcl
         trivial_ = true;
       }
 
-      virtual void
-      copyToFloatArray (const PPFSignature &p, float * out) const
+      void
+      copyToFloatArray (const PPFSignature &p, float * out) const override
       {
         out[0] = p.f1;
         out[1] = p.f2;
@@ -441,8 +439,8 @@ namespace pcl
         trivial_=false;
       }
 
-      virtual void
-      copyToFloatArray (const Narf36 &p, float * out) const
+      void
+      copyToFloatArray (const Narf36 &p, float * out) const override
       {
         for (int i = 0; i < nr_dimensions_; ++i)
           out[i] = p.descriptor[i];
@@ -463,8 +461,8 @@ namespace pcl
         nr_dimensions_ = 1980;
       }
 
-      virtual void
-      copyToFloatArray (const ShapeContext1980 &p, float * out) const
+      void
+      copyToFloatArray (const ShapeContext1980 &p, float * out) const override
       {
         for (int i = 0; i < nr_dimensions_; ++i)
           out[i] = p.descriptor[i];
@@ -481,8 +479,8 @@ namespace pcl
         nr_dimensions_ = 1960;
       }
 
-      virtual void
-      copyToFloatArray (const UniqueShapeContext1960 &p, float * out) const
+      void
+      copyToFloatArray (const UniqueShapeContext1960 &p, float * out) const override
       {
         for (int i = 0; i < nr_dimensions_; ++i)
           out[i] = p.descriptor[i];
@@ -499,8 +497,8 @@ namespace pcl
         nr_dimensions_ = 352;
       }
 
-      virtual void
-      copyToFloatArray (const SHOT352 &p, float * out) const
+      void
+      copyToFloatArray (const SHOT352 &p, float * out) const override
       {
         for (int i = 0; i < nr_dimensions_; ++i)
           out[i] = p.descriptor[i];
@@ -517,8 +515,8 @@ namespace pcl
         nr_dimensions_ = 1344;
       }
 
-      virtual void
-      copyToFloatArray (const SHOT1344 &p, float * out) const
+      void
+      copyToFloatArray (const SHOT1344 &p, float * out) const override
       {
         for (int i = 0; i < nr_dimensions_; ++i)
           out[i] = p.descriptor[i];
@@ -536,8 +534,8 @@ namespace pcl
 
     public:
       // Boost shared pointers
-      typedef boost::shared_ptr<CustomPointRepresentation<PointDefault> > Ptr;
-      typedef boost::shared_ptr<const CustomPointRepresentation<PointDefault> > ConstPtr;
+      using Ptr = shared_ptr<CustomPointRepresentation<PointDefault> >;
+      using ConstPtr = shared_ptr<const CustomPointRepresentation<PointDefault> >;
 
       /** \brief Constructor
         * \param[in] max_dim the maximum number of dimensions to use
@@ -568,8 +566,7 @@ namespace pcl
       {
         // If point type is unknown, treat it as a struct/array of floats
         const float *ptr = (reinterpret_cast<const float*> (&p)) + start_dim_;
-        for (int i = 0; i < nr_dimensions_; ++i)
-          out[i] = ptr[i];
+        std::copy_n(ptr, nr_dimensions_, out);
       }
 
     protected:
@@ -579,5 +576,3 @@ namespace pcl
       int start_dim_;
   };
 }
-
-#endif // #ifndef PCL_POINT_REPRESENTATION_H_
