@@ -87,8 +87,7 @@
 // ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-#ifndef PCL_CUDA_EIGEN_H_
-#define PCL_CUDA_EIGEN_H_
+#pragma once
 
 #include <pcl/cuda/point_cloud.h>
 #include <pcl/cuda/cutil_math.h>
@@ -180,7 +179,7 @@ namespace pcl
       float  c2 = m.data[0].x + m.data[1].y + m.data[2].z;
   
   
-  		if (fabs(c0) < FLT_EPSILON) // one root is 0 -> quadratic equation
+  		if (std::abs(c0) < FLT_EPSILON) // one root is 0 -> quadratic equation
   			computeRoots2 (c2, c1, roots);
   		else
   		{
@@ -202,7 +201,7 @@ namespace pcl
   		  // Compute the eigenvalues by solving for the roots of the polynomial.
   		  float rho = sqrtf (-a_over_3);
   		  float theta = std::atan2 (sqrtf (-q), half_b) * s_inv3;
-  		  float cos_theta = cos (theta);
+  		  float cos_theta = std::cos (theta);
   		  float sin_theta = sin (theta);
   		  roots.x = c2_over_3 + 2.f * rho * cos_theta;
   		  roots.y = c2_over_3 - rho * (cos_theta + s_sqrt3 * sin_theta);
@@ -572,10 +571,10 @@ namespace pcl
         bounds.z += height_ / 2.0f;
         bounds.w += height_ / 2.0f;
   
-        res.x = (int)floor (bounds.x); 
-        res.y = (int)ceil  (bounds.y);
-        res.z = (int)floor (bounds.z);
-        res.w = (int)ceil  (bounds.w);
+        res.x = (int)std::floor (bounds.x); 
+        res.y = (int)std::ceil  (bounds.y);
+        res.z = (int)std::floor (bounds.z);
+        res.w = (int)std::ceil  (bounds.w);
   
         // clamp the coordinates to fit to depth image size
         res.x = clamp (res.x, 0, width_-1);
@@ -770,5 +769,3 @@ namespace pcl
   
   } // namespace
 } // namespace
-
-#endif  //#ifndef PCL_CUDA_EIGEN_H_
