@@ -38,9 +38,9 @@
  *
  */
 
-#ifndef PCL_NORMAL_3D_H_
-#define PCL_NORMAL_3D_H_
+#pragma once
 
+#include <pcl/pcl_macros.h>
 #include <pcl/features/feature.h>
 #include <pcl/common/centroid.h>
 
@@ -206,9 +206,9 @@ namespace pcl
   {
     Eigen::Vector3f normal_mean = Eigen::Vector3f::Zero ();
 
-    for (size_t i = 0; i < normal_indices.size (); ++i)
+    for (const int &normal_index : normal_indices)
     {
-      const PointNT& cur_pt = normal_cloud[normal_indices[i]];
+      const PointNT& cur_pt = normal_cloud[normal_index];
 
       if (pcl::isFinite (cur_pt))
       {
@@ -242,8 +242,8 @@ namespace pcl
   class NormalEstimation: public Feature<PointInT, PointOutT>
   {
     public:
-      typedef boost::shared_ptr<NormalEstimation<PointInT, PointOutT> > Ptr;
-      typedef boost::shared_ptr<const NormalEstimation<PointInT, PointOutT> > ConstPtr;
+      using Ptr = shared_ptr<NormalEstimation<PointInT, PointOutT> >;
+      using ConstPtr = shared_ptr<const NormalEstimation<PointInT, PointOutT> >;
       using Feature<PointInT, PointOutT>::feature_name_;
       using Feature<PointInT, PointOutT>::getClassName;
       using Feature<PointInT, PointOutT>::indices_;
@@ -253,23 +253,21 @@ namespace pcl
       using Feature<PointInT, PointOutT>::search_radius_;
       using Feature<PointInT, PointOutT>::search_parameter_;
       
-      typedef typename Feature<PointInT, PointOutT>::PointCloudOut PointCloudOut;
-      typedef typename Feature<PointInT, PointOutT>::PointCloudConstPtr PointCloudConstPtr;
+      using PointCloudOut = typename Feature<PointInT, PointOutT>::PointCloudOut;
+      using PointCloudConstPtr = typename Feature<PointInT, PointOutT>::PointCloudConstPtr;
       
       /** \brief Empty constructor. */
       NormalEstimation () 
       : vpx_ (0)
       , vpy_ (0)
       , vpz_ (0)
-      , covariance_matrix_ ()
-      , xyz_centroid_ ()
       , use_sensor_origin_ (true)
       {
         feature_name_ = "NormalEstimation";
       };
       
       /** \brief Empty destructor */
-      virtual ~NormalEstimation () {}
+      ~NormalEstimation () {}
 
       /** \brief Compute the Least-Squares plane fit for a given set of points, using their indices,
         * and return the estimated plane parameters together with the surface curvature.
@@ -329,8 +327,8 @@ namespace pcl
       /** \brief Provide a pointer to the input dataset
         * \param cloud the const boost shared pointer to a PointCloud message
         */
-      virtual inline void 
-      setInputCloud (const PointCloudConstPtr &cloud)
+      inline void 
+      setInputCloud (const PointCloudConstPtr &cloud) override
       {
         input_ = cloud;
         if (use_sensor_origin_)
@@ -400,7 +398,7 @@ namespace pcl
         * \param output the resultant point cloud model dataset that contains surface normals and curvatures
         */
       void
-      computeFeature (PointCloudOut &output);
+      computeFeature (PointCloudOut &output) override;
 
       /** \brief Values describing the viewpoint ("pinhole" camera model assumed). For per point viewpoints, inherit
         * from NormalEstimation and provide your own computeFeature (). By default, the viewpoint is set to 0,0,0. */
@@ -416,13 +414,10 @@ namespace pcl
       bool use_sensor_origin_;
 
     public:
-      EIGEN_MAKE_ALIGNED_OPERATOR_NEW
+      PCL_MAKE_ALIGNED_OPERATOR_NEW
   };
 }
 
 #ifdef PCL_NO_PRECOMPILE
 #include <pcl/features/impl/normal_3d.hpp>
 #endif
-
-#endif  //#ifndef PCL_NORMAL_3D_H_
-
