@@ -34,14 +34,6 @@
  *  Author: Anatoly Baskeheev, Itseez Ltd, (myname.mysurname@mycompany.com)
  */
 
-#if (defined(__GNUC__) && !defined(__CUDACC__) && (GTEST_GCC_VER_ >= 40000)) 
-    #define GTEST_USE_OWN_TR1_TUPLE 0
-#endif
-
-#if defined(_MSC_VER) && (_MSC_VER >= 1500)
-    #define GTEST_USE_OWN_TR1_TUPLE 0
-#endif
-
 #include "gtest/gtest.h"
 
 #include <pcl/point_types.h>
@@ -65,11 +57,11 @@ TEST(PCL_FeaturesGPU, pfh_low_level)
 
     source.estimateNormals();
     source.findRadiusNeghbors();
-    cout << "max_radius_nn_size: " << source.max_nn_size << endl;
+    std::cout << "max_radius_nn_size: " << source.max_nn_size << std::endl;
                    
-    vector<int> data;
+    std::vector<int> data;
     source.getNeghborsArray(data);
-    vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
     std::transform(source.normals->points.begin(), source.normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());
     
     //uploading data to GPU
@@ -88,7 +80,7 @@ TEST(PCL_FeaturesGPU, pfh_low_level)
     pfh_gpu.compute(cloud_gpu, normals_gpu, indices, pfh125_features);
 
     int stub;
-    vector<PFHSignature125> downloaded;
+    std::vector<PFHSignature125> downloaded;
     pfh125_features.download(downloaded, stub);
 
     pcl::PFHEstimation<PointXYZ, Normal, PFHSignature125> fe;
@@ -101,15 +93,15 @@ TEST(PCL_FeaturesGPU, pfh_low_level)
     PointCloud<PFHSignature125> pfhs;
     fe.compute (pfhs);
 
-    for(size_t i = 0; i < downloaded.size(); ++i)
+    for(std::size_t i = 0; i < downloaded.size(); ++i)
     {
         PFHSignature125& gpu = downloaded[i];
         PFHSignature125& cpu = pfhs.points[i];
         
-        size_t FSize = sizeof(PFHSignature125)/sizeof(gpu.histogram[0]);                                
+        std::size_t FSize = sizeof(PFHSignature125)/sizeof(gpu.histogram[0]);                                
         
         float norm = 0, norm_diff = 0;
-        for(size_t j = 0; j < FSize; ++j)
+        for(std::size_t j = 0; j < FSize; ++j)
         {
             norm_diff += (gpu.histogram[j] - cpu.histogram[j]) * (gpu.histogram[j] - cpu.histogram[j]);
             norm += cpu.histogram[j] * cpu.histogram[j];
@@ -132,11 +124,11 @@ TEST(PCL_FeaturesGPU, pfh_high_level1)
     //source.generateSurface();
     //source.generateIndices();
 
-    cout << "!indices, !surface" << endl;
+    std::cout << "!indices, !surface" << std::endl;
 
     PointCloud<Normal>::Ptr& normals = source.normals;
 
-    vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
     std::transform(normals->points.begin(), normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());
 
     //uploading data to GPU
@@ -177,18 +169,18 @@ TEST(PCL_FeaturesGPU, pfh_high_level1)
     fe.compute (fpfhs);
 
     int stub;
-    vector<PFHSignature125> downloaded;
+    std::vector<PFHSignature125> downloaded;
     fpfhs_gpu.download(downloaded, stub);
 
-    for(size_t i = 0; i < downloaded.size(); ++i)
+    for(std::size_t i = 0; i < downloaded.size(); ++i)
     {
         PFHSignature125& gpu = downloaded[i];
         PFHSignature125& cpu = fpfhs.points[i];
         
-        size_t FSize = sizeof(PFHSignature125)/sizeof(gpu.histogram[0]);                                
+        std::size_t FSize = sizeof(PFHSignature125)/sizeof(gpu.histogram[0]);                                
         
         float norm = 0, norm_diff = 0;
-        for(size_t j = 0; j < FSize; ++j)
+        for(std::size_t j = 0; j < FSize; ++j)
         {
             norm_diff += (gpu.histogram[j] - cpu.histogram[j]) * (gpu.histogram[j] - cpu.histogram[j]);
             norm += cpu.histogram[j] * cpu.histogram[j];
@@ -210,11 +202,11 @@ TEST(PCL_FeaturesGPU, pfh_high_level2)
     //source.generateSurface();
     source.generateIndices();
 
-    cout << "indices, !surface" << endl;
+    std::cout << "indices, !surface" << std::endl;
 
     PointCloud<Normal>::Ptr& normals = source.normals;
 
-    vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
     std::transform(normals->points.begin(), normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());
 
     //uploading data to GPU
@@ -255,18 +247,18 @@ TEST(PCL_FeaturesGPU, pfh_high_level2)
     fe.compute (fpfhs);
 
     int stub;
-    vector<PFHSignature125> downloaded;
+    std::vector<PFHSignature125> downloaded;
     fpfhs_gpu.download(downloaded, stub);
 
-    for(size_t i = 0; i < downloaded.size(); ++i)
+    for(std::size_t i = 0; i < downloaded.size(); ++i)
     {
         PFHSignature125& gpu = downloaded[i];
         PFHSignature125& cpu = fpfhs.points[i];
         
-        size_t FSize = sizeof(PFHSignature125)/sizeof(gpu.histogram[0]);                                
+        std::size_t FSize = sizeof(PFHSignature125)/sizeof(gpu.histogram[0]);                                
         
         float norm = 0, norm_diff = 0;
-        for(size_t j = 0; j < FSize; ++j)
+        for(std::size_t j = 0; j < FSize; ++j)
         {
             norm_diff += (gpu.histogram[j] - cpu.histogram[j]) * (gpu.histogram[j] - cpu.histogram[j]);
             norm += cpu.histogram[j] * cpu.histogram[j];
@@ -288,11 +280,11 @@ TEST(PCL_FeaturesGPU, pfh_high_level3)
     source.generateSurface();
     //source.generateIndices();
 
-    cout << "!indices, surface" << endl;
+    std::cout << "!indices, surface" << std::endl;
 
     PointCloud<Normal>::Ptr& normals = source.normals_surface;
 
-    vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
     std::transform(normals->points.begin(), normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());
 
     //uploading data to GPU
@@ -333,18 +325,18 @@ TEST(PCL_FeaturesGPU, pfh_high_level3)
     fe.compute (fpfhs);
 
     int stub;
-    vector<PFHSignature125> downloaded;
+    std::vector<PFHSignature125> downloaded;
     fpfhs_gpu.download(downloaded, stub);
 
-    for(size_t i = 0; i < downloaded.size(); ++i)
+    for(std::size_t i = 0; i < downloaded.size(); ++i)
     {
         PFHSignature125& gpu = downloaded[i];
         PFHSignature125& cpu = fpfhs.points[i];
         
-        size_t FSize = sizeof(PFHSignature125)/sizeof(gpu.histogram[0]);                                
+        std::size_t FSize = sizeof(PFHSignature125)/sizeof(gpu.histogram[0]);                                
         
         float norm = 0, norm_diff = 0;
-        for(size_t j = 0; j < FSize; ++j)
+        for(std::size_t j = 0; j < FSize; ++j)
         {
             norm_diff += (gpu.histogram[j] - cpu.histogram[j]) * (gpu.histogram[j] - cpu.histogram[j]);
             norm += cpu.histogram[j] * cpu.histogram[j];
@@ -366,11 +358,11 @@ TEST(PCL_FeaturesGPU, pfh_high_level4)
     source.generateSurface();
     source.generateIndices();
 
-    cout << "indices, surface" << endl;
+    std::cout << "indices, surface" << std::endl;
 
     PointCloud<Normal>::Ptr& normals = source.normals_surface;
 
-    vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
     std::transform(normals->points.begin(), normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());
 
     //uploading data to GPU
@@ -411,18 +403,18 @@ TEST(PCL_FeaturesGPU, pfh_high_level4)
     fe.compute (fpfhs);
 
     int stub;
-    vector<PFHSignature125> downloaded;
+    std::vector<PFHSignature125> downloaded;
     fpfhs_gpu.download(downloaded, stub);
 
-    for(size_t i = 0; i < downloaded.size(); ++i)
+    for(std::size_t i = 0; i < downloaded.size(); ++i)
     {
         PFHSignature125& gpu = downloaded[i];
         PFHSignature125& cpu = fpfhs.points[i];
         
-        size_t FSize = sizeof(PFHSignature125)/sizeof(gpu.histogram[0]);                                
+        std::size_t FSize = sizeof(PFHSignature125)/sizeof(gpu.histogram[0]);                                
         
         float norm = 0, norm_diff = 0;
-        for(size_t j = 0; j < FSize; ++j)
+        for(std::size_t j = 0; j < FSize; ++j)
         {
             norm_diff += (gpu.histogram[j] - cpu.histogram[j]) * (gpu.histogram[j] - cpu.histogram[j]);
             norm += cpu.histogram[j] * cpu.histogram[j];
@@ -444,11 +436,11 @@ TEST(PCL_FeaturesGPU, pfhrgb)
     //source.generateSurface();
     //source.generateIndices();
 
-    cout << "!indices, !surface" << endl;
+    std::cout << "!indices, !surface" << std::endl;
 
     PointCloud<Normal>::Ptr& normals = source.normals;
 
-    vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
     std::transform(normals->points.begin(), normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());
 
     //uploading data to GPU
@@ -480,7 +472,7 @@ TEST(PCL_FeaturesGPU, pfhrgb)
 
     PointCloud<PointXYZRGB>::Ptr cloud_XYZRGB(new PointCloud<PointXYZRGB>());
     cloud_XYZRGB->points.clear();
-    for(size_t i = 0; i < source.cloud->points.size(); ++i)               
+    for(std::size_t i = 0; i < source.cloud->points.size(); ++i)               
     {
         const PointXYZ& p = source.cloud->points[i];
         PointXYZRGB o;
@@ -510,18 +502,18 @@ TEST(PCL_FeaturesGPU, pfhrgb)
     fe.compute (fpfhs);
 
     int stub;
-    vector<PFHRGBSignature250> downloaded;
+    std::vector<PFHRGBSignature250> downloaded;
     fpfhs_gpu.download(downloaded, stub);
 
-    for(size_t i = 170; i < downloaded.size(); ++i)
+    for(std::size_t i = 170; i < downloaded.size(); ++i)
     {
         PFHRGBSignature250& gpu = downloaded[i];
         PFHRGBSignature250& cpu = fpfhs.points[i];
         
-        size_t FSize = sizeof(PFHRGBSignature250)/sizeof(gpu.histogram[0]);                                
+        std::size_t FSize = sizeof(PFHRGBSignature250)/sizeof(gpu.histogram[0]);                                
         
         float norm = 0, norm_diff = 0;
-        for(size_t j = 0; j < FSize; ++j)
+        for(std::size_t j = 0; j < FSize; ++j)
         {
             norm_diff += (gpu.histogram[j] - cpu.histogram[j]) * (gpu.histogram[j] - cpu.histogram[j]);
             norm += cpu.histogram[j] * cpu.histogram[j];
