@@ -84,6 +84,7 @@
 #include "evaluation.h"
 
 #include <pcl/common/angles.h>
+#include <pcl/make_shared.h>
 
 //#include "tsdf_volume.h"
 //#include "tsdf_volume.hpp"
@@ -93,7 +94,7 @@
   #include <opencv2/imgproc/imgproc.hpp>
 //#include "video_recorder.h"
 #endif
-typedef pcl::ScopeTime ScopeTimeT;
+using ScopeTimeT = pcl::ScopeTime;
 
 #include <Eigen/Dense>
 #include <cmath>
@@ -109,7 +110,6 @@ typedef pcl::ScopeTime ScopeTimeT;
 #include "pcl/common/common.h"
 #include "pcl/common/transforms.h"
 #include <pcl/console/print.h>
-#include <pcl/console/time.h>
 // define the following in order to eliminate the deprecated headers warning
 #define VTK_EXCLUDE_STRSTREAM_HEADERS
 #include <pcl/io/vtk_lib_io.h>
@@ -134,7 +134,7 @@ using namespace pcl::console;
 using namespace pcl::io;
 using namespace pcl::simulation;
 using namespace std;
-uint16_t t_gamma[2048];
+std::uint16_t t_gamma[2048];
 Scene::Ptr scene_;
 Camera::Ptr camera_;
 RangeLikelihood::Ptr range_likelihood_;
@@ -161,7 +161,7 @@ struct SampledScopeTime : public StopWatch
     time_ms_ += stopWatch_.getTime ();        
     if (i_ % EACH == 0 && i_)
     {
-      cout << "Average frame time = " << time_ms_ / EACH << "ms ( " << 1000.f * EACH / time_ms_ << "fps )" << endl;
+      std::cout << "Average frame time = " << time_ms_ / EACH << "ms ( " << 1000.f * EACH / time_ms_ << "fps )" << std::endl;
       time_ms_ = 0;        
     }
   }
@@ -197,7 +197,7 @@ getViewerPose (visualization::PCLVisualizer& viewer)
                  -1,  0,  0,
                   0, -1,  0;
 
-  rotation = rotation * axis_reorder;
+  rotation *= axis_reorder;
   pose.linear() = rotation;
   return pose;
 }
@@ -208,7 +208,7 @@ void
 write_depth_image(const float* depth_buffer)
 {
   int npixels = range_likelihood_->getWidth() * range_likelihood_->getHeight();
-  uint8_t* depth_img = new uint8_t[npixels * 3];
+  std::uint8_t* depth_img = new std::uint8_t[npixels * 3];
 
   float min_depth = depth_buffer[0];
   float max_depth = depth_buffer[0];
@@ -232,7 +232,7 @@ write_depth_image(const float* depth_buffer)
       float z = -zf*zn/((zf-zn)*(d - zf/(zf-zn)));
       float b = 0.075;
       float f = 580.0;
-      uint16_t kd = static_cast<uint16_t>(1090 - b*f/z*8);
+      std::uint16_t kd = static_cast<std::uint16_t>(1090 - b*f/z*8);
       if (kd < 0) kd = 0;
       else if (kd>2047) kd = 2047;
 
@@ -292,10 +292,10 @@ write_depth_image(const float* depth_buffer)
 
 
 void
-write_rgb_image(const uint8_t* rgb_buffer)
+write_rgb_image(const std::uint8_t* rgb_buffer)
 {
   int npixels = range_likelihood_->getWidth() * range_likelihood_->getHeight();
-  uint8_t* rgb_img = new uint8_t[npixels * 3];
+  std::uint8_t* rgb_img = new std::uint8_t[npixels * 3];
 
   for (int y = 0; y <  480; ++y)
   {
@@ -326,8 +326,8 @@ write_rgb_image(const uint8_t* rgb_buffer)
 void
 depthBufferToMM(const float* depth_buffer,unsigned short* depth_img)
 {
-  int npixels = range_likelihood_->getWidth() * range_likelihood_->getHeight();
- // unsigned short * depth_img = new unsigned short[npixels ];
+  //int npixels = range_likelihood_->getWidth() * range_likelihood_->getHeight();
+  //unsigned short * depth_img = new unsigned short[npixels ];
   for (int y = 0; y <  480; ++y)
   {
     for (int x = 0; x < 640; ++x)
@@ -337,14 +337,14 @@ depthBufferToMM(const float* depth_buffer,unsigned short* depth_img)
       float zn = 0.7;
       float zf = 20.0;
       float d = depth_buffer[i_in];
-      unsigned short z_new = (unsigned short)  floor( 1000*( -zf*zn/((zf-zn)*(d - zf/(zf-zn)))));
+      unsigned short z_new = (unsigned short)  std::floor( 1000*( -zf*zn/((zf-zn)*(d - zf/(zf-zn)))));
 
       if (z_new < 0) z_new = 0;
 //      else if (z_new>65535) z_new = 65535;
       else if (z_new>5000) z_new = 0;
 
       //      if ( z_new < 18000){
-//	  cout << z_new << " " << d << " " << x << "\n";  
+//	  std::cout << z_new << " " << d << " " << x << "\n";  
 //      }
       depth_img[i] = z_new;
     }
@@ -369,30 +369,30 @@ write_depth_image_uint(unsigned short* depth_img)
 void
 display_tic_toc (vector<double> &tic_toc,const string &fun_name)
 {
-  size_t tic_toc_size = tic_toc.size ();
+  std::size_t tic_toc_size = tic_toc.size ();
 
   double percent_tic_toc_last = 0;
   double dtime = tic_toc[tic_toc_size-1] - tic_toc[0];
-  cout << "fraction_" << fun_name << ",";
-  for (size_t i = 0; i < tic_toc_size; i++)
+  std::cout << "fraction_" << fun_name << ",";
+  for (std::size_t i = 0; i < tic_toc_size; i++)
   {
     double percent_tic_toc =  (tic_toc[i] - tic_toc[0])/(tic_toc[tic_toc_size-1] - tic_toc[0]);
-    cout <<  percent_tic_toc - percent_tic_toc_last << ", ";
+    std::cout <<  percent_tic_toc - percent_tic_toc_last << ", ";
     percent_tic_toc_last = percent_tic_toc;
   }
-  cout << "\ntime_" << fun_name << ",";
+  std::cout << "\ntime_" << fun_name << ",";
   double time_tic_toc_last = 0;
-  for (size_t i = 0; i < tic_toc_size; i++)
+  for (std::size_t i = 0; i < tic_toc_size; i++)
   {
     double percent_tic_toc = (tic_toc[i] - tic_toc[0])/(tic_toc[tic_toc_size-1] - tic_toc[0]);
-    cout <<  percent_tic_toc*dtime - time_tic_toc_last << ", ";
+    std::cout <<  percent_tic_toc*dtime - time_tic_toc_last << ", ";
     time_tic_toc_last = percent_tic_toc*dtime;
   }
-  cout << "\ntotal_time_" << fun_name << " " << dtime << "\n";
+  std::cout << "\ntotal_time_" << fun_name << " " << dtime << "\n";
 }
 
 void
-capture (Eigen::Isometry3d pose_in,unsigned short* depth_buffer_mm,const uint8_t* color_buffer)//, string point_cloud_fname)
+capture (Eigen::Isometry3d pose_in,unsigned short* depth_buffer_mm,const std::uint8_t* color_buffer)//, string point_cloud_fname)
 {
   // No reference image - but this is kept for compatibility with range_test_v2:
   float* reference = new float[range_likelihood_->getRowHeight() * range_likelihood_->getColWidth()];
@@ -410,7 +410,6 @@ capture (Eigen::Isometry3d pose_in,unsigned short* depth_buffer_mm,const uint8_t
 
   std::vector<Eigen::Isometry3d, Eigen::aligned_allocator<Eigen::Isometry3d> > poses;
   std::vector<float> scores;
-  int n = 1;
   poses.push_back (pose_in);
   // HACK: mfallon modified computeLikelihoods to only call render()  (which is currently private)
   // need to make render public and use it.
@@ -453,7 +452,7 @@ capture (Eigen::Isometry3d pose_in,unsigned short* depth_buffer_mm,const uint8_t
     pcl::PCDWriter writer;
     //writer.write (point_cloud_fname, *pc_out,	false);  /// ASCII
     writer.writeBinary (point_cloud_fname, *pc_out);
-    //cout << "finished writing file\n";
+    //std::cout << "finished writing file\n";
   }
   */
 
@@ -491,11 +490,11 @@ generate_halo(
   Eigen::Vector3d focus_center,double halo_r,double halo_dz,int n_poses)
 {
   for (double t=0;t < (2*M_PI);t =t + (2*M_PI)/ ((double) n_poses) ){
-    double x = halo_r*cos(t);
+    double x = halo_r*std::cos(t);
     double y = halo_r*sin(t);
     double z = halo_dz;
-    double pitch =atan2( halo_dz,halo_r); 
-    double yaw = atan2(-y,-x);
+    double pitch =std::atan2( halo_dz,halo_r); 
+    double yaw = std::atan2(-y,-x);
    
     Eigen::Isometry3d pose;
     pose.setIdentity();
@@ -533,7 +532,7 @@ typename PointCloud<MergedT>::Ptr merge(const PointCloud<PointT>& points, const
   //pcl::copyPointCloud (colors, *merged_ptr); why error?
   //pcl::concatenateFields (points, colors, *merged_ptr); why error? 
     
-  for (size_t i = 0; i < colors.size (); ++i)
+  for (std::size_t i = 0; i < colors.size (); ++i)
     merged_ptr->points[i].rgba = colors.points[i].rgba;
       
   return merged_ptr;
@@ -542,21 +541,21 @@ typename PointCloud<MergedT>::Ptr merge(const PointCloud<PointT>& points, const
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-boost::shared_ptr<pcl::PolygonMesh> convertToMesh(const DeviceArray<PointXYZ>& triangles)
+pcl::PolygonMesh::Ptr convertToMesh(const DeviceArray<PointXYZ>& triangles)
 { 
   if (triangles.empty())
-      return boost::shared_ptr<pcl::PolygonMesh>();
+      return PolygonMesh::Ptr ();
 
   pcl::PointCloud<pcl::PointXYZ> cloud;
   cloud.width  = (int)triangles.size();
   cloud.height = 1;
   triangles.download(cloud.points);
-  
-  boost::shared_ptr<pcl::PolygonMesh> mesh_ptr( new pcl::PolygonMesh() ); 
+
+  PolygonMesh::Ptr mesh_ptr = make_shared<PolygonMesh> ();
   pcl::toPCLPointCloud2(cloud, mesh_ptr->cloud);
       
   mesh_ptr->polygons.resize (triangles.size() / 3);
-  for (size_t i = 0; i < mesh_ptr->polygons.size (); ++i)
+  for (std::size_t i = 0; i < mesh_ptr->polygons.size (); ++i)
   {
     pcl::Vertices v;
     v.vertices.push_back(i*3+0);
@@ -566,7 +565,7 @@ boost::shared_ptr<pcl::PolygonMesh> convertToMesh(const DeviceArray<PointXYZ>& t
   }    
   return mesh_ptr;
   
-  cout << mesh_ptr->polygons.size () << " plys\n";
+  std::cout << mesh_ptr->polygons.size () << " plys\n";
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -671,7 +670,7 @@ struct ImageView
     raycaster_ptr_->generateDepthImage(generated_depth_);    
 
     int c;
-    vector<unsigned short> data;
+    std::vector<unsigned short> data;
     generated_depth_.download(data, c);
 
     viewerDepth_.showShortImage (&data[0], generated_depth_.cols(), generated_depth_.rows(), 0, 5000, true);
@@ -681,7 +680,7 @@ struct ImageView
   toggleImagePaint()
   {
     paint_image_ = !paint_image_;
-    cout << "Paint image: " << (paint_image_ ? "On   (requires registration mode)" : "Off") << endl;
+    std::cout << "Paint image: " << (paint_image_ ? "On   (requires registration mode)" : "Off") << std::endl;
   }
 
   bool paint_image_;
@@ -693,14 +692,14 @@ struct ImageView
 
   KinfuTracker::View view_device_;
   KinfuTracker::View colors_device_;
-  vector<KinfuTracker::PixelRGB> view_host_;
+  std::vector<KinfuTracker::PixelRGB> view_host_;
 
   RayCaster::Ptr raycaster_ptr_;
 
   KinfuTracker::DepthMap generated_depth_;
   
 #ifdef HAVE_OPENCV
-  vector<cv::Mat> views_;
+  std::vector<cv::Mat> views_;
 #endif
 };
 
@@ -734,7 +733,7 @@ struct SceneCloudView
     viewer_pose_ = kinfu.getCameraPose();
 
     ScopeTimeT time ("PointCloud Extraction");
-    cout << "\nGetting cloud... " << flush;
+    std::cout << "\nGetting cloud... " << flush;
 
     valid_combined_ = false;
 
@@ -773,8 +772,8 @@ struct SceneCloudView
       else
         point_colors_ptr_->points.clear();
     }
-    size_t points_size = valid_combined_ ? combined_ptr_->points.size () : cloud_ptr_->points.size ();
-    cout << "Done.  Cloud size: " << points_size / 1000 << "K" << endl;
+    std::size_t points_size = valid_combined_ ? combined_ptr_->points.size () : cloud_ptr_->points.size ();
+    std::cout << "Done.  Cloud size: " << points_size / 1000 << "K" << std::endl;
 
     cloud_viewer_.removeAllPointClouds ();    
     if (valid_combined_)
@@ -808,9 +807,9 @@ struct SceneCloudView
 
     switch (extraction_mode_)
     {
-    case 0: cout << "Cloud exctraction mode: GPU, Connected-6" << endl; break;
-    case 1: cout << "Cloud exctraction mode: CPU, Connected-6    (requires a lot of memory)" << endl; break;
-    case 2: cout << "Cloud exctraction mode: CPU, Connected-26   (requires a lot of memory)" << endl; break;
+    case 0: std::cout << "Cloud exctraction mode: GPU, Connected-6" << std::endl; break;
+    case 1: std::cout << "Cloud exctraction mode: CPU, Connected-6    (requires a lot of memory)" << std::endl; break;
+    case 2: std::cout << "Cloud exctraction mode: CPU, Connected-26   (requires a lot of memory)" << std::endl; break;
     }
     ;
   }
@@ -819,7 +818,7 @@ struct SceneCloudView
   toggleNormals ()
   {
     compute_normals_ = !compute_normals_;
-    cout << "Compute normals: " << (compute_normals_ ? "On" : "Off") << endl;
+    std::cout << "Compute normals: " << (compute_normals_ ? "On" : "Off") << std::endl;
   }
 
   void
@@ -829,14 +828,14 @@ struct SceneCloudView
     cloud_ptr_->points.clear ();
     normals_ptr_->points.clear ();    
     if (print_message)
-      cout << "Clouds/Meshes were cleared" << endl;
+      std::cout << "Clouds/Meshes were cleared" << std::endl;
   }
 
   void
   showMesh(KinfuTracker& kinfu, bool /*integrate_colors*/)
   {
     ScopeTimeT time ("Mesh Extraction");
-    cout << "\nGetting mesh... " << flush;
+    std::cout << "\nGetting mesh... " << flush;
 
     if (!marching_cubes_)
       marching_cubes_ = MarchingCubes::Ptr( new MarchingCubes() );
@@ -847,12 +846,12 @@ struct SceneCloudView
     cloud_viewer_.removeAllPointClouds ();
     if (mesh_ptr_){
       cloud_viewer_.addPolygonMesh(*mesh_ptr_);	
-      cout << "mesh ptr exist\n";
+      std::cout << "mesh ptr exist\n";
     }else{
-      cout << "mesh ptr no exist\n";
+      std::cout << "mesh ptr no exist\n";
     }
     
-    cout << "Done.  Triangles number: " << triangles_device.size() / MarchingCubes::POINTS_PER_TRIANGLE / 1000 << "K" << endl;
+    std::cout << "Done.  Triangles number: " << triangles_device.size() / MarchingCubes::POINTS_PER_TRIANGLE / 1000 << "K" << std::endl;
   }
     
   int extraction_mode_;
@@ -879,7 +878,7 @@ struct SceneCloudView
   MarchingCubes::Ptr marching_cubes_;
   DeviceArray<PointXYZ> triangles_buffer_device_;
 
-  boost::shared_ptr<pcl::PolygonMesh> mesh_ptr_;
+  pcl::PolygonMesh::Ptr mesh_ptr_;
 };
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -918,7 +917,7 @@ struct KinFuApp
     image_view_.viewerDepth_.registerKeyboardCallback (keyboard_callback, (void*)this);
 
     float diag = sqrt ((float)kinfu_.cols () * kinfu_.cols () + kinfu_.rows () * kinfu_.rows ());
-    scene_cloud_view_.cloud_viewer_.setCameraFieldOfView (2 * atan (diag / (2 * f)) * 1.5);
+    scene_cloud_view_.cloud_viewer_.setCameraFieldOfView (2 * std::atan (diag / (2 * f)) * 1.5);
     
     scene_cloud_view_.toggleCube(volume_size);    
   }
@@ -932,7 +931,7 @@ struct KinFuApp
   void
   initCurrentFrameView ()
   {
-    current_frame_cloud_view_ = boost::shared_ptr<CurrentFrameCloudView>(new CurrentFrameCloudView ());
+    current_frame_cloud_view_ = make_shared<CurrentFrameCloudView> ();
     current_frame_cloud_view_->cloud_viewer_.registerKeyboardCallback (keyboard_callback, (void*)this);
     current_frame_cloud_view_->setViewerPose (kinfu_.getCameraPose ());
   }
@@ -941,7 +940,7 @@ struct KinFuApp
   tryRegistrationInit ()
   {
     registration_ = capture_.setRegistration (true);
-    cout << "Registration mode: " << (registration_ ?  "On" : "Off (not supported by source)") << endl;
+    std::cout << "Registration mode: " << (registration_ ?  "On" : "Off (not supported by source)") << std::endl;
   }
 
   void 
@@ -953,14 +952,14 @@ struct KinFuApp
       kinfu_.initColorIntegration(max_color_integration_weight);
       integrate_colors_ = true;      
     }
-    cout << "Color integration: " << (integrate_colors_ ? "On" : "Off (not supported by source)") << endl;
+    std::cout << "Color integration: " << (integrate_colors_ ? "On" : "Off (not supported by source)") << std::endl;
   }
 
   void
   toggleIndependentCamera()
   {
     independent_camera_ = !independent_camera_;
-    cout << "Camera mode: " << (independent_camera_ ?  "Independent" : "Bound to Kinect pose") << endl;
+    std::cout << "Camera mode: " << (independent_camera_ ?  "Independent" : "Bound to Kinect pose") << std::endl;
   }
   
   void
@@ -976,7 +975,7 @@ struct KinFuApp
   }
 
   void
-  execute (int argc, char** argv, std::string plyfile)
+  execute (int argc, char** argv, const std::string &plyfile)
   {
     PtrStepSz<const unsigned short> depth;
     PtrStepSz<const KinfuTracker::PixelRGB> rgb24;
@@ -1032,7 +1031,7 @@ struct KinFuApp
     camera_->set(0.471703, 1.59862, 3.10937, 0, 0.418879, -12.2129);
     camera_->set_pitch(0.418879); // not sure why this is here:
 
-    cout << "About to read: "<< plyfile << endl;   
+    std::cout << "About to read: "<< plyfile << std::endl;   
     load_PolygonMesh_model (plyfile);  
     
     // Generate a series of poses:
@@ -1049,13 +1048,12 @@ struct KinFuApp
     generate_halo(poses,focus_center,halo_r,halo_dz,n_poses);    
     
     unsigned short * disparity_buf_ = new unsigned short[width*height ];
-    const KinfuTracker::PixelRGB* color_buf_;
-    const uint8_t* color_buf_uint;
+    const std::uint8_t* color_buf_uint;
     
     // loop though and create the mesh:
     for (int i = 0; !exit_; ++i)
     { 
-      vector<double> tic_toc;
+      std::vector<double> tic_toc;
       tic_toc.push_back(getTime());
       double tic_main = getTime();
 
@@ -1067,9 +1065,9 @@ struct KinFuApp
       std::cout << i << ": " << ss.str() << " pose_simulatedposition\n";      
       
       capture (poses[i],disparity_buf_, color_buf_uint);//,ss.str());
-      color_buf_ = (const KinfuTracker::PixelRGB*) color_buf_uint;
+      const KinfuTracker::PixelRGB* color_buf_ = (const KinfuTracker::PixelRGB*) color_buf_uint;
       PtrStepSz<const unsigned short> depth_sim = PtrStepSz<const unsigned short>(height, width, disparity_buf_, 2*width);
-      //cout << depth_sim.rows << " by " << depth_sim.cols << " | s: " << depth_sim.step << "\n";
+      //std::cout << depth_sim.rows << " by " << depth_sim.cols << " | s: " << depth_sim.step << "\n";
       // RGB-KinFu currently disabled for now - problems with color in KinFu apparently
       // but this constructor might not  be right either: not sure about step size
       integrate_colors_=false;
@@ -1080,7 +1078,7 @@ struct KinFuApp
 	bool has_frame = evaluation_ptr_ ? evaluation_ptr_->grab(i, depth) : capture_.grab (depth, rgb24);      
 	if (!has_frame)
 	{
-	  cout << "Can't grab" << endl;
+	  std::cout << "Can't grab" << std::endl;
 	  break;
 	}
 
@@ -1099,7 +1097,7 @@ struct KinFuApp
 	}
       }else{ //simulate:
 
-	cout << " color: " << integrate_colors_ << "\n"; // integrate_colors_ seems to be zero
+	std::cout << " color: " << integrate_colors_ << "\n"; // integrate_colors_ seems to be zero
 	depth_device_.upload (depth_sim.data, depth_sim.step, depth_sim.rows, depth_sim.cols);
 	if (integrate_colors_){
 	    image_view_.colors_device_.upload (rgb24_sim.data, rgb24_sim.step, rgb24_sim.rows, rgb24_sim.cols);
@@ -1133,7 +1131,7 @@ struct KinFuApp
       // Everything below this is Visualization or I/O:
       if (i >n_pose_stop){
 	int pause;
-	cout << "Enter a key to write Mesh file\n";
+	std::cout << "Enter a key to write Mesh file\n";
 	cin >> pause;
 
 	scene_cloud_view_.showMesh(kinfu_, integrate_colors_);
@@ -1150,24 +1148,24 @@ struct KinFuApp
 	    // download tsdf volume
 	    {
 	      ScopeTimeT time ("tsdf volume download");
-	      cout << "Downloading TSDF volume from device ... " << flush;
+	      std::cout << "Downloading TSDF volume from device ... " << flush;
 	      // kinfu_.volume().downloadTsdfAndWeighs (tsdf_volume_.volumeWriteable (), tsdf_volume_.weightsWriteable ());
               kinfu_.volume ().downloadTsdfAndWeighsLocal ();
 	      // tsdf_volume_.setHeader (Eigen::Vector3i (pcl::device::VOLUME_X, pcl::device::VOLUME_Y, pcl::device::VOLUME_Z), kinfu_.volume().getSize ());
               kinfu_.volume ().setHeader (Eigen::Vector3i (pcl::device::VOLUME_X, pcl::device::VOLUME_Y, pcl::device::VOLUME_Z), kinfu_.volume().getSize ());
-	      // cout << "done [" << tsdf_volume_.size () << " voxels]" << endl << endl;
-              cout << "done [" << kinfu_.volume ().size () << " voxels]" << endl << endl;
+	      // std::cout << "done [" << tsdf_volume_.size () << " voxels]" << std::endl << std::endl;
+              std::cout << "done [" << kinfu_.volume ().size () << " voxels]" << std::endl << std::endl;
 	    }
 	    {
 	      ScopeTimeT time ("converting");
-	      cout << "Converting volume to TSDF cloud ... " << flush;
+	      std::cout << "Converting volume to TSDF cloud ... " << flush;
 	      // tsdf_volume_.convertToTsdfCloud (tsdf_cloud_ptr_);
               kinfu_.volume ().convertToTsdfCloud (tsdf_cloud_ptr_);
-	      cout << "done [" << tsdf_cloud_ptr_->size () << " points]" << endl << endl;
+	      std::cout << "done [" << tsdf_cloud_ptr_->size () << " points]" << std::endl << std::endl;
 	    }
 	  }
 	  else
-	    cout << "[!] tsdf volume download is disabled" << endl << endl;
+	    std::cout << "[!] tsdf volume download is disabled" << std::endl << std::endl;
 	}
 
 	if (scan_mesh_)
@@ -1196,11 +1194,11 @@ struct KinFuApp
 	scene_cloud_view_.cloud_viewer_.spinOnce (3);    
 	
 	// As of April 2012, entering a key will end this program...
-	cout << "Paused after view\n";
+	std::cout << "Paused after view\n";
 	cin >> pause;      
       }
       double elapsed = (getTime() -tic_main);
-      cout << elapsed << " sec elapsed [" << (1/elapsed) << "]\n";          
+      std::cout << elapsed << " sec elapsed [" << (1/elapsed) << "]\n";          
       tic_toc.push_back (getTime ());
       display_tic_toc (tic_toc, "kinfu_app_sim");
     }
@@ -1241,23 +1239,23 @@ struct KinFuApp
   void
   printHelp ()
   {
-    cout << endl;
-    cout << "KinFu app hotkeys" << endl;
-    cout << "=================" << endl;
-    cout << "    H    : print this help" << endl;
-    cout << "   Esc   : exit" << endl;
-    cout << "    T    : take cloud" << endl;
-    cout << "    A    : take mesh" << endl;
-    cout << "    M    : toggle cloud exctraction mode" << endl;
-    cout << "    N    : toggle normals exctraction" << endl;
-    cout << "    I    : toggle independent camera mode" << endl;
-    cout << "    B    : toggle volume bounds" << endl;
-    cout << "    *    : toggle scene view painting ( requires registration mode )" << endl;
-    cout << "    C    : clear clouds" << endl;    
-    cout << "   1,2,3 : save cloud to PCD(binary), PCD(ASCII), PLY(ASCII)" << endl;
-    cout << "    7,8  : save mesh to PLY, VTK" << endl;
-    cout << "   X, V  : TSDF volume utility" << endl;
-    cout << endl;
+    std::cout << std::endl;
+    std::cout << "KinFu app hotkeys" << std::endl;
+    std::cout << "=================" << std::endl;
+    std::cout << "    H    : print this help" << std::endl;
+    std::cout << "   Esc   : exit" << std::endl;
+    std::cout << "    T    : take cloud" << std::endl;
+    std::cout << "    A    : take mesh" << std::endl;
+    std::cout << "    M    : toggle cloud exctraction mode" << std::endl;
+    std::cout << "    N    : toggle normals exctraction" << std::endl;
+    std::cout << "    I    : toggle independent camera mode" << std::endl;
+    std::cout << "    B    : toggle volume bounds" << std::endl;
+    std::cout << "    *    : toggle scene view painting ( requires registration mode )" << std::endl;
+    std::cout << "    C    : clear clouds" << std::endl;    
+    std::cout << "   1,2,3 : save cloud to PCD(binary), PCD(ASCII), PLY(ASCII)" << std::endl;
+    std::cout << "    7,8  : save mesh to PLY, VTK" << std::endl;
+    std::cout << "   X, V  : TSDF volume utility" << std::endl;
+    std::cout << std::endl;
   }  
 
   bool exit_;
@@ -1275,7 +1273,7 @@ struct KinFuApp
 
   SceneCloudView scene_cloud_view_;
   ImageView image_view_;
-  boost::shared_ptr<CurrentFrameCloudView> current_frame_cloud_view_;
+  CurrentFrameCloudView::Ptr current_frame_cloud_view_;
 
   KinfuTracker::DepthMap depth_device_;
 
@@ -1309,17 +1307,17 @@ struct KinFuApp
 
       case (int)'x': case (int)'X':
         app->scan_volume_ = !app->scan_volume_;
-        cout << endl << "Volume scan: " << (app->scan_volume_ ? "enabled" : "disabled") << endl << endl;
+        std::cout << std::endl << "Volume scan: " << (app->scan_volume_ ? "enabled" : "disabled") << std::endl << std::endl;
         break;
       case (int)'v': case (int)'V':
-        cout << "Saving TSDF volume to tsdf_volume.dat ... " << flush;
+        std::cout << "Saving TSDF volume to tsdf_volume.dat ... " << flush;
         // app->tsdf_volume_.save ("tsdf_volume.dat", true);
         app->kinfu_.volume ().save ("tsdf_volume.dat", true);
-        //cout << "done [" << app->tsdf_volume_.size () << " voxels]" << endl;
-        cout << "done [" << app->app->kinfu_.volume ().size () << " voxels]" << endl;
-        cout << "Saving TSDF volume cloud to tsdf_cloud.pcd ... " << flush;
+        //std::cout << "done [" << app->tsdf_volume_.size () << " voxels]" << std::endl;
+        std::cout << "done [" << app->app->kinfu_.volume ().size () << " voxels]" << std::endl;
+        std::cout << "Saving TSDF volume cloud to tsdf_cloud.pcd ... " << flush;
         pcl::io::savePCDFile<pcl::PointXYZI> ("tsdf_cloud.pcd", *app->tsdf_cloud_ptr_, true);
-        cout << "done [" << app->tsdf_cloud_ptr_->size () << " points]" << endl;
+        std::cout << "done [" << app->tsdf_cloud_ptr_->size () << " points]" << std::endl;
         break;
 
       default:
@@ -1335,22 +1333,22 @@ writeCloudFile (int format, const CloudPtr& cloud_prt)
 {
   if (format == KinFuApp::PCD_BIN)
   {
-    cout << "Saving point cloud to 'cloud_bin.pcd' (binary)... " << flush;
+    std::cout << "Saving point cloud to 'cloud_bin.pcd' (binary)... " << flush;
     pcl::io::savePCDFile ("cloud_bin.pcd", *cloud_prt, true);
   }
   else
   if (format == KinFuApp::PCD_ASCII)
   {
-    cout << "Saving point cloud to 'cloud.pcd' (ASCII)... " << flush;
+    std::cout << "Saving point cloud to 'cloud.pcd' (ASCII)... " << flush;
     pcl::io::savePCDFile ("cloud.pcd", *cloud_prt, false);
   }
   else   /* if (format == KinFuApp::PLY) */
   {
-    cout << "Saving point cloud to 'cloud.ply' (ASCII)... " << flush;
+    std::cout << "Saving point cloud to 'cloud.ply' (ASCII)... " << flush;
     pcl::io::savePLYFileASCII ("cloud.ply", *cloud_prt);
   
   }
-  cout << "Done" << endl;
+  std::cout << "Done" << std::endl;
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1358,19 +1356,19 @@ writeCloudFile (int format, const CloudPtr& cloud_prt)
 void
 writePolygonMeshFile (int format, const pcl::PolygonMesh& mesh)
 {
-    cout << "writePolygonMeshFile mf" << endl;
+    std::cout << "writePolygonMeshFile mf" << std::endl;
 
   if (format == KinFuApp::MESH_PLY)
   {
-    cout << "Saving mesh to to 'mesh.ply'... " << flush;
+    std::cout << "Saving mesh to to 'mesh.ply'... " << flush;
     pcl::io::savePLYFile("mesh.ply", mesh);		
   }
   else /* if (format == KinFuApp::MESH_VTK) */
   {
-    cout << "Saving mesh to to 'mesh.vtk'... " << flush;
+    std::cout << "Saving mesh to to 'mesh.vtk'... " << flush;
     pcl::io::saveVTKFile("mesh.vtk", mesh);    
   }  
-  cout << "Done" << endl;
+  std::cout << "Done" << std::endl;
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1378,20 +1376,20 @@ writePolygonMeshFile (int format, const pcl::PolygonMesh& mesh)
 int
 print_cli_help ()
 {
-  cout << "\nKinfu app concole parameters help:" << endl;
-  cout << "    --help, -h                      : print this message" << endl;  
-  cout << "    --registration, -r              : try to enable registration ( requires source to support this )" << endl;
-  cout << "    --current-cloud, -cc            : show current frame cloud" << endl;
-  cout << "    --save-views, -sv               : accumulate scene view and save in the end ( Requires OpenCV. Will cause 'bad_alloc' after some time )" << endl;  
-  cout << "    --registration, -r              : enable registration mode" << endl; 
-  cout << "    --integrate-colors, -ic         : enable color integration mode ( allows to get cloud with colors )" << endl;   
-  cout << "    -volume_suze <size_in_meters>   : define integration volume size" << endl;   
-  cout << "    -dev <device>, -oni <oni_file>  : select depth source. Default will be selected if not specified" << endl;
-  cout << "";
-  cout << " For RGBD benchmark (Requires OpenCV):" << endl; 
-  cout << "    -eval <eval_folder> [-match_file <associations_file_in_the_folder>]" << endl;
-  cout << " For Simuation (Requires pcl::simulation):" << endl; 
-  cout << "    -plyfile                        : path to ply file for simulation testing " << endl;
+  std::cout << "\nKinfu app concole parameters help:" << std::endl;
+  std::cout << "    --help, -h                      : print this message" << std::endl;  
+  std::cout << "    --registration, -r              : try to enable registration ( requires source to support this )" << std::endl;
+  std::cout << "    --current-cloud, -cc            : show current frame cloud" << std::endl;
+  std::cout << "    --save-views, -sv               : accumulate scene view and save in the end ( Requires OpenCV. Will cause 'bad_alloc' after some time )" << std::endl;  
+  std::cout << "    --registration, -r              : enable registration mode" << std::endl; 
+  std::cout << "    --integrate-colors, -ic         : enable color integration mode ( allows to get cloud with colors )" << std::endl;   
+  std::cout << "    -volume_suze <size_in_meters>   : define integration volume size" << std::endl;   
+  std::cout << "    -dev <device>, -oni <oni_file>  : select depth source. Default will be selected if not specified" << std::endl;
+  std::cout << "";
+  std::cout << " For RGBD benchmark (Requires OpenCV):" << std::endl; 
+  std::cout << "    -eval <eval_folder> [-match_file <associations_file_in_the_folder>]" << std::endl;
+  std::cout << " For Simuation (Requires pcl::simulation):" << std::endl; 
+  std::cout << "    -plyfile                        : path to ply file for simulation testing " << std::endl;
     
   return 0;
 }
@@ -1410,7 +1408,7 @@ main (int argc, char* argv[])
   pcl::gpu::printShortCudaDeviceInfo (device);
 
   if(checkIfPreFermiGPU(device))
-    return cout << endl << "Kinfu is not supported for pre-Fermi GPU architectures, and not built for them by default. Exiting..." << endl, 1;
+    return std::cout << std::endl << "Kinfu is not supported for pre-Fermi GPU architectures, and not built for them by default. Exiting..." << std::endl, 1;
 
   CaptureOpenNI capture;
   
@@ -1475,17 +1473,17 @@ main (int argc, char* argv[])
   
   // executing
   try { app.execute (argc, argv,plyfile); }
-  catch (const std::bad_alloc& /*e*/) { cout << "Bad alloc" << endl; }
-  catch (const std::exception& /*e*/) { cout << "Exception" << endl; }
+  catch (const std::bad_alloc& /*e*/) { std::cout << "Bad alloc" << std::endl; }
+  catch (const std::exception& /*e*/) { std::cout << "Exception" << std::endl; }
 
 #ifdef HAVE_OPENCV
-  for (size_t t = 0; t < app.image_view_.views_.size (); ++t)
+  for (std::size_t t = 0; t < app.image_view_.views_.size (); ++t)
   {
     if (t == 0)
     {
-      cout << "Saving depth map of first view." << endl;
+      std::cout << "Saving depth map of first view." << std::endl;
       cv::imwrite ("./depthmap_1stview.png", app.image_view_.views_[0]);
-      cout << "Saving sequence of (" << app.image_view_.views_.size () << ") views." << endl;
+      std::cout << "Saving sequence of (" << app.image_view_.views_.size () << ") views." << std::endl;
     }
     char buf[4096];
     sprintf (buf, "./%06d.png", (int)t);
