@@ -55,9 +55,9 @@
 using namespace std;
 namespace pc = pcl::console;
 
-typedef pcl::PointXYZ    PointT;
-typedef float            VoxelT;
-typedef short            WeightT;
+using PointT = pcl::PointXYZ;
+using VoxelT = float;
+using WeightT = short;
 
 string cloud_file  = "cloud.pcd";
 string volume_file = "tsdf_volume.dat";
@@ -75,8 +75,8 @@ class DeviceVolume
 {
 public:
 
-  typedef boost::shared_ptr<DeviceVolume>       Ptr;
-  typedef boost::shared_ptr<const DeviceVolume> ConstPtr;
+  using Ptr = shared_ptr<DeviceVolume>;
+  using ConstPtr = shared_ptr<const DeviceVolume>;
 
   /** \brief Constructor
    * param[in] volume_size size of the volume in mm
@@ -135,7 +135,7 @@ DeviceVolume::createFromDepth (const pcl::device::PtrStepSz<const unsigned short
 {
   using namespace pcl;
 
-  typedef Eigen::Matrix<float, 3, 3, Eigen::RowMajor> Matrix3frm;
+  using Matrix3frm = Eigen::Matrix<float, 3, 3, Eigen::RowMajor>;
 
   const int rows = 480;
   const int cols = 640;
@@ -168,14 +168,14 @@ DeviceVolume::getVolume (pcl::TSDFVolume<VoxelT, WeightT>::Ptr &volume)
 {
   int volume_size = device_volume_.rows() * device_volume_.cols();
 
-  if ((size_t)volume_size != volume->size())
+  if ((std::size_t)volume_size != volume->size())
   {
     pc::print_error ("Device volume size (%d) and tsdf volume size (%d) don't match. ABORTING!\n", volume_size, volume->size());
     return false;
   }
 
-  vector<VoxelT>&  volume_vec  = volume->volumeWriteable();
-  vector<WeightT>& weights_vec = volume->weightsWriteable();
+  std::vector<VoxelT>&  volume_vec  = volume->volumeWriteable();
+  std::vector<WeightT>& weights_vec = volume->weightsWriteable();
 
   device_volume_.download (&volume_vec[0], device_volume_.cols() * sizeof(int));
 
@@ -255,10 +255,10 @@ convertDepthRGBToCloud (const pcl::device::PtrStepSz<const unsigned short> &dept
       point.x = u * point.z;
       point.y = v * point.z;
 
-/*      uint8_t r = *(rgb24_row_ptr + 0);
-      uint8_t g = *(rgb24_row_ptr + 1);
-      uint8_t b = *(rgb24_row_ptr + 2);
-      uint32_t rgb = ((uint32_t)r << 16 | (uint32_t)g << 8 | (uint32_t)b);
+/*      std::uint8_t r = *(rgb24_row_ptr + 0);
+      std::uint8_t g = *(rgb24_row_ptr + 1);
+      std::uint8_t b = *(rgb24_row_ptr + 2);
+      std::uint32_t rgb = ((std::uint32_t)r << 16 | (std::uint32_t)g << 8 | (std::uint32_t)b);
       point.rgb = *reinterpret_cast<float*>(&rgb);
 
       point.r = *((const char*)rgb24.data + y*rgb24.step + x*rgb24.elem_size);
@@ -318,11 +318,11 @@ keyboard_callback (const pcl::visualization::KeyboardEvent &event, void *cookie)
       case 27:
       case (int)'q': case (int)'Q':
       case (int)'e': case (int)'E':
-        cout << "Exiting program" << endl;
+        std::cout << "Exiting program" << std::endl;
         quit = true;
         break;
       case (int)'s': case (int)'S':
-        cout << "Saving volume and cloud" << endl;
+        std::cout << "Saving volume and cloud" << std::endl;
         save = true;
         break;
       default:
@@ -448,7 +448,7 @@ main (int argc, char* argv[])
 
 
   // integrate depth in device volume
-  pc::print_highlight ("Converting depth map to volume ... "); cout << flush;
+  pc::print_highlight ("Converting depth map to volume ... "); std::cout << flush;
   device_volume->createFromDepth (depth, intr);
 
   // get volume from device
@@ -461,7 +461,7 @@ main (int argc, char* argv[])
 
 
   // generating TSDF cloud
-  pc::print_highlight ("Generating tsdf volume cloud ... "); cout << flush;
+  pc::print_highlight ("Generating tsdf volume cloud ... "); std::cout << flush;
   pcl::PointCloud<pcl::PointXYZI>::Ptr tsdf_cloud (new pcl::PointCloud<pcl::PointXYZI>);
   volume->convertToTsdfCloud (tsdf_cloud);
   pc::print_info ("done [%d points]\n", tsdf_cloud->size());
@@ -471,7 +471,7 @@ main (int argc, char* argv[])
   pcl::PointCloud<pcl::PointXYZ>::Ptr cloud_volume (new pcl::PointCloud<pcl::PointXYZ>);
   if (extract_cloud_volume)
   {
-    pc::print_highlight ("Generating cloud from volume ... "); cout << flush;
+    pc::print_highlight ("Generating cloud from volume ... "); std::cout << flush;
     if (!device_volume->getCloud (cloud_volume))
     {
       pc::print_error ("Cloudn't get cloud from device volume!\n");
@@ -491,7 +491,7 @@ main (int argc, char* argv[])
   pc::print_info ("Saving captured cloud to "); pc::print_value ("%s", cloud_file.c_str()); pc::print_info (" ... ");
   if (pcl::io::savePCDFile (cloud_file, *cloud, true) < 0)
   {
-    cout << endl;
+    std::cout << std::endl;
     pc::print_error ("Cloudn't save the point cloud to file %s.\n", cloud_file.c_str());
   }
   else
@@ -506,7 +506,7 @@ main (int argc, char* argv[])
   pc::print_info ("Saving volume cloud to "); pc::print_value ("%s", tsdf_cloud_file.c_str()); pc::print_info (" ... ");
   if (pcl::io::savePCDFile (tsdf_cloud_file, *tsdf_cloud, true) < 0)
   {
-    cout << endl;
+    std::cout << std::endl;
     pc::print_error ("Cloudn't save the volume point cloud to file %s.\n", tsdf_cloud_file.c_str());
   }
   else
@@ -519,7 +519,7 @@ main (int argc, char* argv[])
     pc::print_info ("Saving cloud from volume to "); pc::print_value ("%s", cloud_volume_file.c_str()); pc::print_info (" ... ");
     if (pcl::io::savePCDFile (cloud_volume_file, *cloud_volume, true) < 0)
     {
-      cout << endl;
+      std::cout << std::endl;
       pc::print_error ("Cloudn't save the point cloud to file %s.\n", cloud_volume_file.c_str());
     }
     else
