@@ -37,15 +37,14 @@
  * Authors: Julius Kammerl (julius@kammerl.de)
  */
 
-#ifndef PCL_ORGANIZED_CONVERSION_H_
-#define PCL_ORGANIZED_CONVERSION_H_
+#pragma once
 
 #include <pcl/pcl_macros.h>
 #include <pcl/point_cloud.h>
 
 #include <vector>
 #include <limits>
-#include <assert.h>
+#include <cassert>
 
 namespace pcl
 {
@@ -56,7 +55,7 @@ namespace pcl
     {
         static const bool hasColor = false;
         static const unsigned int channels = 1;
-        static const size_t bytesPerPoint = 3 * sizeof(float);
+        static const std::size_t bytesPerPoint = 3 * sizeof(float);
     };
 
     template<>
@@ -64,7 +63,7 @@ namespace pcl
     {
         static const bool hasColor = true;
         static const unsigned int channels = 4;
-        static const size_t bytesPerPoint = 3 * sizeof(float) + 3 * sizeof(uint8_t);
+        static const std::size_t bytesPerPoint = 3 * sizeof(float) + 3 * sizeof(std::uint8_t);
     };
 
     template<>
@@ -72,7 +71,7 @@ namespace pcl
     {
         static const bool hasColor = true;
         static const unsigned int channels = 4;
-        static const size_t bytesPerPoint = 3 * sizeof(float) + 3 * sizeof(uint8_t);
+        static const std::size_t bytesPerPoint = 3 * sizeof(float) + 3 * sizeof(std::uint8_t);
     };
 
     //////////////////////////////////////////////////////////////////////////////////////////////
@@ -98,19 +97,17 @@ namespace pcl
                           float disparityShift_arg,
                           float disparityScale_arg,
                           bool ,
-                          typename std::vector<uint16_t>& disparityData_arg,
-                          typename std::vector<uint8_t>&)
+                          typename std::vector<std::uint16_t>& disparityData_arg,
+                          typename std::vector<std::uint8_t>&)
       {
-        size_t cloud_size, i;
-
-        cloud_size = cloud_arg.points.size ();
+        std::size_t cloud_size = cloud_arg.points.size ();
 
         // Clear image data
         disparityData_arg.clear ();
 
         disparityData_arg.reserve (cloud_size);
 
-        for (i = 0; i < cloud_size; ++i)
+        for (std::size_t i = 0; i < cloud_size; ++i)
         {
           // Get point from cloud
           const PointT& point = cloud_arg.points[i];
@@ -118,7 +115,7 @@ namespace pcl
           if (pcl::isFinite (point))
           {
             // Inverse depth quantization
-            uint16_t disparity = static_cast<uint16_t> ( focalLength_arg / (disparityScale_arg * point.z) + disparityShift_arg / disparityScale_arg);
+            std::uint16_t disparity = static_cast<std::uint16_t> ( focalLength_arg / (disparityScale_arg * point.z) + disparityShift_arg / disparityScale_arg);
             disparityData_arg.push_back (disparity);
           }
           else
@@ -139,19 +136,17 @@ namespace pcl
         * \param[out] cloud_arg output point cloud
         * \ingroup io
         */
-      static void convert(typename std::vector<uint16_t>& disparityData_arg,
-                          typename std::vector<uint8_t>&,
+      static void convert(typename std::vector<std::uint16_t>& disparityData_arg,
+                          typename std::vector<std::uint8_t>&,
                           bool,
-                          size_t width_arg,
-                          size_t height_arg,
+                          std::size_t width_arg,
+                          std::size_t height_arg,
                           float focalLength_arg,
                           float disparityShift_arg,
                           float disparityScale_arg,
                           pcl::PointCloud<PointT>& cloud_arg)
       {
-        size_t i;
-        size_t cloud_size = width_arg * height_arg;
-        int x, y, centerX, centerY;
+        std::size_t cloud_size = width_arg * height_arg;
 
         assert(disparityData_arg.size()==cloud_size);
 
@@ -160,23 +155,23 @@ namespace pcl
         cloud_arg.points.reserve (cloud_size);
 
         // Define point cloud parameters
-        cloud_arg.width = static_cast<uint32_t> (width_arg);
-        cloud_arg.height = static_cast<uint32_t> (height_arg);
+        cloud_arg.width = static_cast<std::uint32_t> (width_arg);
+        cloud_arg.height = static_cast<std::uint32_t> (height_arg);
         cloud_arg.is_dense = false;
 
         // Calculate center of disparity image
-        centerX = static_cast<int> (width_arg / 2);
-        centerY = static_cast<int> (height_arg / 2);
+        int centerX = static_cast<int> (width_arg / 2);
+        int centerY = static_cast<int> (height_arg / 2);
 
         const float fl_const = 1.0f / focalLength_arg;
         static const float bad_point = std::numeric_limits<float>::quiet_NaN ();
 
-        i = 0;
-        for (y = -centerY; y < +centerY; ++y)
-          for (x = -centerX; x < +centerX; ++x)
+        std::size_t i = 0;
+        for (int y = -centerY; y < centerY; ++y )
+          for (int x = -centerX; x < centerX; ++x )
           {
             PointT newPoint;
-            const uint16_t& pixel_disparity = disparityData_arg[i];
+            const std::uint16_t& pixel_disparity = disparityData_arg[i];
             ++i;
 
             if (pixel_disparity)
@@ -211,16 +206,14 @@ namespace pcl
         * \ingroup io
         */
       static void convert(typename std::vector<float>& depthData_arg,
-                          typename std::vector<uint8_t>&,
+                          typename std::vector<std::uint8_t>&,
                           bool,
-                          size_t width_arg,
-                          size_t height_arg,
+                          std::size_t width_arg,
+                          std::size_t height_arg,
                           float focalLength_arg,
                           pcl::PointCloud<PointT>& cloud_arg)
       {
-        size_t i;
-        size_t cloud_size = width_arg * height_arg;
-        int x, y, centerX, centerY;
+        std::size_t cloud_size = width_arg * height_arg;
 
         assert(depthData_arg.size()==cloud_size);
 
@@ -229,20 +222,20 @@ namespace pcl
         cloud_arg.points.reserve (cloud_size);
 
         // Define point cloud parameters
-        cloud_arg.width = static_cast<uint32_t> (width_arg);
-        cloud_arg.height = static_cast<uint32_t> (height_arg);
+        cloud_arg.width = static_cast<std::uint32_t> (width_arg);
+        cloud_arg.height = static_cast<std::uint32_t> (height_arg);
         cloud_arg.is_dense = false;
 
         // Calculate center of disparity image
-        centerX = static_cast<int> (width_arg / 2);
-        centerY = static_cast<int> (height_arg / 2);
+        int centerX = static_cast<int> (width_arg / 2);
+        int centerY = static_cast<int> (height_arg / 2);
 
         const float fl_const = 1.0f / focalLength_arg;
         static const float bad_point = std::numeric_limits<float>::quiet_NaN ();
 
-        i = 0;
-        for (y = -centerY; y < +centerY; ++y)
-          for (x = -centerX; x < +centerX; ++x)
+        std::size_t i = 0;
+        for (int y = -centerY; y < centerY; ++y )
+          for (int x = -centerX; x < centerX; ++x )
           {
             PointT newPoint;
             const float& pixel_depth = depthData_arg[i];
@@ -293,12 +286,10 @@ namespace pcl
                           float disparityShift_arg,
                           float disparityScale_arg,
                           bool convertToMono,
-                          typename std::vector<uint16_t>& disparityData_arg,
-                          typename std::vector<uint8_t>& rgbData_arg)
+                          typename std::vector<std::uint16_t>& disparityData_arg,
+                          typename std::vector<std::uint8_t>& rgbData_arg)
       {
-        size_t cloud_size, i;
-
-        cloud_size = cloud_arg.points.size ();
+        std::size_t cloud_size = cloud_arg.points.size ();
 
         // Reset output vectors
         disparityData_arg.clear ();
@@ -315,7 +306,7 @@ namespace pcl
         }
 
 
-        for (i = 0; i < cloud_size; ++i)
+        for (std::size_t i = 0; i < cloud_size; ++i)
         {
           const PointT& point = cloud_arg.points[i];
 
@@ -324,7 +315,7 @@ namespace pcl
             if (convertToMono)
             {
               // Encode point color
-              uint8_t grayvalue = static_cast<uint8_t>(0.2989 * point.r
+              std::uint8_t grayvalue = static_cast<std::uint8_t>(0.2989 * point.r
                                                         + 0.5870 * point.g
                                                         + 0.1140 * point.b);
 
@@ -339,7 +330,7 @@ namespace pcl
 
 
             // Inverse depth quantization
-            uint16_t disparity = static_cast<uint16_t> (focalLength_arg / (disparityScale_arg * point.z) + disparityShift_arg / disparityScale_arg);
+            std::uint16_t disparity = static_cast<std::uint16_t> (focalLength_arg / (disparityScale_arg * point.z) + disparityShift_arg / disparityScale_arg);
 
             // Encode disparity
             disparityData_arg.push_back (disparity);
@@ -377,19 +368,18 @@ namespace pcl
         * \param[out] cloud_arg output point cloud
         * \ingroup io
         */
-      static void convert(typename std::vector<uint16_t>& disparityData_arg,
-                          typename std::vector<uint8_t>& rgbData_arg,
+      static void convert(typename std::vector<std::uint16_t>& disparityData_arg,
+                          typename std::vector<std::uint8_t>& rgbData_arg,
                           bool monoImage_arg,
-                          size_t width_arg,
-                          size_t height_arg,
+                          std::size_t width_arg,
+                          std::size_t height_arg,
                           float focalLength_arg,
                           float disparityShift_arg,
                           float disparityScale_arg,
                           pcl::PointCloud<PointT>& cloud_arg)
       {
-        size_t i;
-        size_t cloud_size = width_arg*height_arg;
-        bool hasColor = (rgbData_arg.size () > 0);
+        std::size_t cloud_size = width_arg*height_arg;
+        bool hasColor = (!rgbData_arg.empty ());
 
         // Check size of input data
         assert (disparityData_arg.size()==cloud_size);
@@ -404,31 +394,29 @@ namespace pcl
           }
         }
 
-        int x, y, centerX, centerY;
-
         // Reset point cloud
         cloud_arg.points.clear();
         cloud_arg.points.reserve(cloud_size);
 
         // Define point cloud parameters
-        cloud_arg.width = static_cast<uint32_t>(width_arg);
-        cloud_arg.height = static_cast<uint32_t>(height_arg);
+        cloud_arg.width = static_cast<std::uint32_t>(width_arg);
+        cloud_arg.height = static_cast<std::uint32_t>(height_arg);
         cloud_arg.is_dense = false;
 
         // Calculate center of disparity image
-        centerX = static_cast<int>(width_arg/2);
-        centerY = static_cast<int>(height_arg/2);
+        int centerX = static_cast<int>(width_arg/2);
+        int centerY = static_cast<int>(height_arg/2);
 
         const float fl_const = 1.0f/focalLength_arg;
         static const float bad_point = std::numeric_limits<float>::quiet_NaN ();
 
-        i = 0;
-        for (y=-centerY; y<+centerY; ++y )
-          for (x=-centerX; x<+centerX; ++x )
+        std::size_t i = 0;
+        for (int y = -centerY; y < centerY; ++y )
+          for (int x = -centerX; x < centerX; ++x )
           {
             PointT newPoint;
 
-            const uint16_t& pixel_disparity = disparityData_arg[i];
+            const std::uint16_t& pixel_disparity = disparityData_arg[i];
 
             if (pixel_disparity && (pixel_disparity!=0x7FF))
             {
@@ -485,16 +473,15 @@ namespace pcl
         * \ingroup io
         */
       static void convert(typename std::vector<float>& depthData_arg,
-                          typename std::vector<uint8_t>& rgbData_arg,
+                          typename std::vector<std::uint8_t>& rgbData_arg,
                           bool monoImage_arg,
-                          size_t width_arg,
-                          size_t height_arg,
+                          std::size_t width_arg,
+                          std::size_t height_arg,
                           float focalLength_arg,
                           pcl::PointCloud<PointT>& cloud_arg)
       {
-        size_t i;
-        size_t cloud_size = width_arg*height_arg;
-        bool hasColor = (rgbData_arg.size () > 0);
+        std::size_t cloud_size = width_arg*height_arg;
+        bool hasColor = (!rgbData_arg.empty ());
 
         // Check size of input data
         assert (depthData_arg.size()==cloud_size);
@@ -509,27 +496,25 @@ namespace pcl
           }
         }
 
-        int x, y, centerX, centerY;
-
         // Reset point cloud
         cloud_arg.points.clear();
         cloud_arg.points.reserve(cloud_size);
 
         // Define point cloud parameters
-        cloud_arg.width = static_cast<uint32_t>(width_arg);
-        cloud_arg.height = static_cast<uint32_t>(height_arg);
+        cloud_arg.width = static_cast<std::uint32_t>(width_arg);
+        cloud_arg.height = static_cast<std::uint32_t>(height_arg);
         cloud_arg.is_dense = false;
 
         // Calculate center of disparity image
-        centerX = static_cast<int>(width_arg/2);
-        centerY = static_cast<int>(height_arg/2);
+        int centerX = static_cast<int>(width_arg/2);
+        int centerY = static_cast<int>(height_arg/2);
 
         const float fl_const = 1.0f/focalLength_arg;
         static const float bad_point = std::numeric_limits<float>::quiet_NaN ();
 
-        i = 0;
-        for (y=-centerY; y<+centerY; ++y )
-          for (x=-centerX; x<+centerX; ++x )
+        std::size_t i = 0;
+        for (int y = -centerY; y < centerY; ++y )
+          for (int x = -centerX; x < centerX; ++x )
           {
             PointT newPoint;
 
@@ -582,6 +567,3 @@ namespace pcl
 
   }
 }
-
-
-#endif
