@@ -43,7 +43,7 @@
 #include <fstream>
 #include <fcntl.h>
 #include <string>
-#include <stdlib.h>
+#include <cstdlib>
 #include <pcl/console/print.h>
 #include <pcl/io/boost.h>
 #include <pcl/io/low_level_io.h>
@@ -62,22 +62,21 @@ pcl::PCDWriter::generateHeader (const pcl::PointCloud<PointT> &cloud, const int
          "\nVERSION 0.7"
          "\nFIELDS";
 
-  std::vector<pcl::PCLPointField> fields;
-  pcl::getFields (cloud, fields);
+  const auto fields = pcl::getFields<PointT> ();
  
   std::stringstream field_names, field_types, field_sizes, field_counts;
-  for (size_t i = 0; i < fields.size (); ++i)
+  for (const auto &field : fields)
   {
-    if (fields[i].name == "_")
+    if (field.name == "_")
       continue;
     // Add the regular dimension
-    field_names << " " << fields[i].name;
-    field_sizes << " " << pcl::getFieldSize (fields[i].datatype);
-    if ("rgb" == fields[i].name)
+    field_names << " " << field.name;
+    field_sizes << " " << pcl::getFieldSize (field.datatype);
+    if ("rgb" == field.name)
       field_types << " " << "U";
     else
-      field_types << " " << pcl::getFieldType (fields[i].datatype);
-    int count = abs (static_cast<int> (fields[i].count));
+      field_types << " " << pcl::getFieldType (field.datatype);
+    int count = std::abs (static_cast<int> (field.count));
     if (count == 0) count = 1;  // check for 0 counts (coming from older converter code)
     field_counts << " " << count;
   }
@@ -141,22 +140,21 @@ pcl::PCDWriter::writeBinary (const std::string &file_name,
   boost::interprocess::file_lock file_lock;
   setLockingPermissions (file_name, file_lock);
 
-  std::vector<pcl::PCLPointField> fields;
+  auto fields = pcl::getFields<PointT> ();
   std::vector<int> fields_sizes;
-  size_t fsize = 0;
-  size_t data_size = 0;
-  size_t nri = 0;
-  pcl::getFields (cloud, fields);
+  std::size_t fsize = 0;
+  std::size_t data_size = 0;
+  std::size_t nri = 0;
   // Compute the total size of the fields
-  for (size_t i = 0; i < fields.size (); ++i)
+  for (const auto &field : fields)
   {
-    if (fields[i].name == "_")
+    if (field.name == "_")
       continue;
     
-    int fs = fields[i].count * getFieldSize (fields[i].datatype);
+    int fs = field.count * getFieldSize (field.datatype);
     fsize += fs;
     fields_sizes.push_back (fs);
-    fields[nri++] = fields[i];
+    fields[nri++] = field;
   }
   fields.resize (nri);
   
@@ -185,7 +183,7 @@ pcl::PCDWriter::writeBinary (const std::string &file_name,
     return (-1);
   }
 
-  char *map = static_cast<char*> (::mmap (0, data_idx + data_size, PROT_WRITE, MAP_SHARED, fd, 0));
+  char *map = static_cast<char*> (::mmap (nullptr, data_idx + data_size, PROT_WRITE, MAP_SHARED, fd, 0));
   if (map == reinterpret_cast<char*> (-1)) //MAP_FAILED)
   {
     io::raw_close (fd);
@@ -200,12 +198,12 @@ pcl::PCDWriter::writeBinary (const std::string &file_name,
 
   // Copy the data
   char *out = &map[0] + data_idx;
-  for (size_t i = 0; i < cloud.points.size (); ++i)
+  for (std::size_t i = 0; i < cloud.points.size (); ++i)
   {
     int nrj = 0;
-    for (size_t j = 0; j < fields.size (); ++j)
+    for (const auto &field : fields)
     {
-      memcpy (out, reinterpret_cast<const char*> (&cloud.points[i]) + fields[j].offset, fields_sizes[nrj]);
+      memcpy (out, reinterpret_cast<const char*> (&cloud.points[i]) + field.offset, fields_sizes[nrj]);
       out += fields_sizes[nrj++];
     }
   }
@@ -274,21 +272,20 @@ pcl::PCDWriter::writeBinaryCompressed (const std::string &file_name,
   boost::interprocess::file_lock file_lock;
   setLockingPermissions (file_name, file_lock);
 
-  std::vector<pcl::PCLPointField> fields;
-  size_t fsize = 0;
-  size_t data_size = 0;
-  size_t nri = 0;
-  pcl::getFields (cloud, fields);
+  auto fields = pcl::getFields<PointT> ();
+  std::size_t fsize = 0;
+  std::size_t data_size = 0;
+  std::size_t nri = 0;
   std::vector<int> fields_sizes (fields.size ());
   // Compute the total size of the fields
-  for (size_t i = 0; i < fields.size (); ++i)
+  for (const auto &field : fields)
   {
-    if (fields[i].name == "_")
+    if (field.name == "_")
       continue;
     
-    fields_sizes[nri] = fields[i].count * pcl::getFieldSize (fields[i].datatype);
+    fields_sizes[nri] = field.count * pcl::getFieldSize (field.datatype);
     fsize += fields_sizes[nri];
-    fields[nri] = fields[i];
+    fields[nri] = field;
     ++nri;
   }
   fields_sizes.resize (nri);
@@ -299,10 +296,10 @@ pcl::PCDWriter::writeBinaryCompressed (const std::string &file_name,
 
   // If the data is to large the two 32 bit integers used to store the
   // compressed and uncompressed size will overflow.
-  if (data_size * 3 / 2 > std::numeric_limits<uint32_t>::max ())
+  if (data_size * 3 / 2 > std::numeric_limits<std::uint32_t>::max ())
   {
     PCL_ERROR ("[pcl::PCDWriter::writeBinaryCompressed] The input data exceeds the maximum size for compressed version 0.7 pcds of %l bytes.\n",
-               static_cast<size_t> (std::numeric_limits<uint32_t>::max ()) * 2 / 3);
+               static_cast<std::size_t> (std::numeric_limits<std::uint32_t>::max ()) * 2 / 3);
     return (-2);
   }
 
@@ -322,17 +319,17 @@ pcl::PCDWriter::writeBinaryCompressed (const std::string &file_name,
   //   pters[3] = &only_valid_data[offset_of_plane_RGB];
   //
   std::vector<char*> pters (fields.size ());
-  size_t toff = 0;
-  for (size_t i = 0; i < pters.size (); ++i)
+  std::size_t toff = 0;
+  for (std::size_t i = 0; i < pters.size (); ++i)
   {
     pters[i] = &only_valid_data[toff];
-    toff += static_cast<size_t>(fields_sizes[i]) * cloud.points.size();
+    toff += static_cast<std::size_t>(fields_sizes[i]) * cloud.points.size();
   }
   
   // Go over all the points, and copy the data in the appropriate places
-  for (size_t i = 0; i < cloud.points.size (); ++i)
+  for (std::size_t i = 0; i < cloud.points.size (); ++i)
   {
-    for (size_t j = 0; j < fields.size (); ++j)
+    for (std::size_t j = 0; j < fields.size (); ++j)
     {
       memcpy (pters[j], reinterpret_cast<const char*> (&cloud.points[i]) + fields[j].offset, fields_sizes[j]);
       // Increment the pointer
@@ -340,12 +337,12 @@ pcl::PCDWriter::writeBinaryCompressed (const std::string &file_name,
     }
   }
 
-  char* temp_buf = static_cast<char*> (malloc (static_cast<size_t> (static_cast<float> (data_size) * 1.5f + 8.0f)));
+  char* temp_buf = static_cast<char*> (malloc (static_cast<std::size_t> (static_cast<float> (data_size) * 1.5f + 8.0f)));
   // Compress the valid data
   unsigned int compressed_size = pcl::lzfCompress (only_valid_data, 
-                                                   static_cast<uint32_t> (data_size), 
+                                                   static_cast<std::uint32_t> (data_size), 
                                                    &temp_buf[8], 
-                                                   static_cast<uint32_t> (static_cast<float>(data_size) * 1.5f));
+                                                   static_cast<std::uint32_t> (static_cast<float>(data_size) * 1.5f));
   unsigned int compressed_final_size = 0;
   // Was the compression successful?
   if (compressed_size)
@@ -354,7 +351,7 @@ pcl::PCDWriter::writeBinaryCompressed (const std::string &file_name,
     memcpy (&header[0], &compressed_size, sizeof (unsigned int));
     memcpy (&header[4], &data_size, sizeof (unsigned int));
     data_size = compressed_size + 8;
-    compressed_final_size = static_cast<uint32_t> (data_size) + data_idx;
+    compressed_final_size = static_cast<std::uint32_t> (data_size) + data_idx;
   }
   else
   {
@@ -384,7 +381,7 @@ pcl::PCDWriter::writeBinaryCompressed (const std::string &file_name,
     return (-1);
   }
 
-  char *map = static_cast<char*> (::mmap (0, compressed_final_size, PROT_WRITE, MAP_SHARED, fd, 0));
+  char *map = static_cast<char*> (::mmap (nullptr, compressed_final_size, PROT_WRITE, MAP_SHARED, fd, 0));
   if (map == reinterpret_cast<char*> (-1)) //MAP_FAILED)
   {
     io::raw_close (fd);
@@ -464,8 +461,7 @@ pcl::PCDWriter::writeASCII (const std::string &file_name, const pcl::PointCloud<
   fs.precision (precision);
   fs.imbue (std::locale::classic ());
 
-  std::vector<pcl::PCLPointField> fields;
-  pcl::getFields (cloud, fields);
+  const auto fields = pcl::getFields<PointT> ();
 
   // Write the header information
   fs << generateHeader<PointT> (cloud) << "DATA ascii\n";
@@ -474,9 +470,9 @@ pcl::PCDWriter::writeASCII (const std::string &file_name, const pcl::PointCloud<
   stream.precision (precision);
   stream.imbue (std::locale::classic ());
   // Iterate through the points
-  for (size_t i = 0; i < cloud.points.size (); ++i)
+  for (std::size_t i = 0; i < cloud.points.size (); ++i)
   {
-    for (size_t d = 0; d < fields.size (); ++d)
+    for (std::size_t d = 0; d < fields.size (); ++d)
     {
       // Ignore invalid padded dimensions that are inherited from binary data
       if (fields[d].name == "_")
@@ -492,62 +488,44 @@ pcl::PCDWriter::writeASCII (const std::string &file_name, const pcl::PointCloud<
         {
           case pcl::PCLPointField::INT8:
           {
-            int8_t value;
-            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (int8_t), sizeof (int8_t));
-            if (pcl_isnan (value))
-              stream << "nan";
-            else
-              stream << boost::numeric_cast<uint32_t>(value);
+            std::int8_t value;
+            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (std::int8_t), sizeof (std::int8_t));
+            stream << boost::numeric_cast<std::int32_t>(value);
             break;
           }
           case pcl::PCLPointField::UINT8:
           {
-            uint8_t value;
-            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (uint8_t), sizeof (uint8_t));
-            if (pcl_isnan (value))
-              stream << "nan";
-            else
-              stream << boost::numeric_cast<uint32_t>(value);
+            std::uint8_t value;
+            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (std::uint8_t), sizeof (std::uint8_t));
+            stream << boost::numeric_cast<std::uint32_t>(value);
             break;
           }
           case pcl::PCLPointField::INT16:
           {
-            int16_t value;
-            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (int16_t), sizeof (int16_t));
-            if (pcl_isnan (value))
-              stream << "nan";
-            else
-              stream << boost::numeric_cast<int16_t>(value);
+            std::int16_t value;
+            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (std::int16_t), sizeof (std::int16_t));
+            stream << boost::numeric_cast<std::int16_t>(value);
             break;
           }
           case pcl::PCLPointField::UINT16:
           {
-            uint16_t value;
-            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (uint16_t), sizeof (uint16_t));
-            if (pcl_isnan (value))
-              stream << "nan";
-            else
-              stream << boost::numeric_cast<uint16_t>(value);
+            std::uint16_t value;
+            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (std::uint16_t), sizeof (std::uint16_t));
+            stream << boost::numeric_cast<std::uint16_t>(value);
             break;
           }
           case pcl::PCLPointField::INT32:
           {
-            int32_t value;
-            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (int32_t), sizeof (int32_t));
-            if (pcl_isnan (value))
-              stream << "nan";
-            else
-              stream << boost::numeric_cast<int32_t>(value);
+            std::int32_t value;
+            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (std::int32_t), sizeof (std::int32_t));
+            stream << boost::numeric_cast<std::int32_t>(value);
             break;
           }
           case pcl::PCLPointField::UINT32:
           {
-            uint32_t value;
-            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (uint32_t), sizeof (uint32_t));
-            if (pcl_isnan (value))
-              stream << "nan";
-            else
-              stream << boost::numeric_cast<uint32_t>(value);
+            std::uint32_t value;
+            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (std::uint32_t), sizeof (std::uint32_t));
+            stream << boost::numeric_cast<std::uint32_t>(value);
             break;
           }
           case pcl::PCLPointField::FLOAT32:
@@ -559,30 +537,24 @@ pcl::PCDWriter::writeASCII (const std::string &file_name, const pcl::PointCloud<
              */
             if ("rgb" == fields[d].name)
             {
-              uint32_t value;
+              std::uint32_t value;
               memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (float), sizeof (float));
-              if (pcl_isnan (value))
-                stream << "nan";
-              else
-                stream << boost::numeric_cast<uint32_t>(value);
+              stream << boost::numeric_cast<std::uint32_t>(value);
               break;
             }
+            float value;
+            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (float), sizeof (float));
+            if (std::isnan (value))
+              stream << "nan";
             else
-            {
-              float value;
-              memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (float), sizeof (float));
-              if (pcl_isnan (value))
-                stream << "nan";
-              else
-                stream << boost::numeric_cast<float>(value);
-            }
+              stream << boost::numeric_cast<float>(value);
             break;
           }
           case pcl::PCLPointField::FLOAT64:
           {
             double value;
             memcpy (&value, reinterpret_cast<const char*> (&cloud.points[i]) + fields[d].offset + c * sizeof (double), sizeof (double));
-            if (pcl_isnan (value))
+            if (std::isnan (value))
               stream << "nan";
             else
               stream << boost::numeric_cast<double>(value);
@@ -645,22 +617,21 @@ pcl::PCDWriter::writeBinary (const std::string &file_name,
   boost::interprocess::file_lock file_lock;
   setLockingPermissions (file_name, file_lock);
 
-  std::vector<pcl::PCLPointField> fields;
+  auto fields = pcl::getFields<PointT> ();
   std::vector<int> fields_sizes;
-  size_t fsize = 0;
-  size_t data_size = 0;
-  size_t nri = 0;
-  pcl::getFields (cloud, fields);
+  std::size_t fsize = 0;
+  std::size_t data_size = 0;
+  std::size_t nri = 0;
   // Compute the total size of the fields
-  for (size_t i = 0; i < fields.size (); ++i)
+  for (const auto &field : fields)
   {
-    if (fields[i].name == "_")
+    if (field.name == "_")
       continue;
     
-    int fs = fields[i].count * getFieldSize (fields[i].datatype);
+    int fs = field.count * getFieldSize (field.datatype);
     fsize += fs;
     fields_sizes.push_back (fs);
-    fields[nri++] = fields[i];
+    fields[nri++] = field;
   }
   fields.resize (nri);
   
@@ -684,7 +655,7 @@ pcl::PCDWriter::writeBinary (const std::string &file_name,
     return (-1);
   }
 
-  char *map = static_cast<char*> (::mmap (0, data_idx + data_size, PROT_WRITE, MAP_SHARED, fd, 0));
+  char *map = static_cast<char*> (::mmap (nullptr, data_idx + data_size, PROT_WRITE, MAP_SHARED, fd, 0));
   if (map == reinterpret_cast<char*> (-1)) //MAP_FAILED)
   {
     io::raw_close (fd);
@@ -699,12 +670,12 @@ pcl::PCDWriter::writeBinary (const std::string &file_name,
 
   char *out = &map[0] + data_idx;
   // Copy the data
-  for (size_t i = 0; i < indices.size (); ++i)
+  for (const int &index : indices)
   {
     int nrj = 0;
-    for (size_t j = 0; j < fields.size (); ++j)
+    for (const auto &field : fields)
     {
-      memcpy (out, reinterpret_cast<const char*> (&cloud.points[indices[i]]) + fields[j].offset, fields_sizes[nrj]);
+      memcpy (out, reinterpret_cast<const char*> (&cloud.points[index]) + field.offset, fields_sizes[nrj]);
       out += fields_sizes[nrj++];
     }
   }
@@ -772,8 +743,7 @@ pcl::PCDWriter::writeASCII (const std::string &file_name,
   fs.precision (precision);
   fs.imbue (std::locale::classic ());
 
-  std::vector<pcl::PCLPointField> fields;
-  pcl::getFields (cloud, fields);
+  const auto fields = pcl::getFields<PointT> ();
 
   // Write the header information
   fs << generateHeader<PointT> (cloud, static_cast<int> (indices.size ())) << "DATA ascii\n";
@@ -783,9 +753,9 @@ pcl::PCDWriter::writeASCII (const std::string &file_name,
   stream.imbue (std::locale::classic ());
 
   // Iterate through the points
-  for (size_t i = 0; i < indices.size (); ++i)
+  for (const int &index : indices)
   {
-    for (size_t d = 0; d < fields.size (); ++d)
+    for (std::size_t d = 0; d < fields.size (); ++d)
     {
       // Ignore invalid padded dimensions that are inherited from binary data
       if (fields[d].name == "_")
@@ -801,62 +771,44 @@ pcl::PCDWriter::writeASCII (const std::string &file_name,
         {
           case pcl::PCLPointField::INT8:
           {
-            int8_t value;
-            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[indices[i]]) + fields[d].offset + c * sizeof (int8_t), sizeof (int8_t));
-            if (pcl_isnan (value))
-              stream << "nan";
-            else
-              stream << boost::numeric_cast<uint32_t>(value);
+            std::int8_t value;
+            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[index]) + fields[d].offset + c * sizeof (std::int8_t), sizeof (std::int8_t));
+            stream << boost::numeric_cast<std::int32_t>(value);
             break;
           }
           case pcl::PCLPointField::UINT8:
           {
-            uint8_t value;
-            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[indices[i]]) + fields[d].offset + c * sizeof (uint8_t), sizeof (uint8_t));
-            if (pcl_isnan (value))
-              stream << "nan";
-            else
-              stream << boost::numeric_cast<uint32_t>(value);
+            std::uint8_t value;
+            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[index]) + fields[d].offset + c * sizeof (std::uint8_t), sizeof (std::uint8_t));
+            stream << boost::numeric_cast<std::uint32_t>(value);
             break;
           }
           case pcl::PCLPointField::INT16:
           {
-            int16_t value;
-            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[indices[i]]) + fields[d].offset + c * sizeof (int16_t), sizeof (int16_t));
-            if (pcl_isnan (value))
-              stream << "nan";
-            else
-              stream << boost::numeric_cast<int16_t>(value);
+            std::int16_t value;
+            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[index]) + fields[d].offset + c * sizeof (std::int16_t), sizeof (std::int16_t));
+            stream << boost::numeric_cast<std::int16_t>(value);
             break;
           }
           case pcl::PCLPointField::UINT16:
           {
-            uint16_t value;
-            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[indices[i]]) + fields[d].offset + c * sizeof (uint16_t), sizeof (uint16_t));
-            if (pcl_isnan (value))
-              stream << "nan";
-            else
-              stream << boost::numeric_cast<uint16_t>(value);
+            std::uint16_t value;
+            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[index]) + fields[d].offset + c * sizeof (std::uint16_t), sizeof (std::uint16_t));
+            stream << boost::numeric_cast<std::uint16_t>(value);
             break;
           }
           case pcl::PCLPointField::INT32:
           {
-            int32_t value;
-            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[indices[i]]) + fields[d].offset + c * sizeof (int32_t), sizeof (int32_t));
-            if (pcl_isnan (value))
-              stream << "nan";
-            else
-              stream << boost::numeric_cast<int32_t>(value);
+            std::int32_t value;
+            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[index]) + fields[d].offset + c * sizeof (std::int32_t), sizeof (std::int32_t));
+            stream << boost::numeric_cast<std::int32_t>(value);
             break;
           }
           case pcl::PCLPointField::UINT32:
           {
-            uint32_t value;
-            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[indices[i]]) + fields[d].offset + c * sizeof (uint32_t), sizeof (uint32_t));
-            if (pcl_isnan (value))
-              stream << "nan";
-            else
-              stream << boost::numeric_cast<uint32_t>(value);
+            std::uint32_t value;
+            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[index]) + fields[d].offset + c * sizeof (std::uint32_t), sizeof (std::uint32_t));
+            stream << boost::numeric_cast<std::uint32_t>(value);
             break;
           }
           case pcl::PCLPointField::FLOAT32:
@@ -868,18 +820,15 @@ pcl::PCDWriter::writeASCII (const std::string &file_name,
              */
             if ("rgb" == fields[d].name)
             {
-              uint32_t value;
-              memcpy (&value, reinterpret_cast<const char*> (&cloud.points[indices[i]]) + fields[d].offset + c * sizeof (float), sizeof (float));
-              if (pcl_isnan (value))
-                stream << "nan";
-              else
-                stream << boost::numeric_cast<uint32_t>(value);
+              std::uint32_t value;
+              memcpy (&value, reinterpret_cast<const char*> (&cloud.points[index]) + fields[d].offset + c * sizeof (float), sizeof (float));
+              stream << boost::numeric_cast<std::uint32_t>(value);
             }
             else
             {
               float value;
-              memcpy (&value, reinterpret_cast<const char*> (&cloud.points[indices[i]]) + fields[d].offset + c * sizeof (float), sizeof (float));
-              if (pcl_isnan (value))
+              memcpy (&value, reinterpret_cast<const char*> (&cloud.points[index]) + fields[d].offset + c * sizeof (float), sizeof (float));
+              if (std::isnan (value))
                 stream << "nan";
               else
                 stream << boost::numeric_cast<float>(value);
@@ -889,8 +838,8 @@ pcl::PCDWriter::writeASCII (const std::string &file_name,
           case pcl::PCLPointField::FLOAT64:
           {
             double value;
-            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[indices[i]]) + fields[d].offset + c * sizeof (double), sizeof (double));
-            if (pcl_isnan (value))
+            memcpy (&value, reinterpret_cast<const char*> (&cloud.points[index]) + fields[d].offset + c * sizeof (double), sizeof (double));
+            if (std::isnan (value))
               stream << "nan";
             else
               stream << boost::numeric_cast<double>(value);
