@@ -205,7 +205,7 @@ pcl::EnsensoGrabber::start ()
 
   frequency_.reset ();
   running_ = true;
-  grabber_thread_ = boost::thread (&pcl::EnsensoGrabber::processGrabbing, this);
+  grabber_thread_ = std::thread (&pcl::EnsensoGrabber::processGrabbing, this);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -324,7 +324,7 @@ pcl::EnsensoGrabber::grabSingleCloud (pcl::PointCloud<pcl::PointXYZ> &cloud)
     cloud.is_dense = false;
 
     // Copy data in point cloud (and convert millimeters in meters)
-    for (size_t i = 0; i < pointMap.size (); i += 3)
+    for (std::size_t i = 0; i < pointMap.size (); i += 3)
     {
       cloud.points[i / 3].x = pointMap[i] / 1000.0;
       cloud.points[i / 3].y = pointMap[i + 1] / 1000.0;
@@ -461,7 +461,7 @@ pcl::EnsensoGrabber::computeCalibrationMatrix (const std::vector<Eigen::Affine3d
     std::vector<Eigen::Affine3d, Eigen::aligned_allocator<Eigen::Affine3d> > robot_poses_mm (robot_poses);
     std::vector<std::string> robot_poses_json;
     robot_poses_json.resize (robot_poses.size ());
-    for (size_t i = 0; i < robot_poses_json.size (); ++i)
+    for (std::size_t i = 0; i < robot_poses_json.size (); ++i)
     {
       robot_poses_mm[i].translation () *= 1000.0; // Convert meters in millimeters
       if (!matrixTransformationToJson (robot_poses_mm[i], robot_poses_json[i]))
@@ -506,7 +506,7 @@ pcl::EnsensoGrabber::computeCalibrationMatrix (const std::vector<Eigen::Affine3d
     }
 
     // Feed all robot poses into the calibration command
-    for (size_t i = 0; i < robot_poses_json.size (); ++i)
+    for (std::size_t i = 0; i < robot_poses_json.size (); ++i)
     {
       // Very weird behavior here:
       // If you modify this loop, check that all the transformations are still here in the [itmExecute][itmParameters] node
@@ -638,7 +638,7 @@ pcl::EnsensoGrabber::setExtrinsicCalibration (const Eigen::Affine3d &transformat
 float
 pcl::EnsensoGrabber::getFramesPerSecond () const
 {
-  boost::mutex::scoped_lock lock (fps_mutex_);
+  std::lock_guard<std::mutex> lock (fps_mutex_);
   return (frequency_.getFrequency ());
 }
 
@@ -929,7 +929,7 @@ pcl::EnsensoGrabber::matrixTransformationToJson (const Eigen::Affine3d &matrix,
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-pcl::uint64_t
+std::uint64_t
 pcl::EnsensoGrabber::getPCLStamp (const double ensenso_stamp)
 {
 #if defined _WIN32 || defined _WIN64
@@ -963,7 +963,7 @@ pcl::EnsensoGrabber::processGrabbing ()
       if (num_slots<sig_cb_ensenso_point_cloud> () > 0 || num_slots<sig_cb_ensenso_images> () > 0 || num_slots<sig_cb_ensenso_point_cloud_images> () > 0)
       {
         pcl::PointCloud<pcl::PointXYZ>::Ptr cloud (new pcl::PointCloud<pcl::PointXYZ>);
-        boost::shared_ptr<PairOfImages> images (new PairOfImages);
+        shared_ptr<PairOfImages> images (new PairOfImages);
 
         fps_mutex_.lock ();
         frequency_.event ();
@@ -1044,7 +1044,7 @@ pcl::EnsensoGrabber::processGrabbing ()
           cloud->is_dense = false;
 
           // Copy data in point cloud (and convert millimeters in meters)
-          for (size_t i = 0; i < pointMap.size (); i += 3)
+          for (std::size_t i = 0; i < pointMap.size (); i += 3)
           {
             cloud->points[i / 3].x = pointMap[i] / 1000.0;
             cloud->points[i / 3].y = pointMap[i + 1] / 1000.0;
