@@ -32,11 +32,7 @@
 #include <OpenNI.h>
 #include <PS1080.h> // For XN_STREAM_PROPERTY_EMITTER_DCMOS_DISTANCE property
 
-#include <boost/shared_ptr.hpp>
-#include <boost/make_shared.hpp>
-#include <boost/lexical_cast.hpp>
 #include <boost/algorithm/string/replace.hpp>
-#include <boost/chrono.hpp>
 
 #include "pcl/io/openni2/openni2_device.h"
 #include "pcl/io/openni2/openni2_convert.h"
@@ -52,10 +48,7 @@ using namespace pcl::io::openni2;
 using openni::VideoMode;
 using std::vector;
 
-typedef boost::chrono::high_resolution_clock hr_clock;
-
 pcl::io::openni2::OpenNI2Device::OpenNI2Device (const std::string& device_URI) :
-  openni_device_(),
   ir_video_started_(false),
   color_video_started_(false),
   depth_video_started_(false)
@@ -64,7 +57,7 @@ pcl::io::openni2::OpenNI2Device::OpenNI2Device (const std::string& device_URI) :
   if (status != openni::STATUS_OK)
     THROW_IO_EXCEPTION ("Initialize failed\n%s\n", OpenNI::getExtendedError ());
 
-  openni_device_ = boost::make_shared<openni::Device>();
+  openni_device_.reset (new openni::Device);
 
   if (device_URI.length () > 0)
     status = openni_device_->open (device_URI.c_str ());
@@ -108,12 +101,12 @@ pcl::io::openni2::OpenNI2Device::OpenNI2Device (const std::string& device_URI) :
     openni_device_->getPlaybackControl ()->setSpeed (1.0f);
   }
 
-  device_info_ = boost::make_shared<openni::DeviceInfo>();
+  device_info_.reset (new openni::DeviceInfo);
   *device_info_ = openni_device_->getDeviceInfo ();
 
-  color_frame_listener = boost::make_shared<OpenNI2FrameListener>();
-  depth_frame_listener = boost::make_shared<OpenNI2FrameListener>();
-  ir_frame_listener    = boost::make_shared<OpenNI2FrameListener>();
+  color_frame_listener.reset (new OpenNI2FrameListener);
+  depth_frame_listener.reset (new OpenNI2FrameListener);
+  ir_frame_listener.reset (new OpenNI2FrameListener);
 }
 
 pcl::io::openni2::OpenNI2Device::~OpenNI2Device ()
@@ -143,13 +136,13 @@ pcl::io::openni2::OpenNI2Device::getName () const
   return (std::string (device_info_->getName ()));
 }
 
-uint16_t
+std::uint16_t
 pcl::io::openni2::OpenNI2Device::getUsbVendorId () const
 {
   return (device_info_->getUsbVendorId ());
 }
 
-uint16_t
+std::uint16_t
 pcl::io::openni2::OpenNI2Device::getUsbProductId () const
 {
   return (device_info_->getUsbProductId ());
@@ -170,13 +163,13 @@ pcl::io::openni2::OpenNI2Device::getStringID () const
 bool
 pcl::io::openni2::OpenNI2Device::isValid () const
 {
-  return (openni_device_.get () != 0) && openni_device_->isValid ();
+  return (openni_device_.get () != nullptr) && openni_device_->isValid ();
 }
 
 float
 pcl::io::openni2::OpenNI2Device::getIRFocalLength () const
 {
-  boost::shared_ptr<openni::VideoStream> stream = getIRVideoStream ();
+  auto stream = getIRVideoStream ();
 
   int frameWidth = stream->getVideoMode ().getResolutionX ();
   float hFov = stream->getHorizontalFieldOfView ();
@@ -187,7 +180,7 @@ pcl::io::openni2::OpenNI2Device::getIRFocalLength () const
 float
 pcl::io::openni2::OpenNI2Device::getColorFocalLength () const
 {
-  boost::shared_ptr<openni::VideoStream> stream = getColorVideoStream ();
+  auto stream = getColorVideoStream ();
 
   int frameWidth = stream->getVideoMode ().getResolutionX ();
   float hFov = stream->getHorizontalFieldOfView ();
@@ -198,7 +191,7 @@ pcl::io::openni2::OpenNI2Device::getColorFocalLength () const
 float
 pcl::io::openni2::OpenNI2Device::getDepthFocalLength () const
 {
-  boost::shared_ptr<openni::VideoStream> stream = getDepthVideoStream ();
+  auto stream = getDepthVideoStream ();
 
   int frameWidth = stream->getVideoMode ().getResolutionX ();
   float hFov = stream->getHorizontalFieldOfView ();
@@ -212,7 +205,7 @@ pcl::io::openni2::OpenNI2Device::getBaseline()
   return (baseline_);
 }
 
-uint64_t
+std::uint64_t
 pcl::io::openni2::OpenNI2Device::getShadowValue()
 {
   return (shadow_value_);
@@ -296,9 +289,7 @@ pcl::io::openni2::OpenNI2Device::hasDepthSensor () const
 void
 pcl::io::openni2::OpenNI2Device::startIRStream ()
 {
-  boost::shared_ptr<openni::VideoStream> stream = getIRVideoStream ();
-
-  if (stream)
+  if (auto stream = getIRVideoStream ())
   {
     stream->setMirroringEnabled (false);
     stream->addNewFrameListener (ir_frame_listener.get ());
@@ -310,9 +301,7 @@ pcl::io::openni2::OpenNI2Device::startIRStream ()
 void
 pcl::io::openni2::OpenNI2Device::startColorStream ()
 {
-  boost::shared_ptr<openni::VideoStream> stream = getColorVideoStream ();
-
-  if (stream)
+  if (auto stream = getColorVideoStream ())
   {
     stream->setMirroringEnabled (false);
     stream->addNewFrameListener (color_frame_listener.get ());
@@ -323,9 +312,7 @@ pcl::io::openni2::OpenNI2Device::startColorStream ()
 void
 pcl::io::openni2::OpenNI2Device::startDepthStream ()
 {
-  boost::shared_ptr<openni::VideoStream> stream = getDepthVideoStream ();
-
-  if (stream)
+  if (auto stream = getDepthVideoStream ())
   {
     stream->setMirroringEnabled (false);
     stream->addNewFrameListener (depth_frame_listener.get ());
@@ -345,7 +332,7 @@ pcl::io::openni2::OpenNI2Device::stopAllStreams ()
 void
 pcl::io::openni2::OpenNI2Device::stopIRStream ()
 {
-  if (ir_video_stream_.get () != 0)
+  if (ir_video_stream_.get () != nullptr)
   {
     ir_video_stream_->stop ();
     ir_video_started_ = false;
@@ -354,7 +341,7 @@ pcl::io::openni2::OpenNI2Device::stopIRStream ()
 void
 pcl::io::openni2::OpenNI2Device::stopColorStream ()
 {
-  if (color_video_stream_.get () != 0)
+  if (color_video_stream_.get () != nullptr)
   {
     color_video_stream_->stop ();
     color_video_started_ = false;
@@ -363,7 +350,7 @@ pcl::io::openni2::OpenNI2Device::stopColorStream ()
 void
 pcl::io::openni2::OpenNI2Device::stopDepthStream ()
 {
-  if (depth_video_stream_.get () != 0)
+  if (depth_video_stream_.get () != nullptr)
   {
     depth_video_stream_->stop ();
     depth_video_started_ = false;
@@ -373,13 +360,13 @@ pcl::io::openni2::OpenNI2Device::stopDepthStream ()
 void
 pcl::io::openni2::OpenNI2Device::shutdown ()
 {
-  if (ir_video_stream_.get () != 0)
+  if (ir_video_stream_.get () != nullptr)
     ir_video_stream_->destroy ();
 
-  if (color_video_stream_.get () != 0)
+  if (color_video_stream_.get () != nullptr)
     color_video_stream_->destroy ();
 
-  if (depth_video_stream_.get () != 0)
+  if (depth_video_stream_.get () != nullptr)
     depth_video_stream_->destroy ();
 
 }
@@ -444,66 +431,34 @@ pcl::io::openni2::OpenNI2Device::setSynchronization (bool enabled)
 const OpenNI2VideoMode
 pcl::io::openni2::OpenNI2Device::getIRVideoMode ()
 {
-  OpenNI2VideoMode ret;
-
-  boost::shared_ptr<openni::VideoStream> stream = getIRVideoStream ();
-
-  if (stream)
-  {
-    openni::VideoMode video_mode = stream->getVideoMode ();
-
-    ret = openniModeToGrabberMode (video_mode);
-  }
-  else
-    THROW_IO_EXCEPTION ("Could not create video stream.");
-
-  return (ret);
+  if (auto stream = getIRVideoStream ())
+    return openniModeToGrabberMode (stream->getVideoMode ());
+  THROW_IO_EXCEPTION ("Could not create video stream.");
+  return {};
 }
 
 const OpenNI2VideoMode
 pcl::io::openni2::OpenNI2Device::getColorVideoMode ()
 {
-  OpenNI2VideoMode ret;
-
-  boost::shared_ptr<openni::VideoStream> stream = getColorVideoStream ();
-
-  if (stream)
-  {
-    openni::VideoMode video_mode = stream->getVideoMode ();
-
-    ret = openniModeToGrabberMode (video_mode);
-  }
-  else
-    THROW_IO_EXCEPTION ("Could not create video stream.");
-
-  return (ret);
+  if (auto stream = getColorVideoStream ())
+    return openniModeToGrabberMode (stream->getVideoMode ());
+  THROW_IO_EXCEPTION ("Could not create video stream.");
+  return {};
 }
 
 const OpenNI2VideoMode
 pcl::io::openni2::OpenNI2Device::getDepthVideoMode ()
 {
-  OpenNI2VideoMode ret;
-
-  boost::shared_ptr<openni::VideoStream> stream = getDepthVideoStream ();
-
-  if (stream)
-  {
-    openni::VideoMode video_mode = stream->getVideoMode ();
-
-    ret = openniModeToGrabberMode (video_mode);
-  }
-  else
-    THROW_IO_EXCEPTION ("Could not create video stream.");
-
-  return (ret);
+  if (auto stream = getDepthVideoStream ())
+    return openniModeToGrabberMode (stream->getVideoMode ());
+  THROW_IO_EXCEPTION ("Could not create video stream.");
+  return {};
 }
 
 void
 pcl::io::openni2::OpenNI2Device::setIRVideoMode (const OpenNI2VideoMode& video_mode)
 {
-  boost::shared_ptr<openni::VideoStream> stream = getIRVideoStream ();
-
-  if (stream)
+  if (auto stream = getIRVideoStream ())
   {
     const openni::VideoMode videoMode = grabberModeToOpenniMode (video_mode);
     const openni::Status rc = stream->setVideoMode (videoMode);
@@ -515,9 +470,7 @@ pcl::io::openni2::OpenNI2Device::setIRVideoMode (const OpenNI2VideoMode& video_m
 void
 pcl::io::openni2::OpenNI2Device::setColorVideoMode (const OpenNI2VideoMode& video_mode)
 {
-  boost::shared_ptr<openni::VideoStream> stream = getColorVideoStream ();
-
-  if (stream)
+  if (auto stream = getColorVideoStream ())
   {
     openni::VideoMode videoMode = grabberModeToOpenniMode (video_mode);
     const openni::Status rc = stream->setVideoMode (videoMode);
@@ -529,9 +482,7 @@ pcl::io::openni2::OpenNI2Device::setColorVideoMode (const OpenNI2VideoMode& vide
 void
 pcl::io::openni2::OpenNI2Device::setDepthVideoMode (const OpenNI2VideoMode& video_mode)
 {
-  boost::shared_ptr<openni::VideoStream> stream = getDepthVideoStream ();
-
-  if (stream)
+  if (auto stream = getDepthVideoStream ())
   {
     const openni::VideoMode videoMode = grabberModeToOpenniMode (video_mode);
     const openni::Status rc = stream->setVideoMode (videoMode);
@@ -544,10 +495,9 @@ OpenNI2VideoMode
 pcl::io::openni2::OpenNI2Device::getDefaultIRMode () const
 {
   // Search for and return VGA@30 Hz mode
-  vector<OpenNI2VideoMode> modeList = getSupportedIRVideoModes ();
-  for (vector<OpenNI2VideoMode>::iterator modeItr = modeList.begin (); modeItr != modeList.end (); ++modeItr)
+  std::vector<OpenNI2VideoMode> modeList = getSupportedIRVideoModes ();
+  for (const auto &mode : modeList)
   {
-    OpenNI2VideoMode mode = *modeItr;
     if ( (mode.x_resolution_ == 640) && (mode.y_resolution_ == 480) && (mode.frame_rate_ == 30.0) )
       return mode;
   }
@@ -558,10 +508,9 @@ OpenNI2VideoMode
 pcl::io::openni2::OpenNI2Device::getDefaultColorMode () const
 {
   // Search for and return VGA@30 Hz mode
-  vector<OpenNI2VideoMode> modeList = getSupportedColorVideoModes ();
-  for (vector<OpenNI2VideoMode>::iterator modeItr = modeList.begin (); modeItr != modeList.end (); ++modeItr)
+  std::vector<OpenNI2VideoMode> modeList = getSupportedColorVideoModes ();
+  for (const auto &mode : modeList)
   {
-    OpenNI2VideoMode mode = *modeItr;
     if ( (mode.x_resolution_ == 640) && (mode.y_resolution_ == 480) && (mode.frame_rate_ == 30.0) )
       return mode;
   }
@@ -572,10 +521,9 @@ OpenNI2VideoMode
 pcl::io::openni2::OpenNI2Device::getDefaultDepthMode () const
 {
   // Search for and return VGA@30 Hz mode
-  vector<OpenNI2VideoMode> modeList = getSupportedDepthVideoModes ();
-  for (vector<OpenNI2VideoMode>::iterator modeItr = modeList.begin (); modeItr != modeList.end (); ++modeItr)
+  std::vector<OpenNI2VideoMode> modeList = getSupportedDepthVideoModes ();
+  for (const auto &mode : modeList)
   {
-    OpenNI2VideoMode mode = *modeItr;
     if ( (mode.x_resolution_ == 640) && (mode.y_resolution_ == 480) && (mode.frame_rate_ == 30.0) )
       return mode;
   }
@@ -585,13 +533,11 @@ pcl::io::openni2::OpenNI2Device::getDefaultDepthMode () const
 const std::vector<OpenNI2VideoMode>&
 pcl::io::openni2::OpenNI2Device::getSupportedIRVideoModes () const
 {
-  boost::shared_ptr<openni::VideoStream> stream = getIRVideoStream ();
   ir_video_modes_.clear ();
 
-  if (stream)
+  if (auto stream = getIRVideoStream ())
   {
     const openni::SensorInfo& sensor_info = stream->getSensorInfo ();
-
     ir_video_modes_ = openniModeToGrabberMode (sensor_info.getSupportedVideoModes ());
   }
 
@@ -601,14 +547,11 @@ pcl::io::openni2::OpenNI2Device::getSupportedIRVideoModes () const
 const std::vector<OpenNI2VideoMode>&
 pcl::io::openni2::OpenNI2Device::getSupportedColorVideoModes () const
 {
-  boost::shared_ptr<openni::VideoStream> stream = getColorVideoStream ();
-
   color_video_modes_.clear ();
 
-  if (stream)
+  if (auto stream = getColorVideoStream ())
   {
     const openni::SensorInfo& sensor_info = stream->getSensorInfo ();
-
     color_video_modes_ = openniModeToGrabberMode (sensor_info.getSupportedVideoModes ());
   }
 
@@ -618,14 +561,11 @@ pcl::io::openni2::OpenNI2Device::getSupportedColorVideoModes () const
 const std::vector<OpenNI2VideoMode>&
 pcl::io::openni2::OpenNI2Device::getSupportedDepthVideoModes () const
 {
-  boost::shared_ptr<openni::VideoStream> stream = getDepthVideoStream ();
-
   depth_video_modes_.clear ();
 
-  if (stream)
+  if (auto stream = getDepthVideoStream ())
   {
     const openni::SensorInfo& sensor_info = stream->getSensorInfo ();
-
     depth_video_modes_ = openniModeToGrabberMode (sensor_info.getSupportedVideoModes ());
   }
 
@@ -640,13 +580,10 @@ pcl::io::openni2::OpenNI2Device::findCompatibleIRMode (const OpenNI2VideoMode& r
     actual_mode = requested_mode;
     return (true);
   }
-  else
-  {
-    // Find a resize-compatable mode
-    std::vector<OpenNI2VideoMode> supportedModes = getSupportedIRVideoModes ();
-    bool found = findCompatibleVideoMode (supportedModes, requested_mode, actual_mode);
-    return (found);
-  }
+  // Find a resize-compatable mode
+  std::vector<OpenNI2VideoMode> supportedModes = getSupportedIRVideoModes ();
+  bool found = findCompatibleVideoMode (supportedModes, requested_mode, actual_mode);
+  return (found);
 }
 
 bool
@@ -657,13 +594,10 @@ pcl::io::openni2::OpenNI2Device::findCompatibleColorMode (const OpenNI2VideoMode
     actual_mode = requested_mode;
     return (true);
   }
-  else
-  {
-    // Find a resize-compatable mode
-    std::vector<OpenNI2VideoMode> supportedModes = getSupportedColorVideoModes ();
-    bool found = findCompatibleVideoMode (supportedModes, requested_mode, actual_mode);
-    return (found);
-  }
+  // Find a resize-compatable mode
+  std::vector<OpenNI2VideoMode> supportedModes = getSupportedColorVideoModes ();
+  bool found = findCompatibleVideoMode (supportedModes, requested_mode, actual_mode);
+  return (found);
 }
 
 bool
@@ -674,33 +608,30 @@ pcl::io::openni2::OpenNI2Device::findCompatibleDepthMode (const OpenNI2VideoMode
     actual_mode = requested_mode;
     return (true);
   }
-  else
-  {
-    // Find a resize-compatable mode
-    std::vector<OpenNI2VideoMode> supportedModes = getSupportedDepthVideoModes ();
-    bool found = findCompatibleVideoMode (supportedModes, requested_mode, actual_mode);
-    return (found);
-  }
+  // Find a resize-compatable mode
+  std::vector<OpenNI2VideoMode> supportedModes = getSupportedDepthVideoModes ();
+  bool found = findCompatibleVideoMode (supportedModes, requested_mode, actual_mode);
+  return (found);
 }
 
 // Generic support method for the above findCompatable...Mode calls above
 bool
-pcl::io::openni2::OpenNI2Device::findCompatibleVideoMode (const std::vector<OpenNI2VideoMode> supportedModes, const OpenNI2VideoMode& requested_mode, OpenNI2VideoMode& actual_mode) const
+pcl::io::openni2::OpenNI2Device::findCompatibleVideoMode (const std::vector<OpenNI2VideoMode>& supportedModes, const OpenNI2VideoMode& requested_mode, OpenNI2VideoMode& actual_mode) const
 {
   bool found = false;
-  for (std::vector<OpenNI2VideoMode>::const_iterator modeIt = supportedModes.begin (); modeIt != supportedModes.end (); ++modeIt)
+  for (const auto &supportedMode : supportedModes)
   {
-    if (modeIt->frame_rate_ == requested_mode.frame_rate_
-      && resizingSupported (modeIt->x_resolution_, modeIt->y_resolution_, requested_mode.x_resolution_, requested_mode.y_resolution_))
+    if (supportedMode.frame_rate_ == requested_mode.frame_rate_
+      && resizingSupported (supportedMode.x_resolution_, supportedMode.y_resolution_, requested_mode.x_resolution_, requested_mode.y_resolution_))
     {
       if (found)
       { // check whether the new mode is better -> smaller than the current one.
-        if (actual_mode.x_resolution_ * actual_mode.x_resolution_ > modeIt->x_resolution_ * modeIt->y_resolution_ )
-          actual_mode = *modeIt;
+        if (actual_mode.x_resolution_ * actual_mode.x_resolution_ > supportedMode.x_resolution_ * supportedMode.y_resolution_ )
+          actual_mode = supportedMode;
       }
       else
       {
-        actual_mode = *modeIt;
+        actual_mode = supportedMode;
         found = true;
       }
     }
@@ -709,7 +640,7 @@ pcl::io::openni2::OpenNI2Device::findCompatibleVideoMode (const std::vector<Open
 }
 
 bool
-pcl::io::openni2::OpenNI2Device::resizingSupported (size_t input_width, size_t input_height, size_t output_width, size_t output_height) const
+pcl::io::openni2::OpenNI2Device::resizingSupported (std::size_t input_width, std::size_t input_height, std::size_t output_width, std::size_t output_height) const
 {
   return (output_width <= input_width && output_height <= input_height && input_width % output_width == 0 && input_height % output_height == 0 );
 }
@@ -717,9 +648,7 @@ pcl::io::openni2::OpenNI2Device::resizingSupported (size_t input_width, size_t i
 void
 pcl::io::openni2::OpenNI2Device::setAutoExposure (bool enable)
 {
-  boost::shared_ptr<openni::VideoStream> stream = getColorVideoStream ();
-
-  if (stream)
+  if (auto stream = getColorVideoStream ())
   {
     openni::CameraSettings* camera_seeting = stream->getCameraSettings ();
     if (camera_seeting)
@@ -735,9 +664,7 @@ pcl::io::openni2::OpenNI2Device::setAutoExposure (bool enable)
 void
 pcl::io::openni2::OpenNI2Device::setAutoWhiteBalance (bool enable)
 {
-  boost::shared_ptr<openni::VideoStream> stream = getColorVideoStream ();
-
-  if (stream)
+  if (auto stream = getColorVideoStream ())
   {
     openni::CameraSettings* camera_seeting = stream->getCameraSettings ();
     if (camera_seeting)
@@ -746,7 +673,6 @@ pcl::io::openni2::OpenNI2Device::setAutoWhiteBalance (bool enable)
       if (rc != openni::STATUS_OK)
         THROW_IO_EXCEPTION ("Couldn't set auto white balance: \n%s\n", openni::OpenNI::getExtendedError ());
     }
-
   }
 }
 
@@ -755,9 +681,7 @@ pcl::io::openni2::OpenNI2Device::getAutoExposure () const
 {
   bool ret = false;
 
-  boost::shared_ptr<openni::VideoStream> stream = getColorVideoStream ();
-
-  if (stream)
+  if (auto stream = getColorVideoStream ())
   {
     openni::CameraSettings* camera_seeting = stream->getCameraSettings ();
     if (camera_seeting)
@@ -772,9 +696,7 @@ pcl::io::openni2::OpenNI2Device::getAutoWhiteBalance () const
 {
   bool ret = false;
 
-  boost::shared_ptr<openni::VideoStream> stream = getColorVideoStream ();
-
-  if (stream)
+  if (auto stream = getColorVideoStream ())
   {
     openni::CameraSettings* camera_setting = stream->getCameraSettings ();
     if (camera_setting)
@@ -816,14 +738,14 @@ bool OpenNI2Device::setPlaybackSpeed (double speed)
     return openni_device_->getPlaybackControl ()->setSpeed (speed) == openni::STATUS_OK;
 }
 
-boost::shared_ptr<openni::VideoStream>
+std::shared_ptr<openni::VideoStream>
 pcl::io::openni2::OpenNI2Device::getIRVideoStream () const
 {
-  if (ir_video_stream_.get () == 0)
+  if (ir_video_stream_.get () == nullptr)
   {
     if (hasIRSensor ())
     {
-      ir_video_stream_ = boost::make_shared<openni::VideoStream>();
+      ir_video_stream_.reset (new openni::VideoStream);
 
       const openni::Status rc = ir_video_stream_->create (*openni_device_, openni::SENSOR_IR);
       if (rc != openni::STATUS_OK)
@@ -833,14 +755,14 @@ pcl::io::openni2::OpenNI2Device::getIRVideoStream () const
   return (ir_video_stream_);
 }
 
-boost::shared_ptr<openni::VideoStream>
+std::shared_ptr<openni::VideoStream>
 pcl::io::openni2::OpenNI2Device::getColorVideoStream () const
 {
-  if (color_video_stream_.get () == 0)
+  if (color_video_stream_.get () == nullptr)
   {
     if (hasColorSensor ())
     {
-      color_video_stream_ = boost::make_shared<openni::VideoStream>();
+      color_video_stream_.reset (new openni::VideoStream);
 
       const openni::Status rc = color_video_stream_->create (*openni_device_, openni::SENSOR_COLOR);
       if (rc != openni::STATUS_OK)
@@ -850,14 +772,14 @@ pcl::io::openni2::OpenNI2Device::getColorVideoStream () const
   return (color_video_stream_);
 }
 
-boost::shared_ptr<openni::VideoStream>
+std::shared_ptr<openni::VideoStream>
 pcl::io::openni2::OpenNI2Device::getDepthVideoStream () const
 {
-  if (depth_video_stream_.get () == 0)
+  if (depth_video_stream_.get () == nullptr)
   {
     if (hasDepthSensor ())
     {
-      depth_video_stream_ = boost::make_shared<openni::VideoStream>();
+      depth_video_stream_.reset (new openni::VideoStream);
 
       const openni::Status rc = depth_video_stream_->create (*openni_device_, openni::SENSOR_DEPTH);
       if (rc != openni::STATUS_OK)
@@ -881,10 +803,8 @@ std::ostream& pcl::io::openni2::operator<< (std::ostream& stream, const OpenNI2D
     stream << "IR sensor video modes:" << std::endl;
     const std::vector<OpenNI2VideoMode>& video_modes = device.getSupportedIRVideoModes ();
 
-    std::vector<OpenNI2VideoMode>::const_iterator it = video_modes.begin ();
-    std::vector<OpenNI2VideoMode>::const_iterator it_end = video_modes.end ();
-    for (; it != it_end; ++it)
-      stream << "   - " << *it << std::endl;
+    for (const auto &video_mode : video_modes)
+      stream << "   - " << video_mode << std::endl;
   }
   else
   {
@@ -896,10 +816,8 @@ std::ostream& pcl::io::openni2::operator<< (std::ostream& stream, const OpenNI2D
     stream << "Color sensor video modes:" << std::endl;
     const std::vector<OpenNI2VideoMode>& video_modes = device.getSupportedColorVideoModes ();
 
-    std::vector<OpenNI2VideoMode>::const_iterator it = video_modes.begin ();
-    std::vector<OpenNI2VideoMode>::const_iterator it_end = video_modes.end ();
-    for (; it != it_end; ++it)
-      stream << "   - " << *it << std::endl;
+    for (const auto &video_mode : video_modes)
+      stream << "   - " << video_mode << std::endl;
   }
   else
   {
@@ -911,10 +829,8 @@ std::ostream& pcl::io::openni2::operator<< (std::ostream& stream, const OpenNI2D
     stream << "Depth sensor video modes:" << std::endl;
     const std::vector<OpenNI2VideoMode>& video_modes = device.getSupportedDepthVideoModes ();
 
-    std::vector<OpenNI2VideoMode>::const_iterator it = video_modes.begin ();
-    std::vector<OpenNI2VideoMode>::const_iterator it_end = video_modes.end ();
-    for (; it != it_end; ++it)
-      stream << "   - " << *it << std::endl;
+    for (const auto &video_mode : video_modes)
+      stream << "   - " << video_mode << std::endl;
   }
   else
   {
@@ -928,17 +844,17 @@ std::ostream& pcl::io::openni2::operator<< (std::ostream& stream, const OpenNI2D
 void
 pcl::io::openni2::OpenNI2Device::setColorCallback (StreamCallbackFunction color_callback)
 {
-  color_frame_listener->setCallback (color_callback);
+  color_frame_listener->setCallback (std::move(color_callback));
 }
 
 void
 pcl::io::openni2::OpenNI2Device::setDepthCallback (StreamCallbackFunction depth_callback)
 {
-  depth_frame_listener->setCallback (depth_callback);
+  depth_frame_listener->setCallback (std::move(depth_callback));
 }
 
 void
 pcl::io::openni2::OpenNI2Device::setIRCallback (StreamCallbackFunction ir_callback)
 {
-  ir_frame_listener->setCallback (ir_callback);
+  ir_frame_listener->setCallback (std::move(ir_callback));
 }
