@@ -36,6 +36,7 @@
  *
  */
 #include <pcl/pcl_config.h>
+#include <pcl/make_shared.h>
 #ifdef HAVE_OPENNI
 
 #ifdef __GNUC__
@@ -46,6 +47,7 @@
 #include <pcl/io/openni_camera/openni_device.h>
 #include <pcl/io/openni_camera/openni_depth_image.h>
 #include <pcl/io/openni_camera/openni_ir_image.h>
+#include <pcl/io/openni_camera/openni_image.h>
 #include <iostream>
 #include <limits>
 #include <sstream>
@@ -67,16 +69,8 @@ openni_wrapper::OpenNIDevice::OpenNIDevice (
     const xn::NodeInfo& ir_node
 #endif
   )
-  : image_callback_ (),
-    depth_callback_ (),
-    ir_callback_ (),
-    available_image_modes_ (),
-    available_depth_modes_ (),
-    context_ (context),
+  : context_ (context),
     device_node_info_ (device_node),
-    depth_generator_ (),
-    image_generator_ (),
-    ir_generator_ (),
     depth_callback_handle_ (),
     image_callback_handle_ (),
     ir_callback_handle_ (),
@@ -89,10 +83,7 @@ openni_wrapper::OpenNIDevice::OpenNIDevice (
     image_callback_handle_counter_ (),
     depth_callback_handle_counter_ (),
     ir_callback_handle_counter_ (),
-    quit_ (),
-    image_mutex_ (), depth_mutex_ (), ir_mutex_ (),
-    image_condition_ (), depth_condition_ (), ir_condition_ (), 
-    image_thread_ (), depth_thread_ (), ir_thread_ ()
+    quit_ () 
 {
 // workaround for MAC from Alex Ichim
 #ifdef __APPLE__
@@ -183,16 +174,8 @@ openni_wrapper::OpenNIDevice::OpenNIDevice (xn::Context& context, const xn::Node
     const xn::NodeInfo& ir_node
 #endif
     )
-  : image_callback_ (),
-    depth_callback_ (),
-    ir_callback_ (),
-    available_image_modes_ (),
-    available_depth_modes_ (),
-    context_ (context),
+  : context_ (context),
     device_node_info_ (device_node),
-    depth_generator_ (),
-    image_generator_ (),
-    ir_generator_ (),
     depth_callback_handle_ (),
     image_callback_handle_ (),
     ir_callback_handle_ (),
@@ -205,10 +188,7 @@ openni_wrapper::OpenNIDevice::OpenNIDevice (xn::Context& context, const xn::Node
     image_callback_handle_counter_ (),
     depth_callback_handle_counter_ (),
     ir_callback_handle_counter_ (),
-    quit_ (),
-    image_mutex_ (), depth_mutex_ (), ir_mutex_ (),
-    image_condition_ (), depth_condition_ (), ir_condition_ (), 
-    image_thread_ (), depth_thread_ (), ir_thread_ ()
+    quit_ () 
 {
 // workaround for MAC from Alex Ichim
 #ifdef __APPLE__
@@ -275,16 +255,8 @@ openni_wrapper::OpenNIDevice::OpenNIDevice (xn::Context& context, const xn::Node
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 // For ONI Player devices
 openni_wrapper::OpenNIDevice::OpenNIDevice (xn::Context& context)
-  : image_callback_ (),
-    depth_callback_ (),
-    ir_callback_ (),
-    available_image_modes_ (),
-    available_depth_modes_ (),
-    context_ (context),
-    device_node_info_ (0),
-    depth_generator_ (),
-    image_generator_ (),
-    ir_generator_ (),
+  : context_ (context),
+    device_node_info_ (nullptr),
     depth_callback_handle_ (),
     image_callback_handle_ (),
     ir_callback_handle_ (),
@@ -297,10 +269,7 @@ openni_wrapper::OpenNIDevice::OpenNIDevice (xn::Context& context)
     image_callback_handle_counter_ (),
     depth_callback_handle_counter_ (),
     ir_callback_handle_counter_ (),
-    quit_ (),
-    image_mutex_ (), depth_mutex_ (), ir_mutex_ (),
-    image_condition_ (), depth_condition_ (), ir_condition_ (), 
-    image_thread_ (), depth_thread_ (), ir_thread_ ()
+    quit_ () 
 {
 }
 
@@ -364,7 +333,7 @@ openni_wrapper::OpenNIDevice::Init ()
   // set Depth resolution here only once... since no other mode for kinect is available -> deactivating setDepthResolution method!
   if (hasDepthStream ())
   {
-    boost::unique_lock<boost::mutex> depth_lock (depth_mutex_);
+    std::unique_lock<std::mutex> depth_lock (depth_mutex_);
     XnStatus status = depth_generator_.GetRealProperty ("ZPPS", pixel_size);
     if (status != XN_STATUS_OK)
       THROW_OPENNI_EXCEPTION ("reading the pixel size of IR camera failed. Reason: %s", xnGetStatusString (status));
@@ -393,19 +362,19 @@ openni_wrapper::OpenNIDevice::Init ()
     //focal length from mm -> pixels (valid for 1280x1024)
     depth_focal_length_SXGA_ = static_cast<float> (static_cast<XnDouble> (depth_focal_length_SXGA) / pixel_size);
 
-    depth_thread_ = boost::thread (&OpenNIDevice::DepthDataThreadFunction, this);
+    depth_thread_ = std::thread (&OpenNIDevice::DepthDataThreadFunction, this);
   }
 
   if (hasImageStream ())
   {
-    boost::lock_guard<boost::mutex> image_lock (image_mutex_);
-    image_thread_ = boost::thread (&OpenNIDevice::ImageDataThreadFunction, this);
+    std::lock_guard<std::mutex> image_lock (image_mutex_);
+    image_thread_ = std::thread (&OpenNIDevice::ImageDataThreadFunction, this);
   }
 
   if (hasIRStream ())
   {
-    boost::lock_guard<boost::mutex> ir_lock (ir_mutex_);
-    ir_thread_ = boost::thread (&OpenNIDevice::IRDataThreadFunction, this);
+    std::lock_guard<std::mutex> ir_lock (ir_mutex_);
+    ir_thread_ = std::thread (&OpenNIDevice::IRDataThreadFunction, this);
   }
 }
 
@@ -418,38 +387,31 @@ void openni_wrapper::OpenNIDevice::InitShiftToDepthConversion ()
   {
     // Calculate shift conversion table
 
-    pcl::uint32_t nIndex = 0;
-    pcl::int32_t nShiftValue = 0;
-    double dFixedRefX = 0;
-    double dMetric = 0;
-    double dDepth = 0;
-    double dPlanePixelSize = shift_conversion_parameters_.zero_plane_pixel_size_;
-    double dPlaneDsr = shift_conversion_parameters_.zero_plane_distance_;
-    double dPlaneDcl = shift_conversion_parameters_.emitter_dcmos_distace_;
-    pcl::int32_t nConstShift = shift_conversion_parameters_.param_coeff_ *
-        shift_conversion_parameters_.const_shift_;
-
-    dPlanePixelSize *= shift_conversion_parameters_.pixel_size_factor_;
-    nConstShift /= shift_conversion_parameters_.pixel_size_factor_;
+    const double dPlanePixelSize = shift_conversion_parameters_.zero_plane_pixel_size_ * shift_conversion_parameters_.pixel_size_factor_;
+    const double dPlaneDsr = shift_conversion_parameters_.zero_plane_distance_;
+    const double dPlaneDcl = shift_conversion_parameters_.emitter_dcmos_distace_;
+    const std::int32_t nConstShift = (shift_conversion_parameters_.param_coeff_ *
+                                      shift_conversion_parameters_.const_shift_) /
+                                      shift_conversion_parameters_.pixel_size_factor_;
 
     shift_to_depth_table_.resize(shift_conversion_parameters_.device_max_shift_+1);
 
-    for (nIndex = 1; nIndex < shift_conversion_parameters_.device_max_shift_; nIndex++)
+    for (std::uint32_t nIndex = 1; nIndex < shift_conversion_parameters_.device_max_shift_; nIndex++)
     {
-      nShiftValue = (pcl::int32_t)nIndex;
+      std::int32_t nShiftValue = (std::int32_t)nIndex;
 
-      dFixedRefX = (double) (nShiftValue - nConstShift) /
-                   (double) shift_conversion_parameters_.param_coeff_;
+      double dFixedRefX = (double) (nShiftValue - nConstShift) /
+                          (double) shift_conversion_parameters_.param_coeff_;
       dFixedRefX -= 0.375;
-      dMetric = dFixedRefX * dPlanePixelSize;
-      dDepth = shift_conversion_parameters_.shift_scale_ *
-               ((dMetric * dPlaneDsr / (dPlaneDcl - dMetric)) + dPlaneDsr);
+      double dMetric = dFixedRefX * dPlanePixelSize;
+      double dDepth = shift_conversion_parameters_.shift_scale_ *
+                      ((dMetric * dPlaneDsr / (dPlaneDcl - dMetric)) + dPlaneDsr);
 
       // check cut-offs
       if ((dDepth > shift_conversion_parameters_.min_depth_) &&
           (dDepth < shift_conversion_parameters_.max_depth_))
       {
-        shift_to_depth_table_[nIndex] = (pcl::uint16_t)(dDepth);
+        shift_to_depth_table_[nIndex] = (std::uint16_t)(dDepth);
       }
     }
 
@@ -543,7 +505,7 @@ openni_wrapper::OpenNIDevice::startImageStream ()
 {
   if (hasImageStream ())
   {
-    boost::lock_guard<boost::mutex> image_lock (image_mutex_);
+    std::lock_guard<std::mutex> image_lock (image_mutex_);
     if (!image_generator_.IsGenerating ())
     {
       XnStatus status = image_generator_.StartGenerating ();
@@ -561,7 +523,7 @@ openni_wrapper::OpenNIDevice::stopImageStream ()
 {
   if (hasImageStream ())
   {
-    boost::lock_guard<boost::mutex> image_lock (image_mutex_);
+    std::lock_guard<std::mutex> image_lock (image_mutex_);
     if (image_generator_.IsGenerating ())
     {
       XnStatus status = image_generator_.StopGenerating ();
@@ -579,7 +541,7 @@ openni_wrapper::OpenNIDevice::startDepthStream ()
 {
   if (hasDepthStream ())
   {
-    boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+    std::lock_guard<std::mutex> depth_lock (depth_mutex_);
     if (!depth_generator_.IsGenerating ())
     {
       XnStatus status = depth_generator_.StartGenerating ();
@@ -598,7 +560,7 @@ openni_wrapper::OpenNIDevice::stopDepthStream ()
 {
   if (hasDepthStream ())
   {
-    boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+    std::lock_guard<std::mutex> depth_lock (depth_mutex_);
     if (depth_generator_.IsGenerating ())
     {
       XnStatus status = depth_generator_.StopGenerating ();
@@ -617,7 +579,7 @@ openni_wrapper::OpenNIDevice::startIRStream ()
 {
   if (hasIRStream ())
   {
-    boost::lock_guard<boost::mutex> ir_lock (ir_mutex_);
+    std::lock_guard<std::mutex> ir_lock (ir_mutex_);
     if (!ir_generator_.IsGenerating ())
     {
       XnStatus status = ir_generator_.StartGenerating ();
@@ -638,7 +600,7 @@ openni_wrapper::OpenNIDevice::stopIRStream ()
 {
   if (hasIRStream ())
   {
-    boost::lock_guard<boost::mutex> ir_lock (ir_mutex_);
+    std::lock_guard<std::mutex> ir_lock (ir_mutex_);
     if (ir_generator_.IsGenerating ())
     {
       XnStatus status = ir_generator_.StopGenerating ();
@@ -655,7 +617,7 @@ openni_wrapper::OpenNIDevice::stopIRStream ()
 bool 
 openni_wrapper::OpenNIDevice::isImageStreamRunning () const throw ()
 {
-  boost::lock_guard<boost::mutex> image_lock (image_mutex_);
+  std::lock_guard<std::mutex> image_lock (image_mutex_);
   return (image_generator_.IsValid () && image_generator_.IsGenerating ());
 }
 
@@ -663,7 +625,7 @@ openni_wrapper::OpenNIDevice::isImageStreamRunning () const throw ()
 bool 
 openni_wrapper::OpenNIDevice::isDepthStreamRunning () const throw ()
 {
-  boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+  std::lock_guard<std::mutex> depth_lock (depth_mutex_);
   return (depth_generator_.IsValid () && depth_generator_.IsGenerating ());
 }
 
@@ -671,7 +633,7 @@ openni_wrapper::OpenNIDevice::isDepthStreamRunning () const throw ()
 bool 
 openni_wrapper::OpenNIDevice::isIRStreamRunning () const throw ()
 {
-  boost::lock_guard<boost::mutex> ir_lock (ir_mutex_);
+  std::lock_guard<std::mutex> ir_lock (ir_mutex_);
   return (ir_generator_.IsValid () && ir_generator_.IsGenerating ());
 }
 
@@ -679,7 +641,7 @@ openni_wrapper::OpenNIDevice::isIRStreamRunning () const throw ()
 bool 
 openni_wrapper::OpenNIDevice::hasImageStream () const throw ()
 {
-  boost::lock_guard<boost::mutex> lock (image_mutex_);
+  std::lock_guard<std::mutex> lock (image_mutex_);
   return (image_generator_.IsValid () != 0);
   //return (available_image_modes_.size() != 0);
 }
@@ -688,7 +650,7 @@ openni_wrapper::OpenNIDevice::hasImageStream () const throw ()
 bool 
 openni_wrapper::OpenNIDevice::hasDepthStream () const throw ()
 {
-  boost::lock_guard<boost::mutex> lock (depth_mutex_);
+  std::lock_guard<std::mutex> lock (depth_mutex_);
   return (depth_generator_.IsValid () != 0);
   //return (available_depth_modes_.size() != 0);
 }
@@ -697,7 +659,7 @@ openni_wrapper::OpenNIDevice::hasDepthStream () const throw ()
 bool 
 openni_wrapper::OpenNIDevice::hasIRStream () const throw ()
 {
-  boost::lock_guard<boost::mutex> ir_lock (ir_mutex_);
+  std::lock_guard<std::mutex> ir_lock (ir_mutex_);
   return (ir_generator_.IsValid () != 0);
 }
 
@@ -707,8 +669,8 @@ openni_wrapper::OpenNIDevice::setDepthRegistration (bool on_off)
 {
   if (hasDepthStream () && hasImageStream())
   {
-    boost::lock_guard<boost::mutex> image_lock (image_mutex_);
-    boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+    std::lock_guard<std::mutex> image_lock (image_mutex_);
+    std::lock_guard<std::mutex> depth_lock (depth_mutex_);
     if (on_off && !depth_generator_.GetAlternativeViewPointCap ().IsViewPointAs (image_generator_))
     {
       if (depth_generator_.GetAlternativeViewPointCap ().IsViewPointSupported (image_generator_))
@@ -741,8 +703,8 @@ openni_wrapper::OpenNIDevice::isDepthRegistered () const throw ()
     xn::DepthGenerator& depth_generator = const_cast<xn::DepthGenerator&>(depth_generator_);
     xn::ImageGenerator& image_generator = const_cast<xn::ImageGenerator&>(image_generator_);
 
-    boost::lock_guard<boost::mutex> image_lock (image_mutex_);
-    boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+    std::lock_guard<std::mutex> image_lock (image_mutex_);
+    std::lock_guard<std::mutex> depth_lock (depth_mutex_);
     return (depth_generator.GetAlternativeViewPointCap ().IsViewPointAs (image_generator) != 0);
   }
   return (false);
@@ -752,8 +714,8 @@ openni_wrapper::OpenNIDevice::isDepthRegistered () const throw ()
 bool 
 openni_wrapper::OpenNIDevice::isDepthRegistrationSupported () const throw ()
 {
-  boost::lock_guard<boost::mutex> image_lock (image_mutex_);
-  boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+  std::lock_guard<std::mutex> image_lock (image_mutex_);
+  std::lock_guard<std::mutex> depth_lock (depth_mutex_);
   xn::ImageGenerator& image_generator = const_cast<xn::ImageGenerator&> (image_generator_);
   return (depth_generator_.IsValid() && image_generator_.IsValid() && depth_generator_.GetAlternativeViewPointCap().IsViewPointSupported(image_generator));
 }
@@ -762,8 +724,8 @@ openni_wrapper::OpenNIDevice::isDepthRegistrationSupported () const throw ()
 bool 
 openni_wrapper::OpenNIDevice::isSynchronizationSupported () const throw ()
 {
-  boost::lock_guard<boost::mutex> image_lock (image_mutex_);
-  boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+  std::lock_guard<std::mutex> image_lock (image_mutex_);
+  std::lock_guard<std::mutex> depth_lock (depth_mutex_);
   return (depth_generator_.IsValid() && image_generator_.IsValid() && depth_generator_.IsCapabilitySupported (XN_CAPABILITY_FRAME_SYNC));
 }
 
@@ -773,8 +735,8 @@ openni_wrapper::OpenNIDevice::setSynchronization (bool on_off)
 {
   if (hasDepthStream () && hasImageStream())
   {
-    boost::lock_guard<boost::mutex> image_lock (image_mutex_);
-    boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+    std::lock_guard<std::mutex> image_lock (image_mutex_);
+    std::lock_guard<std::mutex> depth_lock (depth_mutex_);
     XnStatus status;
 
     if (on_off && !depth_generator_.GetFrameSyncCap ().IsFrameSyncedWith (image_generator_))
@@ -800,21 +762,20 @@ openni_wrapper::OpenNIDevice::isSynchronized () const throw ()
 {
   if (hasDepthStream () && hasImageStream())
   {
-    boost::lock_guard<boost::mutex> image_lock (image_mutex_);
-    boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+    std::lock_guard<std::mutex> image_lock (image_mutex_);
+    std::lock_guard<std::mutex> depth_lock (depth_mutex_);
     xn::DepthGenerator& depth_generator = const_cast<xn::DepthGenerator&>(depth_generator_);
     xn::ImageGenerator& image_generator = const_cast<xn::ImageGenerator&>(image_generator_);
     return (depth_generator.GetFrameSyncCap ().CanFrameSyncWith (image_generator) && depth_generator.GetFrameSyncCap ().IsFrameSyncedWith (image_generator));
   }
-  else
-    return (false);
+  return (false);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 bool 
 openni_wrapper::OpenNIDevice::isDepthCroppingSupported () const throw ()
 {
-  boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+  std::lock_guard<std::mutex> depth_lock (depth_mutex_);
   return (image_generator_.IsValid() && depth_generator_.IsCapabilitySupported (XN_CAPABILITY_CROPPING) );
 }
 
@@ -824,7 +785,7 @@ openni_wrapper::OpenNIDevice::isDepthCropped () const
 {
   if (hasDepthStream ())
   {
-    boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+    std::lock_guard<std::mutex> depth_lock (depth_mutex_);
     XnCropping cropping;
     xn::DepthGenerator& depth_generator = const_cast<xn::DepthGenerator&>(depth_generator_);
     XnStatus status = depth_generator.GetCroppingCap ().GetCropping (cropping);
@@ -842,7 +803,7 @@ openni_wrapper::OpenNIDevice::setDepthCropping (unsigned x, unsigned y, unsigned
 {
   if (hasDepthStream ())
   {
-    boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+    std::lock_guard<std::mutex> depth_lock (depth_mutex_);
     XnCropping cropping;
     cropping.nXOffset = static_cast<XnUInt16> (x);
     cropping.nYOffset = static_cast<XnUInt16> (y);
@@ -865,7 +826,7 @@ openni_wrapper::OpenNIDevice::ImageDataThreadFunction ()
   while (true)
   {
     // lock before checking running flag
-    boost::unique_lock<boost::mutex> image_lock (image_mutex_);
+    std::unique_lock<std::mutex> image_lock (image_mutex_);
     if (quit_)
       return;
     image_condition_.wait (image_lock);
@@ -875,14 +836,14 @@ openni_wrapper::OpenNIDevice::ImageDataThreadFunction ()
     image_generator_.WaitAndUpdateData ();
     xn::ImageMetaData image_md;
     image_generator_.GetMetaData (image_md);
-    boost::shared_ptr<xn::ImageMetaData> image_data (new xn::ImageMetaData);
+    pcl::shared_ptr<xn::ImageMetaData> image_data (new xn::ImageMetaData);
     image_data->CopyFrom (image_md);
     image_lock.unlock ();
     
-    boost::shared_ptr<Image> image = getCurrentImage (image_data);
-    for (std::map< OpenNIDevice::CallbackHandle, ActualImageCallbackFunction >::iterator callbackIt = image_callback_.begin (); callbackIt != image_callback_.end (); ++callbackIt)
+    auto image = getCurrentImage (image_data);
+    for (const auto &callback : image_callback_)
     {
-      callbackIt->second.operator()(image);
+      callback.second.operator()(image);
     }
   }
 }
@@ -894,7 +855,7 @@ openni_wrapper::OpenNIDevice::DepthDataThreadFunction ()
   while (true)
   {
     // lock before checking running flag
-    boost::unique_lock<boost::mutex> depth_lock (depth_mutex_);
+    std::unique_lock<std::mutex> depth_lock (depth_mutex_);
     if (quit_)
       return;
     depth_condition_.wait (depth_lock);
@@ -904,16 +865,15 @@ openni_wrapper::OpenNIDevice::DepthDataThreadFunction ()
     depth_generator_.WaitAndUpdateData ();
     xn::DepthMetaData depth_md;
     depth_generator_.GetMetaData (depth_md);    
-    boost::shared_ptr<xn::DepthMetaData> depth_data (new xn::DepthMetaData);
+    pcl::shared_ptr<xn::DepthMetaData> depth_data (new xn::DepthMetaData);
     depth_data->CopyFrom (depth_md);
     depth_lock.unlock ();
 
-    boost::shared_ptr<DepthImage> depth_image ( new DepthImage (depth_data, baseline_, getDepthFocalLength (), shadow_value_, no_sample_value_) );
+    DepthImage::Ptr depth_image ( new DepthImage (depth_data, baseline_, getDepthFocalLength (), shadow_value_, no_sample_value_) );
 
-    for (std::map< OpenNIDevice::CallbackHandle, ActualDepthImageCallbackFunction >::iterator callbackIt = depth_callback_.begin ();
-         callbackIt != depth_callback_.end (); ++callbackIt)
+    for (const auto &callback : depth_callback_)
     {
-      callbackIt->second.operator()(depth_image);
+      callback.second.operator()(depth_image);
     }
   }
 }
@@ -925,7 +885,7 @@ openni_wrapper::OpenNIDevice::IRDataThreadFunction ()
   while (true)
   {
     // lock before checking running flag
-    boost::unique_lock<boost::mutex> ir_lock (ir_mutex_);
+    std::unique_lock<std::mutex> ir_lock (ir_mutex_);
     if (quit_)
       return;
     ir_condition_.wait (ir_lock);
@@ -935,16 +895,15 @@ openni_wrapper::OpenNIDevice::IRDataThreadFunction ()
     ir_generator_.WaitAndUpdateData ();
     xn::IRMetaData ir_md;
     ir_generator_.GetMetaData (ir_md);
-    boost::shared_ptr<xn::IRMetaData> ir_data (new xn::IRMetaData);
+    pcl::shared_ptr<xn::IRMetaData> ir_data (new xn::IRMetaData);
     ir_data->CopyFrom (ir_md);
     ir_lock.unlock ();
 
-    boost::shared_ptr<IRImage> ir_image ( new IRImage (ir_data) );
+    IRImage::Ptr ir_image ( new IRImage (ir_data) );
 
-    for (std::map< OpenNIDevice::CallbackHandle, ActualIRImageCallbackFunction >::iterator callbackIt = ir_callback_.begin ();
-         callbackIt != ir_callback_.end (); ++callbackIt)
+    for (const auto &callback : ir_callback_)
     {
-      callbackIt->second.operator()(ir_image);
+      callback.second.operator()(ir_image);
     }
   }
 }
@@ -977,7 +936,7 @@ openni_wrapper::OpenNIDevice::NewIRDataAvailable (xn::ProductionNode&, void* coo
 openni_wrapper::OpenNIDevice::CallbackHandle 
 openni_wrapper::OpenNIDevice::registerImageCallback (const ImageCallbackFunction& callback, void* custom_data) throw ()
 {
-  image_callback_[image_callback_handle_counter_] = boost::bind (callback, _1, custom_data);
+  image_callback_[image_callback_handle_counter_] = [=] (const Image::Ptr& img) { callback (img, custom_data); };
   return (image_callback_handle_counter_++);
 }
 
@@ -992,7 +951,7 @@ openni_wrapper::OpenNIDevice::unregisterImageCallback (const OpenNIDevice::Callb
 openni_wrapper::OpenNIDevice::CallbackHandle 
 openni_wrapper::OpenNIDevice::registerDepthCallback (const DepthImageCallbackFunction& callback, void* custom_data) throw ()
 {
-  depth_callback_[depth_callback_handle_counter_] = boost::bind (callback, _1, custom_data);
+  depth_callback_[depth_callback_handle_counter_] = [=] (const DepthImage::Ptr& img) { callback (img, custom_data); };
   return (depth_callback_handle_counter_++);
 }
 
@@ -1007,7 +966,7 @@ openni_wrapper::OpenNIDevice::unregisterDepthCallback (const OpenNIDevice::Callb
 openni_wrapper::OpenNIDevice::CallbackHandle 
 openni_wrapper::OpenNIDevice::registerIRCallback (const IRImageCallbackFunction& callback, void* custom_data) throw ()
 {
-  ir_callback_[ir_callback_handle_counter_] = boost::bind (callback, _1, custom_data);
+  ir_callback_[ir_callback_handle_counter_] = [=] (const IRImage::Ptr& img) { callback (img, custom_data); };
   return (ir_callback_handle_counter_++);
 }
 
@@ -1121,27 +1080,24 @@ openni_wrapper::OpenNIDevice::findCompatibleImageMode (const XnMapOutputMode& ou
     mode = output_mode;
     return (true);
   }
-  else
+  bool found = false;
+  for (const auto &available_image_mode : available_image_modes_)
   {
-    bool found = false;
-    for (std::vector<XnMapOutputMode>::const_iterator modeIt = available_image_modes_.begin (); modeIt != available_image_modes_.end (); ++modeIt)
+    if (available_image_mode.nFPS == output_mode.nFPS && isImageResizeSupported (available_image_mode.nXRes, available_image_mode.nYRes, output_mode.nXRes, output_mode.nYRes))
     {
-      if (modeIt->nFPS == output_mode.nFPS && isImageResizeSupported (modeIt->nXRes, modeIt->nYRes, output_mode.nXRes, output_mode.nYRes))
+      if (found)
+      { // check whether the new mode is better -> smaller than the current one.
+        if (mode.nXRes * mode.nYRes > available_image_mode.nXRes * available_image_mode.nYRes )
+          mode = available_image_mode;
+      }
+      else
       {
-        if (found)
-        { // check whether the new mode is better -> smaller than the current one.
-          if (mode.nXRes * mode.nYRes > modeIt->nXRes * modeIt->nYRes )
-            mode = *modeIt;
-        }
-        else
-        {
-          mode = *modeIt;
-          found = true;
-        }
+        mode = available_image_mode;
+        found = true;
       }
     }
-    return (found);
   }
+  return (found);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1153,36 +1109,33 @@ openni_wrapper::OpenNIDevice::findCompatibleDepthMode (const XnMapOutputMode& ou
     mode = output_mode;
     return (true);
   }
-  else
+  bool found = false;
+  for (const auto &available_depth_mode : available_depth_modes_)
   {
-    bool found = false;
-    for (std::vector<XnMapOutputMode>::const_iterator modeIt = available_depth_modes_.begin (); modeIt != available_depth_modes_.end (); ++modeIt)
+    if (available_depth_mode.nFPS == output_mode.nFPS && isImageResizeSupported (available_depth_mode.nXRes, available_depth_mode.nYRes, output_mode.nXRes, output_mode.nYRes))
     {
-      if (modeIt->nFPS == output_mode.nFPS && isImageResizeSupported (modeIt->nXRes, modeIt->nYRes, output_mode.nXRes, output_mode.nYRes))
+      if (found)
+      { // check whether the new mode is better -> smaller than the current one.
+        if (mode.nXRes * mode.nYRes > available_depth_mode.nXRes * available_depth_mode.nYRes )
+          mode = available_depth_mode;
+      }
+      else
       {
-        if (found)
-        { // check whether the new mode is better -> smaller than the current one.
-          if (mode.nXRes * mode.nYRes > modeIt->nXRes * modeIt->nYRes )
-            mode = *modeIt;
-        }
-        else
-        {
-          mode = *modeIt;
-          found = true;
-        }
+        mode = available_depth_mode;
+        found = true;
       }
     }
-    return (found);
   }
+  return (found);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 bool 
 openni_wrapper::OpenNIDevice::isImageModeSupported (const XnMapOutputMode& output_mode) const throw ()
 {
-  for (std::vector<XnMapOutputMode>::const_iterator modeIt = available_image_modes_.begin (); modeIt != available_image_modes_.end (); ++modeIt)
+  for (const auto &available_image_mode : available_image_modes_)
   {
-    if (modeIt->nFPS == output_mode.nFPS && modeIt->nXRes == output_mode.nXRes && modeIt->nYRes == output_mode.nYRes)
+    if (available_image_mode.nFPS == output_mode.nFPS && available_image_mode.nXRes == output_mode.nXRes && available_image_mode.nYRes == output_mode.nYRes)
       return (true);
   }
   return (false);
@@ -1192,9 +1145,9 @@ openni_wrapper::OpenNIDevice::isImageModeSupported (const XnMapOutputMode& outpu
 bool 
 openni_wrapper::OpenNIDevice::isDepthModeSupported (const XnMapOutputMode& output_mode) const throw ()
 {
-  for (std::vector<XnMapOutputMode>::const_iterator modeIt = available_depth_modes_.begin (); modeIt != available_depth_modes_.end (); ++modeIt)
+  for (const auto &available_depth_mode : available_depth_modes_)
   {
-    if (modeIt->nFPS == output_mode.nFPS && modeIt->nXRes == output_mode.nXRes && modeIt->nYRes == output_mode.nYRes)
+    if (available_depth_mode.nFPS == output_mode.nFPS && available_depth_mode.nXRes == output_mode.nXRes && available_depth_mode.nYRes == output_mode.nYRes)
       return (true);
   }
   return (false);
@@ -1228,7 +1181,7 @@ openni_wrapper::OpenNIDevice::setImageOutputMode (const XnMapOutputMode& output_
 {
   if (hasImageStream ())
   {
-    boost::lock_guard<boost::mutex> image_lock (image_mutex_);
+    std::lock_guard<std::mutex> image_lock (image_mutex_);
     XnStatus status = image_generator_.SetMapOutputMode (output_mode);
     if (status != XN_STATUS_OK)
       THROW_OPENNI_EXCEPTION ("Could not set image stream output mode to %dx%d@%d. Reason: %s", output_mode.nXRes, output_mode.nYRes, output_mode.nFPS, xnGetStatusString (status));
@@ -1243,7 +1196,7 @@ openni_wrapper::OpenNIDevice::setDepthOutputMode (const XnMapOutputMode& output_
 {
   if (hasDepthStream ())
   {
-    boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+    std::lock_guard<std::mutex> depth_lock (depth_mutex_);
     XnStatus status = depth_generator_.SetMapOutputMode (output_mode);
     if (status != XN_STATUS_OK)
       THROW_OPENNI_EXCEPTION ("Could not set depth stream output mode to %dx%d@%d. Reason: %s", output_mode.nXRes, output_mode.nYRes, output_mode.nFPS, xnGetStatusString (status));
@@ -1258,7 +1211,7 @@ openni_wrapper::OpenNIDevice::setDepthOutputFormat (const DepthMode& depth_mode)
 {
   if (hasDepthStream ())
   {
-    boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+    std::lock_guard<std::mutex> depth_lock (depth_mutex_);
     XnStatus status = depth_generator_.SetIntProperty ("OutputFormat", depth_mode);
     if (status != 0)
       THROW_OPENNI_EXCEPTION ("Error setting the depth output format. Reason: %s", xnGetStatusString (status));
@@ -1274,7 +1227,7 @@ openni_wrapper::OpenNIDevice::getDepthOutputFormat () const
   if (!hasDepthStream () )
     THROW_OPENNI_EXCEPTION ("Device does not provide a depth stream");
 
-  boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+  std::lock_guard<std::mutex> depth_lock (depth_mutex_);
   XnUInt64 mode;
   XnStatus status = depth_generator_.GetIntProperty ("OutputFormat", mode);
   if (status != XN_STATUS_OK)
@@ -1288,7 +1241,7 @@ openni_wrapper::OpenNIDevice::setIROutputMode (const XnMapOutputMode& output_mod
 {
   if (hasIRStream ())
   {
-    boost::lock_guard<boost::mutex> ir_lock (ir_mutex_);
+    std::lock_guard<std::mutex> ir_lock (ir_mutex_);
     XnStatus status = ir_generator_.SetMapOutputMode (output_mode);
     if (status != XN_STATUS_OK)
       THROW_OPENNI_EXCEPTION ("Could not set IR stream output mode to %dx%d@%d. Reason: %s", output_mode.nXRes, output_mode.nYRes, output_mode.nFPS, xnGetStatusString (status));
@@ -1307,7 +1260,7 @@ openni_wrapper::OpenNIDevice::getImageOutputMode () const
     THROW_OPENNI_EXCEPTION ("Device does not provide an image stream");
 
   XnMapOutputMode output_mode;
-  boost::lock_guard<boost::mutex> image_lock (image_mutex_);
+  std::lock_guard<std::mutex> image_lock (image_mutex_);
   XnStatus status = image_generator_.GetMapOutputMode (output_mode);
   if (status != XN_STATUS_OK)
     THROW_OPENNI_EXCEPTION ("Could not get image stream output mode. Reason: %s", xnGetStatusString (status));
@@ -1322,7 +1275,7 @@ openni_wrapper::OpenNIDevice::getDepthOutputMode () const
     THROW_OPENNI_EXCEPTION ("Device does not provide a depth stream");
 
   XnMapOutputMode output_mode;
-  boost::lock_guard<boost::mutex> depth_lock (depth_mutex_);
+  std::lock_guard<std::mutex> depth_lock (depth_mutex_);
   XnStatus status = depth_generator_.GetMapOutputMode (output_mode);
   if (status != XN_STATUS_OK)
     THROW_OPENNI_EXCEPTION ("Could not get depth stream output mode. Reason: %s", xnGetStatusString (status));
@@ -1337,7 +1290,7 @@ openni_wrapper::OpenNIDevice::getIROutputMode () const
     THROW_OPENNI_EXCEPTION ("Device does not provide an IR stream");
 
   XnMapOutputMode output_mode;
-  boost::lock_guard<boost::mutex> ir_lock (ir_mutex_);
+  std::lock_guard<std::mutex> ir_lock (ir_mutex_);
   XnStatus status = ir_generator_.GetMapOutputMode (output_mode);
   if (status != XN_STATUS_OK)
     THROW_OPENNI_EXCEPTION ("Could not get IR stream output mode. Reason: %s", xnGetStatusString (status));
