@@ -40,7 +40,7 @@
 #include <fstream>
 #include <fcntl.h>
 #include <string>
-#include <stdlib.h>
+#include <cstdlib>
 #include <pcl/io/boost.h>
 #include <pcl/common/io.h>
 #include <pcl/io/low_level_io.h>
@@ -62,9 +62,7 @@ pcl::PCDWriter::setLockingPermissions (const std::string &file_name,
   (void)lock;
 #ifndef WIN32
 #ifndef NO_MANDATORY_LOCKING
-  // Boost version 1.49 introduced permissions
-#if BOOST_VERSION >= 104900
-  // Attempt to lock the file. 
+  // Attempt to lock the file.
   // For mandatory locking, the filesystem must be mounted with the "mand" option in Linux (see http://www.hackinglinuxexposed.com/articles/20030623.html)
   lock = boost::interprocess::file_lock (file_name.c_str ());
   if (lock.try_lock ())
@@ -83,7 +81,6 @@ pcl::PCDWriter::setLockingPermissions (const std::string &file_name,
   }
 #endif
 #endif
-#endif
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -95,8 +92,6 @@ pcl::PCDWriter::resetLockingPermissions (const std::string &file_name,
   (void)lock;
 #ifndef WIN32
 #ifndef NO_MANDATORY_LOCKING
-  // Boost version 1.49 introduced permissions
-#if BOOST_VERSION >= 104900
   (void)file_name;
   namespace fs = boost::filesystem;
   try
@@ -110,7 +105,6 @@ pcl::PCDWriter::resetLockingPermissions (const std::string &file_name,
   lock.unlock ();
 #endif
 #endif
-#endif
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -131,11 +125,9 @@ pcl::PCDReader::readHeader (std::istream &fs, pcl::PCLPointCloud2 &cloud,
   // By default, assume that there are _no_ invalid (e.g., NaN) points
   //cloud.is_dense = true;
 
-  size_t nr_points = 0;
+  std::size_t nr_points = 0;
   std::string line;
 
-  int specified_channel_count = 0;
-
   // field_sizes represents the size of one element in a field (e.g., float = 4, char = 1)
   // field_counts represents the number of elements in a field (e.g., x = 1, normal_x = 1, fpfh = 33)
   std::vector<int> field_sizes, field_counts;
@@ -150,7 +142,7 @@ pcl::PCDReader::readHeader (std::istream &fs, pcl::PCLPointCloud2 &cloud,
     {
       getline (fs, line);
       // Ignore empty lines
-      if (line == "")
+      if (line.empty())
         continue;
 
       // Tokenize the line
@@ -174,7 +166,7 @@ pcl::PCDReader::readHeader (std::istream &fs, pcl::PCLPointCloud2 &cloud,
       // Get the field indices (check for COLUMNS too for backwards compatibility)
       if ( (line_type.substr (0, 6) == "FIELDS") || (line_type.substr (0, 7) == "COLUMNS") )
       {
-        specified_channel_count = static_cast<int> (st.size () - 1);
+        int specified_channel_count = static_cast<int> (st.size () - 1);
 
         // Allocate enough memory to accommodate all fields
         cloud.fields.resize (specified_channel_count);
@@ -199,7 +191,7 @@ pcl::PCDReader::readHeader (std::istream &fs, pcl::PCLPointCloud2 &cloud,
       // Get the field sizes
       if (line_type.substr (0, 4) == "SIZE")
       {
-        specified_channel_count = static_cast<int> (st.size () - 1);
+        int specified_channel_count = static_cast<int> (st.size () - 1);
 
         // Allocate enough memory to accommodate all fields
         if (specified_channel_count != static_cast<int> (cloud.fields.size ()))
@@ -229,7 +221,7 @@ pcl::PCDReader::readHeader (std::istream &fs, pcl::PCLPointCloud2 &cloud,
         if (field_sizes.empty ())
           throw "TYPE of FIELDS specified before SIZE in header!";
 
-        specified_channel_count = static_cast<int> (st.size () - 1);
+        int specified_channel_count = static_cast<int> (st.size () - 1);
 
         // Allocate enough memory to accommodate all fields
         if (specified_channel_count != static_cast<int> (cloud.fields.size ()))
@@ -241,7 +233,7 @@ pcl::PCDReader::readHeader (std::istream &fs, pcl::PCLPointCloud2 &cloud,
         for (int i = 0; i < specified_channel_count; ++i)
         {
           field_types[i] = st.at (i + 1).c_str ()[0];
-          cloud.fields[i].datatype = static_cast<uint8_t> (getFieldType (field_sizes[i], field_types[i]));
+          cloud.fields[i].datatype = static_cast<std::uint8_t> (getFieldType (field_sizes[i], field_types[i]));
         }
         continue;
       }
@@ -252,7 +244,7 @@ pcl::PCDReader::readHeader (std::istream &fs, pcl::PCLPointCloud2 &cloud,
         if (field_sizes.empty () || field_types.empty ())
           throw "COUNT of FIELDS specified before SIZE or TYPE in header!";
 
-        specified_channel_count = static_cast<int> (st.size () - 1);
+        int specified_channel_count = static_cast<int> (st.size () - 1);
 
         // Allocate enough memory to accommodate all fields
         if (specified_channel_count != static_cast<int> (cloud.fields.size ()))
@@ -388,13 +380,13 @@ pcl::PCDReader::readHeader (const std::string &file_name, pcl::PCLPointCloud2 &c
                             Eigen::Vector4f &origin, Eigen::Quaternionf &orientation, 
                             int &pcd_version, int &data_type, unsigned int &data_idx, const int offset)
 {
-  if (file_name == "" || !boost::filesystem::exists (file_name))
+  if (file_name.empty() || !boost::filesystem::exists (file_name))
   {
     PCL_ERROR ("[pcl::PCDReader::readHeader] Could not find file '%s'.\n", file_name.c_str ());
     return (-1);
   }
 
-  // Open file in binary mode to avoid problem of 
+  // Open file in binary mode to avoid problem of
   // std::getline() corrupting the result of ifstream::tellg()
   std::ifstream fs;
   fs.open (file_name.c_str (), std::ios::binary);
@@ -450,20 +442,20 @@ pcl::PCDReader::readBodyASCII (std::istream &fs, pcl::PCLPointCloud2 &cloud, int
     {
       getline (fs, line);
       // Ignore empty lines
-      if (line == "")
+      if (line.empty())
         continue;
 
       // Tokenize the line
       boost::trim (line);
       boost::split (st, line, boost::is_any_of ("\t\r "), boost::token_compress_on);
-      
+
       if (idx >= nr_points)
       {
         PCL_WARN ("[pcl::PCDReader::read] input has more points (%d) than advertised (%d)!\n", idx, nr_points);
         break;
       }
 
-      size_t total = 0;
+      std::size_t total = 0;
       // Copy data
       for (unsigned int d = 0; d < static_cast<unsigned int> (cloud.fields.size ()); ++d)
       {
@@ -588,13 +580,13 @@ pcl::PCDReader::readBodyBinary (const unsigned char *map, pcl::PCLPointCloud2 &c
     std::vector<pcl::PCLPointField> fields (cloud.fields.size ());
     std::vector<int> fields_sizes (cloud.fields.size ());
     int nri = 0, fsize = 0;
-    for (size_t i = 0; i < cloud.fields.size (); ++i)
+    for (const auto &field : cloud.fields)
     {
-      if (cloud.fields[i].name == "_")
+      if (field.name == "_")
         continue;
-      fields_sizes[nri] = cloud.fields[i].count * pcl::getFieldSize (cloud.fields[i].datatype);
+      fields_sizes[nri] = field.count * pcl::getFieldSize (field.datatype);
       fsize += fields_sizes[nri];
-      fields[nri] = cloud.fields[i];
+      fields[nri] = field;
       ++nri;
     }
     fields.resize (nri);
@@ -602,16 +594,16 @@ pcl::PCDReader::readBodyBinary (const unsigned char *map, pcl::PCLPointCloud2 &c
 
     // Unpack the xxyyzz to xyz
     std::vector<char*> pters (fields.size ());
-    int toff = 0;
-    for (size_t i = 0; i < pters.size (); ++i)
+    std::size_t toff = 0;
+    for (std::size_t i = 0; i < pters.size (); ++i)
     {
       pters[i] = &buf[toff];
       toff += fields_sizes[i] * cloud.width * cloud.height;
     }
     // Copy it to the cloud
-    for (size_t i = 0; i < cloud.width * cloud.height; ++i)
+    for (std::size_t i = 0; i < cloud.width * cloud.height; ++i)
     {
-      for (size_t j = 0; j < pters.size (); ++j)
+      for (std::size_t j = 0; j < pters.size (); ++j)
       {
         memcpy (&cloud.data[i * fsize + fields[j].offset], pters[j], fields_sizes[j]);
         // Increment the pointer
@@ -627,11 +619,11 @@ pcl::PCDReader::readBodyBinary (const unsigned char *map, pcl::PCLPointCloud2 &c
   // Extra checks (not needed for ASCII)
   int point_size = static_cast<int> (cloud.data.size () / (cloud.height * cloud.width));
   // Once copied, we need to go over each field and check if it has NaN/Inf values and assign cloud.is_dense to true or false
-  for (uint32_t i = 0; i < cloud.width * cloud.height; ++i)
+  for (std::uint32_t i = 0; i < cloud.width * cloud.height; ++i)
   {
     for (unsigned int d = 0; d < static_cast<unsigned int> (cloud.fields.size ()); ++d)
     {
-      for (uint32_t c = 0; c < cloud.fields[d].count; ++c)
+      for (std::uint32_t c = 0; c < cloud.fields[d].count; ++c)
       {
         switch (cloud.fields[d].datatype)
         {
@@ -700,7 +692,7 @@ pcl::PCDReader::read (const std::string &file_name, pcl::PCLPointCloud2 &cloud,
   pcl::console::TicToc tt;
   tt.tic ();
 
-  if (file_name == "" || !boost::filesystem::exists (file_name))
+  if (file_name.empty() || !boost::filesystem::exists (file_name))
   {
     PCL_ERROR ("[pcl::PCDReader::read] Could not find file '%s'.\n", file_name.c_str ());
     return (-1);
@@ -713,7 +705,7 @@ pcl::PCDReader::read (const std::string &file_name, pcl::PCLPointCloud2 &cloud,
 
   if (res < 0)
     return (res);
-  
+
   // if ascii
   if (data_type == 0)
   {
@@ -734,7 +726,7 @@ pcl::PCDReader::read (const std::string &file_name, pcl::PCLPointCloud2 &cloud,
     // Close file
     fs.close ();
   }
-  else 
+  else
   /// ---[ Binary mode only
   /// We must re-open the file and read with mmap () for binary
   {
@@ -747,10 +739,10 @@ pcl::PCDReader::read (const std::string &file_name, pcl::PCLPointCloud2 &cloud,
     }
 
     // Infer file size
-    const size_t file_size = io::raw_lseek (fd, 0, SEEK_END);
+    const std::size_t file_size = io::raw_lseek (fd, 0, SEEK_END);
     io::raw_lseek (fd, 0, SEEK_SET);
-    
-    size_t mmap_size = offset + data_idx;   // ...because we mmap from the start of the file.
+
+    std::size_t mmap_size = offset + data_idx;   // ...because we mmap from the start of the file.
     if (data_type == 2)
     {
       // Seek to real start of data.
@@ -762,7 +754,7 @@ pcl::PCDReader::read (const std::string &file_name, pcl::PCLPointCloud2 &cloud,
         PCL_ERROR ("[pcl::PCDReader::read] Error during lseek ()!\n");
         return (-1);
       }
-    
+
       // Read compressed size to compute how much must be mapped
       unsigned int compressed_size = 0;
       ssize_t num_read = io::raw_read (fd, &compressed_size, 4);
@@ -794,10 +786,10 @@ pcl::PCDReader::read (const std::string &file_name, pcl::PCLPointCloud2 &cloud,
 
     // Prepare the map
 #ifdef _WIN32
-    // As we don't know the real size of data (compressed or not), 
+    // As we don't know the real size of data (compressed or not),
     // we set dwMaximumSizeHigh = dwMaximumSizeLow = 0 so as to map the whole file
     HANDLE fm = CreateFileMapping ((HANDLE) _get_osfhandle (fd), NULL, PAGE_READONLY, 0, 0, NULL);
-    // As we don't know the real size of data (compressed or not), 
+    // As we don't know the real size of data (compressed or not),
     // we set dwNumberOfBytesToMap = 0 so as to map the whole file
     unsigned char *map = static_cast<unsigned char*> (MapViewOfFile (fm, FILE_MAP_READ, 0, 0, 0));
     if (map == NULL)
@@ -808,7 +800,7 @@ pcl::PCDReader::read (const std::string &file_name, pcl::PCLPointCloud2 &cloud,
       return (-1);
     }
 #else
-    unsigned char *map = static_cast<unsigned char*> (::mmap (0, mmap_size, PROT_READ, MAP_SHARED, fd, 0));
+    unsigned char *map = static_cast<unsigned char*> (::mmap (nullptr, mmap_size, PROT_READ, MAP_SHARED, fd, 0));
     if (map == reinterpret_cast<unsigned char*> (-1))    // MAP_FAILED
     {
       io::raw_close (fd);
@@ -872,7 +864,7 @@ pcl::PCDWriter::generateHeaderASCII (const pcl::PCLPointCloud2 &cloud,
   stream.imbue (std::locale::classic ());
   std::string result;
 
-  for (size_t d = 0; d < cloud.fields.size () - 1; ++d)
+  for (std::size_t d = 0; d < cloud.fields.size () - 1; ++d)
   {
     // Ignore invalid padded dimensions that are inherited from binary data
     if (cloud.fields[d].name != "_")
@@ -888,7 +880,7 @@ pcl::PCDWriter::generateHeaderASCII (const pcl::PCLPointCloud2 &cloud,
 
   stream.str ("");
   // Write the SIZE of each field
-  for (size_t d = 0; d < cloud.fields.size () - 1; ++d)
+  for (std::size_t d = 0; d < cloud.fields.size () - 1; ++d)
   {
     // Ignore invalid padded dimensions that are inherited from binary data
     if (cloud.fields[d].name != "_")
@@ -905,7 +897,7 @@ pcl::PCDWriter::generateHeaderASCII (const pcl::PCLPointCloud2 &cloud,
 
   stream.str ("");
   // Write the TYPE of each field
-  for (size_t d = 0; d < cloud.fields.size () - 1; ++d)
+  for (std::size_t d = 0; d < cloud.fields.size () - 1; ++d)
   {
     // Ignore invalid padded dimensions that are inherited from binary data
     if (cloud.fields[d].name != "_")
@@ -929,24 +921,24 @@ pcl::PCDWriter::generateHeaderASCII (const pcl::PCLPointCloud2 &cloud,
   result = stream.str ();
   boost::trim (result);
   oss << result << "\nCOUNT ";
-  
+
   stream.str ("");
   // Write the TYPE of each field
-  for (size_t d = 0; d < cloud.fields.size () - 1; ++d)
+  for (std::size_t d = 0; d < cloud.fields.size () - 1; ++d)
   {
     // Ignore invalid padded dimensions that are inherited from binary data
     if (cloud.fields[d].name == "_")
       continue;
-    int count = abs (static_cast<int> (cloud.fields[d].count));
-    if (count == 0) 
+    int count = std::abs (static_cast<int> (cloud.fields[d].count));
+    if (count == 0)
       count = 1;          // we simply cannot tolerate 0 counts (coming from older converter code)
-  
+
     stream << count << " ";
   }
   // Ignore invalid padded dimensions that are inherited from binary data
   if (cloud.fields[cloud.fields.size () - 1].name != "_")
   {
-    int count = abs (static_cast<int> (cloud.fields[cloud.fields.size () - 1].count));
+    int count = std::abs (static_cast<int> (cloud.fields[cloud.fields.size () - 1].count));
     if (count == 0)
       count = 1;
 
@@ -958,9 +950,9 @@ pcl::PCDWriter::generateHeaderASCII (const pcl::PCLPointCloud2 &cloud,
   boost::trim (result);
   oss << result << "\nWIDTH " << cloud.width << "\nHEIGHT " << cloud.height << "\n";
 
-  oss << "VIEWPOINT " << origin[0] << " " << origin[1] << " " << origin[2] << " " << orientation.w () << " " << 
+  oss << "VIEWPOINT " << origin[0] << " " << origin[1] << " " << origin[2] << " " << orientation.w () << " " <<
                          orientation.x () << " " << orientation.y () << " " << orientation.z () << "\n";
-  
+
   oss << "POINTS " << cloud.width * cloud.height << "\n";
 
   return (oss.str ());
@@ -980,9 +972,9 @@ pcl::PCDWriter::generateHeaderBinary (const pcl::PCLPointCloud2 &cloud,
 
   // Compute the total size of the fields
   unsigned int fsize = 0;
-  for (size_t i = 0; i < cloud.fields.size (); ++i)
-    fsize += cloud.fields[i].count * getFieldSize (cloud.fields[i].datatype);
- 
+  for (const auto &field : cloud.fields)
+    fsize += field.count * getFieldSize (field.datatype);
+
   // The size of the fields cannot be larger than point_step
   if (fsize > cloud.point_step)
   {
@@ -993,21 +985,21 @@ pcl::PCDWriter::generateHeaderBinary (const pcl::PCLPointCloud2 &cloud,
   std::stringstream field_names, field_types, field_sizes, field_counts;
   // Check if the size of the fields is smaller than the size of the point step
   unsigned int toffset = 0;
-  for (size_t i = 0; i < cloud.fields.size (); ++i)
+  for (std::size_t i = 0; i < cloud.fields.size (); ++i)
   {
     // If field offsets do not match, then we need to create fake fields
     if (toffset != cloud.fields[i].offset)
     {
       // If we're at the last "valid" field
-      int fake_offset = (i == 0) ? 
+      int fake_offset = (i == 0) ?
         // Use the current_field offset
         (cloud.fields[i].offset)
         :
         // Else, do cur_field.offset - prev_field.offset + sizeof (prev_field)
-        (cloud.fields[i].offset - 
-        (cloud.fields[i-1].offset + 
-         cloud.fields[i-1].count * getFieldSize (cloud.fields[i].datatype)));
-      
+        (cloud.fields[i].offset -
+        (cloud.fields[i-1].offset +
+         cloud.fields[i-1].count * getFieldSize (cloud.fields[i-1].datatype)));
+
       toffset += fake_offset;
 
       field_names << " _";  // By convention, _ is an invalid field name
@@ -1021,7 +1013,7 @@ pcl::PCDWriter::generateHeaderBinary (const pcl::PCLPointCloud2 &cloud,
     field_names << " " << cloud.fields[i].name;
     field_sizes << " " << pcl::getFieldSize (cloud.fields[i].datatype);
     field_types << " " << pcl::getFieldType (cloud.fields[i].datatype);
-    int count = abs (static_cast<int> (cloud.fields[i].count));
+    int count = std::abs (static_cast<int> (cloud.fields[i].count));
     if (count == 0) count = 1;  // check for 0 counts (coming from older converter code)
     field_counts << " " << count;
   }
@@ -1062,9 +1054,9 @@ pcl::PCDWriter::generateHeaderBinaryCompressed (std::ostream &os,
 
   // Compute the total size of the fields
   unsigned int fsize = 0;
-  for (size_t i = 0; i < cloud.fields.size (); ++i)
-    fsize += cloud.fields[i].count * getFieldSize (cloud.fields[i].datatype);
- 
+  for (const auto &field : cloud.fields)
+    fsize += field.count * getFieldSize (field.datatype);
+
   // The size of the fields cannot be larger than point_step
   if (fsize > cloud.point_step)
   {
@@ -1074,27 +1066,27 @@ pcl::PCDWriter::generateHeaderBinaryCompressed (std::ostream &os,
 
   std::stringstream field_names, field_types, field_sizes, field_counts;
   // Check if the size of the fields is smaller than the size of the point step
-  for (size_t i = 0; i < cloud.fields.size (); ++i)
+  for (const auto &field : cloud.fields)
   {
-    if (cloud.fields[i].name == "_")
+    if (field.name == "_")
       continue;
     // Add the regular dimension
-    field_names << " " << cloud.fields[i].name;
-    field_sizes << " " << pcl::getFieldSize (cloud.fields[i].datatype);
-    field_types << " " << pcl::getFieldType (cloud.fields[i].datatype);
-    int count = abs (static_cast<int> (cloud.fields[i].count));
+    field_names << " " << field.name;
+    field_sizes << " " << pcl::getFieldSize (field.datatype);
+    field_types << " " << pcl::getFieldType (field.datatype);
+    int count = std::abs (static_cast<int> (field.count));
     if (count == 0) count = 1;  // check for 0 counts (coming from older converter code)
     field_counts << " " << count;
   }
   os  << field_names.str ();
-  os  << "\nSIZE" << field_sizes.str () 
-      << "\nTYPE" << field_types.str () 
+  os  << "\nSIZE" << field_sizes.str ()
+      << "\nTYPE" << field_types.str ()
       << "\nCOUNT" << field_counts.str ();
   os  << "\nWIDTH " << cloud.width << "\nHEIGHT " << cloud.height << "\n";
 
   os  << "VIEWPOINT " << origin[0] << " " << origin[1] << " " << origin[2] << " " << orientation.w () << " " << 
                          orientation.x () << " " << orientation.y () << " " << orientation.z () << "\n";
-  
+
   os  << "POINTS " << cloud.width * cloud.height << "\n";
 
   return (os ? 0 : -1);
@@ -1156,7 +1148,7 @@ pcl::PCDWriter::writeASCII (const std::string &file_name, const pcl::PCLPointClo
         continue;
 
       int count = cloud.fields[d].count;
-      if (count == 0) 
+      if (count == 0)
         count = 1;          // we simply cannot tolerate 0 counts (coming from older converter code)
 
       for (int c = 0; c < count; ++c)
@@ -1298,7 +1290,7 @@ pcl::PCDWriter::writeBinary (const std::string &file_name, const pcl::PCLPointCl
   CloseHandle (fm);
 
 #else
-  char *map = static_cast<char*> (mmap (0, static_cast<size_t> (data_idx + cloud.data.size ()), PROT_READ | PROT_WRITE, MAP_SHARED, fd, 0));
+  char *map = static_cast<char*> (mmap (nullptr, static_cast<std::size_t> (data_idx + cloud.data.size ()), PROT_READ | PROT_WRITE, MAP_SHARED, fd, 0));
   if (map == reinterpret_cast<char*> (-1))    // MAP_FAILED
   {
     io::raw_close (fd);
@@ -1309,7 +1301,7 @@ pcl::PCDWriter::writeBinary (const std::string &file_name, const pcl::PCLPointCl
 #endif
 
   // copy header
-  memcpy (&map[0], oss.str().c_str (), static_cast<size_t> (data_idx));
+  memcpy (&map[0], oss.str().c_str (), static_cast<std::size_t> (data_idx));
 
   // Copy the data
   memcpy (&map[0] + data_idx, &cloud.data[0], cloud.data.size ());
@@ -1317,14 +1309,14 @@ pcl::PCDWriter::writeBinary (const std::string &file_name, const pcl::PCLPointCl
 #ifndef _WIN32
   // If the user set the synchronization flag on, call msync
   if (map_synchronization_)
-    msync (map, static_cast<size_t> (data_idx + cloud.data.size ()), MS_SYNC);
+    msync (map, static_cast<std::size_t> (data_idx + cloud.data.size ()), MS_SYNC);
 #endif
 
   // Unmap the pages of memory
 #ifdef _WIN32
     UnmapViewOfFile (map);
 #else
-  if (::munmap (map, static_cast<size_t> (data_idx + cloud.data.size ())) == -1)
+  if (::munmap (map, static_cast<std::size_t> (data_idx + cloud.data.size ())) == -1)
   {
     io::raw_close (fd);
     resetLockingPermissions (file_name, file_lock);
@@ -1358,34 +1350,34 @@ pcl::PCDWriter::writeBinaryCompressed (std::ostream &os, const pcl::PCLPointClou
     return (-1);
   }
 
-  size_t fsize = 0;
-  size_t data_size = 0;
-  size_t nri = 0;
+  std::size_t fsize = 0;
+  std::size_t data_size = 0;
+  std::size_t nri = 0;
   std::vector<pcl::PCLPointField> fields (cloud.fields.size ());
   std::vector<int> fields_sizes (cloud.fields.size ());
   // Compute the total size of the fields
-  for (size_t i = 0; i < cloud.fields.size (); ++i)
+  for (const auto &field : cloud.fields)
   {
-    if (cloud.fields[i].name == "_")
+    if (field.name == "_")
       continue;
-    
-    fields_sizes[nri] = cloud.fields[i].count * pcl::getFieldSize (cloud.fields[i].datatype);
+
+    fields_sizes[nri] = field.count * pcl::getFieldSize (field.datatype);
     fsize += fields_sizes[nri];
-    fields[nri] = cloud.fields[i];
+    fields[nri] = field;
     ++nri;
   }
   fields_sizes.resize (nri);
   fields.resize (nri);
- 
+
   // Compute the size of data
   data_size = cloud.width * cloud.height * fsize;
 
   // If the data is too large the two 32 bit integers used to store the
   // compressed and uncompressed size will overflow.
-  if (data_size * 3 / 2 > std::numeric_limits<uint32_t>::max ())
+  if (data_size * 3 / 2 > std::numeric_limits<std::uint32_t>::max ())
   {
     PCL_ERROR ("[pcl::PCDWriter::writeBinaryCompressed] The input data exceeds the maximum size for compressed version 0.7 pcds of %l bytes.\n",
-               static_cast<size_t> (std::numeric_limits<uint32_t>::max ()) * 2 / 3);
+               static_cast<std::size_t> (std::numeric_limits<std::uint32_t>::max ()) * 2 / 3);
     return (-2);
   }
 
@@ -1405,17 +1397,17 @@ pcl::PCDWriter::writeBinaryCompressed (std::ostream &os, const pcl::PCLPointClou
   //   pters[3] = &only_valid_data[offset_of_plane_RGB];
   //
   std::vector<char*> pters (fields.size ());
-  int toff = 0;
-  for (size_t i = 0; i < pters.size (); ++i)
+  std::size_t toff = 0;
+  for (std::size_t i = 0; i < pters.size (); ++i)
   {
     pters[i] = &only_valid_data[toff];
     toff += fields_sizes[i] * cloud.width * cloud.height;
   }
-  
+
   // Go over all the points, and copy the data in the appropriate places
-  for (size_t i = 0; i < cloud.width * cloud.height; ++i)
+  for (std::size_t i = 0; i < cloud.width * cloud.height; ++i)
   {
-    for (size_t j = 0; j < pters.size (); ++j)
+    for (std::size_t j = 0; j < pters.size (); ++j)
     {
       memcpy (pters[j], &cloud.data[i * cloud.point_step + fields[j].offset], fields_sizes[j]);
       // Increment the pointer
@@ -1483,9 +1475,9 @@ pcl::PCDWriter::writeBinaryCompressed (const std::string &file_name, const pcl::
 
 #ifndef _WIN32
   // Stretch the file size to the size of the data
-  size_t page_size = getpagesize ();
-  size_t size_pages = ostr.size () / page_size;
-  size_t partial_pages = (size_pages * page_size < ostr.size ()) ? 1 : 0;
+  std::size_t page_size = getpagesize ();
+  std::size_t size_pages = ostr.size () / page_size;
+  std::size_t partial_pages = (size_pages * page_size < ostr.size ()) ? 1 : 0;
   long result = io::raw_lseek (fd, (size_pages + partial_pages) * page_size - 1, SEEK_SET);
   if (result < 0)
   {
@@ -1513,7 +1505,7 @@ pcl::PCDWriter::writeBinaryCompressed (const std::string &file_name, const pcl::
   CloseHandle (fm);
 
 #else
-  char *map = static_cast<char*> (::mmap (0, ostr.size (), PROT_WRITE, MAP_SHARED, fd, 0));
+  char *map = static_cast<char*> (::mmap (nullptr, ostr.size (), PROT_WRITE, MAP_SHARED, fd, 0));
   if (map == reinterpret_cast<char*> (-1))    // MAP_FAILED
   {
     io::raw_close (fd);
