@@ -85,7 +85,7 @@ pcl::RobotEyeGrabber::getFramesPerSecond () const
 bool
 pcl::RobotEyeGrabber::isRunning () const
 {
-  return (socket_thread_ != NULL);
+  return (socket_thread_ != nullptr);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -131,7 +131,7 @@ pcl::RobotEyeGrabber::setSignalPointCloudSize (std::size_t numberOfPoints)
 }
 
 /////////////////////////////////////////////////////////////////////////////
-boost::shared_ptr<pcl::PointCloud<pcl::PointXYZI> >
+pcl::PointCloud<pcl::PointXYZI>::Ptr
 pcl::RobotEyeGrabber::getPointCloud () const
 {
   return point_cloud_xyzi_;
@@ -160,10 +160,10 @@ pcl::RobotEyeGrabber::consumerThreadLoop ()
 
 /////////////////////////////////////////////////////////////////////////////
 void
-pcl::RobotEyeGrabber::convertPacketData (unsigned char *data_packet, size_t length)
+pcl::RobotEyeGrabber::convertPacketData (unsigned char *data_packet, std::size_t length)
 {
   //Check for the presence of the header
-  size_t offset = 0;
+  std::size_t offset = 0;
   //The old packet data format does not start with an E since it just starts with laser data
   if(data_packet[0] != 'E')
   {
@@ -174,11 +174,11 @@ pcl::RobotEyeGrabber::convertPacketData (unsigned char *data_packet, size_t leng
   {
     //The new packet data format contains this as a header
     //char[6]  "EBRBEP"
-    //uint32_t Timestamp // counts of a 66 MHz clock since power-on of eye.
-    size_t response_size = 6; //"EBRBEP"
+    //std::uint32_t Timestamp // counts of a 66 MHz clock since power-on of eye.
+    std::size_t response_size = 6; //"EBRBEP"
     if( !strncmp((char*)(data_packet), "EBRBEP", response_size) )
     {
-      boost::uint32_t timestamp; // counts of a 66 MHz clock since power-on of eye.
+      std::uint32_t timestamp; // counts of a 66 MHz clock since power-on of eye.
       computeTimestamp(timestamp, data_packet + response_size);
       //std::cout << "Timestamp: " << timestamp << std::endl;
       offset = (response_size + sizeof(timestamp));
@@ -190,10 +190,10 @@ pcl::RobotEyeGrabber::convertPacketData (unsigned char *data_packet, size_t leng
     }
   }
 
-  const size_t bytes_per_point = 8;
-  const size_t total_points = (length - offset)/ bytes_per_point;
+  const std::size_t bytes_per_point = 8;
+  const std::size_t total_points = (length - offset)/ bytes_per_point;
 
-  for (size_t i = 0; i < total_points; ++i)
+  for (std::size_t i = 0; i < total_points; ++i)
   {
     PointXYZI xyzi;
     computeXYZI (xyzi, data_packet + i*bytes_per_point + offset);
@@ -217,28 +217,24 @@ pcl::RobotEyeGrabber::convertPacketData (unsigned char *data_packet, size_t leng
 void
 pcl::RobotEyeGrabber::computeXYZI (pcl::PointXYZI& point, unsigned char* point_data)
 {
-  uint16_t buffer = 0;
+  std::uint16_t buffer = 0;
   double az = 0.0;
   double el = 0.0;
   double range = 0.0;
-  uint16_t intensity = 0;
+  std::uint16_t intensity = 0;
 
-  buffer = 0x00;
   buffer = point_data[0] << 8;
   buffer |= point_data[1]; // First 2-byte read will be Azimuth
   az = (buffer / 100.0);
 
-  buffer = 0x00;
   buffer =  point_data[2] << 8;
   buffer |= point_data[3]; // Second 2-byte read will be Elevation
   el = (signed short int)buffer / 100.0;
 
-  buffer = 0x00;
   buffer =  point_data[4] << 8;
   buffer |= point_data[5]; // Third 2-byte read will be Range
   range = (signed short int)buffer / 100.0;
 
-  buffer = 0x00;
   buffer =  point_data[6] << 8;
   buffer |= point_data[7]; // Fourth 2-byte read will be Intensity
   intensity = buffer;
@@ -251,11 +247,9 @@ pcl::RobotEyeGrabber::computeXYZI (pcl::PointXYZI& point, unsigned char* point_d
 
 /////////////////////////////////////////////////////////////////////////////
 void
-pcl::RobotEyeGrabber::computeTimestamp (boost::uint32_t& timestamp, unsigned char* point_data)
+pcl::RobotEyeGrabber::computeTimestamp (std::uint32_t& timestamp, unsigned char* point_data)
 {
-  boost::uint32_t buffer = 0;
-
-  buffer = 0x00;
+  std::uint32_t buffer;
   buffer = point_data[0] << 24;
   buffer |= point_data[1] << 16;
   buffer |= point_data[2] << 8;
@@ -280,8 +274,9 @@ pcl::RobotEyeGrabber::asyncSocketReceive ()
 {
   // expecting at most max_length bytes (UDP packet).
   socket_->async_receive_from(boost::asio::buffer(receive_buffer_, MAX_LENGTH), sender_endpoint_,
-    boost::bind(&RobotEyeGrabber::socketCallback, this, boost::asio::placeholders::error,
-    boost::asio::placeholders::bytes_transferred));
+    [this] (const boost::system::error_code& error, std::size_t number_of_bytes) {
+      socketCallback (error, number_of_bytes);
+    });
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -326,8 +321,8 @@ pcl::RobotEyeGrabber::start ()
 
   terminate_thread_ = false;
   resetPointCloud ();
-  consumer_thread_.reset(new boost::thread (boost::bind (&RobotEyeGrabber::consumerThreadLoop, this)));
-  socket_thread_.reset(new boost::thread (boost::bind (&RobotEyeGrabber::socketThreadLoop, this)));
+  consumer_thread_.reset(new std::thread (&RobotEyeGrabber::consumerThreadLoop, this));
+  socket_thread_.reset(new std::thread (&RobotEyeGrabber::socketThreadLoop, this));
 }
 
 /////////////////////////////////////////////////////////////////////////////
