@@ -36,8 +36,9 @@
  *
  */
 
-#ifndef PCL_KEYPOINTS_AGAST_KEYPOINT_2D_H_
-#define PCL_KEYPOINTS_AGAST_KEYPOINT_2D_H_
+#pragma once
+
+#include <array>
 
 #include <pcl/point_cloud.h>
 #include <pcl/point_types.h>
@@ -62,8 +63,8 @@ namespace pcl
       class PCL_EXPORTS AbstractAgastDetector
       {
         public:
-          typedef boost::shared_ptr<AbstractAgastDetector> Ptr;
-          typedef boost::shared_ptr<const AbstractAgastDetector> ConstPtr;
+          using Ptr = shared_ptr<AbstractAgastDetector>;
+          using ConstPtr = shared_ptr<const AbstractAgastDetector>;
 
           /** \brief Constructor. 
             * \param[in] width the width of the image to process
@@ -71,8 +72,8 @@ namespace pcl
             * \param[in] threshold the corner detection threshold
             * \param[in] bmax the max image value (default: 255)
             */
-          AbstractAgastDetector (const size_t width, 
-                                 const size_t height, 
+          AbstractAgastDetector (const std::size_t width, 
+                                 const std::size_t height, 
                                  const double threshold,
                                  const double bmax) 
             : width_ (width)
@@ -239,9 +240,9 @@ namespace pcl
                                std::vector<ScoreIndex> & scores);
 
           /** \brief Width of the image to process. */
-          size_t width_;
+          std::size_t width_;
           /** \brief Height of the image to process. */
-          size_t height_;
+          std::size_t height_;
 
           /** \brief Threshold for corner detection. */
           double threshold_;
@@ -264,8 +265,8 @@ namespace pcl
       class PCL_EXPORTS AgastDetector7_12s : public AbstractAgastDetector
       {
         public:
-          typedef boost::shared_ptr<AgastDetector7_12s> Ptr;
-          typedef boost::shared_ptr<const AgastDetector7_12s> ConstPtr;
+          using Ptr = shared_ptr<AgastDetector7_12s>;
+          using ConstPtr = shared_ptr<const AgastDetector7_12s>;
 
           /** \brief Constructor. 
             * \param[in] width the width of the image to process
@@ -273,8 +274,8 @@ namespace pcl
             * \param[in] threshold the corner detection threshold
             * \param[in] bmax the max image value (default: 255)
             */
-          AgastDetector7_12s (const size_t width, 
-                              const size_t height, 
+          AgastDetector7_12s (const std::size_t width, 
+                              const std::size_t height, 
                               const double threshold,
                               const double bmax = 255) 
             : AbstractAgastDetector (width, height, threshold, bmax)
@@ -289,50 +290,39 @@ namespace pcl
             * \param im 
             */
           int 
-          computeCornerScore (const unsigned char* im) const;
+          computeCornerScore (const unsigned char* im) const override;
 
           /** \brief Computes corner score. 
             * \param im 
             */
           int 
-          computeCornerScore (const float* im) const;
+          computeCornerScore (const float* im) const override;
 
           /** \brief Detects points of interest (i.e., keypoints) in the given image
             * \param[in] im the image to detect keypoints in 
             * \param[out] corners_all the resultant set of keypoints detected
             */
           void 
-          detect (const unsigned char* im, std::vector<pcl::PointUV, Eigen::aligned_allocator<pcl::PointUV> > &corners_all) const;
+          detect (const unsigned char* im, std::vector<pcl::PointUV, Eigen::aligned_allocator<pcl::PointUV> > &corners_all) const override;
 
           /** \brief Detects points of interest (i.e., keypoints) in the given image
             * \param[in] im the image to detect keypoints in 
             * \param[out] corners_all the resultant set of keypoints detected
             */
           void 
-          detect (const float* im, std::vector<pcl::PointUV, Eigen::aligned_allocator<pcl::PointUV> > &corners_all) const;
+          detect (const float* im, std::vector<pcl::PointUV, Eigen::aligned_allocator<pcl::PointUV> > &corners_all) const override;
 
         protected:
           /** \brief Initializes the sample pattern. */
           void 
-          initPattern ();
+          initPattern () override;
 
         private:
           /** \brief Border width. */
           static const int border_width_ = 2;
 
           // offsets defining the sample pattern
-          int_fast16_t s_offset0_;
-          int_fast16_t s_offset1_;
-          int_fast16_t s_offset2_;
-          int_fast16_t s_offset3_;
-          int_fast16_t s_offset4_;
-          int_fast16_t s_offset5_;
-          int_fast16_t s_offset6_;
-          int_fast16_t s_offset7_;
-          int_fast16_t s_offset8_;
-          int_fast16_t s_offset9_;
-          int_fast16_t s_offset10_;
-          int_fast16_t s_offset11_;
+          std::array<std::int_fast16_t, 12> offset_;
       };
 
       /** \brief Detector class for AGAST corner point detector (5_8). 
@@ -346,8 +336,8 @@ namespace pcl
       class PCL_EXPORTS AgastDetector5_8 : public AbstractAgastDetector
       {
         public:
-          typedef boost::shared_ptr<AgastDetector5_8> Ptr;
-          typedef boost::shared_ptr<const AgastDetector5_8> ConstPtr;
+          using Ptr = shared_ptr<AgastDetector5_8>;
+          using ConstPtr = shared_ptr<const AgastDetector5_8>;
 
           /** \brief Constructor. 
             * \param[in] width the width of the image to process
@@ -355,8 +345,8 @@ namespace pcl
             * \param[in] threshold the corner detection threshold
             * \param[in] bmax the max image value (default: 255)
             */
-          AgastDetector5_8 (const size_t width, 
-                            const size_t height, 
+          AgastDetector5_8 (const std::size_t width, 
+                            const std::size_t height, 
                             const double threshold,
                             const double bmax = 255) 
             : AbstractAgastDetector (width, height, threshold, bmax)
@@ -371,46 +361,39 @@ namespace pcl
             * \param im 
             */
           int 
-          computeCornerScore (const unsigned char* im) const;
+          computeCornerScore (const unsigned char* im) const override;
 
           /** \brief Computes corner score. 
             * \param im 
             */
           int 
-          computeCornerScore (const float* im) const;
+          computeCornerScore (const float* im) const override;
 
           /** \brief Detects points of interest (i.e., keypoints) in the given image
             * \param[in] im the image to detect keypoints in 
             * \param[out] corners_all the resultant set of keypoints detected
             */
           void 
-          detect (const unsigned char* im, std::vector<pcl::PointUV, Eigen::aligned_allocator<pcl::PointUV> > &corners_all) const;
+          detect (const unsigned char* im, std::vector<pcl::PointUV, Eigen::aligned_allocator<pcl::PointUV> > &corners_all) const override;
 
           /** \brief Detects points of interest (i.e., keypoints) in the given image
             * \param[in] im the image to detect keypoints in 
             * \param[out] corners_all the resultant set of keypoints detected
             */
           void 
-          detect (const float* im, std::vector<pcl::PointUV, Eigen::aligned_allocator<pcl::PointUV> > &corners_all) const;
+          detect (const float* im, std::vector<pcl::PointUV, Eigen::aligned_allocator<pcl::PointUV> > &corners_all) const override;
 
         protected:
           /** \brief Initializes the sample pattern. */
           void 
-          initPattern ();
+          initPattern () override;
 
         private:
           /** \brief Border width. */
           static const int border_width_ = 1;
 
           // offsets defining the sample pattern
-          int_fast16_t s_offset0_;
-          int_fast16_t s_offset1_;
-          int_fast16_t s_offset2_;
-          int_fast16_t s_offset3_;
-          int_fast16_t s_offset4_;
-          int_fast16_t s_offset5_;
-          int_fast16_t s_offset6_;
-          int_fast16_t s_offset7_;
+          std::array<std::int_fast16_t, 8> offset_;
       };
 
       /** \brief Detector class for AGAST corner point detector (OAST 9_16). 
@@ -424,8 +407,8 @@ namespace pcl
       class PCL_EXPORTS OastDetector9_16 : public AbstractAgastDetector
       {
         public:
-          typedef boost::shared_ptr<OastDetector9_16> Ptr;
-          typedef boost::shared_ptr<const OastDetector9_16> ConstPtr;
+          using Ptr = shared_ptr<OastDetector9_16>;
+          using ConstPtr = shared_ptr<const OastDetector9_16>;
 
           /** \brief Constructor. 
             * \param[in] width the width of the image to process
@@ -433,8 +416,8 @@ namespace pcl
             * \param[in] threshold the corner detection threshold
             * \param[in] bmax the max image value (default: 255)
             */
-          OastDetector9_16 (const size_t width, 
-                            const size_t height, 
+          OastDetector9_16 (const std::size_t width, 
+                            const std::size_t height, 
                             const double threshold,
                             const double bmax = 255) 
             : AbstractAgastDetector (width, height, threshold, bmax)
@@ -449,54 +432,39 @@ namespace pcl
             * \param im 
             */
           int 
-          computeCornerScore (const unsigned char* im) const;
+          computeCornerScore (const unsigned char* im) const override;
 
           /** \brief Computes corner score. 
             * \param im 
             */
           int 
-          computeCornerScore (const float* im) const;
+          computeCornerScore (const float* im) const override;
 
           /** \brief Detects points of interest (i.e., keypoints) in the given image
             * \param[in] im the image to detect keypoints in 
             * \param[out] corners_all the resultant set of keypoints detected
             */
           void 
-          detect (const unsigned char* im, std::vector<pcl::PointUV, Eigen::aligned_allocator<pcl::PointUV> > &corners_all) const;
+          detect (const unsigned char* im, std::vector<pcl::PointUV, Eigen::aligned_allocator<pcl::PointUV> > &corners_all) const override;
 
           /** \brief Detects points of interest (i.e., keypoints) in the given image
             * \param[in] im the image to detect keypoints in 
             * \param[out] corners_all the resultant set of keypoints detected
             */
           void 
-          detect (const float* im, std::vector<pcl::PointUV, Eigen::aligned_allocator<pcl::PointUV> > &corners_all) const;
+          detect (const float* im, std::vector<pcl::PointUV, Eigen::aligned_allocator<pcl::PointUV> > &corners_all) const override;
 
         protected:
           /** \brief Initializes the sample pattern. */
           void 
-          initPattern ();
+          initPattern () override;
 
         private:
           /** \brief Border width. */
           static const int border_width_ = 3;
 
           // offsets defining the sample pattern
-          int_fast16_t s_offset0_;
-          int_fast16_t s_offset1_;
-          int_fast16_t s_offset2_;
-          int_fast16_t s_offset3_;
-          int_fast16_t s_offset4_;
-          int_fast16_t s_offset5_;
-          int_fast16_t s_offset6_;
-          int_fast16_t s_offset7_;
-          int_fast16_t s_offset8_;
-          int_fast16_t s_offset9_;
-          int_fast16_t s_offset10_;
-          int_fast16_t s_offset11_;
-          int_fast16_t s_offset12_;
-          int_fast16_t s_offset13_;
-          int_fast16_t s_offset14_;
-          int_fast16_t s_offset15_;
+          std::array<std::int_fast16_t, 16> offset_;
       };
     } // namespace agast
   } // namespace keypoints
@@ -520,7 +488,7 @@ namespace pcl
         {
           pcl::PointCloud<pcl::PointUV> output_temp;
           detector->applyNonMaxSuppression (image_data, tmp_cloud, output_temp);
-          pcl::copyPointCloud<pcl::PointUV, Out> (output_temp, output);
+          pcl::copyPointCloud (output_temp, output);
         }
       };
 
@@ -548,7 +516,7 @@ namespace pcl
         {
           pcl::PointCloud<pcl::PointUV> output_temp;
           detector->detectKeypoints (image_data, output_temp);
-          pcl::copyPointCloud<pcl::PointUV, Out> (output_temp, output);
+          pcl::copyPointCloud (output_temp, output);
         }
       };
 
@@ -587,12 +555,12 @@ namespace pcl
   class AgastKeypoint2DBase : public Keypoint<PointInT, PointOutT>
   {
     public:
-      typedef typename Keypoint<PointInT, PointOutT>::PointCloudIn PointCloudIn;
-      typedef typename Keypoint<PointInT, PointOutT>::PointCloudOut PointCloudOut;
-      typedef typename Keypoint<PointInT, PointOutT>::KdTree KdTree;
-      typedef typename PointCloudIn::ConstPtr PointCloudInConstPtr;
+      using PointCloudIn = typename Keypoint<PointInT, PointOutT>::PointCloudIn;
+      using PointCloudOut = typename Keypoint<PointInT, PointOutT>::PointCloudOut;
+      using KdTree = typename Keypoint<PointInT, PointOutT>::KdTree;
+      using PointCloudInConstPtr = typename PointCloudIn::ConstPtr;
 
-      typedef pcl::keypoints::agast::AbstractAgastDetector::Ptr AgastDetectorPtr;
+      using AgastDetectorPtr = pcl::keypoints::agast::AbstractAgastDetector::Ptr;
      
       using Keypoint<PointInT, PointOutT>::name_;
       using Keypoint<PointInT, PointOutT>::input_;
@@ -604,14 +572,13 @@ namespace pcl
         : threshold_ (10)
         , apply_non_max_suppression_ (true)
         , bmax_ (255)
-        , detector_ ()
         , nr_max_keypoints_ (std::numeric_limits<unsigned int>::max ())
       {
         k_ = 1;
       }
 
       /** \brief Destructor. */
-      virtual ~AgastKeypoint2DBase ()
+      ~AgastKeypoint2DBase ()
       {
       }
 
@@ -695,13 +662,13 @@ namespace pcl
 
       /** \brief Initializes everything and checks whether input data is fine. */
       bool 
-      initCompute ();
+      initCompute () override;
       
       /** \brief Detects the keypoints.
         * \param[out] output the resultant keypoints
         */
-      virtual void 
-      detectKeypoints (PointCloudOut &output) = 0;
+      void 
+      detectKeypoints (PointCloudOut &output) override = 0;
 
       /** \brief Intensity field accessor. */
       IntensityT intensity_;
@@ -751,7 +718,7 @@ namespace pcl
   class AgastKeypoint2D : public AgastKeypoint2DBase<PointInT, PointOutT, pcl::common::IntensityFieldAccessor<PointInT> >
   {
     public:
-      typedef typename Keypoint<PointInT, PointOutT>::PointCloudOut PointCloudOut;
+      using PointCloudOut = typename Keypoint<PointInT, PointOutT>::PointCloudOut;
 
       using Keypoint<PointInT, PointOutT>::name_;
       using Keypoint<PointInT, PointOutT>::input_;
@@ -771,7 +738,7 @@ namespace pcl
       }
 
       /** \brief Destructor. */
-      virtual ~AgastKeypoint2D ()
+      ~AgastKeypoint2D ()
       {
       }
 
@@ -779,8 +746,8 @@ namespace pcl
       /** \brief Detects the keypoints.
         * \param[out] output the resultant keypoints
         */
-      virtual void 
-      detectKeypoints (PointCloudOut &output);
+      void 
+      detectKeypoints (PointCloudOut &output) override;
   };
 
   /** \brief Detects 2D AGAST corner points. Based on the original work and
@@ -822,7 +789,7 @@ namespace pcl
       }
 
       /** \brief Destructor. */
-      virtual ~AgastKeypoint2D ()
+      ~AgastKeypoint2D ()
       {
       }
 
@@ -830,13 +797,10 @@ namespace pcl
       /** \brief Detects the keypoints.
         * \param[out] output the resultant keypoints
         */
-      virtual void 
-      detectKeypoints (pcl::PointCloud<pcl::PointUV> &output);
+      void 
+      detectKeypoints (pcl::PointCloud<pcl::PointUV> &output) override;
   };
 
 }
 
 #include <pcl/keypoints/impl/agast_2d.hpp>
-
-#endif
-
