@@ -39,7 +39,7 @@
 #ifndef PCL_OCTREE_POINTCLOUD_HPP_
 #define PCL_OCTREE_POINTCLOUD_HPP_
 
-#include <assert.h>
+#include <cassert>
 
 #include <pcl/common/common.h>
 #include <pcl/octree/impl/octree_base.hpp>
@@ -54,34 +54,26 @@ pcl::octree::OctreePointCloud<PointT, LeafContainerT, BranchContainerT, OctreeT>
   assert (resolution > 0.0f);
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
-template<typename PointT, typename LeafContainerT, typename BranchContainerT, typename OctreeT>
-pcl::octree::OctreePointCloud<PointT, LeafContainerT, BranchContainerT, OctreeT>::~OctreePointCloud ()
-{
-}
-
 //////////////////////////////////////////////////////////////////////////////////////////////
 template<typename PointT, typename LeafContainerT, typename BranchContainerT, typename OctreeT> void
 pcl::octree::OctreePointCloud<PointT, LeafContainerT, BranchContainerT, OctreeT>::addPointsFromInputCloud ()
 {
-  size_t i;
-
   if (indices_)
   {
-    for (std::vector<int>::const_iterator current = indices_->begin (); current != indices_->end (); ++current)
+    for (const int &index : *indices_)
     {
-      assert( (*current>=0) && (*current < static_cast<int> (input_->points.size ())));
+      assert( (index >= 0) && (index < static_cast<int> (input_->points.size ())));
       
-      if (isFinite (input_->points[*current]))
+      if (isFinite (input_->points[index]))
       {
         // add points to octree
-        this->addPointIdx (*current);
+        this->addPointIdx (index);
       }
     }
   }
   else
   {
-    for (i = 0; i < input_->points.size (); i++)
+    for (std::size_t i = 0; i < input_->points.size (); i++)
     {
       if (isFinite (input_->points[i]))
       {
@@ -223,7 +215,7 @@ pcl::octree::OctreePointCloud<PointT, LeafContainerT, BranchContainerT, OctreeT>
   float norm = direction.norm ();
   direction.normalize ();
 
-  const float step_size = static_cast<const float> (resolution_) * precision;
+  const float step_size = static_cast<float> (resolution_) * precision;
   // Ensure we get at least one step for the first voxel.
   const int nsteps = std::max (1, static_cast<int> (norm / step_size));
 
@@ -234,7 +226,7 @@ pcl::octree::OctreePointCloud<PointT, LeafContainerT, BranchContainerT, OctreeT>
   // Walk along the line segment with small steps.
   for (int i = 0; i < nsteps; ++i)
   {
-    Eigen::Vector3f p = origin + (direction * step_size * static_cast<const float> (i));
+    Eigen::Vector3f p = origin + (direction * step_size * static_cast<float> (i));
 
     PointT octree_p;
     octree_p.x = p.x ();
@@ -522,7 +514,7 @@ pcl::octree::OctreePointCloud<PointT, LeafContainerT, BranchContainerT, OctreeT>
   if (depth_mask)
   {
     // get amount of objects in leaf container
-    size_t leaf_obj_count = (*leaf_node)->getSize ();
+    std::size_t leaf_obj_count = (*leaf_node)->getSize ();
 
   // copy leaf data
     std::vector<int> leafIndices;
@@ -538,16 +530,13 @@ pcl::octree::OctreePointCloud<PointT, LeafContainerT, BranchContainerT, OctreeT>
     BranchNode* childBranch = this->createBranchChild (*parent_branch, child_idx);
     this->branch_count_ ++;
 
-    typename std::vector<int>::iterator it = leafIndices.begin();
-    typename std::vector<int>::const_iterator it_end = leafIndices.end();
-
     // add data to new branch
     OctreeKey new_index_key;
 
-    for (it = leafIndices.begin(); it!=it_end; ++it)
+    for (const int &leafIndex : leafIndices)
     {
 
-      const PointT& point_from_index = input_->points[*it];
+      const PointT& point_from_index = input_->points[leafIndex];
       // generate key
       genOctreeKeyforPoint (point_from_index, new_index_key);
 
@@ -555,7 +544,7 @@ pcl::octree::OctreePointCloud<PointT, LeafContainerT, BranchContainerT, OctreeT>
       BranchNode* newBranchParent;
       this->createLeafRecursive (new_index_key, depth_mask, childBranch, newLeaf, newBranchParent);
 
-      (*newLeaf)->addPointIndex(*it);
+      (*newLeaf)->addPointIndex(leafIndex);
     }
   }
 
@@ -586,7 +575,7 @@ pcl::octree::OctreePointCloud<PointT, LeafContainerT, BranchContainerT, OctreeT>
   if (this->dynamic_depth_enabled_ && depth_mask)
   {
     // get amount of objects in leaf container
-    size_t leaf_obj_count = (*leaf_node)->getSize ();
+    std::size_t leaf_obj_count = (*leaf_node)->getSize ();
 
     while  (leaf_obj_count>=max_objs_per_leaf_ && depth_mask)
     {
@@ -631,16 +620,16 @@ pcl::octree::OctreePointCloud<PointT, LeafContainerT, BranchContainerT, OctreeT>
   const float minValue = std::numeric_limits<float>::epsilon();
 
   // find maximum key values for x, y, z
-  max_key_x = static_cast<unsigned int> (ceil ((max_x_ - min_x_ - minValue) / resolution_));
-  max_key_y = static_cast<unsigned int> (ceil ((max_y_ - min_y_ - minValue) / resolution_));
-  max_key_z = static_cast<unsigned int> (ceil ((max_z_ - min_z_ - minValue) / resolution_));
+  max_key_x = static_cast<unsigned int> (std::ceil ((max_x_ - min_x_ - minValue) / resolution_));
+  max_key_y = static_cast<unsigned int> (std::ceil ((max_y_ - min_y_ - minValue) / resolution_));
+  max_key_z = static_cast<unsigned int> (std::ceil ((max_z_ - min_z_ - minValue) / resolution_));
 
   // find maximum amount of keys
   max_voxels = std::max (std::max (std::max (max_key_x, max_key_y), max_key_z), static_cast<unsigned int> (2));
 
 
   // tree depth == amount of bits of max_voxels
-  this->octree_depth_ = std::max ((std::min (static_cast<unsigned int> (OctreeKey::maxDepth), static_cast<unsigned int> (ceil (this->Log2 (max_voxels)-minValue)))),
+  this->octree_depth_ = std::max ((std::min (static_cast<unsigned int> (OctreeKey::maxDepth), static_cast<unsigned int> (std::ceil (std::log2 (max_voxels) - minValue)))),
                                   static_cast<unsigned int> (0));
 
   octree_side_len = static_cast<double> (1 << this->octree_depth_) * resolution_;
@@ -804,13 +793,10 @@ pcl::octree::OctreePointCloud<PointT, LeafContainerT, BranchContainerT, OctreeT>
     const OctreeKey& key_arg,
     AlignedPointTVector &voxel_center_list_arg) const
 {
-  // child iterator
-  unsigned char child_idx;
-
   int voxel_count = 0;
 
   // iterate over all children
-  for (child_idx = 0; child_idx < 8; child_idx++)
+  for (unsigned char child_idx = 0; child_idx < 8; child_idx++)
   {
     if (!this->branchHasChild (*node_arg, child_idx))
       continue;
