@@ -39,7 +39,7 @@
 #ifndef PCL_OCTREE_SEARCH_IMPL_H_
 #define PCL_OCTREE_SEARCH_IMPL_H_
 
-#include <assert.h>
+#include <cassert>
 
 //////////////////////////////////////////////////////////////////////////////////////////////
 template<typename PointT, typename LeafContainerT, typename BranchContainerT> bool
@@ -88,9 +88,6 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::n
   if (k < 1)
     return 0;
   
-  unsigned int i;
-  unsigned int result_count;
-
   prioPointQueueEntry point_entry;
   std::vector<prioPointQueueEntry> point_candidates;
 
@@ -102,12 +99,12 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::n
 
   getKNearestNeighborRecursive (p_q, k, this->root_node_, key, 1, smallest_dist, point_candidates);
 
-  result_count = static_cast<unsigned int> (point_candidates.size ());
+  unsigned int result_count = static_cast<unsigned int> (point_candidates.size ());
 
   k_indices.resize (result_count);
   k_sqr_distances.resize (result_count);
   
-  for (i = 0; i < result_count; ++i)
+  for (unsigned int i = 0; i < result_count; ++i)
   {
     k_indices [i] = point_candidates [i].point_idx_;
     k_sqr_distances [i] = point_candidates [i].point_distance_;
@@ -212,8 +209,6 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::g
   std::vector<prioBranchQueueEntry> search_heap;
   search_heap.resize (8);
 
-  unsigned char child_idx;
-
   OctreeKey new_key;
 
   double smallest_squared_dist = squared_search_radius;
@@ -222,7 +217,7 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::g
   double voxelSquaredDiameter = this->getVoxelSquaredDiameter (tree_depth);
 
   // iterate over all children
-  for (child_idx = 0; child_idx < 8; child_idx++)
+  for (unsigned char child_idx = 0; child_idx < 8; child_idx++)
   {
     if (this->branchHasChild (*node, child_idx))
     {
@@ -267,9 +262,6 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::g
     else
     {
       // we reached leaf node level
-
-      float squared_dist;
-      size_t i;
       std::vector<int> decoded_point_vector;
 
       const LeafNode* child_leaf = static_cast<const LeafNode*> (child_node);
@@ -278,13 +270,13 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::g
       (*child_leaf)->getPointIndices (decoded_point_vector);
 
       // Linearly iterate over all decoded (unsorted) points
-      for (i = 0; i < decoded_point_vector.size (); i++)
+      for (const int &point_index : decoded_point_vector)
       {
 
-        const PointT& candidate_point = this->getPointByIndex (decoded_point_vector[i]);
+        const PointT& candidate_point = this->getPointByIndex (point_index);
 
         // calculate point distance to search point
-        squared_dist = pointSquaredDist (candidate_point, point);
+        float squared_dist = pointSquaredDist (candidate_point, point);
 
         // check if a closer match is found
         if (squared_dist < smallest_squared_dist)
@@ -292,7 +284,7 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::g
           prioPointQueueEntry point_entry;
 
           point_entry.point_distance_ = squared_dist;
-          point_entry.point_idx_ = decoded_point_vector[i];
+          point_entry.point_idx_ = point_index;
           point_candidates.push_back (point_entry);
         }
       }
@@ -319,14 +311,11 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::g
     unsigned int tree_depth, std::vector<int>& k_indices, std::vector<float>& k_sqr_distances,
     unsigned int max_nn) const
 {
-  // child iterator
-  unsigned char child_idx;
-
   // get spatial voxel information
   double voxel_squared_diameter = this->getVoxelSquaredDiameter (tree_depth);
 
   // iterate over all children
-  for (child_idx = 0; child_idx < 8; child_idx++)
+  for (unsigned char child_idx = 0; child_idx < 8; child_idx++)
   {
     if (!this->branchHasChild (*node, child_idx))
       continue;
@@ -365,8 +354,6 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::g
       else
       {
         // we reached leaf node level
-
-        size_t i;
         const LeafNode* child_leaf = static_cast<const LeafNode*> (child_node);
         std::vector<int> decoded_point_vector;
 
@@ -374,9 +361,9 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::g
         (*child_leaf)->getPointIndices (decoded_point_vector);
 
         // Linearly iterate over all decoded (unsorted) points
-        for (i = 0; i < decoded_point_vector.size (); i++)
+        for (const int &index : decoded_point_vector)
         {
-          const PointT& candidate_point = this->getPointByIndex (decoded_point_vector[i]);
+          const PointT& candidate_point = this->getPointByIndex (index);
 
           // calculate point distance to search point
           squared_dist = pointSquaredDist (candidate_point, point);
@@ -386,7 +373,7 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::g
             continue;
 
           // add point to result vector
-          k_indices.push_back (decoded_point_vector[i]);
+          k_indices.push_back (index);
           k_sqr_distances.push_back (squared_dist);
 
           if (max_nn != 0 && k_indices.size () == static_cast<unsigned int> (max_nn))
@@ -406,22 +393,18 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::a
                                                                                            int& result_index,
                                                                                            float& sqr_distance)
 {
-  unsigned char child_idx;
-  unsigned char min_child_idx;
-  double min_voxel_center_distance;
-
   OctreeKey minChildKey;
   OctreeKey new_key;
 
   const OctreeNode* child_node;
 
   // set minimum voxel distance to maximum value
-  min_voxel_center_distance = std::numeric_limits<double>::max ();
+  double min_voxel_center_distance = std::numeric_limits<double>::max ();
 
-  min_child_idx = 0xFF;
+  unsigned char min_child_idx = 0xFF;
 
   // iterate over all children
-  for (child_idx = 0; child_idx < 8; child_idx++)
+  for (unsigned char child_idx = 0; child_idx < 8; child_idx++)
   {
     if (!this->branchHasChild (*node, child_idx))
       continue;
@@ -461,32 +444,28 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::a
   else
   {
     // we reached leaf node level
-
-    double squared_dist;
-    double smallest_squared_dist;
-    size_t i;
     std::vector<int> decoded_point_vector;
 
     const LeafNode* child_leaf = static_cast<const LeafNode*> (child_node);
 
-    smallest_squared_dist = std::numeric_limits<double>::max ();
+    double smallest_squared_dist = std::numeric_limits<double>::max ();
 
     // decode leaf node into decoded_point_vector
     (**child_leaf).getPointIndices (decoded_point_vector);
 
     // Linearly iterate over all decoded (unsorted) points
-    for (i = 0; i < decoded_point_vector.size (); i++)
+    for (const int &index : decoded_point_vector)
     {
-      const PointT& candidate_point = this->getPointByIndex (decoded_point_vector[i]);
+      const PointT& candidate_point = this->getPointByIndex (index);
 
       // calculate point distance to search point
-      squared_dist = pointSquaredDist (candidate_point, point);
+      double squared_dist = pointSquaredDist (candidate_point, point);
 
       // check if a closer match is found
       if (squared_dist >= smallest_squared_dist)
         continue;
 
-      result_index = decoded_point_vector[i];
+      result_index = index;
       smallest_squared_dist = squared_dist;
       sqr_distance = static_cast<float> (squared_dist);
     }
@@ -510,11 +489,8 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::b
                                                                                  unsigned int tree_depth,
                                                                                  std::vector<int>& k_indices) const
 {
-  // child iterator
-  unsigned char child_idx;
-
   // iterate over all children
-  for (child_idx = 0; child_idx < 8; child_idx++)
+  for (unsigned char child_idx = 0; child_idx < 8; child_idx++)
   {
 
     const OctreeNode* child_node;
@@ -550,7 +526,6 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::b
       else
       {
         // we reached leaf node level
-        size_t i;
         std::vector<int> decoded_point_vector;
         bool bInBox;
 
@@ -560,9 +535,9 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::b
         (**child_leaf).getPointIndices (decoded_point_vector);
 
         // Linearly iterate over all decoded (unsorted) points
-        for (i = 0; i < decoded_point_vector.size (); i++)
+        for (const int &index : decoded_point_vector)
         {
-          const PointT& candidate_point = this->getPointByIndex (decoded_point_vector[i]);
+          const PointT& candidate_point = this->getPointByIndex (index);
 
           // check if point falls within search box
           bInBox = ( (candidate_point.x >= min_pt (0)) && (candidate_point.x <= max_pt (0)) &&
@@ -571,7 +546,7 @@ pcl::octree::OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT>::b
 
           if (bInBox)
             // add to result vector
-            k_indices.push_back (decoded_point_vector[i]);
+            k_indices.push_back (index);
         }
       }
     }
