@@ -36,8 +36,7 @@
  * $Id: octree_nodes.h 5596 2012-04-17 15:09:31Z jkammerl $
  */
 
-#ifndef PCL_OCTREE_CONTAINER_H
-#define PCL_OCTREE_CONTAINER_H
+#pragma once
 
 #include <vector>
 #include <cstddef>
@@ -55,21 +54,7 @@ namespace pcl
     class OctreeContainerBase
     {
     public:
-      /** \brief Empty constructor. */
-      OctreeContainerBase ()
-      {
-      }
-
-      /** \brief Empty constructor. */
-      OctreeContainerBase (const OctreeContainerBase&)
-      {
-      }
-
-      /** \brief Empty deconstructor. */
-      virtual
-      ~OctreeContainerBase ()
-      {
-      }
+      virtual ~OctreeContainerBase () = default;
 
       /** \brief Equal comparison operator
        */
@@ -91,7 +76,7 @@ namespace pcl
       /** \brief Pure abstract method to get size of container (number of indices)
        * \return number of points/indices stored in leaf node container.
        */
-      virtual size_t
+      virtual std::size_t
       getSize () const
       {
         return 0u;
@@ -133,24 +118,6 @@ namespace pcl
     class OctreeContainerEmpty : public OctreeContainerBase
     {
     public:
-      /** \brief Empty constructor. */
-      OctreeContainerEmpty () :
-          OctreeContainerBase ()
-      {
-      }
-
-      /** \brief Empty constructor. */
-      OctreeContainerEmpty (const OctreeContainerEmpty&) :
-          OctreeContainerBase ()
-      {
-      }
-
-      /** \brief Empty deconstructor. */
-      virtual
-      ~OctreeContainerEmpty ()
-      {
-      }
-
       /** \brief Octree deep copy method */
       virtual OctreeContainerEmpty *
       deepCopy () const
@@ -161,15 +128,15 @@ namespace pcl
       /** \brief Abstract get size of container (number of DataT objects)
        * \return number of DataT elements in leaf node container.
        */
-      virtual size_t
-      getSize () const
+      std::size_t
+      getSize () const override
       {
         return 0;
       }
 
       /** \brief Abstract reset leaf node implementation. */
-      virtual void
-      reset ()
+      void
+      reset () override
       {
 
       }
@@ -208,24 +175,11 @@ namespace pcl
       {
       public:
         /** \brief Empty constructor. */
-        OctreeContainerPointIndex () :
-            OctreeContainerBase (), data_ ()
+        OctreeContainerPointIndex ()
         {
           reset ();
         }
 
-        /** \brief Empty constructor. */
-        OctreeContainerPointIndex (const OctreeContainerPointIndex& source) :
-            OctreeContainerBase (), data_ (source.data_)
-        {
-        }
-
-        /** \brief Empty deconstructor. */
-        virtual
-        ~OctreeContainerPointIndex ()
-        {
-        }
-
         /** \brief Octree deep copy method */
         virtual OctreeContainerPointIndex*
         deepCopy () const
@@ -236,8 +190,8 @@ namespace pcl
         /** \brief Equal comparison operator
          * \param[in] other OctreeContainerBase to compare with
          */
-        virtual bool
-        operator== (const OctreeContainerBase& other) const
+        bool
+        operator== (const OctreeContainerBase& other) const override
         {
           const OctreeContainerPointIndex* otherConDataT = dynamic_cast<const OctreeContainerPointIndex*> (&other);
 
@@ -275,15 +229,15 @@ namespace pcl
         /** \brief Get size of container (number of DataT objects)
          * \return number of DataT elements in leaf node container.
          */
-        size_t
-        getSize () const
+        std::size_t
+        getSize () const override
         {
           return data_<0 ? 0 : 1;
         }
 
         /** \brief Reset leaf node memory to zero. */
-        virtual void
-        reset ()
+        void
+        reset () override
         {
           data_ = -1;
         }
@@ -300,24 +254,6 @@ namespace pcl
       class OctreeContainerPointIndices : public OctreeContainerBase
       {
       public:
-        /** \brief Empty constructor. */
-        OctreeContainerPointIndices () :
-          OctreeContainerBase (), leafDataTVector_ ()
-        {
-        }
-
-        /** \brief Empty constructor. */
-        OctreeContainerPointIndices (const OctreeContainerPointIndices& source) :
-            OctreeContainerBase (), leafDataTVector_ (source.leafDataTVector_)
-        {
-        }
-
-        /** \brief Empty deconstructor. */
-        virtual
-        ~OctreeContainerPointIndices ()
-        {
-        }
-
         /** \brief Octree deep copy method */
         virtual OctreeContainerPointIndices *
         deepCopy () const
@@ -328,8 +264,8 @@ namespace pcl
         /** \brief Equal comparison operator
          * \param[in] other OctreeContainerDataTVector to compare with
          */
-        virtual bool
-        operator== (const OctreeContainerBase& other) const
+        bool
+        operator== (const OctreeContainerBase& other) const override
         {
           const OctreeContainerPointIndices* otherConDataTVec = dynamic_cast<const OctreeContainerPointIndices*> (&other);
 
@@ -375,15 +311,15 @@ namespace pcl
         /** \brief Get size of container (number of indices)
          * \return number of point indices in container.
          */
-        size_t
-        getSize () const
+        std::size_t
+        getSize () const override
         {
           return leafDataTVector_.size ();
         }
 
         /** \brief Reset leaf node. Clear DataT vector.*/
-        virtual void
-        reset ()
+        void
+        reset () override
         {
           leafDataTVector_.clear ();
         }
@@ -395,5 +331,3 @@ namespace pcl
 
   }
 }
-
-#endif
