@@ -36,8 +36,7 @@
  * $Id$
  */
 
-#ifndef PCL_OCTREE_SEARCH_H_
-#define PCL_OCTREE_SEARCH_H_
+#pragma once
 
 #include <pcl/point_cloud.h>
 
@@ -58,23 +57,23 @@ namespace pcl
     {
       public:
         // public typedefs
-        typedef boost::shared_ptr<std::vector<int> > IndicesPtr;
-        typedef boost::shared_ptr<const std::vector<int> > IndicesConstPtr;
+        using IndicesPtr = shared_ptr<std::vector<int> >;
+        using IndicesConstPtr = shared_ptr<const std::vector<int> >;
 
-        typedef pcl::PointCloud<PointT> PointCloud;
-        typedef boost::shared_ptr<PointCloud> PointCloudPtr;
-        typedef boost::shared_ptr<const PointCloud> PointCloudConstPtr;
+        using PointCloud = pcl::PointCloud<PointT>;
+        using PointCloudPtr = typename PointCloud::Ptr;
+        using PointCloudConstPtr = typename PointCloud::ConstPtr;
 
         // Boost shared pointers
-        typedef boost::shared_ptr<OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT> > Ptr;
-        typedef boost::shared_ptr<const OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT> > ConstPtr;
+        using Ptr = shared_ptr<OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT> >;
+        using ConstPtr = shared_ptr<const OctreePointCloudSearch<PointT, LeafContainerT, BranchContainerT> >;
 
         // Eigen aligned allocator
-        typedef std::vector<PointT, Eigen::aligned_allocator<PointT> > AlignedPointTVector;
+        using AlignedPointTVector = std::vector<PointT, Eigen::aligned_allocator<PointT> >;
 
-        typedef OctreePointCloud<PointT, LeafContainerT, BranchContainerT> OctreeT;
-        typedef typename OctreeT::LeafNode LeafNode;
-        typedef typename OctreeT::BranchNode BranchNode;
+        using OctreeT = OctreePointCloud<PointT, LeafContainerT, BranchContainerT>;
+        using LeafNode = typename OctreeT::LeafNode;
+        using BranchNode = typename OctreeT::BranchNode;
 
         /** \brief Constructor.
           * \param[in] resolution octree resolution at lowest octree level
@@ -84,12 +83,6 @@ namespace pcl
         {
         }
 
-        /** \brief Empty class destructor. */
-        virtual
-        ~OctreePointCloudSearch ()
-        {
-        }
-
         /** \brief Search for neighbors within a voxel at given point
           * \param[in] point point addressing a leaf node voxel
           * \param[out] point_idx_data the resultant indices of the neighboring voxel points
@@ -264,7 +257,7 @@ namespace pcl
         public:
           /** \brief Empty constructor  */
           prioBranchQueueEntry () :
-              node (), point_distance (0), key ()
+              node (), point_distance (0)
           {
           }
 
@@ -582,18 +575,11 @@ namespace pcl
           {
             if (x < z)
               return a;
-            else
-              return c;
+            return c;
           }
-          else
-          {
-            if (y < z)
-              return b;
-            else
-              return c;
-          }
-
-          return 0;
+          if (y < z)
+            return b;
+          return c;
         }
 
       };
@@ -603,5 +589,3 @@ namespace pcl
 #ifdef PCL_NO_PRECOMPILE
 #include <pcl/octree/impl/octree_search.hpp>
 #endif
-
-#endif    // PCL_OCTREE_SEARCH_H_
