@@ -1,5 +1,4 @@
-#ifndef PCL_OUTOFCORE_GEOMETRY_H_
-#define PCL_OUTOFCORE_GEOMETRY_H_
+#pragma once
 
 // C++
 #include <string>
@@ -24,7 +23,7 @@ protected:
 
 public:
 
-  virtual
+  
   ~Geometry () { }
 
 public:
@@ -35,9 +34,7 @@ public:
   getActor () const
   {
     std::cout << "Get Geometry Actor" << std::endl;
-    return NULL;
+    return nullptr;
   }
 
 };
-
-#endif
