@@ -41,7 +41,7 @@
 
 #include <pcl/people/hog.h>
 
-#include <string.h>
+#include <cstring>
 
 #if defined(__SSE2__)
 #include <pcl/sse.h>
@@ -104,7 +104,7 @@ pcl::people::HOG::gradMag( float *I, int h, int w, int d, float *M, float *O ) c
 
   memcpy( M+x*h, M2, h*sizeof(float) );
   // compute and store gradient orientation (O) via table lookup
-  if(O!=0) for( y=0; y<h; y++ ) O[x*h+y] = acost[(int)Gx[y]];
+  if(O!=nullptr) for( y=0; y<h; y++ ) O[x*h+y] = acost[(int)Gx[y]];
   }
   alFree(Gx); alFree(Gy); alFree(M2); 
 #else
@@ -184,13 +184,15 @@ pcl::people::HOG::gradHist( float *M, float *O, int h, int w, int bin_size, int
     if( !soft_bin || bin_size==1 ) {
       // interpolate w.r.t. orientation only, not spatial bin_size
       H1=H+(x/bin_size)*hb;
-      #define GH H1[O0[y]]+=M0[y]; H1[O1[y]]+=M1[y]; y++;
-      if( bin_size==1 )      for(y=0; y<h0;) { GH; H1++; }
-      else if( bin_size==2 ) for(y=0; y<h0;) { GH; GH; H1++; }
-      else if( bin_size==3 ) for(y=0; y<h0;) { GH; GH; GH; H1++; }
-      else if( bin_size==4 ) for(y=0; y<h0;) { GH; GH; GH; GH; H1++; }
-      else for( y=0; y<h0;) { for( int y1=0; y1<bin_size; y1++ ) { GH; } H1++; }
-      #undef GH
+      const auto GH = [&H1, &O0, &O1, &y, &M0, &M1]()
+      {
+          H1[O0[y]]+=M0[y]; H1[O1[y]]+=M1[y]; y++;
+      };
+      if( bin_size==1 )      for(y=0; y<h0;) { GH(); H1++; }
+      else if( bin_size==2 ) for(y=0; y<h0;) { GH(); GH(); H1++; }
+      else if( bin_size==3 ) for(y=0; y<h0;) { GH(); GH(); GH(); H1++; }
+      else if( bin_size==4 ) for(y=0; y<h0;) { GH(); GH(); GH(); GH(); H1++; }
+      else for( y=0; y<h0;) { for( int y1=0; y1<bin_size; y1++ ) { GH(); } H1++; }
 
     } else {
       // interpolate using trilinear interpolation
@@ -200,19 +202,34 @@ pcl::people::HOG::gradHist( float *M, float *O, int h, int w, int bin_size, int
       if( x==0 ) { init=(0+.5f)*sInv-0.5f; xb=init; }
       hasLf = xb>=0; xb0 = hasLf?(int)xb:-1; hasRt = xb0 < wb-1;
       xd=xb-xb0; xb+=sInv; yb=init; y=0;
-      // macros for code conciseness
-      #define GHinit yd=yb-yb0; yb+=sInv; H0=H+xb0*hb+yb0; xyd=xd*yd; \
-      ms[0]=1-xd-yd+xyd; ms[1]=yd-xyd; ms[2]=xd-xyd; ms[3]=xyd;
-      #define GH(H,ma,mb) H1=H; pcl::sse_stru(*H1,pcl::sse_add(pcl::sse_ldu(*H1),pcl::sse_mul(ma,mb)));
+      // lambda for code conciseness
+      // @TODO: remove the very generic closure for specific variable one
+      const auto GHinit = [&]()
+      {
+          yd=yb-yb0;
+          yb+=sInv;
+          H0=H+xb0*hb+yb0;
+          xyd=xd*yd;
+
+          ms[0]=1-xd-yd+xyd;
+          ms[1]=yd-xyd;
+          ms[2]=xd-xyd;
+          ms[3]=xyd;
+      };
+      const auto GH = [&H1](const auto&H, const auto&ma, const auto&mb)
+      {
+          H1=H;
+          pcl::sse_stru(*H1, pcl::sse_add(pcl::sse_ldu(*H1), pcl::sse_mul(ma,mb)));
+      };
       // leading rows, no top bin_size
       for( ; y<bin_size/2; y++ ) {
-        yb0=-1; GHinit;
+        yb0=-1; GHinit();
         if(hasLf) { H0[O0[y]+1]+=ms[1]*M0[y]; H0[O1[y]+1]+=ms[1]*M1[y]; }
         if(hasRt) { H0[O0[y]+hb+1]+=ms[3]*M0[y]; H0[O1[y]+hb+1]+=ms[3]*M1[y]; }
       }
       // main rows, has top and bottom bins, use SSE for minor speedup
       for( ; ; y++ ) {
-        yb0 = (int) yb; if(yb0>=hb-1) break; GHinit;
+        yb0 = (int) yb; if(yb0>=hb-1) break; GHinit();
         _m0=pcl::sse_set(M0[y]); _m1=pcl::sse_set(M1[y]);
         if(hasLf) { _m=pcl::sse_set(0,0,ms[1],ms[0]);
         GH(H0+O0[y],_m,_m0); GH(H0+O1[y],_m,_m1); }
@@ -221,24 +238,32 @@ pcl::people::HOG::gradHist( float *M, float *O, int h, int w, int bin_size, int
       }      
       // final rows, no bottom bin_size
       for( ; y<h0; y++ ) {
-        yb0 = (int) yb; GHinit;
+        yb0 = (int) yb; GHinit();
         if(hasLf) { H0[O0[y]]+=ms[0]*M0[y]; H0[O1[y]]+=ms[0]*M1[y]; }
         if(hasRt) { H0[O0[y]+hb]+=ms[2]*M0[y]; H0[O1[y]+hb]+=ms[2]*M1[y]; }
       }       
-      #undef GHinit
-      #undef GH
 #else
       float ms[4], xyd, yb, xd, yd;  
       bool hasLf, hasRt; int xb0, yb0;
       if( x==0 ) { init=(0+.5f)*sInv-0.5f; xb=init; }
       hasLf = xb>=0; xb0 = hasLf?(int)xb:-1; hasRt = xb0 < wb-1;
       xd=xb-xb0; xb+=sInv; yb=init; y=0;
-      // macros for code conciseness
-      #define GHinit yd=yb-yb0; yb+=sInv; H0=H+xb0*hb+yb0; xyd=xd*yd; \
-      ms[0]=1-xd-yd+xyd; ms[1]=yd-xyd; ms[2]=xd-xyd; ms[3]=xyd;
+      // lambda for code conciseness
+      const auto GHinit = [&]()
+      {
+          yd=yb-yb0;
+          yb+=sInv;
+          H0=H+xb0*hb+yb0;
+          xyd=xd*yd;
+
+          ms[0]=1-xd-yd+xyd;
+          ms[1]=yd-xyd;
+          ms[2]=xd-xyd;
+          ms[3]=xyd;
+      };
       // leading rows, no top bin_size
       for( ; y<bin_size/2; y++ ) {
-        yb0=-1; GHinit;
+        yb0=-1; GHinit();
         if(hasLf) { H0[O0[y]+1]+=ms[1]*M0[y]; H0[O1[y]+1]+=ms[1]*M1[y]; }
         if(hasRt) { H0[O0[y]+hb+1]+=ms[3]*M0[y]; H0[O1[y]+hb+1]+=ms[3]*M1[y]; }
       }
@@ -247,7 +272,7 @@ pcl::people::HOG::gradHist( float *M, float *O, int h, int w, int bin_size, int
         yb0 = (int) yb;
         if(yb0>=hb-1) 
           break; 
-        GHinit;
+        GHinit();
   
         if(hasLf) 
         {
@@ -266,11 +291,10 @@ pcl::people::HOG::gradHist( float *M, float *O, int h, int w, int bin_size, int
       }      
       // final rows, no bottom bin_size
       for( ; y<h0; y++ ) {
-        yb0 = (int) yb; GHinit;
+        yb0 = (int) yb; GHinit();
         if(hasLf) { H0[O0[y]]+=ms[0]*M0[y]; H0[O1[y]]+=ms[0]*M1[y]; }
         if(hasRt) { H0[O0[y]+hb]+=ms[2]*M0[y]; H0[O1[y]+hb]+=ms[2]*M1[y]; }
       }       
-      #undef GHinit
 #endif     
     }
   }
@@ -287,11 +311,14 @@ pcl::people::HOG::normalization (float *H, int h, int w, int bin_size, int n_ori
   N = (float*) calloc(nb,sizeof(float));
   for( o=0; o<n_orients; o++ ) for( x=0; x<nb; x++ ) N[x]+=H[x+o*nb]*H[x+o*nb];
   for( x=0; x<wb-1; x++ ) for( y=0; y<hb-1; y++ ) {
-    N1=N+x*hb+y; *N1=1/float(sqrt( N1[0] + N1[1] + N1[hb] + N1[hb+1] +eps )); }
+    N1=N+x*hb+y; *N1=1/float(std::sqrt( N1[0] + N1[1] + N1[hb] + N1[hb+1] +eps )); }
   // perform 4 normalizations per spatial block (handling boundary regions)
-  #define U(a,b) Gs[a][y]=H1[y]*N1[y-(b)]; if(Gs[a][y]>clip) Gs[a][y]=clip;
   for( o=0; o<n_orients; o++ ) for( x=0; x<wb; x++ ) {
     H1=H+o*nb+x*hb; N1=N+x*hb; float *Gs[4]; Gs[0]=G+o*nb+x*hb;
+    const auto U = [&Gs, &H1, &N1, &y, &clip](const auto&a, const auto&b)
+    {
+        Gs[a][y] = std::min(clip, H1[y] * N1[y - b]);
+    };
     for( y=1; y<4; y++ ) Gs[y]=Gs[y-1]+nb*n_orients;
     bool lf, md, rt; lf=(x==0); rt=(x==wb-1); md=(!lf && !rt);
     y=0; if(!rt) U(0,0); if(!lf) U(2,hb);
@@ -300,7 +327,6 @@ pcl::people::HOG::normalization (float *H, int h, int w, int bin_size, int n_ori
     if(rt) for( y=1; y<hb-1; y++ ) { U(2,hb); U(3,hb+1); }
     y=hb-1; if(!rt) U(1,1); if(!lf) U(3,hb+1);
   } free(N);
-  #undef U
 }
       
 void
@@ -355,27 +381,56 @@ void
 pcl::people::HOG::grad1 (float *I, float *Gx, float *Gy, int h, int w, int x) const
 {
 #if defined(__SSE2__)
-  int y, y1; float *Ip, *In, r; __m128 *_Ip, *_In, *_G, _r;
+  int y, y1;
+  float *Ip, *In, r;
+  __m128 *_G, _r;
   // compute column of Gx
-  Ip=I-h; In=I+h; r=.5f;
-  if(x==0) { r=1; Ip+=h; } else if(x==w-1) { r=1; In-=h; }
-  if( h<4 || h%4>0 || (size_t(I)&15) || (size_t(Gx)&15) ) {
-  for( y=0; y<h; y++ ) *Gx++=(*In++-*Ip++)*r;
+  Ip = I-h;
+  In = I+h;
+  r = .5f;
+  if(x == 0)
+  {
+    r = 1;
+    Ip += h;
+  }
+  else if(x == w-1)
+  {
+    r = 1;
+    In -= h;
+  }
+  if( h<4 || h%4>0 || (std::size_t(I)&15) || (std::size_t(Gx)&15) )
+  {
+    for( y = 0; y < h; y++ )
+      *Gx++ = (*In++ - *Ip++) * r;
   } else {
-  _G=(__m128*) Gx; _Ip=(__m128*) Ip; _In=(__m128*) In; _r = pcl::sse_set(r);
-  for(y=0; y<h; y+=4) *_G++=pcl::sse_mul(pcl::sse_sub(*_In++,*_Ip++),_r);
+    _G = (__m128*) Gx;
+    __m128 *_Ip = (__m128*) Ip;
+    __m128 *_In = (__m128*) In;
+    _r = pcl::sse_set(r);
+    for(y = 0; y < h; y += 4)
+      *_G++ = pcl::sse_mul(pcl::sse_sub(*_In++,*_Ip++), _r);
   }
   // compute column of Gy
-  #define GRADY(r) *Gy++=(*In++-*Ip++)*r;
-  Ip=I; In=Ip+1;
-  // GRADY(1); Ip--; for(y=1; y<h-1; y++) GRADY(.5f); In--; GRADY(1);
-  y1=((~((size_t) Gy) + 1) & 15)/4; if(y1==0) y1=4; if(y1>h-1) y1=h-1;
-  GRADY(1); Ip--; for(y=1; y<y1; y++) GRADY(.5f);
-  _r = pcl::sse_set(.5f); _G=(__m128*) Gy;
-  for(; y+4<h-1; y+=4, Ip+=4, In+=4, Gy+=4)
-  *_G++=pcl::sse_mul(pcl::sse_sub(pcl::sse_ldu(*In),pcl::sse_ldu(*Ip)),_r);
-  for(; y<h-1; y++) GRADY(.5f); In--; GRADY(1);
-  #undef GRADY
+  const auto GRADY = [&Gy, &In, &Ip](const auto& r)
+  {
+      *Gy++ = (*In++ - *Ip++) * r;
+  };
+  Ip = I;
+  In = Ip + 1;
+  // GRADY(1); Ip--; for(y = 1; y < h-1; y++) GRADY(.5f); In--; GRADY(1);
+  y1 = ((~((std::size_t) Gy) + 1) & 15)/4;
+  if(y1 == 0) y1 = 4;
+  if(y1 > h-1) y1 = h-1;
+  GRADY(1);
+  Ip--;
+  for(y = 1; y < y1; y++) GRADY(.5f);
+  _r = pcl::sse_set(.5f);
+  _G = (__m128*) Gy;
+  for(; y+4 < h-1; y += 4, Ip += 4, In += 4, Gy += 4)
+    *_G++ = pcl::sse_mul(pcl::sse_sub(pcl::sse_ldu(*In),pcl::sse_ldu(*Ip)), _r);
+  for(; y < h-1; y++) GRADY(.5f);
+  In--;
+  GRADY(1);
 #else
   int y, y1;
   float *Ip, *In, r;
@@ -387,99 +442,113 @@ pcl::people::HOG::grad1 (float *I, float *Gx, float *Gy, int h, int w, int x) co
   
   if(x == 0)
   {
-  r = 1;
-  Ip += h;
+    r = 1;
+    Ip += h;
   }
   else if (x == w-1)
   {
-  r = 1;
-  In -= h;
+    r = 1;
+    In -= h;
   }
 
   for (y = 0; y < h; y++)
-  *Gx++=(*In++ - *Ip++)*r;
+    *Gx++=(*In++ - *Ip++)*r;
   
   // compute column of Gy
-  #define GRADY(r) *Gy++=(*In++-*Ip++)*r;
+  const auto GRADY = [&Gy, &In, &Ip](const auto& r)
+  {
+      *Gy++ = (*In++ - *Ip++) * r;
+  };
   Ip=I; In=Ip+1;
   // GRADY(1); Ip--; for(y=1; y<h-1; y++) GRADY(.5f); In--; GRADY(1);
-  y1=((~((size_t) Gy) + 1) & 15)/4; if(y1==0) y1=4; if(y1>h-1) y1=h-1;
+  y1=((~((std::size_t) Gy) + 1) & 15)/4; if(y1==0) y1=4; if(y1>h-1) y1=h-1;
   GRADY(1); Ip--; for(y=1; y<y1; y++) GRADY(.5f);
   
   r = 0.5f;
   for(; y<h-1; y++)
     GRADY(.5f); In--; GRADY(1);
-  #undef GRADY
 #endif
 }
       
 float* 
 pcl::people::HOG::acosTable () const
 {
-  int i, n=25000, n2=n/2; float t, ni;
-  static float a[25000]; static bool init=false;
+  int n = 25000;
+  int n2 = n / 2;
+  static float a[25000];
+  static bool init = false;
   if( init ) return a+n2;
-  ni = 2.02f/(float) n;
-  for( i=0; i<n; i++ ) {
-    t = i*ni - 1.01f;
+  float ni = 2.02f/(float) n;
+  for(int i=0; i<n; i++ )
+  {
+    float t = i*ni - 1.01f;
     t = t<-1 ? -1 : (t>1 ? 1 : t);
-    t = (float) acos( t );
+    t = (float) std::acos( t );
     a[i] = (t <= M_PI-1e-5f) ? t : 0;
   }
-  init=true; return a+n2;
+  init = true;
+  return a+n2;
 }
       
 void 
 pcl::people::HOG::gradQuantize (float *O, float *M, int *O0, int *O1, float *M0, float *M1, int n_orients, int nb, int n, float norm) const
 {
-#if defined(__SSE2__)
-  // assumes all *OUTPUT* matrices are 4-byte aligned
-  int i, o0, o1; float o, od, m;
-  __m128i _o0, _o1, *_O0, *_O1; __m128 _o, _o0f, _m, *_M0, *_M1;
   // define useful constants
-  const float oMult=(float)n_orients/M_PI; const int oMax=n_orients*nb;
-  const __m128 _norm=pcl::sse_set(norm), _oMult=pcl::sse_set(oMult), _nbf=pcl::sse_set((float)nb);
-  const __m128i _oMax=pcl::sse_set(oMax), _nb=pcl::sse_set(nb);
+  const float oMult = (float)n_orients/M_PI;
+  const int oMax = n_orients * nb;
+
+  int i = 0;
+#if defined(__SSE2__)
+  // assumes all *OUTPUT* matrices are 4-byte aligned  
+  __m128i _o0, _o1, *_O0, *_O1; __m128 _o, _o0f, _m, *_M0, *_M1;
+  const __m128 _norm = pcl::sse_set(norm);
+  const __m128 _oMult = pcl::sse_set(oMult);
+  const __m128 _nbf = pcl::sse_set((float)nb);
+  const __m128i _oMax = pcl::sse_set(oMax);
+  const __m128i _nb = pcl::sse_set(nb);
 
   // perform the majority of the work with sse
-  _O0=(__m128i*) O0; _O1=(__m128i*) O1; _M0=(__m128*) M0; _M1=(__m128*) M1;
-  for( i=0; i<=n-4; i+=4 ) {
-  _o=pcl::sse_mul(pcl::sse_ldu(O[i]),_oMult); _o0f=pcl::sse_cvt(pcl::sse_cvt(_o)); _o0=pcl::sse_cvt(pcl::sse_mul(_o0f,_nbf));
-  _o1=pcl::sse_add(_o0,_nb); _o1=pcl::sse_and(pcl::sse_cmpgt(_oMax,_o1),_o1);
-  *_O0++=_o0; *_O1++=_o1; _m=pcl::sse_mul(pcl::sse_ldu(M[i]),_norm);
-  *_M1=pcl::sse_mul(pcl::sse_sub(_o,_o0f),_m); *_M0=pcl::sse_sub(_m,*_M1); _M0++; _M1++;
-  }
-
-  // compute trailing locations without sse
-  for( ; i<n; i++ ) {
-  o=O[i]*oMult; m=M[i]*norm; o0=(int) o; od=o-o0;
-  o0*=nb; o1=o0+nb; if(o1==oMax) o1=0;
-  O0[i]=o0; O1[i]=o1; M1[i]=od*m; M0[i]=m-M1[i];
-  }
-#else
-  int i, o0, o1;
-  float o, od, m;
-
-  // define useful constants
-  const float oMult=(float)n_orients/M_PI; const int oMax=n_orients*nb;
-
-  // compute trailing locations without sse
-  for( i = 0; i<n; i++ )
-  {
-    o=O[i]*oMult; m=M[i]*norm; o0=(int) o; od=o-o0;
-    o0*=nb; o1=o0+nb; if(o1==oMax) o1=0;
-    O0[i]=o0; O1[i]=o1; M1[i]=od*m; M0[i]=m-M1[i];
+  _O0=(__m128i*) O0;
+  _O1=(__m128i*) O1;
+  _M0=(__m128*) M0;
+  _M1=(__m128*) M1;
+  for( ; i <= n-4; i += 4 ) {
+    _o = pcl::sse_mul(pcl::sse_ldu(O[i]),_oMult);
+    _o0f = pcl::sse_cvt(pcl::sse_cvt(_o));
+    _o0 = pcl::sse_cvt(pcl::sse_mul(_o0f,_nbf));
+    _o1 = pcl::sse_add(_o0,_nb);
+    _o1 = pcl::sse_and(pcl::sse_cmpgt(_oMax,_o1),_o1);
+    *_O0++ = _o0;
+    *_O1++ = _o1;
+    _m = pcl::sse_mul(pcl::sse_ldu(M[i]),_norm);
+    *_M1 = pcl::sse_mul(pcl::sse_sub(_o,_o0f),_m);
+    *_M0 = pcl::sse_sub(_m,*_M1); _M0++; _M1++;
   }
 #endif
+
+  // compute trailing locations without sse
+  for( ; i < n; i++ ) {
+    float o = O[i] * oMult;
+    float m = M[i] * norm;
+    int o0 = (int) o;
+    float od = o - o0;
+    o0 *= nb;
+    int o1 = o0 + nb;
+    if(o1 == oMax) o1 = 0;
+    O0[i] = o0;
+    O1[i] = o1;
+    M1[i] = od * m;
+    M0[i] = m - M1[i];
+  }
 }
 
 inline void* 
-pcl::people::HOG::alMalloc (size_t size, int alignment) const
+pcl::people::HOG::alMalloc (std::size_t size, int alignment) const
 {
-  const size_t pSize = sizeof(void*), a = alignment-1;
+  const std::size_t pSize = sizeof(void*), a = alignment-1;
   void *raw = malloc(size + a + pSize);
-  void *aligned = (void*) (((size_t) raw + pSize + a) & ~a);
-  *(void**) ((size_t) aligned-pSize) = raw;
+  void *aligned = (void*) (((std::size_t) raw + pSize + a) & ~a);
+  *(void**) ((std::size_t) aligned-pSize) = raw;
   return aligned;
 }
 
