@@ -3,7 +3,7 @@
  *
  *  Point Cloud Library (PCL) - www.pointclouds.org
  *  Copyright (c) 2010-2012, Willow Garage, Inc.
- *  
+ *
  *  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
@@ -37,13 +37,15 @@
  *
  */
 
-#ifndef PCL_RECOGNITION_HOUGH_3D_H_
-#define PCL_RECOGNITION_HOUGH_3D_H_
+#pragma once
 
 #include <pcl/recognition/cg/correspondence_grouping.h>
 #include <pcl/recognition/boost.h>
+#include <pcl/pcl_macros.h>
 #include <pcl/point_types.h>
 
+#include <unordered_map>
+
 namespace pcl
 {
   namespace recognition
@@ -56,12 +58,14 @@ namespace pcl
     {
 
       public:
-      
-        EIGEN_MAKE_ALIGNED_OPERATOR_NEW
-      
+        PCL_MAKE_ALIGNED_OPERATOR_NEW
+
+        using Ptr = shared_ptr<HoughSpace3D>;
+        using ConstPtr = shared_ptr<const HoughSpace3D>;
+
         /** \brief Constructor
           *
-          * \param[in] min_coord minimum (x,y,z) coordinates of the Hough space 
+          * \param[in] min_coord minimum (x,y,z) coordinates of the Hough space
           * \param[in] bin_size  size of each bing of the Hough space.
           * \param[in] max_coord maximum (x,y,z) coordinates of the Hough space.
           */
@@ -72,7 +76,7 @@ namespace pcl
         reset ();
 
         /** \brief Casting a vote for a given position in the Hough space.
-          * 
+          *
           * \param[in] single_vote_coord coordinates of the vote being cast (in absolute coordinates)
           * \param[in] weight weight associated with the vote.
           * \param[in] voter_id the numeric id of the voter. Useful to trace back the voting correspondence, if the vote is returned by findMaxima as part of a maximum of the Hough Space.
@@ -82,7 +86,7 @@ namespace pcl
         vote (const Eigen::Vector3d &single_vote_coord, double weight, int voter_id);
 
         /** \brief Vote for a given position in the 3D space. The weight is interpolated between the bin pointed by single_vote_coord and its neighbors.
-          * 
+          *
           * \param[in] single_vote_coord coordinates of the vote being cast.
           * \param[in] weight weight associated with the vote.
           * \param[in] voter_id the numeric id of the voter. Useful to trace back the voting correspondence, if the vote is returned by findMaxima as a part of a maximum of the Hough Space.
@@ -92,11 +96,11 @@ namespace pcl
         voteInt (const Eigen::Vector3d &single_vote_coord, double weight, int voter_id);
 
         /** \brief Find the bins with most votes.
-          * 
-          * \param[in] min_threshold the minimum number of votes to be included in a bin in order to have its value returned. 
+          *
+          * \param[in] min_threshold the minimum number of votes to be included in a bin in order to have its value returned.
           * If set to a value between -1 and 0 the Hough space maximum_vote is found and the returned values are all the votes greater than -min_threshold * maximum_vote.
           * \param[out] maxima_values the list of Hough Space bin values greater than min_threshold.
-          * \param[out] maxima_voter_ids for each value returned, a list of the voter ids who cast a vote in that position. 
+          * \param[out] maxima_voter_ids for each value returned, a list of the voter ids who cast a vote in that position.
           * \return The min_threshold used, either set by the user or found by this method.
           */
         double
@@ -121,18 +125,17 @@ namespace pcl
 
         /** \brief The Hough Space. */
         std::vector<double> hough_space_;
-        //boost::unordered_map<int, double> hough_space_;
 
         /** \brief List of voters for each bin. */
-        boost::unordered_map<int, std::vector<int> > voter_ids_;
+        std::unordered_map<int, std::vector<int> > voter_ids_;
     };
   }
 
   /** \brief Class implementing a 3D correspondence grouping algorithm that can deal with multiple instances of a model template
     * found into a given scene. Each correspondence casts a vote for a reference point in a 3D Hough Space.
-	* The remaining 3 DOF are taken into account by associating each correspondence with a local Reference Frame. 
+	* The remaining 3 DOF are taken into account by associating each correspondence with a local Reference Frame.
     * The suggested PointModelRfT is pcl::ReferenceFrame
-    * 
+    *
     * \note If you use this code in any academic work, please cite the original paper:
     *   - F. Tombari, L. Di Stefano:
     *     Object recognition in 3D scenes with occlusions and clutter by Hough voting.
@@ -145,34 +148,31 @@ namespace pcl
   class Hough3DGrouping : public CorrespondenceGrouping<PointModelT, PointSceneT>
   {
     public:
-      typedef pcl::PointCloud<PointModelRfT> ModelRfCloud;
-      typedef typename ModelRfCloud::Ptr ModelRfCloudPtr;
-      typedef typename ModelRfCloud::ConstPtr ModelRfCloudConstPtr;
+      using ModelRfCloud = pcl::PointCloud<PointModelRfT>;
+      using ModelRfCloudPtr = typename ModelRfCloud::Ptr;
+      using ModelRfCloudConstPtr = typename ModelRfCloud::ConstPtr;
 
-      typedef pcl::PointCloud<PointSceneRfT> SceneRfCloud;
-      typedef typename SceneRfCloud::Ptr SceneRfCloudPtr;
-      typedef typename SceneRfCloud::ConstPtr SceneRfCloudConstPtr;
+      using SceneRfCloud = pcl::PointCloud<PointSceneRfT>;
+      using SceneRfCloudPtr = typename SceneRfCloud::Ptr;
+      using SceneRfCloudConstPtr = typename SceneRfCloud::ConstPtr;
 
-      typedef pcl::PointCloud<PointModelT> PointCloud;
-      typedef typename PointCloud::Ptr PointCloudPtr;
-      typedef typename PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = pcl::PointCloud<PointModelT>;
+      using PointCloudPtr = typename PointCloud::Ptr;
+      using PointCloudConstPtr = typename PointCloud::ConstPtr;
 
-      typedef typename pcl::CorrespondenceGrouping<PointModelT, PointSceneT>::SceneCloudConstPtr SceneCloudConstPtr;
+      using SceneCloudConstPtr = typename pcl::CorrespondenceGrouping<PointModelT, PointSceneT>::SceneCloudConstPtr;
 
       /** \brief Constructor */
-      Hough3DGrouping () 
+      Hough3DGrouping ()
         : input_rf_ ()
         , scene_rf_ ()
         , needs_training_ (true)
-        , model_votes_ ()
-        , hough_threshold_ (-1)
+        ,hough_threshold_ (-1)
         , hough_bin_size_ (1.0)
         , use_interpolation_ (true)
         , use_distance_weight_ (false)
         , local_rf_normals_search_radius_ (0.0f)
         , local_rf_search_radius_ (0.0f)
-        , hough_space_ ()
-        , found_transformations_ ()
         , hough_space_initialized_ (false)
       {}
 
@@ -180,7 +180,7 @@ namespace pcl
         * \param[in] cloud the const boost shared pointer to a PointCloud message.
         */
       inline void
-      setInputCloud (const PointCloudConstPtr &cloud)
+      setInputCloud (const PointCloudConstPtr &cloud) override
       {
         PCLBase<PointModelT>::setInputCloud (cloud);
         needs_training_ = true;
@@ -188,10 +188,10 @@ namespace pcl
         input_rf_.reset();
       }
 
-      /** \brief Provide a pointer to the input dataset's reference frames. 
+      /** \brief Provide a pointer to the input dataset's reference frames.
         * Each point in the reference frame cloud should be the reference frame of
         * the correspondent point in the input dataset.
-        * 
+        *
         * \param[in] input_rf the pointer to the input cloud's reference frames.
         */
       inline void
@@ -202,10 +202,10 @@ namespace pcl
         hough_space_initialized_ = false;
       }
 
-      /** \brief Getter for the input dataset's reference frames. 
+      /** \brief Getter for the input dataset's reference frames.
         * Each point in the reference frame cloud should be the reference frame of
         * the correspondent point in the input dataset.
-        * 
+        *
         * \return the pointer to the input cloud's reference frames.
         */
       inline ModelRfCloudConstPtr
@@ -213,23 +213,23 @@ namespace pcl
       {
         return (input_rf_);
       }
-      
+
       /** \brief Provide a pointer to the scene dataset (i.e. the cloud in which the algorithm has to search for instances of the input model)
-        * 
+        *
         * \param[in] scene the const boost shared pointer to a PointCloud message.
         */
       inline void
-      setSceneCloud (const SceneCloudConstPtr &scene)
+      setSceneCloud (const SceneCloudConstPtr &scene) override
       {
         scene_ = scene;
         hough_space_initialized_ = false;
         scene_rf_.reset();
       }
 
-      /** \brief Provide a pointer to the scene dataset's reference frames. 
+      /** \brief Provide a pointer to the scene dataset's reference frames.
         * Each point in the reference frame cloud should be the reference frame of
         * the correspondent point in the scene dataset.
-        * 
+        *
         * \param[in] scene_rf the pointer to the scene cloud's reference frames.
         */
       inline void
@@ -239,10 +239,10 @@ namespace pcl
         hough_space_initialized_ = false;
       }
 
-      /** \brief Getter for the scene dataset's reference frames. 
+      /** \brief Getter for the scene dataset's reference frames.
         * Each point in the reference frame cloud should be the reference frame of
         * the correspondent point in the scene dataset.
-        * 
+        *
         * \return the pointer to the scene cloud's reference frames.
         */
       inline SceneRfCloudConstPtr
@@ -251,21 +251,21 @@ namespace pcl
         return (scene_rf_);
       }
 
-      /** \brief Provide a pointer to the precomputed correspondences between points in the input dataset and 
+      /** \brief Provide a pointer to the precomputed correspondences between points in the input dataset and
         * points in the scene dataset. The correspondences are going to be clustered into different model instances
         * by the algorithm.
-        * 
+        *
         * \param[in] corrs the correspondences between the model and the scene.
         */
       inline void
-      setModelSceneCorrespondences (const CorrespondencesConstPtr &corrs)
+      setModelSceneCorrespondences (const CorrespondencesConstPtr &corrs) override
       {
         model_scene_corrs_ = corrs;
         hough_space_initialized_ = false;
       }
 
       /** \brief Sets the minimum number of votes in the Hough space needed to infer the presence of a model instance into the scene cloud.
-        * 
+        *
         * \param[in] threshold the threshold for the Hough space voting, if set between -1 and 0 the maximum vote in the
         * entire space is automatically calculated and -threshold the maximum value is used as a threshold. This means
         * that a value between -1 and 0 should be used only if at least one instance of the model is always present in
@@ -278,7 +278,7 @@ namespace pcl
       }
 
       /** \brief Gets the minimum number of votes in the Hough space needed to infer the presence of a model instance into the scene cloud.
-        * 
+        *
         * \return the threshold for the Hough space voting.
         */
       inline double
@@ -288,7 +288,7 @@ namespace pcl
       }
 
       /** \brief Sets the size of each bin into the Hough space.
-        * 
+        *
         * \param[in] bin_size the size of each Hough space's bin.
         */
       inline void
@@ -299,7 +299,7 @@ namespace pcl
       }
 
       /** \brief Gets the size of each bin into the Hough space.
-        * 
+        *
         * \return the size of each Hough space's bin.
         */
       inline double
@@ -310,7 +310,7 @@ namespace pcl
 
       /** \brief Sets whether the vote casting procedure interpolates
         * the score between neighboring bins of the Hough space or not.
-        * 
+        *
         * \param[in] use_interpolation the algorithm should interpolate the vote score between neighboring bins.
         */
       inline void
@@ -322,7 +322,7 @@ namespace pcl
 
       /** \brief Gets whether the vote casting procedure interpolates
         * the score between neighboring bins of the Hough space or not.
-        * 
+        *
         * \return if the algorithm should interpolate the vote score between neighboring bins.
         */
       inline bool
@@ -332,7 +332,7 @@ namespace pcl
       }
 
       /** \brief Sets whether the vote casting procedure uses the correspondence's distance as a score.
-        * 
+        *
         * \param[in] use_distance_weight the algorithm should use the weighted distance when calculating the Hough voting score.
         */
       inline void
@@ -343,14 +343,14 @@ namespace pcl
       }
 
       /** \brief Gets whether the vote casting procedure uses the correspondence's distance as a score.
-        * 
+        *
         * \return if the algorithm should use the weighted distance when calculating the Hough voting score.
         */
       inline bool
       getUseDistanceWeight () const
       {
         return (use_distance_weight_);
-      }	
+      }
 
       /** \brief If the Local reference frame has not been set for either the model cloud or the scene cloud,
         * this algorithm makes the computation itself but needs a suitable search radius to compute the normals
@@ -380,7 +380,7 @@ namespace pcl
 
       /** \brief If the Local reference frame has not been set for either the model cloud or the scene cloud,
         * this algorithm makes the computation itself but needs a suitable search radius to do so.
-        * \attention This parameter NEEDS to be set if the reference frames are not precomputed externally, 
+        * \attention This parameter NEEDS to be set if the reference frames are not precomputed externally,
         * otherwise the recognition results won't be correct.
         *
         * \param[in] local_rf_search_radius the search radius for the local reference frame calculation.
@@ -395,7 +395,7 @@ namespace pcl
 
       /** \brief If the Local reference frame has not been set for either the model cloud or the scene cloud,
         * this algorithm makes the computation itself but needs a suitable search radius to do so.
-        * \attention This parameter NEEDS to be set if the reference frames are not precomputed externally, 
+        * \attention This parameter NEEDS to be set if the reference frames are not precomputed externally,
         * otherwise the recognition results won't be correct.
         *
         * \return the search radius for the local reference frame calculation.
@@ -408,14 +408,14 @@ namespace pcl
 
       /** \brief Call this function after setting the input, the input_rf and the hough_bin_size parameters to perform an off line training of the algorithm. This might be useful if one wants to perform once and for all a pre-computation of votes that only concern the models, increasing the on-line efficiency of the grouping algorithm. 
         * The algorithm is automatically trained on the first invocation of the recognize method or the cluster method if this training function has not been manually invoked.
-        * 
+        *
         * \return true if the training had been successful or false if errors have occurred.
         */
       bool
       train ();
 
       /** \brief The main function, recognizes instances of the model into the scene set by the user.
-        * 
+        *
         * \param[out] transformations a vector containing one transformation matrix for each instance of the model recognized into the scene.
         *
         * \return true if the recognition had been successful or false if errors have occurred.
@@ -424,7 +424,7 @@ namespace pcl
       recognize (std::vector<Eigen::Matrix4f, Eigen::aligned_allocator<Eigen::Matrix4f> > &transformations);
 
       /** \brief The main function, recognizes instances of the model into the scene set by the user.
-        * 
+        *
         * \param[out] transformations a vector containing one transformation matrix for each instance of the model recognized into the scene.
         * \param[out] clustered_corrs a vector containing the correspondences for each instance of the model found within the input data (the same output of clusterCorrespondences).
         *
@@ -469,7 +469,7 @@ namespace pcl
       float local_rf_search_radius_;
 
       /** \brief The Hough space. */
-      boost::shared_ptr<pcl::recognition::HoughSpace3D> hough_space_;
+      pcl::recognition::HoughSpace3D::Ptr hough_space_;
 
       /** \brief Transformations found by clusterCorrespondences method. */
       std::vector<Eigen::Matrix4f, Eigen::aligned_allocator<Eigen::Matrix4f> > found_transformations_;
@@ -480,12 +480,12 @@ namespace pcl
       bool hough_space_initialized_;
 
       /** \brief Cluster the input correspondences in order to distinguish between different instances of the model into the scene.
-        * 
+        *
         * \param[out] model_instances a vector containing the clustered correspondences for each model found on the scene.
         * \return true if the clustering had been successful or false if errors have occurred.
-        */ 
+        */
       void
-      clusterCorrespondences (std::vector<Correspondences> &model_instances);
+      clusterCorrespondences (std::vector<Correspondences> &model_instances) override;
 
       /*  \brief Finds the transformation matrix between the input and the scene cloud for a set of correspondences using a RANSAC algorithm.
         * \param[in] the scene cloud in which the PointSceneT has been converted to PointModelT.
@@ -507,12 +507,10 @@ namespace pcl
         * \param[out] rf the resulting reference frame.
         */
       template<typename PointType, typename PointRfType> void
-      computeRf (const boost::shared_ptr<const pcl::PointCloud<PointType> > &input, pcl::PointCloud<PointRfType> &rf);
+      computeRf (const typename pcl::PointCloud<PointType>::ConstPtr &input, pcl::PointCloud<PointRfType> &rf);
   };
 }
 
 #ifdef PCL_NO_PRECOMPILE
 #include <pcl/recognition/impl/cg/hough_3d.hpp>
 #endif
-
-#endif // PCL_RECOGNITION_HOUGH_3D_H_
