@@ -35,8 +35,7 @@
  *
  */
 
-#ifndef PCL_RECOGNITION_COLOR_GRADIENT_MODALITY
-#define PCL_RECOGNITION_COLOR_GRADIENT_MODALITY
+#pragma once
 
 #include <pcl/recognition/quantizable_modality.h>
 
@@ -82,7 +81,7 @@ namespace pcl
       };
 
     public:
-      typedef typename pcl::PointCloud<PointInT> PointCloudIn;
+      using PointCloudIn = pcl::PointCloud<PointInT>;
 
       /** \brief Different methods for feature selection/extraction. */
       enum FeatureSelectionMethod
@@ -95,7 +94,7 @@ namespace pcl
       /** \brief Constructor. */
       ColorGradientModality ();
       /** \brief Destructor. */
-      virtual ~ColorGradientModality ();
+      ~ColorGradientModality ();
   
       /** \brief Sets the threshold for the gradient magnitude which is used when quantizing the data.
         *        Gradients with a smaller magnitude are ignored. 
@@ -128,7 +127,7 @@ namespace pcl
   
       /** \brief Sets the spreading size for spreading the quantized data. */
       inline void
-      setSpreadingSize (const size_t spreading_size)
+      setSpreadingSize (const std::size_t spreading_size)
       {
         spreading_size_ = spreading_size;
       }
@@ -144,14 +143,14 @@ namespace pcl
 
       /** \brief Returns a reference to the internally computed quantized map. */
       inline QuantizedMap &
-      getQuantizedMap () 
+      getQuantizedMap () override 
       { 
         return (filtered_quantized_color_gradients_);
       }
   
       /** \brief Returns a reference to the internally computed spread quantized map. */
       inline QuantizedMap &
-      getSpreadedQuantizedMap () 
+      getSpreadedQuantizedMap () override 
       { 
         return (spreaded_filtered_quantized_color_gradients_);
       }
@@ -171,8 +170,8 @@ namespace pcl
         * \param[out] features the destination for the extracted features.
         */
       void
-      extractFeatures (const MaskMap & mask, size_t nr_features, size_t modalityIndex,
-                       std::vector<QuantizedMultiModFeature> & features) const;
+      extractFeatures (const MaskMap & mask, std::size_t nr_features, std::size_t modalityIndex,
+                       std::vector<QuantizedMultiModFeature> & features) const override;
   
       /** \brief Extracts all possible features from the modality within the specified mask.
         * \param[in] mask defines the areas where features are searched in. 
@@ -181,14 +180,14 @@ namespace pcl
         * \param[out] features the destination for the extracted features.
         */
       void
-      extractAllFeatures (const MaskMap & mask, size_t nr_features, size_t modalityIndex,
-                          std::vector<QuantizedMultiModFeature> & features) const;
+      extractAllFeatures (const MaskMap & mask, std::size_t nr_features, std::size_t modalityIndex,
+                          std::vector<QuantizedMultiModFeature> & features) const override;
   
       /** \brief Provide a pointer to the input dataset (overwrites the PCLBase::setInputCloud method)
         * \param cloud the const boost shared pointer to a PointCloud message
         */
-      virtual void 
-      setInputCloud (const typename PointCloudIn::ConstPtr & cloud) 
+      void 
+      setInputCloud (const typename PointCloudIn::ConstPtr & cloud) override 
       { 
         input_ = cloud;
       }
@@ -209,7 +208,7 @@ namespace pcl
         * \param[in] sigma the sigma.
         * \param[out] kernel_values the destination for the values of the kernel. */
       void
-      computeGaussianKernel (const size_t kernel_size, const float sigma, std::vector <float> & kernel_values);
+      computeGaussianKernel (const std::size_t kernel_size, const float sigma, std::vector <float> & kernel_values);
 
       /** \brief Computes the max-RGB gradients for the specified cloud.
         * \param[in] cloud the cloud for which the gradients are computed.
@@ -258,7 +257,7 @@ namespace pcl
       pcl::PointCloud<pcl::GradientXY> color_gradients_;
 
       /** \brief The spreading size. */
-      size_t spreading_size_;
+      std::size_t spreading_size_;
   
       /** \brief The map which holds the quantized max-RGB gradients. */
       pcl::QuantizedMap quantized_color_gradients_;
@@ -280,11 +279,7 @@ ColorGradientModality ()
   , feature_selection_method_ (DISTANCE_MAGNITUDE_SCORE)
   , gradient_magnitude_threshold_ (10.0f)
   , gradient_magnitude_threshold_feature_extraction_ (55.0f)
-  , color_gradients_ ()
   , spreading_size_ (8)
-  , quantized_color_gradients_ ()
-  , filtered_quantized_color_gradients_ ()
-  , spreaded_filtered_quantized_color_gradients_ ()
 {
 }
 
@@ -298,7 +293,7 @@ pcl::ColorGradientModality<PointInT>::
 //////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointInT> void
 pcl::ColorGradientModality<PointInT>::
-computeGaussianKernel (const size_t kernel_size, const float sigma, std::vector <float> & kernel_values)
+computeGaussianKernel (const std::size_t kernel_size, const float sigma, std::vector <float> & kernel_values)
 {
   // code taken from OpenCV
   const int n = int (kernel_size);
@@ -312,7 +307,7 @@ computeGaussianKernel (const size_t kernel_size, const float sigma, std::vector
   };
 
   const float* fixed_kernel = n % 2 == 1 && n <= SMALL_GAUSSIAN_SIZE && sigma <= 0 ?
-      small_gaussian_tab[n>>1] : 0;
+      small_gaussian_tab[n>>1] : nullptr;
 
   //CV_Assert( ktype == CV_32F || ktype == CV_64F );
   /*Mat kernel(n, 1, ktype);*/
@@ -324,8 +319,7 @@ computeGaussianKernel (const size_t kernel_size, const float sigma, std::vector
   double scale2X = -0.5/(sigmaX*sigmaX);
   double sum = 0;
 
-  int i;
-  for( i = 0; i < n; i++ )
+  for( int i = 0; i < n; i++ )
   {
     double x = i - (n-1)*0.5;
     double t = fixed_kernel ? double (fixed_kernel[i]) : std::exp (scale2X*x*x);
@@ -335,7 +329,7 @@ computeGaussianKernel (const size_t kernel_size, const float sigma, std::vector
   }
 
   sum = 1./sum;
-  for (i = 0; i < n; i++ )
+  for ( int i = 0; i < n; i++ )
   {
     cf[i] = float (cf[i]*sum);
   }
@@ -348,7 +342,7 @@ pcl::ColorGradientModality<PointInT>::
 processInputData ()
 {
   // compute gaussian kernel values
-  const size_t kernel_size = 7;
+  const std::size_t kernel_size = 7;
   std::vector<float> kernel_values;
   computeGaussianKernel (kernel_size, 0.0f, kernel_values);
 
@@ -361,16 +355,16 @@ processInputData ()
 
   pcl::PointCloud<pcl::RGB>::Ptr rgb_input_ (new pcl::PointCloud<pcl::RGB>());
   
-  const uint32_t width = input_->width;
-  const uint32_t height = input_->height;
+  const std::uint32_t width = input_->width;
+  const std::uint32_t height = input_->height;
 
   rgb_input_->resize (width*height);
   rgb_input_->width = width;
   rgb_input_->height = height;
   rgb_input_->is_dense = input_->is_dense;
-  for (size_t row_index = 0; row_index < height; ++row_index)
+  for (std::size_t row_index = 0; row_index < height; ++row_index)
   {
-    for (size_t col_index = 0; col_index < width; ++col_index)
+    for (std::size_t col_index = 0; col_index < width; ++col_index)
     {
       (*rgb_input_) (col_index, row_index).r = (*input_) (col_index, row_index).r;
       (*rgb_input_) (col_index, row_index).g = (*input_) (col_index, row_index).g;
@@ -415,11 +409,11 @@ processInputDataFromFiltered ()
 //////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointInT>
 void pcl::ColorGradientModality<PointInT>::
-extractFeatures (const MaskMap & mask, const size_t nr_features, const size_t modality_index,
+extractFeatures (const MaskMap & mask, const std::size_t nr_features, const std::size_t modality_index,
                  std::vector<QuantizedMultiModFeature> & features) const
 {
-  const size_t width = mask.getWidth ();
-  const size_t height = mask.getHeight ();
+  const std::size_t width = mask.getWidth ();
+  const std::size_t height = mask.getHeight ();
   
   std::list<Candidate> list1;
   std::list<Candidate> list2;
@@ -427,9 +421,9 @@ extractFeatures (const MaskMap & mask, const size_t nr_features, const size_t mo
 
   if (feature_selection_method_ == DISTANCE_MAGNITUDE_SCORE)
   {
-    for (size_t row_index = 0; row_index < height; ++row_index)
+    for (std::size_t row_index = 0; row_index < height; ++row_index)
     {
-      for (size_t col_index = 0; col_index < width; ++col_index)
+      for (std::size_t col_index = 0; col_index < width; ++col_index)
       {
         if (mask (col_index, row_index) != 0)
         {
@@ -612,12 +606,11 @@ extractFeatures (const MaskMap & mask, const size_t nr_features, const size_t mo
     MaskMap eroded_mask;
     erode (mask, eroded_mask);
 
-    MaskMap diff_mask;
-    MaskMap::getDifferenceMask (mask, eroded_mask, diff_mask);
+    auto diff_mask = MaskMap::getDifferenceMask (mask, eroded_mask);
 
-    for (size_t row_index = 0; row_index < height; ++row_index)
+    for (std::size_t row_index = 0; row_index < height; ++row_index)
     {
-      for (size_t col_index = 0; col_index < width; ++col_index)
+      for (std::size_t col_index = 0; col_index < width; ++col_index)
       {
         if (diff_mask (col_index, row_index) != 0)
         {
@@ -654,10 +647,10 @@ extractFeatures (const MaskMap & mask, const size_t nr_features, const size_t mo
       return;
     }
 
-    size_t distance = list1.size () / nr_features + 1; // ??? 
+    std::size_t distance = list1.size () / nr_features + 1; // ??? 
     while (list2.size () != nr_features)
     {
-      const size_t sqr_distance = distance*distance;
+      const std::size_t sqr_distance = distance*distance;
       for (typename std::list<Candidate>::iterator iter1 = list1.begin (); iter1 != list1.end (); ++iter1)
       {
         bool candidate_accepted = true;
@@ -702,19 +695,19 @@ extractFeatures (const MaskMap & mask, const size_t nr_features, const size_t mo
 //////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointInT> void 
 pcl::ColorGradientModality<PointInT>::
-extractAllFeatures (const MaskMap & mask, const size_t, const size_t modality_index,
+extractAllFeatures (const MaskMap & mask, const std::size_t, const std::size_t modality_index,
                  std::vector<QuantizedMultiModFeature> & features) const
 {
-  const size_t width = mask.getWidth ();
-  const size_t height = mask.getHeight ();
+  const std::size_t width = mask.getWidth ();
+  const std::size_t height = mask.getHeight ();
   
   std::list<Candidate> list1;
   std::list<Candidate> list2;
 
 
-  for (size_t row_index = 0; row_index < height; ++row_index)
+  for (std::size_t row_index = 0; row_index < height; ++row_index)
   {
-    for (size_t col_index = 0; col_index < width; ++col_index)
+    for (std::size_t col_index = 0; col_index < width; ++col_index)
     {
       if (mask (col_index, row_index) != 0)
       {
@@ -800,7 +793,7 @@ computeMaxColorGradients (const typename pcl::PointCloud<pcl::RGB>::ConstPtr & c
       {
         GradientXY gradient;
         gradient.magnitude = sqrt (sqr_mag_r);
-        gradient.angle = atan2 (r_dy, r_dx) * 180.0f / pi;
+        gradient.angle = std::atan2 (r_dy, r_dx) * 180.0f / pi;
         gradient.x = static_cast<float> (col_index);
         gradient.y = static_cast<float> (row_index);
 
@@ -810,7 +803,7 @@ computeMaxColorGradients (const typename pcl::PointCloud<pcl::RGB>::ConstPtr & c
       {
         GradientXY gradient;
         gradient.magnitude = sqrt (sqr_mag_g);
-        gradient.angle = atan2 (g_dy, g_dx) * 180.0f / pi;
+        gradient.angle = std::atan2 (g_dy, g_dx) * 180.0f / pi;
         gradient.x = static_cast<float> (col_index);
         gradient.y = static_cast<float> (row_index);
 
@@ -820,7 +813,7 @@ computeMaxColorGradients (const typename pcl::PointCloud<pcl::RGB>::ConstPtr & c
       {
         GradientXY gradient;
         gradient.magnitude = sqrt (sqr_mag_b);
-        gradient.angle = atan2 (b_dy, b_dx) * 180.0f / pi;
+        gradient.angle = std::atan2 (b_dy, b_dx) * 180.0f / pi;
         gradient.x = static_cast<float> (col_index);
         gradient.y = static_cast<float> (row_index);
 
@@ -916,7 +909,7 @@ computeMaxColorGradientsSobel (const typename pcl::PointCloud<pcl::RGB>::ConstPt
       {
         GradientXY gradient;
         gradient.magnitude = std::sqrt (static_cast<float> (sqr_mag_r));
-        gradient.angle = atan2f (static_cast<float> (r_dy), static_cast<float> (r_dx)) * 180.0f / pi;
+        gradient.angle = std::atan2 (static_cast<float> (r_dy), static_cast<float> (r_dx)) * 180.0f / pi;
         if (gradient.angle < -180.0f) gradient.angle += 360.0f;
         if (gradient.angle >= 180.0f) gradient.angle -= 360.0f;
         gradient.x = static_cast<float> (col_index);
@@ -928,7 +921,7 @@ computeMaxColorGradientsSobel (const typename pcl::PointCloud<pcl::RGB>::ConstPt
       {
         GradientXY gradient;
         gradient.magnitude = std::sqrt (static_cast<float> (sqr_mag_g));
-        gradient.angle = atan2f (static_cast<float> (g_dy), static_cast<float> (g_dx)) * 180.0f / pi;
+        gradient.angle = std::atan2 (static_cast<float> (g_dy), static_cast<float> (g_dx)) * 180.0f / pi;
         if (gradient.angle < -180.0f) gradient.angle += 360.0f;
         if (gradient.angle >= 180.0f) gradient.angle -= 360.0f;
         gradient.x = static_cast<float> (col_index);
@@ -940,7 +933,7 @@ computeMaxColorGradientsSobel (const typename pcl::PointCloud<pcl::RGB>::ConstPt
       {
         GradientXY gradient;
         gradient.magnitude = std::sqrt (static_cast<float> (sqr_mag_b));
-        gradient.angle = atan2f (static_cast<float> (b_dy), static_cast<float> (b_dx)) * 180.0f / pi;
+        gradient.angle = std::atan2 (static_cast<float> (b_dy), static_cast<float> (b_dx)) * 180.0f / pi;
         if (gradient.angle < -180.0f) gradient.angle += 360.0f;
         if (gradient.angle >= 180.0f) gradient.angle -= 360.0f;
         gradient.x = static_cast<float> (col_index);
@@ -975,8 +968,8 @@ quantizeColorGradients ()
   //}
 
 
-  const size_t width = input_->width;
-  const size_t height = input_->height;
+  const std::size_t width = input_->width;
+  const std::size_t height = input_->height;
 
   quantized_color_gradients_.resize (width, height);
 
@@ -984,9 +977,9 @@ quantizeColorGradients ()
 
   //float min_angle = std::numeric_limits<float>::max ();
   //float max_angle = -std::numeric_limits<float>::max ();
-  for (size_t row_index = 0; row_index < height; ++row_index)
+  for (std::size_t row_index = 0; row_index < height; ++row_index)
   {
-    for (size_t col_index = 0; col_index < width; ++col_index)
+    for (std::size_t col_index = 0; col_index < width; ++col_index)
     {
       if (color_gradients_ (col_index, row_index).magnitude < gradient_magnitude_threshold_) 
       {
@@ -1026,15 +1019,15 @@ void
 pcl::ColorGradientModality<PointInT>::
 filterQuantizedColorGradients ()
 {
-  const size_t width = input_->width;
-  const size_t height = input_->height;
+  const std::size_t width = input_->width;
+  const std::size_t height = input_->height;
 
   filtered_quantized_color_gradients_.resize (width, height);
 
   // filter data
-  for (size_t row_index = 1; row_index < height-1; ++row_index)
+  for (std::size_t row_index = 1; row_index < height-1; ++row_index)
   {
-    for (size_t col_index = 1; col_index < width-1; ++col_index)
+    for (std::size_t col_index = 1; col_index < width-1; ++col_index)
     {
       unsigned char histogram[9] = {0,0,0,0,0,0,0,0,0};
 
@@ -1097,14 +1090,14 @@ pcl::ColorGradientModality<PointInT>::
 erode (const pcl::MaskMap & mask_in, 
        pcl::MaskMap & mask_out)
 {
-  const size_t width = mask_in.getWidth ();
-  const size_t height = mask_in.getHeight ();
+  const std::size_t width = mask_in.getWidth ();
+  const std::size_t height = mask_in.getHeight ();
 
   mask_out.resize (width, height);
 
-  for (size_t row_index = 1; row_index < height-1; ++row_index)
+  for (std::size_t row_index = 1; row_index < height-1; ++row_index)
   {
-    for (size_t col_index = 1; col_index < width-1; ++col_index)
+    for (std::size_t col_index = 1; col_index < width-1; ++col_index)
     {
       if (mask_in (col_index, row_index-1) == 0 ||
           mask_in (col_index-1, row_index) == 0 ||
@@ -1120,5 +1113,3 @@ erode (const pcl::MaskMap & mask_in,
     }
   }
 }
-
-#endif 
