@@ -43,19 +43,6 @@
 #include <fcntl.h>
 #include <pcl/point_cloud.h>
 #include <limits>
-#ifdef _WIN32
-# include <io.h>
-# include <windows.h>
-# define pcl_open                    _open
-# define pcl_close(fd)               _close(fd)
-# define pcl_lseek(fd,offset,origin) _lseek(fd,offset,origin)
-#else
-#include <unistd.h>
-# include <sys/mman.h>
-# define pcl_open                    open
-# define pcl_close(fd)               close(fd)
-# define pcl_lseek(fd,offset,origin) lseek(fd,offset,origin)
-#endif
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointXYZT, typename PointRGBT> bool
@@ -84,10 +71,10 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::readLTMHeader (int fd, pcl::io::TARHeader &
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointXYZT, typename PointRGBT> bool
-pcl::LineRGBD<PointXYZT, PointRGBT>::loadTemplates (const std::string &file_name, const size_t object_id)
+pcl::LineRGBD<PointXYZT, PointRGBT>::loadTemplates (const std::string &file_name, const std::size_t object_id)
 {
   // Open the file
-  int ltm_fd = pcl_open (file_name.c_str (), O_RDONLY);
+  int ltm_fd = io::raw_open(file_name.c_str (), O_RDONLY);
   if (ltm_fd == -1)
     return (false);
   
@@ -151,16 +138,16 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::loadTemplates (const std::string &file_name
       delete [] buffer;
     }
 
-    if (static_cast<int> (pcl_lseek (ltm_fd, ltm_offset, SEEK_SET)) < 0)
+    if (io::raw_lseek(ltm_fd, ltm_offset, SEEK_SET) < 0)
       break;
   }
 
   // Close the file
-  pcl_close (ltm_fd);
+  io::raw_close(ltm_fd);
 
   // Compute 3D bounding boxes from the template point clouds
   bounding_boxes_.resize (template_point_clouds_.size ());
-  for (size_t i = 0; i < template_point_clouds_.size (); ++i)
+  for (std::size_t i = 0; i < template_point_clouds_.size (); ++i)
   {
     PointCloud<PointXYZRGBA> & template_point_cloud = template_point_clouds_[i];
     BoundingBoxXYZ & bb = bounding_boxes_[i];
@@ -176,12 +163,12 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::loadTemplates (const std::string &file_name
     float max_x = -std::numeric_limits<float>::max ();
     float max_y = -std::numeric_limits<float>::max ();
     float max_z = -std::numeric_limits<float>::max ();
-    size_t counter = 0;
-    for (size_t j = 0; j < template_point_cloud.size (); ++j)
+    std::size_t counter = 0;
+    for (std::size_t j = 0; j < template_point_cloud.size (); ++j)
     {
       const PointXYZRGBA & p = template_point_cloud.points[j];
 
-      if (!pcl_isfinite (p.x) || !pcl_isfinite (p.y) || !pcl_isfinite (p.z))
+      if (!std::isfinite (p.x) || !std::isfinite (p.y) || !std::isfinite (p.z))
         continue;
 
       min_x = std::min (min_x, p.x);
@@ -210,11 +197,11 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::loadTemplates (const std::string &file_name
     bb.y = (min_y + bb.height / 2.0f) - center_y - bb.height / 2.0f;
     bb.z = (min_z + bb.depth / 2.0f) - center_z - bb.depth / 2.0f;
 
-    for (size_t j = 0; j < template_point_cloud.size (); ++j)
+    for (std::size_t j = 0; j < template_point_cloud.size (); ++j)
     {
       PointXYZRGBA p = template_point_cloud.points[j];
 
-      if (!pcl_isfinite (p.x) || !pcl_isfinite (p.y) || !pcl_isfinite (p.z))
+      if (!std::isfinite (p.x) || !std::isfinite (p.y) || !std::isfinite (p.z))
         continue;
 
       p.x -= center_x;
@@ -232,7 +219,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::loadTemplates (const std::string &file_name
 template <typename PointXYZT, typename PointRGBT> int
 pcl::LineRGBD<PointXYZT, PointRGBT>::createAndAddTemplate (
   pcl::PointCloud<pcl::PointXYZRGBA> & cloud,
-  const size_t object_id,
+  const std::size_t object_id,
   const MaskMap & mask_xyz,
   const MaskMap & mask_rgb,
   const RegionXY & region)
@@ -247,7 +234,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::createAndAddTemplate (
   // Compute 3D bounding boxes from the template point clouds
   bounding_boxes_.resize (template_point_clouds_.size ());
   {
-    const size_t i = template_point_clouds_.size () - 1;
+    const std::size_t i = template_point_clouds_.size () - 1;
 
     PointCloud<PointXYZRGBA> & template_point_cloud = template_point_clouds_[i];
     BoundingBoxXYZ & bb = bounding_boxes_[i];
@@ -263,12 +250,12 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::createAndAddTemplate (
     float max_x = -std::numeric_limits<float>::max ();
     float max_y = -std::numeric_limits<float>::max ();
     float max_z = -std::numeric_limits<float>::max ();
-    size_t counter = 0;
-    for (size_t j = 0; j < template_point_cloud.size (); ++j)
+    std::size_t counter = 0;
+    for (std::size_t j = 0; j < template_point_cloud.size (); ++j)
     {
       const PointXYZRGBA & p = template_point_cloud.points[j];
 
-      if (!pcl_isfinite (p.x) || !pcl_isfinite (p.y) || !pcl_isfinite (p.z))
+      if (!std::isfinite (p.x) || !std::isfinite (p.y) || !std::isfinite (p.z))
         continue;
 
       min_x = std::min (min_x, p.x);
@@ -297,11 +284,11 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::createAndAddTemplate (
     bb.y = (min_y + bb.height / 2.0f) - center_y - bb.height / 2.0f;
     bb.z = (min_z + bb.depth / 2.0f) - center_z - bb.depth / 2.0f;
 
-    for (size_t j = 0; j < template_point_cloud.size (); ++j)
+    for (std::size_t j = 0; j < template_point_cloud.size (); ++j)
     {
       PointXYZRGBA p = template_point_cloud.points[j];
 
-      if (!pcl_isfinite (p.x) || !pcl_isfinite (p.y) || !pcl_isfinite (p.z))
+      if (!std::isfinite (p.x) || !std::isfinite (p.y) || !std::isfinite (p.z))
         continue;
 
       p.x -= center_x;
@@ -326,7 +313,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::createAndAddTemplate (
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointXYZT, typename PointRGBT> bool
-pcl::LineRGBD<PointXYZT, PointRGBT>::addTemplate (const SparseQuantizedMultiModTemplate & sqmmt, pcl::PointCloud<pcl::PointXYZRGBA> & cloud, size_t object_id)
+pcl::LineRGBD<PointXYZT, PointRGBT>::addTemplate (const SparseQuantizedMultiModTemplate & sqmmt, pcl::PointCloud<pcl::PointXYZRGBA> & cloud, std::size_t object_id)
 {
   // add point cloud
   template_point_clouds_.resize (template_point_clouds_.size () + 1);
@@ -339,7 +326,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::addTemplate (const SparseQuantizedMultiModT
   // Compute 3D bounding boxes from the template point clouds
   bounding_boxes_.resize (template_point_clouds_.size ());
   {
-    const size_t i = template_point_clouds_.size () - 1;
+    const std::size_t i = template_point_clouds_.size () - 1;
 
     PointCloud<PointXYZRGBA> & template_point_cloud = template_point_clouds_[i];
     BoundingBoxXYZ & bb = bounding_boxes_[i];
@@ -355,12 +342,12 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::addTemplate (const SparseQuantizedMultiModT
     float max_x = -std::numeric_limits<float>::max ();
     float max_y = -std::numeric_limits<float>::max ();
     float max_z = -std::numeric_limits<float>::max ();
-    size_t counter = 0;
-    for (size_t j = 0; j < template_point_cloud.size (); ++j)
+    std::size_t counter = 0;
+    for (std::size_t j = 0; j < template_point_cloud.size (); ++j)
     {
       const PointXYZRGBA & p = template_point_cloud.points[j];
 
-      if (!pcl_isfinite (p.x) || !pcl_isfinite (p.y) || !pcl_isfinite (p.z))
+      if (!std::isfinite (p.x) || !std::isfinite (p.y) || !std::isfinite (p.z))
         continue;
 
       min_x = std::min (min_x, p.x);
@@ -389,11 +376,11 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::addTemplate (const SparseQuantizedMultiModT
     bb.y = (min_y + bb.height / 2.0f) - center_y - bb.height / 2.0f;
     bb.z = (min_z + bb.depth / 2.0f) - center_z - bb.depth / 2.0f;
 
-    for (size_t j = 0; j < template_point_cloud.size (); ++j)
+    for (std::size_t j = 0; j < template_point_cloud.size (); ++j)
     {
       PointXYZRGBA p = template_point_cloud.points[j];
 
-      if (!pcl_isfinite (p.x) || !pcl_isfinite (p.y) || !pcl_isfinite (p.z))
+      if (!std::isfinite (p.x) || !std::isfinite (p.y) || !std::isfinite (p.z))
         continue;
 
       p.x -= center_x;
@@ -423,7 +410,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::detect (
   detections_.reserve (linemod_detections.size ());
   detections.clear ();
   detections.reserve (linemod_detections.size ());
-  for (size_t detection_id = 0; detection_id < linemod_detections.size (); ++detection_id)
+  for (std::size_t detection_id = 0; detection_id < linemod_detections.size (); ++detection_id)
   {
     pcl::LINEMODDetection & linemod_detection = linemod_detections[detection_id];
 
@@ -441,12 +428,12 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::detect (
     const pcl::SparseQuantizedMultiModTemplate & linemod_template = 
       linemod_.getTemplate (linemod_detection.template_id);
 
-    const size_t start_x = std::max (linemod_detection.x, 0);
-    const size_t start_y = std::max (linemod_detection.y, 0);
-    const size_t end_x = std::min (static_cast<size_t> (start_x + linemod_template.region.width),
-                                   static_cast<size_t> (cloud_xyz_->width));
-    const size_t end_y = std::min (static_cast<size_t> (start_y + linemod_template.region.height),
-                                   static_cast<size_t> (cloud_xyz_->height));
+    const std::size_t start_x = std::max (linemod_detection.x, 0);
+    const std::size_t start_y = std::max (linemod_detection.y, 0);
+    const std::size_t end_x = std::min (static_cast<std::size_t> (start_x + linemod_template.region.width),
+                                   static_cast<std::size_t> (cloud_xyz_->width));
+    const std::size_t end_y = std::min (static_cast<std::size_t> (start_y + linemod_template.region.height),
+                                   static_cast<std::size_t> (cloud_xyz_->height));
 
     detection.region.x = linemod_detection.x;
     detection.region.y = linemod_detection.y;
@@ -461,14 +448,14 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::detect (
     float center_x = 0.0f;
     float center_y = 0.0f;
     float center_z = 0.0f;
-    size_t counter = 0;
-    for (size_t row_index = start_y; row_index < end_y; ++row_index)
+    std::size_t counter = 0;
+    for (std::size_t row_index = start_y; row_index < end_y; ++row_index)
     {
-      for (size_t col_index = start_x; col_index < end_x; ++col_index)
+      for (std::size_t col_index = start_x; col_index < end_x; ++col_index)
       {
         const PointXYZT & point = (*cloud_xyz_) (col_index, row_index);
 
-        if (pcl_isfinite (point.x) && pcl_isfinite (point.y) && pcl_isfinite (point.z))
+        if (std::isfinite (point.x) && std::isfinite (point.y) && std::isfinite (point.z))
         {
           center_x += point.x;
           center_y += point.y;
@@ -499,7 +486,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::detect (
   // remove overlaps
   removeOverlappingDetections ();
 
-  for (size_t detection_index = 0; detection_index < detections_.size (); ++detection_index)
+  for (std::size_t detection_index = 0; detection_index < detections_.size (); ++detection_index)
   {
     detections.push_back (detections_[detection_index]);
   }
@@ -524,7 +511,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::detectSemiScaleInvariant (
   detections_.reserve (linemod_detections.size ());
   detections.clear ();
   detections.reserve (linemod_detections.size ());
-  for (size_t detection_id = 0; detection_id < linemod_detections.size (); ++detection_id)
+  for (std::size_t detection_id = 0; detection_id < linemod_detections.size (); ++detection_id)
   {
     pcl::LINEMODDetection & linemod_detection = linemod_detections[detection_id];
 
@@ -542,12 +529,12 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::detectSemiScaleInvariant (
     const pcl::SparseQuantizedMultiModTemplate & linemod_template = 
       linemod_.getTemplate (linemod_detection.template_id);
 
-    const size_t start_x = std::max (linemod_detection.x, 0);
-    const size_t start_y = std::max (linemod_detection.y, 0);
-    const size_t end_x = std::min (static_cast<size_t> (start_x + linemod_template.region.width * linemod_detection.scale),
-                                   static_cast<size_t> (cloud_xyz_->width));
-    const size_t end_y = std::min (static_cast<size_t> (start_y + linemod_template.region.height * linemod_detection.scale),
-                                   static_cast<size_t> (cloud_xyz_->height));
+    const std::size_t start_x = std::max (linemod_detection.x, 0);
+    const std::size_t start_y = std::max (linemod_detection.y, 0);
+    const std::size_t end_x = std::min (static_cast<std::size_t> (start_x + linemod_template.region.width * linemod_detection.scale),
+                                   static_cast<std::size_t> (cloud_xyz_->width));
+    const std::size_t end_y = std::min (static_cast<std::size_t> (start_y + linemod_template.region.height * linemod_detection.scale),
+                                   static_cast<std::size_t> (cloud_xyz_->height));
 
     detection.region.x = linemod_detection.x;
     detection.region.y = linemod_detection.y;
@@ -562,14 +549,14 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::detectSemiScaleInvariant (
     float center_x = 0.0f;
     float center_y = 0.0f;
     float center_z = 0.0f;
-    size_t counter = 0;
-    for (size_t row_index = start_y; row_index < end_y; ++row_index)
+    std::size_t counter = 0;
+    for (std::size_t row_index = start_y; row_index < end_y; ++row_index)
     {
-      for (size_t col_index = start_x; col_index < end_x; ++col_index)
+      for (std::size_t col_index = start_x; col_index < end_x; ++col_index)
       {
         const PointXYZT & point = (*cloud_xyz_) (col_index, row_index);
 
-        if (pcl_isfinite (point.x) && pcl_isfinite (point.y) && pcl_isfinite (point.z))
+        if (std::isfinite (point.x) && std::isfinite (point.y) && std::isfinite (point.z))
         {
           center_x += point.x;
           center_y += point.y;
@@ -600,7 +587,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::detectSemiScaleInvariant (
   // remove overlaps
   removeOverlappingDetections ();
 
-  for (size_t detection_index = 0; detection_index < detections_.size (); ++detection_index)
+  for (std::size_t detection_index = 0; detection_index < detections_.size (); ++detection_index)
   {
     detections.push_back (detections_[detection_index]);
   }
@@ -609,12 +596,12 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::detectSemiScaleInvariant (
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointXYZT, typename PointRGBT> void 
 pcl::LineRGBD<PointXYZT, PointRGBT>::computeTransformedTemplatePoints (
-    const size_t detection_id, pcl::PointCloud<pcl::PointXYZRGBA> &cloud)
+    const std::size_t detection_id, pcl::PointCloud<pcl::PointXYZRGBA> &cloud)
 {
   if (detection_id >= detections_.size ())
     PCL_ERROR ("ERROR pcl::LineRGBD::computeTransformedTemplatePoints - detection_id is out of bounds\n");
 
-  const size_t template_id = detections_[detection_id].template_id;
+  const std::size_t template_id = detections_[detection_id].template_id;
   const pcl::PointCloud<pcl::PointXYZRGBA> & template_point_cloud = template_point_clouds_[template_id];
 
   const pcl::BoundingBoxXYZ & template_bounding_box = bounding_boxes_[template_id];
@@ -637,11 +624,11 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::computeTransformedTemplatePoints (
   //  << translation_y << ", "
   //  << translation_z << std::endl;
 
-  const size_t nr_points = template_point_cloud.size ();
+  const std::size_t nr_points = template_point_cloud.size ();
   cloud.resize (nr_points);
   cloud.width = template_point_cloud.width;
   cloud.height = template_point_cloud.height;
-  for (size_t point_index = 0; point_index < nr_points; ++point_index)
+  for (std::size_t point_index = 0; point_index < nr_points; ++point_index)
   {
     pcl::PointXYZRGBA point = template_point_cloud.points[point_index];
 
@@ -657,29 +644,29 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::computeTransformedTemplatePoints (
 template <typename PointXYZT, typename PointRGBT> void 
 pcl::LineRGBD<PointXYZT, PointRGBT>::refineDetectionsAlongDepth ()
 {
-  const size_t nr_detections = detections_.size ();
-  for (size_t detection_index = 0; detection_index < nr_detections; ++detection_index)
+  const std::size_t nr_detections = detections_.size ();
+  for (std::size_t detection_index = 0; detection_index < nr_detections; ++detection_index)
   {
     typename LineRGBD<PointXYZT, PointRGBT>::Detection & detection = detections_[detection_index];
 
     // find depth with most valid points
-    const size_t start_x = std::max (detection.region.x, 0);
-    const size_t start_y = std::max (detection.region.y, 0);
-    const size_t end_x = std::min (static_cast<size_t> (detection.region.x + detection.region.width),
-                                   static_cast<size_t> (cloud_xyz_->width));
-    const size_t end_y = std::min (static_cast<size_t> (detection.region.y + detection.region.height),
-                                   static_cast<size_t> (cloud_xyz_->height));
+    const std::size_t start_x = std::max (detection.region.x, 0);
+    const std::size_t start_y = std::max (detection.region.y, 0);
+    const std::size_t end_x = std::min (static_cast<std::size_t> (detection.region.x + detection.region.width),
+                                   static_cast<std::size_t> (cloud_xyz_->width));
+    const std::size_t end_y = std::min (static_cast<std::size_t> (detection.region.y + detection.region.height),
+                                   static_cast<std::size_t> (cloud_xyz_->height));
 
 
     float min_depth = std::numeric_limits<float>::max ();
     float max_depth = -std::numeric_limits<float>::max ();
-    for (size_t row_index = start_y; row_index < end_y; ++row_index)
+    for (std::size_t row_index = start_y; row_index < end_y; ++row_index)
     {
-      for (size_t col_index = start_x; col_index < end_x; ++col_index)
+      for (std::size_t col_index = start_x; col_index < end_x; ++col_index)
       {
         const PointXYZT & point = (*cloud_xyz_) (col_index, row_index);
 
-        if (/*pcl_isfinite (point.x) && pcl_isfinite (point.y) && */pcl_isfinite (point.z))
+        if (/*std::isfinite (point.x) && std::isfinite (point.y) && */std::isfinite (point.z))
         {
           min_depth = std::min (min_depth, point.z);
           max_depth = std::max (max_depth, point.z);
@@ -687,38 +674,38 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::refineDetectionsAlongDepth ()
       }
     }
 
-    const size_t nr_bins = 1000;
+    const std::size_t nr_bins = 1000;
     const float step_size = (max_depth - min_depth) / static_cast<float> (nr_bins-1);
-    std::vector<size_t> depth_bins (nr_bins, 0);
-    for (size_t row_index = start_y; row_index < end_y; ++row_index)
+    std::vector<std::size_t> depth_bins (nr_bins, 0);
+    for (std::size_t row_index = start_y; row_index < end_y; ++row_index)
     {
-      for (size_t col_index = start_x; col_index < end_x; ++col_index)
+      for (std::size_t col_index = start_x; col_index < end_x; ++col_index)
       {
         const PointXYZT & point = (*cloud_xyz_) (col_index, row_index);
 
-        if (/*pcl_isfinite (point.x) && pcl_isfinite (point.y) && */pcl_isfinite (point.z))
+        if (/*std::isfinite (point.x) && std::isfinite (point.y) && */std::isfinite (point.z))
         {
-          const size_t bin_index = static_cast<size_t> ((point.z - min_depth) / step_size);
+          const std::size_t bin_index = static_cast<std::size_t> ((point.z - min_depth) / step_size);
           ++depth_bins[bin_index];
         }
       }
     }
 
-    std::vector<size_t> integral_depth_bins (nr_bins, 0);
+    std::vector<std::size_t> integral_depth_bins (nr_bins, 0);
     
     integral_depth_bins[0] = depth_bins[0];
-    for (size_t bin_index = 1; bin_index < nr_bins; ++bin_index)
+    for (std::size_t bin_index = 1; bin_index < nr_bins; ++bin_index)
     {
       integral_depth_bins[bin_index] = depth_bins[bin_index] + integral_depth_bins[bin_index-1];
     }
 
-    const size_t bb_depth_range = static_cast<size_t> (detection.bounding_box.depth / step_size);
+    const std::size_t bb_depth_range = static_cast<std::size_t> (detection.bounding_box.depth / step_size);
 
-    size_t max_nr_points = 0;
-    size_t max_index = 0;
-    for (size_t bin_index = 0; (bin_index+bb_depth_range) < nr_bins; ++bin_index)
+    std::size_t max_nr_points = 0;
+    std::size_t max_index = 0;
+    for (std::size_t bin_index = 0; (bin_index+bb_depth_range) < nr_bins; ++bin_index)
     {
-      const size_t nr_points_in_range = integral_depth_bins[bin_index+bb_depth_range] - integral_depth_bins[bin_index];
+      const std::size_t nr_points_in_range = integral_depth_bins[bin_index+bb_depth_range] - integral_depth_bins[bin_index];
 
       if (nr_points_in_range > max_nr_points)
       {
@@ -737,28 +724,28 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::refineDetectionsAlongDepth ()
 template <typename PointXYZT, typename PointRGBT> void 
 pcl::LineRGBD<PointXYZT, PointRGBT>::applyProjectiveDepthICPOnDetections ()
 {
-  const size_t nr_detections = detections_.size ();
-  for (size_t detection_index = 0; detection_index < nr_detections; ++detection_index)
+  const std::size_t nr_detections = detections_.size ();
+  for (std::size_t detection_index = 0; detection_index < nr_detections; ++detection_index)
   {
     typename pcl::LineRGBD<PointXYZT, PointRGBT>::Detection & detection = detections_[detection_index];
 
-    const size_t template_id = detection.template_id;
+    const std::size_t template_id = detection.template_id;
     pcl::PointCloud<pcl::PointXYZRGBA> & point_cloud = template_point_clouds_[template_id];
 
-    const size_t start_x = detection.region.x;
-    const size_t start_y = detection.region.y;
-    const size_t pc_width = point_cloud.width;
-    const size_t pc_height = point_cloud.height;
+    const std::size_t start_x = detection.region.x;
+    const std::size_t start_y = detection.region.y;
+    const std::size_t pc_width = point_cloud.width;
+    const std::size_t pc_height = point_cloud.height;
     
     std::vector<std::pair<float, float> > depth_matches;
-    for (size_t row_index = 0; row_index < pc_height; ++row_index)
+    for (std::size_t row_index = 0; row_index < pc_height; ++row_index)
     {
-      for (size_t col_index = 0; col_index < pc_width; ++col_index)
+      for (std::size_t col_index = 0; col_index < pc_width; ++col_index)
       {
         const pcl::PointXYZRGBA & point_template = point_cloud (col_index, row_index);
         const PointXYZT & point_input = (*cloud_xyz_) (col_index + start_x, row_index + start_y);
 
-        if (!pcl_isfinite (point_template.z) || !pcl_isfinite (point_input.z))
+        if (!std::isfinite (point_template.z) || !std::isfinite (point_input.z))
           continue;
 
         depth_matches.push_back (std::make_pair (point_template.z, point_input.z));
@@ -766,21 +753,21 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::applyProjectiveDepthICPOnDetections ()
     }
 
     // apply ransac on matches
-    const size_t nr_matches = depth_matches.size ();
-    const size_t nr_iterations = 100; // todo: should be a parameter...
+    const std::size_t nr_matches = depth_matches.size ();
+    const std::size_t nr_iterations = 100; // todo: should be a parameter...
     const float inlier_threshold = 0.01f; // 5cm // todo: should be a parameter...
-    size_t best_nr_inliers = 0;
+    std::size_t best_nr_inliers = 0;
     float best_z_translation = 0.0f;
-    for (size_t iteration_index = 0; iteration_index < nr_iterations; ++iteration_index)
+    for (std::size_t iteration_index = 0; iteration_index < nr_iterations; ++iteration_index)
     {
-      const size_t rand_index = (rand () * nr_matches) / RAND_MAX;
+      const std::size_t rand_index = (rand () * nr_matches) / RAND_MAX;
 
       const float z_translation = depth_matches[rand_index].second - depth_matches[rand_index].first;
 
-      size_t nr_inliers = 0;
-      for (size_t match_index = 0; match_index < nr_matches; ++match_index)
+      std::size_t nr_inliers = 0;
+      for (std::size_t match_index = 0; match_index < nr_matches; ++match_index)
       {
-        const float error = fabsf (depth_matches[match_index].first + z_translation - depth_matches[match_index].second);
+        const float error = std::abs (depth_matches[match_index].first + z_translation - depth_matches[match_index].second);
 
         if (error <= inlier_threshold)
         {
@@ -796,10 +783,10 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::applyProjectiveDepthICPOnDetections ()
     }
 
     float average_depth = 0.0f;
-    size_t average_counter = 0;
-    for (size_t match_index = 0; match_index < nr_matches; ++match_index)
+    std::size_t average_counter = 0;
+    for (std::size_t match_index = 0; match_index < nr_matches; ++match_index)
     {
-      const float error = fabsf (depth_matches[match_index].first + best_z_translation - depth_matches[match_index].second);
+      const float error = std::abs (depth_matches[match_index].first + best_z_translation - depth_matches[match_index].second);
 
       if (error <= inlier_threshold)
       {
@@ -819,11 +806,11 @@ template <typename PointXYZT, typename PointRGBT> void
 pcl::LineRGBD<PointXYZT, PointRGBT>::removeOverlappingDetections ()
 {
   // compute overlap between each detection
-  const size_t nr_detections = detections_.size ();
+  const std::size_t nr_detections = detections_.size ();
   Eigen::MatrixXf overlaps (nr_detections, nr_detections);
-  for (size_t detection_index_1 = 0; detection_index_1 < nr_detections; ++detection_index_1)
+  for (std::size_t detection_index_1 = 0; detection_index_1 < nr_detections; ++detection_index_1)
   {
-    for (size_t detection_index_2 = detection_index_1+1; detection_index_2 < nr_detections; ++detection_index_2)
+    for (std::size_t detection_index_2 = detection_index_1+1; detection_index_2 < nr_detections; ++detection_index_2)
     {
       const float bounding_box_volume = detections_[detection_index_1].bounding_box.width
                                       * detections_[detection_index_1].bounding_box.height
@@ -840,24 +827,24 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::removeOverlappingDetections ()
 
   // create clusters of detections
   std::vector<int> detection_to_cluster_mapping (nr_detections, -1);
-  std::vector<std::vector<size_t> > clusters;
-  for (size_t detection_index = 0; detection_index < nr_detections; ++detection_index)
+  std::vector<std::vector<std::size_t> > clusters;
+  for (std::size_t detection_index = 0; detection_index < nr_detections; ++detection_index)
   {
     if (detection_to_cluster_mapping[detection_index] != -1)
       continue; // already part of a cluster
 
-    std::vector<size_t> cluster;
-    const size_t cluster_id = clusters.size ();
+    std::vector<std::size_t> cluster;
+    const std::size_t cluster_id = clusters.size ();
 
     cluster.push_back (detection_index);
     detection_to_cluster_mapping[detection_index] = static_cast<int> (cluster_id);
 
     // check for detections which have sufficient overlap with a detection in the cluster
-    for (size_t cluster_index = 0; cluster_index < cluster.size (); ++cluster_index)
+    for (std::size_t cluster_index = 0; cluster_index < cluster.size (); ++cluster_index)
     {
-      const size_t detection_index_1 = cluster[cluster_index];
+      const std::size_t detection_index_1 = cluster[cluster_index];
 
-      for (size_t detection_index_2 = detection_index_1+1; detection_index_2 < nr_detections; ++detection_index_2)
+      for (std::size_t detection_index_2 = detection_index_1+1; detection_index_2 < nr_detections; ++detection_index_2)
       {
         if (detection_to_cluster_mapping[detection_index_2] != -1)
           continue; // already part of a cluster
@@ -876,10 +863,10 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::removeOverlappingDetections ()
   // compute detection representatives for every cluster
   std::vector<typename LineRGBD<PointXYZT, PointRGBT>::Detection> clustered_detections;
 
-  const size_t nr_clusters = clusters.size ();
-  for (size_t cluster_id = 0; cluster_id < nr_clusters; ++cluster_id)
+  const std::size_t nr_clusters = clusters.size ();
+  for (std::size_t cluster_id = 0; cluster_id < nr_clusters; ++cluster_id)
   {
-    std::vector<size_t> & cluster = clusters[cluster_id];
+    std::vector<std::size_t> & cluster = clusters[cluster_id];
     
     float average_center_x = 0.0f;
     float average_center_y = 0.0f;
@@ -887,15 +874,15 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::removeOverlappingDetections ()
     float weight_sum = 0.0f;
 
     float best_response = 0.0f;
-    size_t best_detection_id = 0;
+    std::size_t best_detection_id = 0;
 
     float average_region_x = 0.0f;
     float average_region_y = 0.0f;
 
-    const size_t elements_in_cluster = cluster.size ();
-    for (size_t cluster_index = 0; cluster_index < elements_in_cluster; ++cluster_index)
+    const std::size_t elements_in_cluster = cluster.size ();
+    for (std::size_t cluster_index = 0; cluster_index < elements_in_cluster; ++cluster_index)
     {
-      const size_t detection_id = cluster[cluster_index];
+      const std::size_t detection_id = cluster[cluster_index];
 
       const float weight = detections_[detection_id].response;
 
