@@ -1,4 +1,4 @@
- 
+
 /*
  * Software License Agreement (BSD License)
  *
@@ -38,11 +38,13 @@
  *
  */
 
-#ifndef PCL_SEGMENTATION_SUPERVOXEL_CLUSTERING_H_
-#define PCL_SEGMENTATION_SUPERVOXEL_CLUSTERING_H_
+#pragma once
+
+#include <boost/version.hpp>
 
 #include <pcl/features/normal_3d.h>
 #include <pcl/pcl_base.h>
+#include <pcl/pcl_macros.h>
 #include <pcl/point_cloud.h>
 #include <pcl/point_types.h>
 #include <pcl/octree/octree_search.h>
@@ -58,7 +60,7 @@
 
 namespace pcl
 {
-  /** \brief Supervoxel container class - stores a cluster extracted using supervoxel clustering 
+  /** \brief Supervoxel container class - stores a cluster extracted using supervoxel clustering
    */
   template <typename PointT>
   class Supervoxel
@@ -69,22 +71,22 @@ namespace pcl
         normals_ (new pcl::PointCloud<Normal> ())
         {  } 
 
-      typedef boost::shared_ptr<Supervoxel<PointT> > Ptr;
-      typedef boost::shared_ptr<const Supervoxel<PointT> > ConstPtr;
+      using Ptr = shared_ptr<Supervoxel<PointT> >;
+      using ConstPtr = shared_ptr<const Supervoxel<PointT> >;
 
       /** \brief Gets the centroid of the supervoxel
        *  \param[out] centroid_arg centroid of the supervoxel
-       */ 
+       */
       void
       getCentroidPoint (PointXYZRGBA &centroid_arg)
       {
         centroid_arg = centroid_;
       }
 
-      /** \brief Gets the point normal for the supervoxel 
+      /** \brief Gets the point normal for the supervoxel
        * \param[out] normal_arg Point normal of the supervoxel
        * \note This isn't an average, it is a normal computed using all of the voxels in the supervoxel as support
-       */ 
+       */
       void
       getCentroidPointNormal (PointNormal &normal_arg)
       {
@@ -107,16 +109,16 @@ namespace pcl
       typename pcl::PointCloud<Normal>::Ptr normals_;
 
     public:
-      EIGEN_MAKE_ALIGNED_OPERATOR_NEW  
+      PCL_MAKE_ALIGNED_OPERATOR_NEW
   };
-  
+
   /** \brief Implements a supervoxel algorithm based on voxel structure, normals, and rgb values
-   *   \note Supervoxels are oversegmented volumetric patches (usually surfaces) 
+   *   \note Supervoxels are oversegmented volumetric patches (usually surfaces)
    *   \note Usually, color isn't needed (and can be detrimental)- spatial structure is mainly used
     * - J. Papon, A. Abramov, M. Schoeler, F. Woergoetter
     *   Voxel Cloud Connectivity Segmentation - Supervoxels from PointClouds
     *   In Proceedings of the IEEE Conference on Computer Vision and Pattern Recognition (CVPR) 2013
-    *  \ingroup segmentation 
+    *  \ingroup segmentation
     *  \author Jeremie Papon (jpapon@gmail.com)
     */
   template <typename PointT>
@@ -137,18 +139,20 @@ namespace pcl
             rgb_ (0.0f, 0.0f, 0.0f),
             normal_ (0.0f, 0.0f, 0.0f, 0.0f),
             curvature_ (0.0f),
-            owner_ (0)
+            distance_(0),
+            idx_(0),
+            owner_ (nullptr)
             {}
 
           /** \brief Gets the data of in the form of a point
            *  \param[out] point_arg Will contain the point value of the voxeldata
-           */  
+           */
           void
           getPoint (PointT &point_arg) const;
 
           /** \brief Gets the data of in the form of a normal
            *  \param[out] normal_arg Will contain the normal value of the voxeldata
-           */            
+           */
           void
           getNormal (Normal &normal_arg) const;
 
@@ -161,42 +165,42 @@ namespace pcl
           SupervoxelHelper* owner_;
 
         public:
-          EIGEN_MAKE_ALIGNED_OPERATOR_NEW
+          PCL_MAKE_ALIGNED_OPERATOR_NEW
       };
 
-      typedef pcl::octree::OctreePointCloudAdjacencyContainer<PointT, VoxelData> LeafContainerT;
-      typedef std::vector <LeafContainerT*> LeafVectorT;
+      using LeafContainerT = pcl::octree::OctreePointCloudAdjacencyContainer<PointT, VoxelData>;
+      using LeafVectorT = std::vector<LeafContainerT *>;
 
-      typedef typename pcl::PointCloud<PointT> PointCloudT;
-      typedef typename pcl::PointCloud<Normal> NormalCloudT;
-      typedef typename pcl::octree::OctreePointCloudAdjacency<PointT, LeafContainerT> OctreeAdjacencyT;
-      typedef typename pcl::octree::OctreePointCloudSearch <PointT> OctreeSearchT;
-      typedef typename pcl::search::KdTree<PointT> KdTreeT;
-      typedef boost::shared_ptr<std::vector<int> > IndicesPtr;
+      using PointCloudT = pcl::PointCloud<PointT>;
+      using NormalCloudT = pcl::PointCloud<Normal>;
+      using OctreeAdjacencyT = pcl::octree::OctreePointCloudAdjacency<PointT, LeafContainerT>;
+      using OctreeSearchT = pcl::octree::OctreePointCloudSearch<PointT>;
+      using KdTreeT = pcl::search::KdTree<PointT>;
+      using IndicesPtr = pcl::IndicesPtr;
 
       using PCLBase <PointT>::initCompute;
       using PCLBase <PointT>::deinitCompute;
       using PCLBase <PointT>::input_;
 
-      typedef boost::adjacency_list<boost::setS, boost::setS, boost::undirectedS, uint32_t, float> VoxelAdjacencyList;
-      typedef VoxelAdjacencyList::vertex_descriptor VoxelID;
-      typedef VoxelAdjacencyList::edge_descriptor EdgeID;
+      using VoxelAdjacencyList = boost::adjacency_list<boost::setS, boost::setS, boost::undirectedS, std::uint32_t, float>;
+      using VoxelID = VoxelAdjacencyList::vertex_descriptor;
+      using EdgeID = VoxelAdjacencyList::edge_descriptor;
 
     public:
 
-      /** \brief Constructor that sets default values for member variables. 
+      /** \brief Constructor that sets default values for member variables.
        *  \param[in] voxel_resolution The resolution (in meters) of voxels used
        *  \param[in] seed_resolution The average size (in meters) of resulting supervoxels
        */
       SupervoxelClustering (float voxel_resolution, float seed_resolution);
 
-      PCL_DEPRECATED ("SupervoxelClustering constructor with flag for using the single camera transform is deprecated. Default behavior is now to use the transform for organized clouds, and not use it for unorganized. To force use/disuse of the transform, use the setUseSingleCameraTransform(bool) function.")
-      SupervoxelClustering (float voxel_resolution, float seed_resolution, bool);
+      [[deprecated("constructor with flag for using the single camera transform is deprecated. Default behavior is now to use the transform for organized clouds, and not use it for unorganized. Use setUseSingleCameraTransform() to override the defaults.")]]
+      SupervoxelClustering (float voxel_resolution, float seed_resolution, bool) : SupervoxelClustering (voxel_resolution, seed_resolution) { }
 
       /** \brief This destructor destroys the cloud, normals and search method used for
         * finding neighbors. In other words it frees memory.
         */
-      virtual
+
       ~SupervoxelClustering ();
 
       /** \brief Set the resolution of the octree voxels */
@@ -204,7 +208,7 @@ namespace pcl
       setVoxelResolution (float resolution);
 
       /** \brief Get the resolution of the octree voxels */
-      float 
+      float
       getVoxelResolution () const;
 
       /** \brief Set the resolution of the octree seed voxels */
@@ -212,7 +216,7 @@ namespace pcl
       setSeedResolution (float seed_resolution);
 
       /** \brief Get the resolution of the octree seed voxels */
-      float 
+      float
       getSeedResolution () const;
 
       /** \brief Set the importance of color for supervoxels */
@@ -227,7 +231,7 @@ namespace pcl
       void
       setNormalImportance (float val);
 
-      /** \brief Set whether or not to use the single camera transform 
+      /** \brief Set whether or not to use the single camera transform
        *  \note By default it will be used for organized clouds, but not for unorganized - this parameter will override that behavior
        *  The single camera transform scales bin size so that it increases exponentially with depth (z dimension).
        *  This is done to account for the decreasing point density found with depth when using an RGB-D camera.
@@ -239,22 +243,22 @@ namespace pcl
        */
       void
       setUseSingleCameraTransform (bool val);
-      
+
       /** \brief This method launches the segmentation algorithm and returns the supervoxels that were
        * obtained during the segmentation.
        * \param[out] supervoxel_clusters A map of labels to pointers to supervoxel structures
        */
       virtual void
-      extract (std::map<uint32_t,typename Supervoxel<PointT>::Ptr > &supervoxel_clusters);
+      extract (std::map<std::uint32_t,typename Supervoxel<PointT>::Ptr > &supervoxel_clusters);
 
       /** \brief This method sets the cloud to be supervoxelized
        * \param[in] cloud The cloud to be supervoxelize
        */
-      virtual void
-      setInputCloud (const typename pcl::PointCloud<PointT>::ConstPtr& cloud);
+      void
+      setInputCloud (const typename pcl::PointCloud<PointT>::ConstPtr& cloud) override;
 
       /** \brief This method sets the normals to be used for supervoxels (should be same size as input cloud)
-      * \param[in] normal_cloud The input normals                         
+      * \param[in] normal_cloud The input normals
       */
       virtual void
       setNormalCloud (typename NormalCloudT::ConstPtr normal_cloud);
@@ -264,7 +268,7 @@ namespace pcl
        * \param[out] supervoxel_clusters The resulting refined supervoxels
        */
       virtual void
-      refineSupervoxels (int num_itr, std::map<uint32_t,typename Supervoxel<PointT>::Ptr > &supervoxel_clusters);
+      refineSupervoxels (int num_itr, std::map<std::uint32_t,typename Supervoxel<PointT>::Ptr > &supervoxel_clusters);
 
       ////////////////////////////////////////////////////////////
       /** \brief Returns an RGB colorized cloud showing superpixels
@@ -274,11 +278,11 @@ namespace pcl
         * color(it's random). Points that are unlabeled will be black
         * \note This will expand the label_colors_ vector so that it can accommodate all labels
         */
-      PCL_DEPRECATED ("SupervoxelClustering::getColoredCloud is deprecated. Use the getLabeledCloud function instead. examples/segmentation/example_supervoxels.cpp shows how to use this to display and save with colorized labels.")
+      [[deprecated("use getLabeledCloud() instead. An example of how to display and save with colorized labels can be found in examples/segmentation/example_supervoxels.cpp")]]
       typename pcl::PointCloud<PointXYZRGBA>::Ptr
       getColoredCloud () const
       { 
-        return boost::shared_ptr<pcl::PointCloud<PointXYZRGBA> > (new pcl::PointCloud<PointXYZRGBA>);
+        return pcl::PointCloud<PointXYZRGBA>::Ptr (new pcl::PointCloud<PointXYZRGBA>);
       }
 
       /** \brief Returns a deep copy of the voxel centroid cloud */
@@ -292,24 +296,10 @@ namespace pcl
       typename pcl::PointCloud<PointXYZL>::Ptr
       getLabeledCloud () const;
 
-      /** \brief Returns an RGB colorized voxelized cloud showing superpixels
-       * Otherwise it returns an empty pointer.
-       * Points that belong to the same supervoxel have the same color.
-       * But this function doesn't guarantee that different segments will have different
-       * color(it's random). Points that are unlabeled will be black
-       * \note This will expand the label_colors_ vector so that it can accommodate all labels
-       */
-      PCL_DEPRECATED ("SupervoxelClustering::getColoredVoxelCloud is deprecated. Use the getLabeledVoxelCloud function instead. examples/segmentation/example_supervoxels.cpp shows how to use this to display and save with colorized labels.")
-      pcl::PointCloud<pcl::PointXYZRGBA>::Ptr
-      getColoredVoxelCloud () const
-      {
-        return boost::shared_ptr<pcl::PointCloud<PointXYZRGBA> > (new pcl::PointCloud<PointXYZRGBA>);
-      }
-
       /** \brief Returns labeled voxelized cloud
        * Points that belong to the same supervoxel have the same label.
        * Labels for segments start from 1, unlabled points have label 0
-       */      
+       */
       pcl::PointCloud<pcl::PointXYZL>::Ptr
       getLabeledVoxelCloud () const;
 
@@ -322,16 +312,16 @@ namespace pcl
       /** \brief Get a multimap which gives supervoxel adjacency
        *  \param[out] label_adjacency Multi-Map which maps a supervoxel label to all adjacent supervoxel labels
        */
-      void 
-      getSupervoxelAdjacency (std::multimap<uint32_t, uint32_t> &label_adjacency) const;
+      void
+      getSupervoxelAdjacency (std::multimap<std::uint32_t, std::uint32_t> &label_adjacency) const;
 
-      /** \brief Static helper function which returns a pointcloud of normals for the input supervoxels 
+      /** \brief Static helper function which returns a pointcloud of normals for the input supervoxels
        *  \param[in] supervoxel_clusters Supervoxel cluster map coming from this class
        *  \returns Cloud of PointNormals of the supervoxels
-       * 
+       *
        */
       static pcl::PointCloud<pcl::PointNormal>::Ptr
-      makeSupervoxelNormalCloud (std::map<uint32_t,typename Supervoxel<PointT>::Ptr > &supervoxel_clusters);
+      makeSupervoxelNormalCloud (std::map<std::uint32_t,typename Supervoxel<PointT>::Ptr > &supervoxel_clusters);
 
       /** \brief Returns the current maximum (highest) label */
       int
@@ -361,7 +351,7 @@ namespace pcl
       expandSupervoxels (int depth);
 
       /** \brief This sets the data of the voxels in the tree */
-      void 
+      void
       computeVoxelData ();
 
       /** \brief Reseeds the supervoxels by finding the voxel closest to current centroid */
@@ -370,7 +360,7 @@ namespace pcl
 
       /** \brief Constructs the map of supervoxel clusters from the internal supervoxel helpers */
       void
-      makeSupervoxels (std::map<uint32_t,typename Supervoxel<PointT>::Ptr > &supervoxel_clusters);
+      makeSupervoxels (std::map<std::uint32_t,typename Supervoxel<PointT>::Ptr > &supervoxel_clusters);
 
       /** \brief Stores the resolution used in the octree */
       float resolution_;
@@ -404,18 +394,18 @@ namespace pcl
       float spatial_importance_;
       /** \brief Importance of similarity in normals for clustering */
       float normal_importance_;
-      
-      /** \brief Whether or not to use the transform compressing depth in Z 
+
+      /** \brief Whether or not to use the transform compressing depth in Z
        *  This is only checked if it has been manually set by the user.
        *  The default behavior is to use the transform for organized, and not for unorganized.
        */
       bool use_single_camera_transform_;
       /** \brief Whether to use default transform behavior or not */
       bool use_default_transform_behaviour_;
-      
-      /** \brief Internal storage class for supervoxels 
-       * \note Stores pointers to leaves of clustering internal octree, 
-       * \note so should not be used outside of clustering class 
+
+      /** \brief Internal storage class for supervoxels
+       * \note Stores pointers to leaves of clustering internal octree,
+       * \note so should not be used outside of clustering class
        */
       class SupervoxelHelper
       {
@@ -432,11 +422,11 @@ namespace pcl
               return leaf_data_left.idx_ < leaf_data_right.idx_;
             }
           };
-          typedef std::set<LeafContainerT*, typename SupervoxelHelper::compareLeaves> LeafSetT;
-          typedef typename LeafSetT::iterator iterator;
-          typedef typename LeafSetT::const_iterator const_iterator;
+          using LeafSetT = std::set<LeafContainerT*, typename SupervoxelHelper::compareLeaves>;
+          using iterator = typename LeafSetT::iterator;
+          using const_iterator = typename LeafSetT::const_iterator;
 
-          SupervoxelHelper (uint32_t label, SupervoxelClustering* parent_arg):
+          SupervoxelHelper (std::uint32_t label, SupervoxelClustering* parent_arg):
             label_ (label),
             parent_ (parent_arg)
           { }
@@ -450,37 +440,37 @@ namespace pcl
           void
           removeAllLeaves ();
 
-          void 
+          void
           expand ();
 
-          void 
+          void
           refineNormals ();
 
-          void 
+          void
           updateCentroid ();
 
-          void 
+          void
           getVoxels (typename pcl::PointCloud<PointT>::Ptr &voxels) const;
 
-          void 
+          void
           getNormals (typename pcl::PointCloud<Normal>::Ptr &normals) const;
 
-          typedef float (SupervoxelClustering::*DistFuncPtr)(const VoxelData &v1, const VoxelData &v2);
+          using DistFuncPtr = float (SupervoxelClustering<PointT>::*)(const VoxelData &, const VoxelData &);
 
-          uint32_t
-          getLabel () const 
+          std::uint32_t
+          getLabel () const
           { return label_; }
 
-          Eigen::Vector4f 
-          getNormal () const 
+          Eigen::Vector4f
+          getNormal () const
           { return centroid_.normal_; }
 
-          Eigen::Vector3f 
-          getRGB () const 
+          Eigen::Vector3f
+          getRGB () const
           { return centroid_.rgb_; }
 
           Eigen::Vector3f
-          getXYZ () const 
+          getXYZ () const
           { return centroid_.xyz_;}
 
           void
@@ -488,16 +478,16 @@ namespace pcl
           { x=centroid_.xyz_[0]; y=centroid_.xyz_[1]; z=centroid_.xyz_[2]; }
 
           void
-          getRGB (uint32_t &rgba) const
-          { 
-            rgba = static_cast<uint32_t>(centroid_.rgb_[0]) << 16 | 
-                   static_cast<uint32_t>(centroid_.rgb_[1]) << 8 | 
-                   static_cast<uint32_t>(centroid_.rgb_[2]); 
+          getRGB (std::uint32_t &rgba) const
+          {
+            rgba = static_cast<std::uint32_t>(centroid_.rgb_[0]) << 16 |
+                   static_cast<std::uint32_t>(centroid_.rgb_[1]) << 8 |
+                   static_cast<std::uint32_t>(centroid_.rgb_[2]);
           }
 
-          void 
-          getNormal (pcl::Normal &normal_arg) const 
-          { 
+          void
+          getNormal (pcl::Normal &normal_arg) const
+          {
             normal_arg.normal_x = centroid_.normal_[0];
             normal_arg.normal_y = centroid_.normal_[1];
             normal_arg.normal_z = centroid_.normal_[2];
@@ -505,36 +495,39 @@ namespace pcl
           }
 
           void
-          getNeighborLabels (std::set<uint32_t> &neighbor_labels) const;
+          getNeighborLabels (std::set<std::uint32_t> &neighbor_labels) const;
 
           VoxelData
           getCentroid () const
           { return centroid_; }
 
-          size_t
+          std::size_t
           size () const { return leaves_.size (); }
         private:
           //Stores leaves
           LeafSetT leaves_;
-          uint32_t label_;
+          std::uint32_t label_;
           VoxelData centroid_;
           SupervoxelClustering* parent_;
         public:
           //Type VoxelData may have fixed-size Eigen objects inside
-          EIGEN_MAKE_ALIGNED_OPERATOR_NEW
+          PCL_MAKE_ALIGNED_OPERATOR_NEW
       };
 
       //Make boost::ptr_list can access the private class SupervoxelHelper
+#if BOOST_VERSION >= 107000
+      friend void boost::checked_delete<> (const typename pcl::SupervoxelClustering<PointT>::SupervoxelHelper *) BOOST_NOEXCEPT;
+#else
       friend void boost::checked_delete<> (const typename pcl::SupervoxelClustering<PointT>::SupervoxelHelper *);
+#endif
 
-      typedef boost::ptr_list<SupervoxelHelper> HelperListT;
+      using HelperListT = boost::ptr_list<SupervoxelHelper>;
       HelperListT supervoxel_helpers_;
 
       //TODO DEBUG REMOVE
       StopWatch timer_;
     public:
-      EIGEN_MAKE_ALIGNED_OPERATOR_NEW
-
+      PCL_MAKE_ALIGNED_OPERATOR_NEW
   };
 
 }
@@ -542,5 +535,3 @@ namespace pcl
 #ifdef PCL_NO_PRECOMPILE
 #include <pcl/segmentation/impl/supervoxel_clustering.hpp>
 #endif
-
-#endif
