@@ -35,12 +35,14 @@
  *
  */
 
-#ifndef PCL_SURFACE_GRID_PROJECTION_H_
-#define PCL_SURFACE_GRID_PROJECTION_H_
+#pragma once
 
+#include <pcl/pcl_macros.h>
 #include <pcl/surface/boost.h>
 #include <pcl/surface/reconstruction.h>
 
+#include <unordered_map>
+
 namespace pcl
 {
   /** \brief The 12 edges of a cell. */
@@ -72,28 +74,28 @@ namespace pcl
   class GridProjection : public SurfaceReconstruction<PointNT>
   {
     public:
-      typedef boost::shared_ptr<GridProjection<PointNT> > Ptr;
-      typedef boost::shared_ptr<const GridProjection<PointNT> > ConstPtr;
+      using Ptr = shared_ptr<GridProjection<PointNT> >;
+      using ConstPtr = shared_ptr<const GridProjection<PointNT> >;
 
       using SurfaceReconstruction<PointNT>::input_;
       using SurfaceReconstruction<PointNT>::tree_;
 
-      typedef typename pcl::PointCloud<PointNT>::Ptr PointCloudPtr;
+      using PointCloudPtr = typename pcl::PointCloud<PointNT>::Ptr;
 
-      typedef typename pcl::KdTree<PointNT> KdTree;
-      typedef typename pcl::KdTree<PointNT>::Ptr KdTreePtr;
+      using KdTree = pcl::KdTree<PointNT>;
+      using KdTreePtr = typename KdTree::Ptr;
 
       /** \brief Data leaf. */
       struct Leaf
       {
-        Leaf () : data_indices (), pt_on_surface (), vect_at_grid_pt () {}
+        Leaf () {}
 
         std::vector<int> data_indices;
         Eigen::Vector4f pt_on_surface; 
         Eigen::Vector3f vect_at_grid_pt;
       };
 
-      typedef boost::unordered_map<int, Leaf, boost::hash<int>, std::equal_to<int>, Eigen::aligned_allocator<int> > HashMap;
+      typedef std::unordered_map<int, Leaf, std::hash<int>, std::equal_to<>, Eigen::aligned_allocator<std::pair<const int, Leaf>>> HashMap;
 
       /** \brief Constructor. */ 
       GridProjection ();
@@ -213,7 +215,7 @@ namespace pcl
         * \param[out] output the resultant polygonal mesh
         */
       void 
-      performReconstruction (pcl::PolygonMesh &output);
+      performReconstruction (pcl::PolygonMesh &output) override;
 
       /** \brief Create the surface. 
         *
@@ -227,7 +229,7 @@ namespace pcl
         */
       void 
       performReconstruction (pcl::PointCloud<PointNT> &points, 
-                             std::vector<pcl::Vertices> &polygons);
+                             std::vector<pcl::Vertices> &polygons) override;
 
       /** \brief When the input data points don't fill into the 1*1*1 box, 
         * scale them so that they can be filled in the unit box. Otherwise, 
@@ -495,12 +497,9 @@ namespace pcl
       boost::dynamic_bitset<> occupied_cell_list_;
 
       /** \brief Class get name method. */
-      std::string getClassName () const { return ("GridProjection"); }
+      std::string getClassName () const override { return ("GridProjection"); }
 
     public:
-      EIGEN_MAKE_ALIGNED_OPERATOR_NEW
+      PCL_MAKE_ALIGNED_OPERATOR_NEW
   };
 }
-
-#endif  // PCL_SURFACE_GRID_PROJECTION_H_
- 
