@@ -38,29 +38,34 @@
  */
 
 #include <gtest/gtest.h>
+
+#include <random>
+
 #include <pcl/point_types.h>
 #include <pcl/common/eigen.h>
-#include "boost.h"
 
 using namespace pcl;
 using namespace std;
 
-boost::variate_generator< boost::mt19937, boost::uniform_real<double> > rand_double(boost::mt19937 (), boost::uniform_real<double> (0, 1));
-boost::variate_generator< boost::mt19937, boost::uniform_int<unsigned> > rand_uint(boost::mt19937 (), boost::uniform_int<unsigned> (0, 100));
+namespace
+{
+  std::mt19937 rng;
+  std::uniform_real_distribution<> rand_double(0.0, 1.0);
+  std::uniform_int_distribution<unsigned int> rand_uint(0, 100);
+}
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, InverseGeneral3x3f)
 {
-  typedef float Scalar;
-  typedef Eigen::Matrix<Scalar, 3, 3, Eigen::RowMajor> RMatrix;
-  typedef Eigen::Matrix<Scalar, 3, 3, Eigen::ColMajor> CMatrix;
+  using Scalar = float;
+  using RMatrix = Eigen::Matrix<Scalar, 3, 3, Eigen::RowMajor>;
+  using CMatrix = Eigen::Matrix<Scalar, 3, 3, Eigen::ColMajor>;
   RMatrix r_matrix = RMatrix::Zero ();
   RMatrix r_inverse = RMatrix::Zero ();
   CMatrix c_matrix = CMatrix::Zero ();
   CMatrix c_inverse = CMatrix::Zero ();
   Eigen::Matrix<Scalar, 3, 3> result = Eigen::Matrix<Scalar, 3, 3>::Zero ();
   Eigen::Matrix<Scalar, 3, 3> error = Eigen::Matrix<Scalar, 3, 3>::Zero ();
-  Scalar determinant;
   const Scalar epsilon = 1e-5f;
   const unsigned iterations = 1000000;
 
@@ -68,15 +73,15 @@ TEST (PCL, InverseGeneral3x3f)
   for (unsigned idx = 0; idx < iterations; ++idx)
   {
     for (unsigned elIdx = 0; elIdx < 9; ++elIdx)
-      r_matrix.coeffRef (elIdx) = Scalar(rand_double ());
+      r_matrix.coeffRef (elIdx) = Scalar(rand_double (rng));
 
     c_matrix = r_matrix;
 
     // test row-major -> row-major
-    determinant = invert3x3Matrix (r_matrix, r_inverse);
-    if (fabs (determinant) > epsilon)
+    Scalar determinant = invert3x3Matrix (r_matrix, r_inverse);
+    if (std::abs (determinant) > epsilon)
     {
-      float eps = std::max (epsilon, epsilon / fabs(determinant));
+      float eps = std::max (epsilon, epsilon / std::abs(determinant));
 
       result = r_inverse * r_matrix;
       error = result - Eigen::Matrix<Scalar, 3, 3>::Identity ();
@@ -91,9 +96,9 @@ TEST (PCL, InverseGeneral3x3f)
 
     // test row-major -> col-major
     determinant = invert3x3Matrix (c_matrix, c_inverse);
-    if (fabs (determinant) > epsilon)
+    if (std::abs (determinant) > epsilon)
     {
-      Scalar eps = std::max (epsilon, epsilon / fabs(determinant));
+      Scalar eps = std::max (epsilon, epsilon / std::abs(determinant));
 
       result = c_inverse * c_matrix;
       error = result - Eigen::Matrix<Scalar, 3, 3>::Identity ();
@@ -111,16 +116,15 @@ TEST (PCL, InverseGeneral3x3f)
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, InverseGeneral3x3d)
 {
-  typedef double Scalar;
-  typedef Eigen::Matrix<Scalar, 3, 3, Eigen::RowMajor> RMatrix;
-  typedef Eigen::Matrix<Scalar, 3, 3, Eigen::ColMajor> CMatrix;
+  using Scalar = double;
+  using RMatrix = Eigen::Matrix<Scalar, 3, 3, Eigen::RowMajor>;
+  using CMatrix = Eigen::Matrix<Scalar, 3, 3, Eigen::ColMajor>;
   RMatrix r_matrix = RMatrix::Zero ();
   RMatrix r_inverse = RMatrix::Zero ();
   CMatrix c_matrix = CMatrix::Zero ();
   CMatrix c_inverse = CMatrix::Zero ();
   Eigen::Matrix<Scalar, 3, 3> result = Eigen::Matrix<Scalar, 3, 3>::Zero ();
   Eigen::Matrix<Scalar, 3, 3> error = Eigen::Matrix<Scalar, 3, 3>::Zero ();
-  Scalar determinant;
   const Scalar epsilon = 1e-13;
   const unsigned iterations = 1000000;
 
@@ -129,14 +133,14 @@ TEST (PCL, InverseGeneral3x3d)
   {
     for (unsigned elIdx = 0; elIdx < 9; ++elIdx)
     {
-      r_matrix.coeffRef (elIdx) = Scalar(rand_double ());
+      r_matrix.coeffRef (elIdx) = Scalar(rand_double (rng));
     }
     c_matrix = r_matrix;
     // test row-major -> row-major
-    determinant = invert3x3Matrix (r_matrix, r_inverse);
-    if (fabs (determinant) > epsilon)
+    Scalar determinant = invert3x3Matrix (r_matrix, r_inverse);
+    if (std::abs (determinant) > epsilon)
     {
-      Scalar eps = std::max (epsilon, epsilon / fabs (determinant));
+      Scalar eps = std::max (epsilon, epsilon / std::abs (determinant));
 
       result = r_inverse * r_matrix;
       error = result - Eigen::Matrix<Scalar, 3, 3>::Identity ();
@@ -151,9 +155,9 @@ TEST (PCL, InverseGeneral3x3d)
 
     // test row-major -> col-major
     determinant = invert3x3Matrix (c_matrix, c_inverse);
-    if (fabs (determinant) > epsilon)
+    if (std::abs (determinant) > epsilon)
     {
-      Scalar eps = std::max (epsilon, epsilon / fabs(determinant));
+      Scalar eps = std::max (epsilon, epsilon / std::abs(determinant));
 
       result = c_inverse * c_matrix;
       error = result - Eigen::Matrix<Scalar, 3, 3>::Identity ();
@@ -171,16 +175,15 @@ TEST (PCL, InverseGeneral3x3d)
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, InverseSymmetric3x3f)
 {
-  typedef float Scalar;
-  typedef Eigen::Matrix<Scalar, 3, 3, Eigen::RowMajor> RMatrix;
-  typedef Eigen::Matrix<Scalar, 3, 3, Eigen::ColMajor> CMatrix;
+  using Scalar = float;
+  using RMatrix = Eigen::Matrix<Scalar, 3, 3, Eigen::RowMajor>;
+  using CMatrix = Eigen::Matrix<Scalar, 3, 3, Eigen::ColMajor>;
   RMatrix r_matrix = RMatrix::Zero ();
   RMatrix r_inverse = RMatrix::Zero ();
   CMatrix c_matrix = CMatrix::Zero ();
   CMatrix c_inverse = CMatrix::Zero ();
   Eigen::Matrix<Scalar, 3, 3> result = Eigen::Matrix<Scalar, 3, 3>::Zero ();
   Eigen::Matrix<Scalar, 3, 3> error = Eigen::Matrix<Scalar, 3, 3>::Zero ();
-  Scalar determinant;
   const Scalar epsilon = 1e-5f;
   const unsigned iterations = 1000000;
 
@@ -188,7 +191,7 @@ TEST (PCL, InverseSymmetric3x3f)
   for (unsigned idx = 0; idx < iterations; ++idx)
   {
     for (unsigned elIdx = 0; elIdx < 9; ++elIdx)
-      r_matrix.coeffRef (elIdx) = Scalar(rand_double ());
+      r_matrix.coeffRef (elIdx) = Scalar(rand_double (rng));
 
     r_matrix.coeffRef (3) = r_matrix.coeffRef (1);
     r_matrix.coeffRef (6) = r_matrix.coeffRef (2);
@@ -199,10 +202,10 @@ TEST (PCL, InverseSymmetric3x3f)
     //c_matrix.coeffRef (7) = c_matrix.coeffRef (5);
 
     // test row-major -> row-major
-    determinant = invert3x3SymMatrix (r_matrix, r_inverse);
-    if (fabs (determinant) > epsilon)
+    Scalar determinant = invert3x3SymMatrix (r_matrix, r_inverse);
+    if (std::abs (determinant) > epsilon)
     {
-      float eps = std::max (epsilon, epsilon / fabs(determinant));
+      float eps = std::max (epsilon, epsilon / std::abs(determinant));
 
       result = r_inverse * r_matrix;
       error = result - Eigen::Matrix<Scalar, 3, 3>::Identity ();
@@ -217,9 +220,9 @@ TEST (PCL, InverseSymmetric3x3f)
 
     // test row-major -> col-major
     determinant = invert3x3SymMatrix (c_matrix, c_inverse);
-    if (fabs (determinant) > epsilon)
+    if (std::abs (determinant) > epsilon)
     {
-      Scalar eps = std::max (epsilon, epsilon / fabs(determinant));
+      Scalar eps = std::max (epsilon, epsilon / std::abs(determinant));
 
       result = c_inverse * c_matrix;
       error = result - Eigen::Matrix<Scalar, 3, 3>::Identity ();
@@ -237,16 +240,15 @@ TEST (PCL, InverseSymmetric3x3f)
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, InverseSymmetric3x3d)
 {
-  typedef double Scalar;
-  typedef Eigen::Matrix<Scalar, 3, 3, Eigen::RowMajor> RMatrix;
-  typedef Eigen::Matrix<Scalar, 3, 3, Eigen::ColMajor> CMatrix;
+  using Scalar = double;
+  using RMatrix = Eigen::Matrix<Scalar, 3, 3, Eigen::RowMajor>;
+  using CMatrix = Eigen::Matrix<Scalar, 3, 3, Eigen::ColMajor>;
   RMatrix r_matrix = RMatrix::Zero ();
   RMatrix r_inverse = RMatrix::Zero ();
   CMatrix c_matrix = CMatrix::Zero ();
   CMatrix c_inverse = CMatrix::Zero ();
   Eigen::Matrix<Scalar, 3, 3> result = Eigen::Matrix<Scalar, 3, 3>::Zero ();
   Eigen::Matrix<Scalar, 3, 3> error = Eigen::Matrix<Scalar, 3, 3>::Zero ();
-  Scalar determinant;
   const Scalar epsilon = 1e-13;
   const unsigned iterations = 1000000;
 
@@ -254,7 +256,7 @@ TEST (PCL, InverseSymmetric3x3d)
   for (unsigned idx = 0; idx < iterations; ++idx)
   {
     for (unsigned elIdx = 0; elIdx < 9; ++elIdx)
-      r_matrix.coeffRef (elIdx) = Scalar(rand_double ());
+      r_matrix.coeffRef (elIdx) = Scalar(rand_double (rng));
 
     r_matrix.coeffRef (3) = r_matrix.coeffRef (1);
     r_matrix.coeffRef (6) = r_matrix.coeffRef (2);
@@ -265,10 +267,10 @@ TEST (PCL, InverseSymmetric3x3d)
     //c_matrix.coeffRef (7) = c_matrix.coeffRef (5);
 
     // test row-major -> row-major
-    determinant = invert3x3SymMatrix (r_matrix, r_inverse);
-    if (fabs (determinant) > epsilon)
+    Scalar determinant = invert3x3SymMatrix (r_matrix, r_inverse);
+    if (std::abs (determinant) > epsilon)
     {
-      Scalar eps = std::max (epsilon, epsilon / fabs (determinant));
+      Scalar eps = std::max (epsilon, epsilon / std::abs (determinant));
 
       result = r_inverse * r_matrix;
       error = result - Eigen::Matrix<Scalar, 3, 3>::Identity ();
@@ -283,9 +285,9 @@ TEST (PCL, InverseSymmetric3x3d)
 
     // test row-major -> col-major
     determinant = invert3x3SymMatrix (c_matrix, c_inverse);
-    if (fabs (determinant) > epsilon)
+    if (std::abs (determinant) > epsilon)
     {
-      Scalar eps = std::max (epsilon, epsilon / fabs(determinant));
+      Scalar eps = std::max (epsilon, epsilon / std::abs(determinant));
 
       result = c_inverse * c_matrix;
       error = result - Eigen::Matrix<Scalar, 3, 3>::Identity ();
@@ -304,16 +306,15 @@ TEST (PCL, InverseSymmetric3x3d)
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, Inverse2x2f)
 {
-  typedef float Scalar;
-  typedef Eigen::Matrix<Scalar, 2, 2, Eigen::RowMajor> RMatrix;
-  typedef Eigen::Matrix<Scalar, 2, 2, Eigen::ColMajor> CMatrix;
+  using Scalar = float;
+  using RMatrix = Eigen::Matrix<Scalar, 2, 2, Eigen::RowMajor>;
+  using CMatrix = Eigen::Matrix<Scalar, 2, 2, Eigen::ColMajor>;
   RMatrix r_matrix = RMatrix::Zero ();
   RMatrix r_inverse = RMatrix::Zero ();
   CMatrix c_matrix = CMatrix::Zero ();
   CMatrix c_inverse = CMatrix::Zero ();
   Eigen::Matrix<Scalar, 2, 2> result = Eigen::Matrix<Scalar, 2, 2>::Zero ();
   Eigen::Matrix<Scalar, 2, 2> error = Eigen::Matrix<Scalar, 2, 2>::Zero ();
-  Scalar determinant;
   const Scalar epsilon = 1e-6f;
   const unsigned iterations = 1000000;
 
@@ -321,14 +322,14 @@ TEST (PCL, Inverse2x2f)
   for (unsigned idx = 0; idx < iterations; ++idx)
   {
     for (unsigned elIdx = 0; elIdx < 4; ++elIdx)
-      r_matrix.coeffRef (elIdx) = Scalar(rand_double ());
+      r_matrix.coeffRef (elIdx) = Scalar(rand_double (rng));
 
     c_matrix = r_matrix;
     // test row-major -> row-major
-    determinant = invert2x2 (r_matrix, r_inverse);
-    if (fabs (determinant) > epsilon)
+    Scalar determinant = invert2x2 (r_matrix, r_inverse);
+    if (std::abs (determinant) > epsilon)
     {
-      float eps = std::max (epsilon, epsilon / fabs(determinant));
+      float eps = std::max (epsilon, epsilon / std::abs(determinant));
 
       result = r_inverse * r_matrix;
       error = result - Eigen::Matrix<Scalar, 2, 2>::Identity ();
@@ -343,9 +344,9 @@ TEST (PCL, Inverse2x2f)
 
     // test row-major -> col-major
     determinant = invert2x2 (c_matrix, c_inverse);
-    if (fabs (determinant) > epsilon)
+    if (std::abs (determinant) > epsilon)
     {
-      Scalar eps = std::max (epsilon, epsilon / fabs(determinant));
+      Scalar eps = std::max (epsilon, epsilon / std::abs(determinant));
 
       result = c_inverse * c_matrix;
       error = result - Eigen::Matrix<Scalar, 2, 2>::Identity ();
@@ -363,16 +364,15 @@ TEST (PCL, Inverse2x2f)
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, Inverse2x2d)
 {
-  typedef double Scalar;
-  typedef Eigen::Matrix<Scalar, 2, 2, Eigen::RowMajor> RMatrix;
-  typedef Eigen::Matrix<Scalar, 2, 2, Eigen::ColMajor> CMatrix;
+  using Scalar = double;
+  using RMatrix = Eigen::Matrix<Scalar, 2, 2, Eigen::RowMajor>;
+  using CMatrix = Eigen::Matrix<Scalar, 2, 2, Eigen::ColMajor>;
   RMatrix r_matrix = RMatrix::Zero ();
   RMatrix r_inverse = RMatrix::Zero ();
   CMatrix c_matrix = CMatrix::Zero ();
   CMatrix c_inverse = CMatrix::Zero ();
   Eigen::Matrix<Scalar, 2, 2> result;
   Eigen::Matrix<Scalar, 2, 2> error;
-  Scalar determinant;
   const Scalar epsilon = 1e-15;
   const unsigned iterations = 1000000;
 
@@ -380,14 +380,14 @@ TEST (PCL, Inverse2x2d)
   for (unsigned idx = 0; idx < iterations; ++idx)
   {
     for (unsigned elIdx = 0; elIdx < 4; ++elIdx)
-      r_matrix.coeffRef (elIdx) = Scalar(rand_double ());
+      r_matrix.coeffRef (elIdx) = Scalar(rand_double (rng));
 
     c_matrix = r_matrix;
     // test row-major -> row-major
-    determinant = invert2x2 (r_matrix, r_inverse);
-    if (fabs (determinant) > epsilon)
+    Scalar determinant = invert2x2 (r_matrix, r_inverse);
+    if (std::abs (determinant) > epsilon)
     {
-      Scalar eps = std::max (epsilon, epsilon / fabs (determinant));
+      Scalar eps = std::max (epsilon, epsilon / std::abs (determinant));
 
       result = r_inverse * r_matrix;
       error = result - Eigen::Matrix<Scalar, 2, 2>::Identity ();
@@ -402,9 +402,9 @@ TEST (PCL, Inverse2x2d)
 
     // test row-major -> col-major
     determinant = invert2x2 (c_matrix, c_inverse);
-    if (fabs (determinant) > epsilon)
+    if (std::abs (determinant) > epsilon)
     {
-      Scalar eps = std::max (epsilon, epsilon / fabs(determinant));
+      Scalar eps = std::max (epsilon, epsilon / std::abs(determinant));
 
       result = c_inverse * c_matrix;
       error = result - Eigen::Matrix<Scalar, 2, 2>::Identity ();
@@ -422,12 +422,12 @@ TEST (PCL, Inverse2x2d)
 template<class Matrix>
 inline void generateSymPosMatrix2x2 (Matrix& matrix)
 {
-  typedef typename Matrix::Scalar Scalar;
+  using Scalar = typename Matrix::Scalar;
 
-  unsigned test_case = rand_uint () % 10;
+  unsigned test_case = rand_uint (rng) % 10;
 
-  Scalar val1 = Scalar (rand_double ());
-  Scalar val2 = Scalar (rand_double ());
+  Scalar val1 = Scalar (rand_double (rng));
+  Scalar val2 = Scalar (rand_double (rng));
 
   // 10% of test cases include equal eigenvalues
   if (test_case == 0)
@@ -442,13 +442,13 @@ inline void generateSymPosMatrix2x2 (Matrix& matrix)
   Matrix eigenvectors = Matrix::Identity ();
   Matrix eigenvalues = Matrix::Zero ();
 
-  unsigned test_case2 = rand_uint () % 10;
+  unsigned test_case2 = rand_uint (rng) % 10;
   if (test_case2 != 0)
   {
     do
     {
-      eigenvectors.col (0)[0] = Scalar (rand_double ());
-      eigenvectors.col (0)[1] = Scalar (rand_double ());
+      eigenvectors.col (0)[0] = Scalar (rand_double (rng));
+      eigenvectors.col (0)[1] = Scalar (rand_double (rng));
       sqrNorm = eigenvectors.col (0).squaredNorm ();
     } while (sqrNorm == 0);
     eigenvectors.col (0) /= sqrt (sqrNorm);
@@ -464,9 +464,9 @@ inline void generateSymPosMatrix2x2 (Matrix& matrix)
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, eigen22d)
 {
-  typedef double Scalar;
-  typedef Eigen::Matrix<Scalar, 2, 2, Eigen::RowMajor> RMatrix;
-  typedef Eigen::Matrix<Scalar, 2, 2, Eigen::ColMajor> CMatrix;
+  using Scalar = double;
+  using RMatrix = Eigen::Matrix<Scalar, 2, 2, Eigen::RowMajor>;
+  using CMatrix = Eigen::Matrix<Scalar, 2, 2, Eigen::ColMajor>;
   RMatrix r_matrix;
   RMatrix r_vectors;
   Eigen::Matrix<Scalar, 2, 1> r_eigenvalues;
@@ -479,7 +479,6 @@ TEST (PCL, eigen22d)
   Eigen::Matrix<Scalar, 2, 2> g_error;
   Eigen::Matrix<Scalar, 2, 2> c_result;
   Eigen::Matrix<Scalar, 2, 2> c_error;
-  Scalar diff;
 
   const Scalar epsilon = 1.25e-14;
   const unsigned iterations = 1000000;
@@ -497,7 +496,7 @@ TEST (PCL, eigen22d)
     // test if U * V * U^T = M
     r_result = r_vectors * r_eigenvalues.asDiagonal () * r_vectors.transpose ();
     r_error = r_result - r_matrix;
-    diff = r_error.cwiseAbs ().maxCoeff ();
+    Scalar diff = r_error.cwiseAbs ().maxCoeff ();
     EXPECT_LE (diff, epsilon);
 
     // test if the eigenvalues are orthonormal
@@ -523,9 +522,9 @@ TEST (PCL, eigen22d)
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, eigen22f)
 {
-  typedef float Scalar;
-  typedef Eigen::Matrix<Scalar, 2, 2, Eigen::RowMajor> RMatrix;
-  typedef Eigen::Matrix<Scalar, 2, 2, Eigen::ColMajor> CMatrix;
+  using Scalar = float;
+  using RMatrix = Eigen::Matrix<Scalar, 2, 2, Eigen::RowMajor>;
+  using CMatrix = Eigen::Matrix<Scalar, 2, 2, Eigen::ColMajor>;
   RMatrix r_matrix;
   RMatrix r_vectors;
   Eigen::Matrix<Scalar, 2, 1> r_eigenvalues;
@@ -538,7 +537,6 @@ TEST (PCL, eigen22f)
   Eigen::Matrix<Scalar, 2, 2> g_error;
   Eigen::Matrix<Scalar, 2, 2> c_result;
   Eigen::Matrix<Scalar, 2, 2> c_error;
-  Scalar diff;
 
   const Scalar epsilon = 3.1e-5f;
   const unsigned iterations = 1000000;
@@ -556,7 +554,7 @@ TEST (PCL, eigen22f)
     // test if U * V * U^T = M
     r_result = r_vectors * r_eigenvalues.asDiagonal () * r_vectors.transpose ();
     r_error = r_result - r_matrix;
-    diff = r_error.cwiseAbs ().maxCoeff ();
+    Scalar diff = r_error.cwiseAbs ().maxCoeff ();
     EXPECT_LE (diff, epsilon);
 
     // test if the eigenvalues are orthonormal
@@ -584,7 +582,7 @@ TEST (PCL, eigen22f)
 template<class Matrix>
 inline void generateSymPosMatrix3x3 (Matrix& matrix)
 {
-  typedef typename Matrix::Scalar Scalar;
+  using Scalar = typename Matrix::Scalar;
 
   // 3 equal elements != 0
   // 2 equal elements none 0
@@ -593,11 +591,11 @@ inline void generateSymPosMatrix3x3 (Matrix& matrix)
   // 1 x 0
   // anything
 
-  unsigned test_case = rand_uint ();
+  unsigned test_case = rand_uint (rng);
 
-  Scalar val1 = Scalar (rand_double ());
-  Scalar val2 = Scalar (rand_double ());
-  Scalar val3 = Scalar (rand_double ());
+  Scalar val1 = Scalar (rand_double (rng));
+  Scalar val2 = Scalar (rand_double (rng));
+  Scalar val3 = Scalar (rand_double (rng));
 
   // 1%: all three values are equal and non-zero
   if (test_case == 0)
@@ -638,12 +636,12 @@ inline void generateSymPosMatrix3x3 (Matrix& matrix)
 
   do
   {
-    eigenvectors.col (0)[0] = Scalar (rand_double ());
-    eigenvectors.col (0)[1] = Scalar (rand_double ());
-    eigenvectors.col (0)[2] = Scalar (rand_double ());
-    eigenvectors.col (1)[0] = Scalar (rand_double ());
-    eigenvectors.col (1)[1] = Scalar (rand_double ());
-    eigenvectors.col (1)[2] = Scalar (rand_double ());
+    eigenvectors.col (0)[0] = Scalar (rand_double (rng));
+    eigenvectors.col (0)[1] = Scalar (rand_double (rng));
+    eigenvectors.col (0)[2] = Scalar (rand_double (rng));
+    eigenvectors.col (1)[0] = Scalar (rand_double (rng));
+    eigenvectors.col (1)[1] = Scalar (rand_double (rng));
+    eigenvectors.col (1)[2] = Scalar (rand_double (rng));
     eigenvectors.col (2) = eigenvectors.col (0).cross (eigenvectors.col (1));
 
     sqrNorm = eigenvectors.col (2).squaredNorm ();
@@ -663,9 +661,9 @@ inline void generateSymPosMatrix3x3 (Matrix& matrix)
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, eigen33d)
 {
-  typedef double Scalar;
-  typedef Eigen::Matrix<Scalar, 3, 3, Eigen::RowMajor> RMatrix;
-  typedef Eigen::Matrix<Scalar, 3, 3, Eigen::ColMajor> CMatrix;
+  using Scalar = double;
+  using RMatrix = Eigen::Matrix<Scalar, 3, 3, Eigen::RowMajor>;
+  using CMatrix = Eigen::Matrix<Scalar, 3, 3, Eigen::ColMajor>;
   RMatrix r_matrix;
   RMatrix r_vectors;
   Eigen::Matrix<Scalar, 3, 1> r_eigenvalues;
@@ -678,11 +676,25 @@ TEST (PCL, eigen33d)
   Eigen::Matrix<Scalar, 3, 3> g_error;
   Eigen::Matrix<Scalar, 3, 3> c_result;
   Eigen::Matrix<Scalar, 3, 3> c_error;
-  Scalar diff;
 
   const Scalar epsilon = 2e-5;
   const unsigned iterations = 1000000;
 
+  // special case
+  r_matrix = Eigen::Matrix<Scalar, 3, 1>(3, 2, 1).asDiagonal();
+  c_matrix = r_matrix;
+
+  eigen33(r_matrix, r_vectors, r_eigenvalues);
+  // check if the main vector is the positive Z direction. In this case it is equal to (0,0,1)
+  EXPECT_NEAR(r_vectors(0, 0), 0, epsilon);
+  EXPECT_NEAR(r_vectors(0, 1), 0, epsilon);
+  EXPECT_NEAR(r_vectors(0, 2), 1, epsilon);
+
+  eigen33(c_matrix, c_vectors, c_eigenvalues);
+  EXPECT_NEAR(c_vectors(0, 0), 0, epsilon);
+  EXPECT_NEAR(c_vectors(0, 1), 0, epsilon);
+  EXPECT_NEAR(c_vectors(0, 2), 1, epsilon);
+
   // test floating point row-major : row-major
   for (unsigned idx = 0; idx < iterations; ++idx)
   {
@@ -696,7 +708,7 @@ TEST (PCL, eigen33d)
     // test if U * V * U^T = M
     r_result = r_vectors * r_eigenvalues.asDiagonal () * r_vectors.transpose ();
     r_error = r_result - r_matrix;
-    diff = r_error.cwiseAbs (). sum ();
+    Scalar diff = r_error.cwiseAbs (). sum ();
     EXPECT_LE (diff, epsilon);
 
     // test if the eigenvalues are orthonormal
@@ -724,9 +736,9 @@ TEST (PCL, eigen33d)
 // some errors > 0.2 but less than 1% is > 1e-3 -> we will just check whether the failure rate is below 1%
 TEST (PCL, eigen33f)
 {
-  typedef float Scalar;
-  typedef Eigen::Matrix<Scalar, 3, 3, Eigen::RowMajor> RMatrix;
-  typedef Eigen::Matrix<Scalar, 3, 3, Eigen::ColMajor> CMatrix;
+  using Scalar = float;
+  using RMatrix = Eigen::Matrix<Scalar, 3, 3, Eigen::RowMajor>;
+  using CMatrix = Eigen::Matrix<Scalar, 3, 3, Eigen::ColMajor>;
   RMatrix r_matrix;
   RMatrix r_vectors;
   Eigen::Matrix<Scalar, 3, 1> r_eigenvalues;
@@ -739,19 +751,15 @@ TEST (PCL, eigen33f)
   Eigen::Matrix<Scalar, 3, 3> g_error;
   Eigen::Matrix<Scalar, 3, 3> c_result;
   Eigen::Matrix<Scalar, 3, 3> c_error;
-  Scalar diff;
 
   const Scalar epsilon = 1e-3f;
-  const unsigned iterations = 1000000;
-  bool r_failed;
-  bool c_failed;
+  constexpr unsigned iterations = 1000000;
   unsigned r_fail_count = 0;
-  unsigned c_fail_count = 0;
 
   // test floating point row-major : row-major
   for (unsigned idx = 0; idx < iterations; ++idx)
   {
-    r_failed = c_failed = false;
+    bool r_failed = false;
     // generate test matrices
     generateSymPosMatrix3x3 (r_matrix);
     c_matrix = r_matrix;
@@ -762,7 +770,7 @@ TEST (PCL, eigen33f)
     // test if U * V * U^T = M
     r_result = r_vectors * r_eigenvalues.asDiagonal () * r_vectors.transpose ();
     r_error = r_result - r_matrix;
-    diff = r_error.cwiseAbs (). sum ();
+    Scalar diff = r_error.cwiseAbs (). sum ();
     if (diff > epsilon)
       r_failed = true;
 
@@ -780,18 +788,9 @@ TEST (PCL, eigen33f)
     eigen33 (c_matrix, c_vectors, c_eigenvalues);
     c_result = c_vectors * c_eigenvalues.asDiagonal () * c_vectors.transpose ();
     c_error = c_result - c_matrix;
-    diff = c_error.cwiseAbs (). sum ();
-    if (diff > epsilon)
-      c_failed = true;
 
     g_result = c_vectors * c_vectors.transpose ();
     g_error = g_result - CMatrix::Identity ();
-    diff = g_error.cwiseAbs (). sum ();
-    if (diff > epsilon)
-      c_failed = true;
-
-    if(c_failed)
-      ++c_fail_count;
   }
 
   // less than 1% failure rate
