@@ -47,7 +47,7 @@ pcl::PointCloud<pcl::PointXYZ>::Ptr cloud;
 void
 createColorCloud (pcl::PointCloud<pcl::PointXYZRGBA> &colorCloud)
 {
-  for (size_t i = 0; i < cloud->points.size (); ++i)
+  for (std::size_t i = 0; i < cloud->points.size (); ++i)
   {
     pcl::PointXYZRGBA p;
     p.getVector3fMap () = cloud->points[i].getVector3fMap ();
@@ -74,9 +74,9 @@ TEST(PCL, GASDTransformEstimation)
   -0.035592, -0.369596, -0.928511, 0.0622551,
   0, 0, 0, 1;
 
-  for (int i = 0; i < trans.rows(); ++i)
+  for (Eigen::Index i = 0; i < trans.rows(); ++i)
   {
-    for (int j = 0; j < trans.cols (); ++j)
+    for (Eigen::Index j = 0; j < trans.cols (); ++j)
     {
       EXPECT_NEAR (trans (i, j), ref_trans (i, j), 1e-5);
     }
@@ -114,7 +114,7 @@ TEST (PCL, GASDShapeEstimationNoInterp)
     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
 
   EXPECT_EQ (descriptor.points.size (), 1);
-  for (size_t i = 0; i < size_t (descriptor.points[0].descriptorSize ()); ++i)
+  for (std::size_t i = 0; i < std::size_t (descriptor.points[0].descriptorSize ()); ++i)
   {
     EXPECT_NEAR (descriptor.points[0].histogram[i], ref_values[i], 1e-5);
   }
@@ -158,7 +158,7 @@ TEST(PCL, GASDShapeEstimationTrilinearInterp)
     0, 0, 0, 0, 0, 0, 0, 0};
 
   EXPECT_EQ (descriptor.points.size (), 1);
-  for (size_t i = 0; i < size_t (descriptor.points[0].descriptorSize ()); ++i)
+  for (std::size_t i = 0; i < std::size_t (descriptor.points[0].descriptorSize ()); ++i)
   {
     EXPECT_NEAR (descriptor.points[0].histogram[i], ref_values[i], 1e-5);
   }
@@ -217,7 +217,7 @@ TEST (PCL, GASDShapeAndColorEstimationNoInterp)
     0, 0, 0, 0, 0, 0, 0, 0};
 
   EXPECT_EQ (descriptor.points.size (), 1);
-  for (size_t i = 0; i < size_t (descriptor.points[0].descriptorSize ()); ++i)
+  for (std::size_t i = 0; i < std::size_t (descriptor.points[0].descriptorSize ()); ++i)
   {
     EXPECT_NEAR (descriptor.points[0].histogram[i], ref_values[i], 1e-5);
   }
@@ -304,7 +304,7 @@ TEST(PCL, GASDShapeAndColorEstimationQuadrilinearInterp)
     0, 0, 0, 0, 0, 0, 0, 0};
 
   EXPECT_EQ (descriptor.points.size (), 1);
-  for (size_t i = 0; i < size_t( descriptor.points[0].descriptorSize ()); ++i)
+  for (std::size_t i = 0; i < std::size_t( descriptor.points[0].descriptorSize ()); ++i)
   {
     EXPECT_NEAR (descriptor.points[0].histogram[i], ref_values[i], 1e-5);
   }
