@@ -42,7 +42,6 @@
 #include <pcl/point_types.h>
 #include <pcl/io/pcd_io.h>
 #include <pcl/features/normal_3d.h>
-#include <pcl/features/fpfh.h>
 #include <pcl/registration/registration.h>
 #include <pcl/registration/icp.h>
 #include <pcl/registration/joint_icp.h>
@@ -55,12 +54,10 @@
 #include <pcl/registration/correspondence_rejection_sample_consensus.h>
 #include <pcl/registration/correspondence_rejection_surface_normal.h>
 #include <pcl/registration/correspondence_estimation_normal_shooting.h>
-#include <pcl/registration/ia_ransac.h>
 #include <pcl/registration/pyramid_feature_matching.h>
 #include <pcl/features/ppf.h>
 #include <pcl/registration/ppf_registration.h>
-#include <pcl/registration/ndt.h>
-#include <pcl/registration/sample_consensus_prerejective.h>
+#include <pcl/filters/voxel_grid.h>
 // We need Histogram<2> to function, so we'll explicitly add kdtree_flann.hpp here
 #include <pcl/kdtree/impl/kdtree_flann.hpp>
 //(pcl::Histogram<2>)
@@ -91,8 +88,8 @@ public:
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, findFeatureCorrespondences)
 {
-  typedef Histogram<2> FeatureT;
-  typedef PointCloud<FeatureT> FeatureCloud;
+  using FeatureT = Histogram<2>;
+  using FeatureCloud = PointCloud<FeatureT>;
 
   RegistrationWrapper <PointXYZ, PointXYZ> reg;
 
@@ -122,10 +119,10 @@ TEST (PCL, findFeatureCorrespondences)
       feature3.points.push_back (f);
     }
   }
-  feature0.width = static_cast<uint32_t> (feature0.points.size ());
-  feature1.width = static_cast<uint32_t> (feature1.points.size ());
-  feature2.width = static_cast<uint32_t> (feature2.points.size ());
-  feature3.width = static_cast<uint32_t> (feature3.points.size ());
+  feature0.width = static_cast<std::uint32_t> (feature0.points.size ());
+  feature1.width = static_cast<std::uint32_t> (feature1.points.size ());
+  feature2.width = static_cast<std::uint32_t> (feature2.points.size ());
+  feature3.width = static_cast<std::uint32_t> (feature3.points.size ());
 
   KdTreeFLANN<FeatureT> tree;
 
@@ -150,7 +147,7 @@ TEST (PCL, findFeatureCorrespondences)
 
   ASSERT_EQ ((int)indices.size (), 10);
   const int correct_values[] = {1197, 1248, 1249, 1299, 1300, 1301, 1302, 1350, 1351, 1401};
-  for (size_t i = 0; i < indices.size (); ++i)
+  for (std::size_t i = 0; i < indices.size (); ++i)
   {
     EXPECT_EQ (indices[i], correct_values[i]);
   }
@@ -194,6 +191,17 @@ TEST (PCL, IterativeClosestPoint)
 //  EXPECT_EQ (transformation (3, 3), 1);
 }
 
+TEST (PCL, IterativeClosestPointWithNormals)
+{
+  IterativeClosestPointWithNormals<PointNormal, PointNormal, float> reg_float;
+  reg_float.setUseSymmetricObjective(true);
+  EXPECT_TRUE(reg_float.getUseSymmetricObjective());
+
+  IterativeClosestPointWithNormals<PointNormal, PointNormal, double> reg_double;
+  reg_double.setUseSymmetricObjective(true);
+  EXPECT_TRUE(reg_double.getUseSymmetricObjective());
+}
+
 ////////////////////////////////////////////////////////////////////////////////////////////////////////
 void
 sampleRandomTransform (Eigen::Affine3f &trans, float max_angle, float max_trans)
@@ -224,8 +232,8 @@ TEST (PCL, IterativeClosestPointWithRejectors)
   pcl::registration::CorrespondenceRejectorSampleConsensus<PointXYZ>::Ptr rej_samp (new pcl::registration::CorrespondenceRejectorSampleConsensus<PointXYZ>);
   reg.addCorrespondenceRejector (rej_samp);
 
-  size_t ntransforms = 10;
-  for (size_t t = 0; t < ntransforms; t++)
+  std::size_t ntransforms = 10;
+  for (std::size_t t = 0; t < ntransforms; t++)
   {
     // Sample a fixed offset between cloud pairs
     Eigen::Affine3f delta_transform;
@@ -274,8 +282,8 @@ TEST (PCL, JointIterativeClosestPoint)
   pcl::registration::CorrespondenceRejectorSampleConsensus<PointXYZ>::Ptr rej_samp (new pcl::registration::CorrespondenceRejectorSampleConsensus<PointXYZ>);
   reg.addCorrespondenceRejector (rej_samp);
 
-  size_t ntransforms = 10;
-  for (size_t t = 0; t < ntransforms; t++)
+  std::size_t ntransforms = 10;
+  for (std::size_t t = 0; t < ntransforms; t++)
   {
 
     // Sample a fixed offset between cloud pairs
@@ -283,8 +291,8 @@ TEST (PCL, JointIterativeClosestPoint)
     // No rotation, since at a random offset this could make it converge to a wrong (but still reasonable) result
     sampleRandomTransform (delta_transform, 0., 0.10);
     // Make a few transformed versions of the data, plus noise
-    size_t nclouds = 5;
-    for (size_t i = 0; i < nclouds; i++)
+    std::size_t nclouds = 5;
+    for (std::size_t i = 0; i < nclouds; i++)
     {
       PointCloud<PointXYZ>::ConstPtr source (cloud_source.makeShared ());
       // Sample random global transform for each pair
@@ -318,7 +326,7 @@ TEST (PCL, JointIterativeClosestPoint)
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, IterativeClosestPointNonLinear)
 {
-  typedef PointXYZRGB PointT;
+  using PointT = PointXYZRGB;
   PointCloud<PointT>::Ptr temp_src (new PointCloud<PointT>);
   copyPointCloud (cloud_source, *temp_src);
   PointCloud<PointT>::Ptr temp_tgt (new PointCloud<PointT>);
@@ -389,7 +397,7 @@ TEST (PCL, IterativeClosestPointNonLinear)
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, IterativeClosestPoint_PointToPlane)
 {
-  typedef PointNormal PointT;
+  using PointT = PointNormal;
   PointCloud<PointT>::Ptr src (new PointCloud<PointT>);
   copyPointCloud (cloud_source, *src);
   PointCloud<PointT>::Ptr tgt (new PointCloud<PointT>);
@@ -403,8 +411,8 @@ TEST (PCL, IterativeClosestPoint_PointToPlane)
   norm_est.compute (*tgt);
 
   IterativeClosestPoint<PointT, PointT> reg;
-  typedef registration::TransformationEstimationPointToPlane<PointT, PointT> PointToPlane;
-  boost::shared_ptr<PointToPlane> point_to_plane (new PointToPlane);
+  using PointToPlane = registration::TransformationEstimationPointToPlane<PointT, PointT>;
+  PointToPlane::Ptr point_to_plane (new PointToPlane);
   reg.setTransformationEstimation (point_to_plane);
   reg.setInputSource (src);
   reg.setInputTarget (tgt);
@@ -478,7 +486,7 @@ TEST (PCL, IterativeClosestPoint_PointToPlane)
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, GeneralizedIterativeClosestPoint)
 {
-  typedef PointXYZ PointT;
+  using PointT = PointXYZ;
   PointCloud<PointT>::Ptr src (new PointCloud<PointT>);
   copyPointCloud (cloud_source, *src);
   PointCloud<PointT>::Ptr tgt (new PointCloud<PointT>);
@@ -539,7 +547,7 @@ TEST (PCL, GeneralizedIterativeClosestPoint)
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, GeneralizedIterativeClosestPoint6D)
 {
-  typedef PointXYZRGBA PointT;
+  using PointT = PointXYZRGBA;
   Eigen::Affine3f delta_transform;
   PointCloud<PointT>::Ptr src_full (new PointCloud<PointT>);
   copyPointCloud (cloud_with_color, *src_full);
@@ -592,234 +600,6 @@ TEST (PCL, GeneralizedIterativeClosestPoint6D)
   }
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-TEST (PCL, NormalDistributionsTransform)
-{
-  typedef PointNormal PointT;
-  PointCloud<PointT>::Ptr src (new PointCloud<PointT>);
-  copyPointCloud (cloud_source, *src);
-  PointCloud<PointT>::Ptr tgt (new PointCloud<PointT>);
-  copyPointCloud (cloud_target, *tgt);
-  PointCloud<PointT> output;
-
-  NormalDistributionsTransform<PointT, PointT> reg;
-  reg.setStepSize (0.05);
-  reg.setResolution (0.025f);
-  reg.setInputSource (src);
-  reg.setInputTarget (tgt);
-  reg.setMaximumIterations (50);
-  reg.setTransformationEpsilon (1e-8);
-  // Register
-  reg.align (output);
-  EXPECT_EQ (int (output.points.size ()), int (cloud_source.points.size ()));
-  EXPECT_LT (reg.getFitnessScore (), 0.001);
-
-  // Check again, for all possible caching schemes
-  for (int iter = 0; iter < 4; iter++)
-  {
-    bool force_cache = (bool) iter/2;
-    bool force_cache_reciprocal = (bool) iter%2;
-    pcl::search::KdTree<PointT>::Ptr tree(new pcl::search::KdTree<PointT>);
-    // Ensure that, when force_cache is not set, we are robust to the wrong input
-    if (force_cache)
-      tree->setInputCloud (tgt);
-    reg.setSearchMethodTarget (tree, force_cache);
-
-    pcl::search::KdTree<PointT>::Ptr tree_recip (new pcl::search::KdTree<PointT>);
-    if (force_cache_reciprocal)
-      tree_recip->setInputCloud (src);
-    reg.setSearchMethodSource (tree_recip, force_cache_reciprocal);
-
-    // Register
-    reg.align (output);
-    EXPECT_EQ (int (output.points.size ()), int (cloud_source.points.size ()));
-    EXPECT_LT (reg.getFitnessScore (), 0.001);
-  }
-}
-
-
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-TEST (PCL, SampleConsensusInitialAlignment)
-{
-  // Transform the source cloud by a large amount
-  Eigen::Vector3f initial_offset (100, 0, 0);
-  float angle = static_cast<float> (M_PI) / 2.0f;
-  Eigen::Quaternionf initial_rotation (cos (angle / 2), 0, 0, sin (angle / 2));
-  PointCloud<PointXYZ> cloud_source_transformed;
-  transformPointCloud (cloud_source, cloud_source_transformed, initial_offset, initial_rotation);
-
-  // Create shared pointers
-  PointCloud<PointXYZ>::Ptr cloud_source_ptr, cloud_target_ptr;
-  cloud_source_ptr = cloud_source_transformed.makeShared ();
-  cloud_target_ptr = cloud_target.makeShared ();
-
-  // Initialize estimators for surface normals and FPFH features
-  search::KdTree<PointXYZ>::Ptr tree (new search::KdTree<PointXYZ>);
-
-  NormalEstimation<PointXYZ, Normal> norm_est;
-  norm_est.setSearchMethod (tree);
-  norm_est.setRadiusSearch (0.05);
-  PointCloud<Normal> normals;
-
-  FPFHEstimation<PointXYZ, Normal, FPFHSignature33> fpfh_est;
-  fpfh_est.setSearchMethod (tree);
-  fpfh_est.setRadiusSearch (0.05);
-  PointCloud<FPFHSignature33> features_source, features_target;
-
-  // Estimate the FPFH features for the source cloud
-  norm_est.setInputCloud (cloud_source_ptr);
-  norm_est.compute (normals);
-  fpfh_est.setInputCloud (cloud_source_ptr);
-  fpfh_est.setInputNormals (normals.makeShared ());
-  fpfh_est.compute (features_source);
-
-  // Estimate the FPFH features for the target cloud
-  norm_est.setInputCloud (cloud_target_ptr);
-  norm_est.compute (normals);
-  fpfh_est.setInputCloud (cloud_target_ptr);
-  fpfh_est.setInputNormals (normals.makeShared ());
-  fpfh_est.compute (features_target);
-
-  // Initialize Sample Consensus Initial Alignment (SAC-IA)
-  SampleConsensusInitialAlignment<PointXYZ, PointXYZ, FPFHSignature33> reg;
-  reg.setMinSampleDistance (0.05f);
-  reg.setMaxCorrespondenceDistance (0.1);
-  reg.setMaximumIterations (1000);
-
-  reg.setInputSource (cloud_source_ptr);
-  reg.setInputTarget (cloud_target_ptr);
-  reg.setSourceFeatures (features_source.makeShared ());
-  reg.setTargetFeatures (features_target.makeShared ());
-
-  // Register
-  reg.align (cloud_reg);
-  EXPECT_EQ (int (cloud_reg.points.size ()), int (cloud_source.points.size ()));
-  EXPECT_LT (reg.getFitnessScore (), 0.0005);
-
-  // Check again, for all possible caching schemes
-  typedef pcl::PointXYZ PointT;
-  for (int iter = 0; iter < 4; iter++)
-  {
-    bool force_cache = (bool) iter/2;
-    bool force_cache_reciprocal = (bool) iter%2;
-    pcl::search::KdTree<PointT>::Ptr tree(new pcl::search::KdTree<PointT>);
-    // Ensure that, when force_cache is not set, we are robust to the wrong input
-    if (force_cache)
-      tree->setInputCloud (cloud_target_ptr);
-    reg.setSearchMethodTarget (tree, force_cache);
-
-    pcl::search::KdTree<PointT>::Ptr tree_recip (new pcl::search::KdTree<PointT>);
-    if (force_cache_reciprocal)
-      tree_recip->setInputCloud (cloud_source_ptr);
-    reg.setSearchMethodSource(tree_recip, force_cache_reciprocal);
-
-    // Register
-    reg.align (cloud_reg);
-    EXPECT_EQ (int (cloud_reg.points.size ()), int (cloud_source.points.size ()));
-    EXPECT_LT (reg.getFitnessScore (), 0.0005);
-  }
-}
-
-
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-TEST (PCL, SampleConsensusPrerejective)
-{
-  /*
-   * This test is a near-exact copy of the SampleConsensusInitialAlignment test,
-   * with the only modifications that:
-   *   1) the number of iterations is increased 1000 --> 5000
-   *   2) the feature correspondence randomness (the number of kNNs) is decreased 10 --> 2
-   */
-
-  // Transform the source cloud by a large amount
-  Eigen::Vector3f initial_offset (100, 0, 0);
-  float angle = static_cast<float> (M_PI) / 2.0f;
-  Eigen::Quaternionf initial_rotation (cos (angle / 2), 0, 0, sin (angle / 2));
-  PointCloud<PointXYZ> cloud_source_transformed;
-  transformPointCloud (cloud_source, cloud_source_transformed, initial_offset, initial_rotation);
-
-  // Create shared pointers
-  PointCloud<PointXYZ>::Ptr cloud_source_ptr, cloud_target_ptr;
-  cloud_source_ptr = cloud_source_transformed.makeShared ();
-  cloud_target_ptr = cloud_target.makeShared ();
-
-  // Initialize estimators for surface normals and FPFH features
-  search::KdTree<PointXYZ>::Ptr tree (new search::KdTree<PointXYZ>);
-
-  // Normal estimator
-  NormalEstimation<PointXYZ, Normal> norm_est;
-  norm_est.setSearchMethod (tree);
-  norm_est.setRadiusSearch (0.005);
-  PointCloud<Normal> normals;
-
-  // FPFH estimator
-  FPFHEstimation<PointXYZ, Normal, FPFHSignature33> fpfh_est;
-  fpfh_est.setSearchMethod (tree);
-  fpfh_est.setRadiusSearch (0.05);
-  PointCloud<FPFHSignature33> features_source, features_target;
-
-  // Estimate the normals and the FPFH features for the source cloud
-  norm_est.setInputCloud (cloud_source_ptr);
-  norm_est.compute (normals);
-  fpfh_est.setInputCloud (cloud_source_ptr);
-  fpfh_est.setInputNormals (normals.makeShared ());
-  fpfh_est.compute (features_source);
-
-  // Estimate the normals and the FPFH features for the target cloud
-  norm_est.setInputCloud (cloud_target_ptr);
-  norm_est.compute (normals);
-  fpfh_est.setInputCloud (cloud_target_ptr);
-  fpfh_est.setInputNormals (normals.makeShared ());
-  fpfh_est.compute (features_target);
-
-  // Initialize Sample Consensus Prerejective with 5x the number of iterations and 1/5 feature kNNs as SAC-IA
-  SampleConsensusPrerejective<PointXYZ, PointXYZ, FPFHSignature33> reg;
-  reg.setMaxCorrespondenceDistance (0.1);
-  reg.setMaximumIterations (5000);
-  reg.setSimilarityThreshold (0.6f);
-  reg.setCorrespondenceRandomness (2);
-
-  // Set source and target cloud/features
-  reg.setInputSource (cloud_source_ptr);
-  reg.setInputTarget (cloud_target_ptr);
-  reg.setSourceFeatures (features_source.makeShared ());
-  reg.setTargetFeatures (features_target.makeShared ());
-
-  // Register
-  reg.align (cloud_reg);
-
-  // Check output consistency and quality of alignment
-  EXPECT_EQ (static_cast<int> (cloud_reg.points.size ()), static_cast<int> (cloud_source.points.size ()));
-  float inlier_fraction = static_cast<float> (reg.getInliers ().size ()) / static_cast<float> (cloud_source.points.size ());
-  EXPECT_GT (inlier_fraction, 0.95f);
-
-  // Check again, for all possible caching schemes
-  typedef pcl::PointXYZ PointT;
-  for (int iter = 0; iter < 4; iter++)
-  {
-    bool force_cache = (bool) iter/2;
-    bool force_cache_reciprocal = (bool) iter%2;
-    pcl::search::KdTree<PointT>::Ptr tree(new pcl::search::KdTree<PointT>);
-    // Ensure that, when force_cache is not set, we are robust to the wrong input
-    if (force_cache)
-      tree->setInputCloud (cloud_target_ptr);
-    reg.setSearchMethodTarget (tree, force_cache);
-
-    pcl::search::KdTree<PointT>::Ptr tree_recip (new pcl::search::KdTree<PointT>);
-    if (force_cache_reciprocal)
-      tree_recip->setInputCloud (cloud_source_ptr);
-    reg.setSearchMethodSource(tree_recip, force_cache_reciprocal);
-
-    // Register
-    reg.align (cloud_reg);
-
-    // Check output consistency and quality of alignment
-    EXPECT_EQ (int (cloud_reg.points.size ()), int (cloud_source.points.size ()));
-    inlier_fraction = static_cast<float> (reg.getInliers ().size ()) / static_cast<float> (cloud_source.points.size ());
-    EXPECT_GT (inlier_fraction, 0.95f);
-  }
-}
-
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, PyramidFeatureHistogram)
@@ -853,11 +633,11 @@ TEST (PCL, PyramidFeatureHistogram)
   ppf_estimator.compute (*ppf_signature_target);
 
 
-  vector<pair<float, float> > dim_range_input, dim_range_target;
-  for (size_t i = 0; i < 3; ++i) dim_range_input.push_back (pair<float, float> (static_cast<float> (-M_PI), static_cast<float> (M_PI)));
-  dim_range_input.push_back (pair<float, float> (0.0f, 1.0f));
-  for (size_t i = 0; i < 3; ++i) dim_range_target.push_back (pair<float, float> (static_cast<float> (-M_PI) * 10.0f, static_cast<float> (M_PI) * 10.0f));
-  dim_range_target.push_back (pair<float, float> (0.0f, 50.0f));
+  std::vector<pair<float, float> > dim_range_input, dim_range_target;
+  for (std::size_t i = 0; i < 3; ++i) dim_range_input.emplace_back(static_cast<float> (-M_PI), static_cast<float> (M_PI));
+  dim_range_input.emplace_back(0.0f, 1.0f);
+  for (std::size_t i = 0; i < 3; ++i) dim_range_target.emplace_back(static_cast<float> (-M_PI) * 10.0f, static_cast<float> (M_PI) * 10.0f);
+  dim_range_target.emplace_back(0.0f, 50.0f);
 
 
   PyramidFeatureHistogram<PPFSignature>::Ptr pyramid_source (new PyramidFeatureHistogram<PPFSignature> ()),
@@ -875,9 +655,9 @@ TEST (PCL, PyramidFeatureHistogram)
   float similarity_value = PyramidFeatureHistogram<PPFSignature>::comparePyramidFeatureHistograms (pyramid_source, pyramid_target);
   EXPECT_NEAR (similarity_value, 0.74101555347442627, 1e-4);
 
-  vector<pair<float, float> > dim_range_target2;
-  for (size_t i = 0; i < 3; ++i) dim_range_target2.push_back (pair<float, float> (static_cast<float> (-M_PI) * 5.0f, static_cast<float> (M_PI) * 5.0f));
-    dim_range_target2.push_back (pair<float, float> (0.0f, 20.0f));
+  std::vector<pair<float, float> > dim_range_target2;
+  for (std::size_t i = 0; i < 3; ++i) dim_range_target2.emplace_back(static_cast<float> (-M_PI) * 5.0f, static_cast<float> (M_PI) * 5.0f);
+    dim_range_target2.emplace_back(0.0f, 20.0f);
 
   pyramid_source->setTargetDimensionRange (dim_range_target2);
   pyramid_source->compute ();
@@ -889,9 +669,9 @@ TEST (PCL, PyramidFeatureHistogram)
   EXPECT_NEAR (similarity_value2, 0.80097091197967529, 1e-4);
 
 
-  vector<pair<float, float> > dim_range_target3;
-  for (size_t i = 0; i < 3; ++i) dim_range_target3.push_back (pair<float, float> (static_cast<float> (-M_PI) * 2.0f, static_cast<float> (M_PI) * 2.0f));
-  dim_range_target3.push_back (pair<float, float> (0.0f, 10.0f));
+  std::vector<pair<float, float> > dim_range_target3;
+  for (std::size_t i = 0; i < 3; ++i) dim_range_target3.emplace_back(static_cast<float> (-M_PI) * 2.0f, static_cast<float> (M_PI) * 2.0f);
+  dim_range_target3.emplace_back(0.0f, 10.0f);
 
   pyramid_source->setTargetDimensionRange (dim_range_target3);
   pyramid_source->compute ();
@@ -912,7 +692,7 @@ TEST (PCL, PPFRegistration)
   // Transform the source cloud by a large amount
   Eigen::Vector3f initial_offset (100, 0, 0);
   float angle = M_PI/6;
-  Eigen::Quaternionf initial_rotation (cos (angle / 2), 0, 0, sin (angle / 2));
+  Eigen::Quaternionf initial_rotation (std::cos (angle / 2), 0, 0, sin (angle / 2));
   PointCloud<PointXYZ> cloud_source_transformed;
   transformPointCloud (cloud_source, cloud_source_transformed, initial_offset, initial_rotation);
 
@@ -1015,7 +795,7 @@ main (int argc, char** argv)
   return (RUN_ALL_TESTS ());
 
   // Tranpose the cloud_model
-  /*for (size_t i = 0; i < cloud_model.points.size (); ++i)
+  /*for (std::size_t i = 0; i < cloud_model.points.size (); ++i)
   {
   //  cloud_model.points[i].z += 1;
   }*/
