@@ -93,20 +93,32 @@ compute (const pcl::PCLPointCloud2::ConstPtr &input, pcl::PCLPointCloud2 &output
   // Estimate
   TicToc tt;
   tt.tic ();
-  
+
   print_highlight (stderr, "Computing ");
 
-  UniformSampling<PointXYZ> us;
-  us.setInputCloud (xyz);
-  us.setRadiusSearch (radius);
-  PointCloud<PointXYZ> output_;
-  us.filter (output_);
+  UniformSampling<PointXYZ> us(true); // extract removed indices
+  us.setInputCloud(xyz);
+  us.setRadiusSearch(radius);
+  PointCloud<PointXYZ> temp;
+  us.filter(temp);
+
+  pcl::PointIndices removed_indices;
+  // These are "fake" indices generated by initCompute(), already sorted
+  auto input_indices = us.getIndices();
+  // Removed indices, not guaranteed to be sorted
+  us.getRemovedIndices(removed_indices);
+  std::sort(removed_indices.indices.begin(), removed_indices.indices.end());
+  // Compute retained indices as a set difference between all and removed
+  std::vector<int> retained;
+  std::set_difference(input_indices->begin(),
+                      input_indices->end(),
+                      removed_indices.indices.begin(),
+                      removed_indices.indices.end(),
+                      std::inserter(retained, retained.begin()));
+  pcl::copyPointCloud(*input, retained, output);
 
   print_info ("[done, "); print_value ("%g", tt.toc ()); print_info (" ms : ");
-  print_value ("%d", output_.size()); print_info (" points]\n");
-
-  // Convert data back
-  toPCLPointCloud2 (output_, output);
+  print_value ("%d", retained.size()); print_info (" points]\n");
 }
 
 void
@@ -122,15 +134,15 @@ saveCloud (const string &filename, const pcl::PCLPointCloud2 &output)
   std::string output_ext = boost::filesystem::extension (filename);
   std::transform (output_ext.begin (), output_ext.end (), output_ext.begin (), ::tolower);
 
-  if (output_ext.compare (".pcd") == 0)
+  if (output_ext == ".pcd")
   {
     w_pcd.writeBinaryCompressed (filename, output);
   }
-  else if (output_ext.compare (".ply") == 0)
+  else if (output_ext == ".ply")
   {
     w_ply.writeBinary (filename, output);
   }
-  else if (output_ext.compare (".vtk") == 0)
+  else if (output_ext == ".vtk")
   {
     w_ply.writeBinary (filename, output);
   }
@@ -151,11 +163,11 @@ main (int argc, char** argv)
   }
 
   // Parse the command line arguments for .pcd files
-  vector<int> p_file_indices;
-  vector<std::string> extension;
-  extension.push_back (".pcd");
-  extension.push_back (".ply");
-  extension.push_back (".vtk");
+  std::vector<int> p_file_indices;
+  std::vector<std::string> extension;
+  extension.emplace_back(".pcd");
+  extension.emplace_back(".ply");
+  extension.emplace_back(".vtk");
   p_file_indices = parse_file_extension_argument (argc, argv, extension);
 
   if (p_file_indices.size () != 2)
