@@ -40,7 +40,6 @@
 
 #include <pcl/common/time.h>
 #include <pcl/common/utils.h>
-#include <pcl/tracking/boost.h>
 #include <pcl/common/io.h>
 #include <pcl/common/utils.h>
 
@@ -155,8 +154,7 @@ pcl::tracking::PyramidalKLTTracker<PointInT, IntensityT>::initCompute ()
     computePyramids (ref_, ref_pyramid_, pcl::BORDER_REFLECT_101);
     return (true);
   }
-  else
-    initialized_ = true;
+  initialized_ = true;
 
   return (true);
 }
@@ -507,13 +505,13 @@ pcl::tracking::PyramidalKLTTracker<PointInT, IntensityT>::track (const PointClou
 
       next_pts[ptidx] = next_pt;
 
-      Eigen::Array2i iprev_point, inext_pt;
+      Eigen::Array2i iprev_point;
       prev_pt -= half_win;
-      iprev_point[0] = floor (prev_pt[0]);
-      iprev_point[1] = floor (prev_pt[1]);
+      iprev_point[0] = std::floor (prev_pt[0]);
+      iprev_point[1] = std::floor (prev_pt[1]);
 
-      if (iprev_point[0] < -track_width_ || (uint32_t) iprev_point[0] >= grad_x.width ||
-          iprev_point[1] < -track_height_ || (uint32_t) iprev_point[1] >= grad_y.height)
+      if (iprev_point[0] < -track_width_ || (std::uint32_t) iprev_point[0] >= grad_x.width ||
+          iprev_point[1] < -track_height_ || (std::uint32_t) iprev_point[1] >= grad_y.height)
       {
         if (level == 0)
           status [ptidx] = -1;
@@ -543,14 +541,13 @@ pcl::tracking::PyramidalKLTTracker<PointInT, IntensityT>::track (const PointClou
       det = 1.f/det;
       next_pt -= half_win;
 
-      Eigen::Array2f prev_delta;
+      Eigen::Array2f prev_delta (0, 0);
       for (unsigned int j = 0; j < max_iterations_; j++)
       {
-        inext_pt[0] = floor (next_pt[0]);
-        inext_pt[1] = floor (next_pt[1]);
+        Eigen::Array2i inext_pt = next_pt.floor ().cast<int> ();
 
-        if (inext_pt[0] < -track_width_ || (uint32_t) inext_pt[0] >= next.width ||
-            inext_pt[1] < -track_height_ || (uint32_t) inext_pt[1] >= next.height)
+        if (inext_pt[0] < -track_width_ || (std::uint32_t) inext_pt[0] >= next.width ||
+            inext_pt[1] < -track_height_ || (std::uint32_t) inext_pt[1] >= next.height)
         {
           if (level == 0)
             status[ptidx] = -1;
@@ -592,11 +589,11 @@ pcl::tracking::PyramidalKLTTracker<PointInT, IntensityT>::track (const PointClou
         Eigen::Array2f next_point = next_pts[ptidx] - half_win;
         Eigen::Array2i inext_point;
 
-        inext_point[0] = floor (next_point[0]);
-        inext_point[1] = floor (next_point[1]);
+        inext_point[0] = std::floor (next_point[0]);
+        inext_point[1] = std::floor (next_point[1]);
 
-        if (inext_point[0] < -track_width_ || (uint32_t) inext_point[0] >= next.width ||
-            inext_point[1] < -track_height_ || (uint32_t) inext_point[1] >= next.height)
+        if (inext_point[0] < -track_width_ || (std::uint32_t) inext_point[0] >= next.width ||
+            inext_point[1] < -track_height_ || (std::uint32_t) inext_point[1] >= next.height)
         {
           status[ptidx] = -1;
           continue;
@@ -607,12 +604,12 @@ pcl::tracking::PyramidalKLTTracker<PointInT, IntensityT>::track (const PointClou
         n.v = next_pts[ptidx][1];
         keypoints->push_back (n);
         // add points pair to compute transformation
-        inext_point[0] = floor (next_pts[ptidx][0]);
-        inext_point[1] = floor (next_pts[ptidx][1]);
-        iprev_point[0] = floor (prev_keypoints->points[ptidx].u);
-        iprev_point[1] = floor (prev_keypoints->points[ptidx].v);
+        inext_point[0] = std::floor (next_pts[ptidx][0]);
+        inext_point[1] = std::floor (next_pts[ptidx][1]);
+        iprev_point[0] = std::floor (prev_keypoints->points[ptidx].u);
+        iprev_point[1] = std::floor (prev_keypoints->points[ptidx].v);
         const PointInT& prev_pt = prev_input->points[iprev_point[1]*prev_input->width + iprev_point[0]];
-        const PointInT& next_pt = input->points[inext_pt[1]*input->width + inext_pt[0]];
+        const PointInT& next_pt = input->points[inext_point[1]*input->width + inext_point[0]];
         transformation_computer.add (prev_pt.getVector3fMap (), next_pt.getVector3fMap (), 1.0);
       }
     }
