@@ -34,8 +34,8 @@
  *  POSSIBILITY OF SUCH DAMAGE.
  *
  */
-#ifndef PCL_POINT_CLOUD_COLOR_HANDLERS_H_
-#define PCL_POINT_CLOUD_COLOR_HANDLERS_H_
+
+#pragma once
 
 #if defined __GNUC__
 #pragma GCC system_header
@@ -64,12 +64,12 @@ namespace pcl
     class PointCloudColorHandler
     {
       public:
-        typedef pcl::PointCloud<PointT> PointCloud;
-        typedef typename PointCloud::Ptr PointCloudPtr;
-        typedef typename PointCloud::ConstPtr PointCloudConstPtr;
+        using PointCloud = pcl::PointCloud<PointT>;
+        using PointCloudPtr = typename PointCloud::Ptr;
+        using PointCloudConstPtr = typename PointCloud::ConstPtr;
 
-        typedef boost::shared_ptr<PointCloudColorHandler<PointT> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandler<PointT> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandler<PointT> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandler<PointT> >;
 
         /** \brief Constructor. */
         PointCloudColorHandler () :
@@ -96,13 +96,29 @@ namespace pcl
         virtual std::string
         getFieldName () const = 0;
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and 
-          * the input cloud was given as a valid pointer), false otherwise
-          */
+        /** Obtain the actual color for the input dataset as a VTK data array.
+          * Deriving handlers should override this method. The default implementation is
+          * provided only for backwards compatibility with handlers that were written
+          * before PCL 1.10.0 and will be removed in future.
+          * \return smart pointer to VTK array if the operation was successful (the
+          * handler is capable and the input cloud was given), a null pointer otherwise */
+        virtual vtkSmartPointer<vtkDataArray>
+        getColor () const {
+          vtkSmartPointer<vtkDataArray> scalars;
+          getColor (scalars);
+          return scalars;
+        }
+
+        /** Obtain the actual color for the input dataset as a VTK data array.
+          * This virtual method should not be overriden or used. The default implementation
+          * is provided only for backwards compatibility with handlers that were written
+          * before PCL 1.10.0 and will be removed in future. */
+        [[deprecated("use getColor() without parameters instead")]]
         virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const = 0;
+        getColor (vtkSmartPointer<vtkDataArray> &scalars) const {
+          scalars = getColor ();
+          return scalars.Get() != nullptr;
+        }
 
         /** \brief Set the input cloud to be used.
           * \param[in] cloud the input cloud to be used by the handler
@@ -137,13 +153,13 @@ namespace pcl
     template <typename PointT>
     class PointCloudColorHandlerRandom : public PointCloudColorHandler<PointT>
     {
-      typedef typename PointCloudColorHandler<PointT>::PointCloud PointCloud;
-      typedef typename PointCloud::Ptr PointCloudPtr;
-      typedef typename PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = typename PointCloudColorHandler<PointT>::PointCloud;
+      using PointCloudPtr = typename PointCloud::Ptr;
+      using PointCloudConstPtr = typename PointCloud::ConstPtr;
 
       public:
-        typedef boost::shared_ptr<PointCloudColorHandlerRandom<PointT> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandlerRandom<PointT> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandlerRandom<PointT> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandlerRandom<PointT> >;
 
         /** \brief Constructor. */
         PointCloudColorHandlerRandom () :
@@ -167,13 +183,10 @@ namespace pcl
         virtual std::string
         getFieldName () const { return ("[random]"); }
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and 
-          * the input cloud was given as a valid pointer), false otherwise
-          */
-        virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const;
+        vtkSmartPointer<vtkDataArray>
+        getColor () const override;
+
+        using PointCloudColorHandler<PointT>::getColor;
 
       protected:
         // Members derived from the base class
@@ -190,13 +203,13 @@ namespace pcl
     template <typename PointT>
     class PointCloudColorHandlerCustom : public PointCloudColorHandler<PointT>
     {
-      typedef typename PointCloudColorHandler<PointT>::PointCloud PointCloud;
-      typedef typename PointCloud::Ptr PointCloudPtr;
-      typedef typename PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = typename PointCloudColorHandler<PointT>::PointCloud;
+      using PointCloudPtr = typename PointCloud::Ptr;
+      using PointCloudConstPtr = typename PointCloud::ConstPtr;
 
       public:
-        typedef boost::shared_ptr<PointCloudColorHandlerCustom<PointT> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandlerCustom<PointT> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandlerCustom<PointT> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandlerCustom<PointT> >;
 
         /** \brief Constructor. */
         PointCloudColorHandlerCustom (double r, double g, double b)
@@ -230,13 +243,10 @@ namespace pcl
         virtual std::string
         getFieldName () const { return (""); }
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and 
-          * the input cloud was given as a valid pointer), false otherwise
-          */
-        virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const;
+        vtkSmartPointer<vtkDataArray>
+        getColor () const override;
+
+        using PointCloudColorHandler<PointT>::getColor;
 
       protected:
         // Members derived from the base class
@@ -256,13 +266,13 @@ namespace pcl
     template <typename PointT>
     class PointCloudColorHandlerRGBField : public PointCloudColorHandler<PointT>
     {
-      typedef typename PointCloudColorHandler<PointT>::PointCloud PointCloud;
-      typedef typename PointCloud::Ptr PointCloudPtr;
-      typedef typename PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = typename PointCloudColorHandler<PointT>::PointCloud;
+      using PointCloudPtr = typename PointCloud::Ptr;
+      using PointCloudConstPtr = typename PointCloud::ConstPtr;
 
       public:
-        typedef boost::shared_ptr<PointCloudColorHandlerRGBField<PointT> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandlerRGBField<PointT> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandlerRGBField<PointT> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandlerRGBField<PointT> >;
 
         /** \brief Constructor. */
         PointCloudColorHandlerRGBField ()
@@ -284,13 +294,10 @@ namespace pcl
         virtual std::string
         getFieldName () const { return ("rgb"); }
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and 
-          * the input cloud was given as a valid pointer), false otherwise
-          */
-        virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const;
+        vtkSmartPointer<vtkDataArray>
+        getColor () const override;
+
+        using PointCloudColorHandler<PointT>::getColor;
 
         /** \brief Set the input cloud to be used.
           * \param[in] cloud the input cloud to be used by the handler
@@ -319,13 +326,13 @@ namespace pcl
     template <typename PointT>
     class PointCloudColorHandlerHSVField : public PointCloudColorHandler<PointT>
     {
-      typedef typename PointCloudColorHandler<PointT>::PointCloud PointCloud;
-      typedef typename PointCloud::Ptr PointCloudPtr;
-      typedef typename PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = typename PointCloudColorHandler<PointT>::PointCloud;
+      using PointCloudPtr = typename PointCloud::Ptr;
+      using PointCloudConstPtr = typename PointCloud::ConstPtr;
 
       public:
-        typedef boost::shared_ptr<PointCloudColorHandlerHSVField<PointT> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandlerHSVField<PointT> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandlerHSVField<PointT> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandlerHSVField<PointT> >;
 
         /** \brief Constructor. */
         PointCloudColorHandlerHSVField (const PointCloudConstPtr &cloud);
@@ -337,13 +344,10 @@ namespace pcl
         virtual std::string
         getFieldName () const { return ("hsv"); }
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and 
-          * the input cloud was given as a valid pointer), false otherwise
-          */
-        virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const;
+        vtkSmartPointer<vtkDataArray>
+        getColor () const override;
+
+        using PointCloudColorHandler<PointT>::getColor;
 
       protected:
         /** \brief Class getName method. */
@@ -372,13 +376,13 @@ namespace pcl
     template <typename PointT>
     class PointCloudColorHandlerGenericField : public PointCloudColorHandler<PointT>
     {
-      typedef typename PointCloudColorHandler<PointT>::PointCloud PointCloud;
-      typedef typename PointCloud::Ptr PointCloudPtr;
-      typedef typename PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = typename PointCloudColorHandler<PointT>::PointCloud;
+      using PointCloudPtr = typename PointCloud::Ptr;
+      using PointCloudConstPtr = typename PointCloud::ConstPtr;
 
       public:
-        typedef boost::shared_ptr<PointCloudColorHandlerGenericField<PointT> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandlerGenericField<PointT> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandlerGenericField<PointT> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandlerGenericField<PointT> >;
 
         /** \brief Constructor. */
         PointCloudColorHandlerGenericField (const std::string &field_name)
@@ -402,13 +406,10 @@ namespace pcl
         /** \brief Get the name of the field used. */
         virtual std::string getFieldName () const { return (field_name_); }
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and 
-          * the input cloud was given as a valid pointer), false otherwise
-          */
-        virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const;
+        vtkSmartPointer<vtkDataArray>
+        getColor () const override;
+
+        using PointCloudColorHandler<PointT>::getColor;
 
         /** \brief Set the input cloud to be used.
           * \param[in] cloud the input cloud to be used by the handler
@@ -441,13 +442,13 @@ namespace pcl
     template <typename PointT>
     class PointCloudColorHandlerRGBAField : public PointCloudColorHandler<PointT>
     {
-      typedef typename PointCloudColorHandler<PointT>::PointCloud PointCloud;
-      typedef typename PointCloud::Ptr PointCloudPtr;
-      typedef typename PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = typename PointCloudColorHandler<PointT>::PointCloud;
+      using PointCloudPtr = typename PointCloud::Ptr;
+      using PointCloudConstPtr = typename PointCloud::ConstPtr;
 
       public:
-        typedef boost::shared_ptr<PointCloudColorHandlerRGBAField<PointT> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandlerRGBAField<PointT> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandlerRGBAField<PointT> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandlerRGBAField<PointT> >;
 
         /** \brief Constructor. */
         PointCloudColorHandlerRGBAField ()
@@ -469,13 +470,10 @@ namespace pcl
         virtual std::string
         getFieldName () const { return ("rgba"); }
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and
-          * the input cloud was given as a valid pointer), false otherwise
-          */
-        virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const;
+        vtkSmartPointer<vtkDataArray>
+        getColor () const override;
+
+        using PointCloudColorHandler<PointT>::getColor;
 
         /** \brief Set the input cloud to be used.
           * \param[in] cloud the input cloud to be used by the handler
@@ -505,13 +503,13 @@ namespace pcl
     template <typename PointT>
     class PointCloudColorHandlerLabelField : public PointCloudColorHandler<PointT>
     {
-      typedef typename PointCloudColorHandler<PointT>::PointCloud PointCloud;
-      typedef typename PointCloud::Ptr PointCloudPtr;
-      typedef typename PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = typename PointCloudColorHandler<PointT>::PointCloud;
+      using PointCloudPtr = typename PointCloud::Ptr;
+      using PointCloudConstPtr = typename PointCloud::ConstPtr;
 
       public:
-        typedef boost::shared_ptr<PointCloudColorHandlerLabelField<PointT> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandlerLabelField<PointT> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandlerLabelField<PointT> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandlerLabelField<PointT> >;
 
         /** \brief Constructor.
           * \param[in] static_mapping Use a static colormapping from label_id to color (default true) */
@@ -539,13 +537,10 @@ namespace pcl
         virtual std::string
         getFieldName () const { return ("label"); }
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and 
-          * the input cloud was given as a valid pointer), false otherwise
-          */
-        virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const;
+        vtkSmartPointer<vtkDataArray>
+        getColor () const override;
+
+        using PointCloudColorHandler<PointT>::getColor;
 
         /** \brief Set the input cloud to be used.
           * \param[in] cloud the input cloud to be used by the handler
@@ -576,12 +571,12 @@ namespace pcl
     class PCL_EXPORTS PointCloudColorHandler<pcl::PCLPointCloud2>
     {
       public:
-        typedef pcl::PCLPointCloud2 PointCloud;
-        typedef PointCloud::Ptr PointCloudPtr;
-        typedef PointCloud::ConstPtr PointCloudConstPtr;
+        using PointCloud = pcl::PCLPointCloud2;
+        using PointCloudPtr = PointCloud::Ptr;
+        using PointCloudConstPtr = PointCloud::ConstPtr;
 
-        typedef boost::shared_ptr<PointCloudColorHandler<PointCloud> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandler<PointCloud> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandler<PointCloud> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandler<PointCloud> >;
 
         /** \brief Constructor. */
         PointCloudColorHandler (const PointCloudConstPtr &cloud) :
@@ -603,13 +598,29 @@ namespace pcl
         virtual std::string
         getFieldName () const = 0;
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and 
-          * the input cloud was given as a valid pointer), false otherwise
-          */
+        /** Obtain the actual color for the input dataset as a VTK data array.
+          * Deriving handlers should override this method. The default implementation is
+          * provided only for backwards compatibility with handlers that were written
+          * before PCL 1.10.0 and will be removed in future.
+          * \return smart pointer to VTK array if the operation was successful (the
+          * handler is capable and the input cloud was given), a null pointer otherwise */
+        virtual vtkSmartPointer<vtkDataArray>
+        getColor () const {
+          vtkSmartPointer<vtkDataArray> scalars;
+          getColor (scalars);
+          return scalars;
+        }
+
+        /** Obtain the actual color for the input dataset as a VTK data array.
+          * This virtual method should not be overriden or used. The default implementation
+          * is provided only for backwards compatibility with handlers that were written
+          * before PCL 1.10.0 and will be removed in future. */
+        [[deprecated("use getColor() without parameters instead")]]
         virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const = 0;
+        getColor (vtkSmartPointer<vtkDataArray> &scalars) const {
+          scalars = getColor ();
+          return scalars.Get() != nullptr;
+        }
 
         /** \brief Set the input cloud to be used.
           * \param[in] cloud the input cloud to be used by the handler
@@ -641,13 +652,13 @@ namespace pcl
     template <>
     class PCL_EXPORTS PointCloudColorHandlerRandom<pcl::PCLPointCloud2> : public PointCloudColorHandler<pcl::PCLPointCloud2>
     {
-      typedef PointCloudColorHandler<pcl::PCLPointCloud2>::PointCloud PointCloud;
-      typedef PointCloud::Ptr PointCloudPtr;
-      typedef PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = PointCloudColorHandler<pcl::PCLPointCloud2>::PointCloud;
+      using PointCloudPtr = PointCloud::Ptr;
+      using PointCloudConstPtr = PointCloud::ConstPtr;
 
       public:
-        typedef boost::shared_ptr<PointCloudColorHandlerRandom<PointCloud> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandlerRandom<PointCloud> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandlerRandom<PointCloud> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandlerRandom<PointCloud> >;
 
         /** \brief Constructor. */
         PointCloudColorHandlerRandom (const PointCloudConstPtr &cloud) :
@@ -667,13 +678,10 @@ namespace pcl
         virtual std::string
         getFieldName () const { return ("[random]"); }
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and 
-          * the input cloud was given as a valid pointer), false otherwise
-          */
-        virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const;
+        vtkSmartPointer<vtkDataArray>
+        getColor () const override;
+
+        using PointCloudColorHandler<pcl::PCLPointCloud2>::getColor;
     };
 
     //////////////////////////////////////////////////////////////////////////////////////
@@ -685,9 +693,9 @@ namespace pcl
     template <>
     class PCL_EXPORTS PointCloudColorHandlerCustom<pcl::PCLPointCloud2> : public PointCloudColorHandler<pcl::PCLPointCloud2>
     {
-      typedef PointCloudColorHandler<pcl::PCLPointCloud2>::PointCloud PointCloud;
-      typedef PointCloud::Ptr PointCloudPtr;
-      typedef PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = PointCloudColorHandler<pcl::PCLPointCloud2>::PointCloud;
+      using PointCloudPtr = PointCloud::Ptr;
+      using PointCloudConstPtr = PointCloud::ConstPtr;
 
       public:
         /** \brief Constructor. */
@@ -710,13 +718,10 @@ namespace pcl
         virtual std::string
         getFieldName () const { return (""); }
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and 
-          * the input cloud was given as a valid pointer), false otherwise
-          */
-        virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const;
+        vtkSmartPointer<vtkDataArray>
+        getColor () const override;
+
+        using PointCloudColorHandler<pcl::PCLPointCloud2>::getColor;
 
       protected:
         /** \brief Internal R, G, B holding the values given by the user. */
@@ -732,13 +737,13 @@ namespace pcl
     template <>
     class PCL_EXPORTS PointCloudColorHandlerRGBField<pcl::PCLPointCloud2> : public PointCloudColorHandler<pcl::PCLPointCloud2>
     {
-      typedef PointCloudColorHandler<pcl::PCLPointCloud2>::PointCloud PointCloud;
-      typedef PointCloud::Ptr PointCloudPtr;
-      typedef PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = PointCloudColorHandler<pcl::PCLPointCloud2>::PointCloud;
+      using PointCloudPtr = PointCloud::Ptr;
+      using PointCloudConstPtr = PointCloud::ConstPtr;
 
       public:
-        typedef boost::shared_ptr<PointCloudColorHandlerRGBField<PointCloud> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandlerRGBField<PointCloud> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandlerRGBField<PointCloud> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandlerRGBField<PointCloud> >;
 
         /** \brief Constructor. */
         PointCloudColorHandlerRGBField (const PointCloudConstPtr &cloud);
@@ -746,13 +751,10 @@ namespace pcl
         /** \brief Empty destructor */
         virtual ~PointCloudColorHandlerRGBField () {}
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and 
-          * the input cloud was given as a valid pointer), false otherwise
-          */
-        virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const;
+        vtkSmartPointer<vtkDataArray>
+        getColor () const override;
+
+        using PointCloudColorHandler<pcl::PCLPointCloud2>::getColor;
 
       protected:
         /** \brief Get the name of the class. */
@@ -772,13 +774,13 @@ namespace pcl
     template <>
     class PCL_EXPORTS PointCloudColorHandlerHSVField<pcl::PCLPointCloud2> : public PointCloudColorHandler<pcl::PCLPointCloud2>
     {
-      typedef PointCloudColorHandler<pcl::PCLPointCloud2>::PointCloud PointCloud;
-      typedef PointCloud::Ptr PointCloudPtr;
-      typedef PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = PointCloudColorHandler<pcl::PCLPointCloud2>::PointCloud;
+      using PointCloudPtr = PointCloud::Ptr;
+      using PointCloudConstPtr = PointCloud::ConstPtr;
 
       public:
-        typedef boost::shared_ptr<PointCloudColorHandlerHSVField<PointCloud> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandlerHSVField<PointCloud> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandlerHSVField<PointCloud> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandlerHSVField<PointCloud> >;
 
         /** \brief Constructor. */
         PointCloudColorHandlerHSVField (const PointCloudConstPtr &cloud);
@@ -786,13 +788,10 @@ namespace pcl
         /** \brief Empty destructor */
         virtual ~PointCloudColorHandlerHSVField () {}
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and 
-          * the input cloud was given as a valid pointer), false otherwise
-          */
-        virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const;
+        vtkSmartPointer<vtkDataArray>
+        getColor () const override;
+
+        using PointCloudColorHandler<pcl::PCLPointCloud2>::getColor;
 
       protected:
         /** \brief Get the name of the class. */
@@ -819,13 +818,13 @@ namespace pcl
     template <>
     class PCL_EXPORTS PointCloudColorHandlerGenericField<pcl::PCLPointCloud2> : public PointCloudColorHandler<pcl::PCLPointCloud2>
     {
-      typedef PointCloudColorHandler<pcl::PCLPointCloud2>::PointCloud PointCloud;
-      typedef PointCloud::Ptr PointCloudPtr;
-      typedef PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = PointCloudColorHandler<pcl::PCLPointCloud2>::PointCloud;
+      using PointCloudPtr = PointCloud::Ptr;
+      using PointCloudConstPtr = PointCloud::ConstPtr;
 
       public:
-        typedef boost::shared_ptr<PointCloudColorHandlerGenericField<PointCloud> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandlerGenericField<PointCloud> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandlerGenericField<PointCloud> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandlerGenericField<PointCloud> >;
 
         /** \brief Constructor. */
         PointCloudColorHandlerGenericField (const PointCloudConstPtr &cloud,
@@ -834,13 +833,10 @@ namespace pcl
         /** \brief Empty destructor */
         virtual ~PointCloudColorHandlerGenericField () {}
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and 
-          * the input cloud was given as a valid pointer), false otherwise
-          */
-        virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const;
+        vtkSmartPointer<vtkDataArray>
+        getColor () const override;
+
+        using PointCloudColorHandler<pcl::PCLPointCloud2>::getColor;
 
       protected:
         /** \brief Get the name of the class. */
@@ -865,13 +861,13 @@ namespace pcl
     template <>
     class PCL_EXPORTS PointCloudColorHandlerRGBAField<pcl::PCLPointCloud2> : public PointCloudColorHandler<pcl::PCLPointCloud2>
     {
-      typedef PointCloudColorHandler<pcl::PCLPointCloud2>::PointCloud PointCloud;
-      typedef PointCloud::Ptr PointCloudPtr;
-      typedef PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = PointCloudColorHandler<pcl::PCLPointCloud2>::PointCloud;
+      using PointCloudPtr = PointCloud::Ptr;
+      using PointCloudConstPtr = PointCloud::ConstPtr;
 
       public:
-        typedef boost::shared_ptr<PointCloudColorHandlerRGBAField<PointCloud> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandlerRGBAField<PointCloud> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandlerRGBAField<PointCloud> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandlerRGBAField<PointCloud> >;
 
         /** \brief Constructor. */
         PointCloudColorHandlerRGBAField (const PointCloudConstPtr &cloud);
@@ -879,13 +875,10 @@ namespace pcl
         /** \brief Empty destructor */
         virtual ~PointCloudColorHandlerRGBAField () {}
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and
-          * the input cloud was given as a valid pointer), false otherwise
-          */
-        virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const;
+        vtkSmartPointer<vtkDataArray>
+        getColor () const override;
+
+        using PointCloudColorHandler<pcl::PCLPointCloud2>::getColor;
 
       protected:
         /** \brief Get the name of the class. */
@@ -906,13 +899,13 @@ namespace pcl
     template <>
     class PCL_EXPORTS PointCloudColorHandlerLabelField<pcl::PCLPointCloud2> : public PointCloudColorHandler<pcl::PCLPointCloud2>
     {
-      typedef PointCloudColorHandler<pcl::PCLPointCloud2>::PointCloud PointCloud;
-      typedef PointCloud::Ptr PointCloudPtr;
-      typedef PointCloud::ConstPtr PointCloudConstPtr;
+      using PointCloud = PointCloudColorHandler<pcl::PCLPointCloud2>::PointCloud;
+      using PointCloudPtr = PointCloud::Ptr;
+      using PointCloudConstPtr = PointCloud::ConstPtr;
 
       public:
-        typedef boost::shared_ptr<PointCloudColorHandlerLabelField<PointCloud> > Ptr;
-        typedef boost::shared_ptr<const PointCloudColorHandlerLabelField<PointCloud> > ConstPtr;
+        using Ptr = shared_ptr<PointCloudColorHandlerLabelField<PointCloud> >;
+        using ConstPtr = shared_ptr<const PointCloudColorHandlerLabelField<PointCloud> >;
 
         /** \brief Constructor.
           * \param[in] static_mapping Use a static colormapping from label_id to color (default true) */
@@ -922,13 +915,10 @@ namespace pcl
         /** \brief Empty destructor */
         virtual ~PointCloudColorHandlerLabelField () {}
 
-        /** \brief Obtain the actual color for the input dataset as vtk scalars.
-          * \param[out] scalars the output scalars containing the color for the dataset
-          * \return true if the operation was successful (the handler is capable and
-          * the input cloud was given as a valid pointer), false otherwise
-          */
-        virtual bool
-        getColor (vtkSmartPointer<vtkDataArray> &scalars) const;
+        vtkSmartPointer<vtkDataArray>
+        getColor () const override;
+
+        using PointCloudColorHandler<pcl::PCLPointCloud2>::getColor;
 
       protected:
         /** \brief Get the name of the class. */
@@ -946,6 +936,3 @@ namespace pcl
 }
 
 #include <pcl/visualization/impl/point_cloud_color_handlers.hpp>
-
-#endif      // PCL_POINT_CLOUD_COLOR_HANDLERS_H_
-
