@@ -53,7 +53,6 @@
 #include <fstream>
 #include <sstream>
 
-#include <pcl/visualization/interactor.h>
 #include <pcl/visualization/pcl_plotter.h>
 #include <pcl/common/common_headers.h>
 
@@ -124,14 +123,10 @@ pcl::visualization::PCLPlotter::addPlotData (
   //adding to chart
   //vtkPlot *line = chart_->AddPlot(vtkChart::LINE);
   vtkPlot *line = chart_->AddPlot (type);
-#if VTK_MAJOR_VERSION < 6
-  line->SetInput (table, 0, 1);
-#else
   line->SetInputData (table, 0, 1);
-#endif
   line->SetWidth (1);
 
-  if (color == NULL)    //color automatically based on the ColorScheme
+  if (!color)    //color automatically based on the ColorScheme
   {
     vtkColor3ub vcolor = color_series_->GetColorRepeating (current_plot_);
     line->SetColor (vcolor[0], vcolor[1], vcolor[2], 255);
@@ -149,7 +144,7 @@ pcl::visualization::PCLPlotter::addPlotData (
     int type /* = vtkChart::LINE */, 
     std::vector<char> const &color)
 {
-  this->addPlotData (&array_X[0], &array_Y[0], static_cast<unsigned long> (array_X.size ()), name, type, (color.size () == 0) ? NULL : &color[0]);
+  this->addPlotData (&array_X[0], &array_Y[0], static_cast<unsigned long> (array_X.size ()), name, type, (color.empty ()) ? nullptr : &color[0]);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -163,12 +158,12 @@ pcl::visualization::PCLPlotter::addPlotData (
   double *array_x = new double[plot_data.size ()];
   double *array_y = new double[plot_data.size ()];
 
-  for (unsigned int i = 0; i < plot_data.size (); i++)
+  for (std::size_t i = 0; i < plot_data.size (); i++)
   {
     array_x[i] = plot_data[i].first;
     array_y[i] = plot_data[i].second;
   }
-  this->addPlotData (array_x, array_y, static_cast<unsigned long> (plot_data.size ()), name, type, (color.size () == 0) ? NULL : &color[0]);
+  this->addPlotData (array_x, array_y, static_cast<unsigned long> (plot_data.size ()), name, type, (color.empty ()) ? nullptr : &color[0]);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -256,7 +251,7 @@ pcl::visualization::PCLPlotter::addPlotData (
   getline (fin, line);
   stringstream ss(line);
   
-  vector<string> pnames;       //plot names
+  std::vector<string> pnames;       //plot names
   string xname, temp;         //plot name of X axis
   
   //checking X axis name
@@ -267,8 +262,8 @@ pcl::visualization::PCLPlotter::addPlotData (
     
   int nop = int (pnames.size ());// number of plots (y coordinate vectors)  
   
-  vector<double> xarray;      //array of X coordinates
-  vector< vector<double> > yarrays (nop); //a set of array of Y coordinates
+  std::vector<double> xarray;      //array of X coordinates
+  std::vector< std::vector<double> > yarrays (nop); //a set of array of Y coordinates
   
   //reading the entire table
   double x, y;
@@ -357,8 +352,8 @@ pcl::visualization::PCLPlotter::addFeatureHistogram (
 
   // Compute the total size of the fields
   unsigned int fsize = 0;
-  for (size_t i = 0; i < cloud.fields.size (); ++i)
-    fsize += cloud.fields[i].count * pcl::getFieldSize (cloud.fields[i].datatype);
+  for (const auto &field : cloud.fields)
+    fsize += field.count * pcl::getFieldSize (field.datatype);
   
   int hsize = cloud.fields[field_idx].count;
   std::vector<double> array_x (hsize), array_y (hsize);
@@ -590,9 +585,9 @@ pcl::visualization::PCLPlotter::computeHistogram (
 
   //find min and max in the data
   double min = data[0], max = data[0];
-  for (size_t i = 1; i < data.size (); i++)
+  for (std::size_t i = 1; i < data.size (); i++)
   {
-    if (pcl_isfinite (data[i]))
+    if (std::isfinite (data[i]))
     {
       if (data[i] < min) min = data[i];
       if (data[i] > max) max = data[i];
@@ -611,11 +606,11 @@ pcl::visualization::PCLPlotter::computeHistogram (
   }
 
   //fill the freq for each data
-  for (size_t i = 0; i < data.size (); i++)
+  for (const double &value : data)
   {
-    if (pcl_isfinite (data[i]))
+    if (std::isfinite (value))
     {
-      unsigned int index = (unsigned int) (floor ((data[i] - min) / size));
+      unsigned int index = (unsigned int) (std::floor ((value - min) / size));
       if (index == (unsigned int) nbins) index = nbins - 1; //including right boundary
       histogram[index].second++;
     }
@@ -629,7 +624,7 @@ pcl::visualization::PCLPlotter::compute (
     double val)
 {
   double res = 0;
-  for (size_t i = 0; i < p_function.size (); i++)
+  for (std::size_t i = 0; i < p_function.size (); i++)
     res += (p_function[i] * pow (val, static_cast<double> (i)) );
   return (res);
 }
@@ -658,10 +653,9 @@ pcl::visualization::PCLPlotter::setViewInteractor (
 bool
 pcl::visualization::PCLPlotter::wasStopped () const
 {
-  if (view_->GetInteractor() != NULL) 
+  if (view_->GetInteractor()) 
     return (stopped_); 
-  else 
-    return (true);
+  return (true);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -693,11 +687,7 @@ pcl::visualization::PCLPlotter::ExitMainLoopTimerCallback::Execute (
     return;
 
   // Stop vtk loop and send notification to app to wake it up
-#if ((VTK_MAJOR_VERSION == 5) && (VTK_MINOR_VERSION <= 4))
-  interactor->stopLoop ();
-#else
   interactor->TerminateApp ();
-#endif
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
